from .Animate import Animate
from .Circle import Circle
from .ClipPath import ClipPath
from .Defs import Defs
from .Desc import Desc
from .Ellipse import Ellipse
from .FeBlend import FeBlend
from .FeColorMatrix import FeColorMatrix
from .FeComponentTransfer import FeComponentTransfer
from .FeComposite import FeComposite
from .FeConvolveMatrix import FeConvolveMatrix
from .FeDiffuseLighting import FeDiffuseLighting
from .FeDisplacementMap import FeDisplacementMap
from .FeDistantLight import FeDistantLight
from .FeDropShadow import FeDropShadow
from .FeFlood import FeFlood
from .FeFuncA import FeFuncA
from .FeFuncB import FeFuncB
from .FeFuncG import FeFuncG
from .FeFuncR import FeFuncR
from .FeGaussianBlur import FeGaussianBlur
from .FeImage import FeImage
from .FeMerge import FeMerge
from .FeMergeNode import FeMergeNode
from .FeMorphology import FeMorphology
from .FeOffset import FeOffset
from .FePointLight import FePointLight
from .FeSpecularLighting import FeSpecularLighting
from .FeSpotLight import FeSpotLight
from .FeTile import FeTile
from .FeTurbulence import FeTurbulence
from .Filter import Filter
from .ForeignObject import ForeignObject
from .G import G
from .Image import Image
from .Line import Line
from .LinearGradient import LinearGradient
from .Marker import Marker
from .Mask import Mask
from .Metadata import Metadata
from .Path import Path
from .Pattern import Pattern
from .Polygon import Polygon
from .Polyline import Polyline
from .RadialGradient import RadialGradient
from .Rect import Rect
from .Stop import Stop
from .Svg import Svg
from .Switch import Switch
from .Symbol import Symbol
from .Text import Text
from .TextPath import TextPath
from .Tspan import Tspan
from .Use import Use
from .View import View

__all__ = [
    "Animate",
    "Circle",
    "ClipPath",
    "Defs",
    "Desc",
    "Ellipse",
    "FeBlend",
    "FeColorMatrix",
    "FeComponentTransfer",
    "FeComposite",
    "FeConvolveMatrix",
    "FeDiffuseLighting",
    "FeDisplacementMap",
    "FeDistantLight",
    "FeDropShadow",
    "FeFlood",
    "FeFuncA",
    "FeFuncB",
    "FeFuncG",
    "FeFuncR",
    "FeGaussianBlur",
    "FeImage",
    "FeMerge",
    "FeMergeNode",
    "FeMorphology",
    "FeOffset",
    "FePointLight",
    "FeSpecularLighting",
    "FeSpotLight",
    "FeTile",
    "FeTurbulence",
    "Filter",
    "ForeignObject",
    "G",
    "Image",
    "Line",
    "LinearGradient",
    "Marker",
    "Mask",
    "Metadata",
    "Path",
    "Pattern",
    "Polygon",
    "Polyline",
    "RadialGradient",
    "Rect",
    "Stop",
    "Svg",
    "Switch",
    "Symbol",
    "Text",
    "TextPath",
    "Tspan",
    "Use",
    "View"
]