window["dash_svg"] =
/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";var getCurrentScript = function() {
/******/ 	    var script = document.currentScript;
/******/ 	    if (!script) {
/******/ 	        /* Shim for IE11 and below */
/******/ 	        /* Do not take into account async scripts and inline scripts */
/******/
/******/ 	        var doc_scripts = document.getElementsByTagName('script');
/******/ 	        var scripts = [];
/******/
/******/ 	        for (var i = 0; i < doc_scripts.length; i++) {
/******/ 	            scripts.push(doc_scripts[i]);
/******/ 	        }
/******/
/******/ 	        scripts = scripts.filter(function(s) { return !s.async && !s.text && !s.textContent; });
/******/ 	        script = scripts.slice(-1)[0];
/******/ 	    }
/******/
/******/ 	    return script;
/******/ 	};
/******/
/******/ 	var isLocalScript = function(script) {
/******/ 	    return /\/_dash-component-suites\//.test(script.src);
/******/ 	};
/******/
/******/ 	Object.defineProperty(__webpack_require__, 'p', {
/******/ 	    get: (function () {
/******/ 	        var script = getCurrentScript();
/******/
/******/ 	        var url = script.src.split('/').slice(0, -1).join('/') + '/';
/******/
/******/ 	        return function() {
/******/ 	            return url;
/******/ 	        };
/******/ 	    })()
/******/ 	});
/******/
/******/ 	if (typeof jsonpScriptSrc !== 'undefined') {
/******/ 	    var __jsonpScriptSrc__ = jsonpScriptSrc;
/******/ 	    jsonpScriptSrc = function(chunkId) {
/******/ 	        var script = getCurrentScript();
/******/ 	        var isLocal = isLocalScript(script);
/******/
/******/ 	        var src = __jsonpScriptSrc__(chunkId);
/******/
/******/ 	        if(!isLocal) {
/******/ 	            return src;
/******/ 	        }
/******/
/******/ 	        var srcFragments = src.split('/');
/******/ 	        var fileFragments = srcFragments.slice(-1)[0].split('.');
/******/
/******/ 	        fileFragments.splice(1, 0, "v0_0_12m1677485319");
/******/ 	        srcFragments.splice(-1, 1, fileFragments.join('.'))
/******/
/******/ 	        return srcFragments.join('/');
/******/ 	    };
/******/ 	}
/******/
/******/
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = "./src/lib/index.js");
/******/ })
/************************************************************************/
/******/ ({

/***/ "./node_modules/ramda/es/F.js":
/*!************************************!*\
  !*** ./node_modules/ramda/es/F.js ***!
  \************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);


/**
 * A function that always returns `false`. Any passed in parameters are ignored.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Function
 * @sig * -> Boolean
 * @param {*}
 * @return {Boolean}
 * @see R.T
 * @example
 *
 *      R.F(); //=> false
 */
var F = function () {
  return false;
};
/* harmony default export */ __webpack_exports__["default"] = (F);

/***/ }),

/***/ "./node_modules/ramda/es/T.js":
/*!************************************!*\
  !*** ./node_modules/ramda/es/T.js ***!
  \************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);


/**
 * A function that always returns `true`. Any passed in parameters are ignored.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Function
 * @sig * -> Boolean
 * @param {*}
 * @return {Boolean}
 * @see R.F
 * @example
 *
 *      R.T(); //=> true
 */
var T = function () {
  return true;
};
/* harmony default export */ __webpack_exports__["default"] = (T);

/***/ }),

/***/ "./node_modules/ramda/es/__.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/__.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/**
 * A special placeholder value used to specify "gaps" within curried functions,
 * allowing partial application of any combination of arguments, regardless of
 * their positions.
 *
 * If `g` is a curried ternary function and `_` is `R.__`, the following are
 * equivalent:
 *
 *   - `g(1, 2, 3)`
 *   - `g(_, 2, 3)(1)`
 *   - `g(_, _, 3)(1)(2)`
 *   - `g(_, _, 3)(1, 2)`
 *   - `g(_, 2, _)(1, 3)`
 *   - `g(_, 2)(1)(3)`
 *   - `g(_, 2)(1, 3)`
 *   - `g(_, 2)(_, 3)(1)`
 *
 * @name __
 * @constant
 * @memberOf R
 * @since v0.6.0
 * @category Function
 * @example
 *
 *      const greet = R.replace('{name}', R.__, 'Hello, {name}!');
 *      greet('Alice'); //=> 'Hello, Alice!'
 */
/* harmony default export */ __webpack_exports__["default"] = ({ '@@functional/placeholder': true });

/***/ }),

/***/ "./node_modules/ramda/es/add.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/add.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Adds two values.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Math
 * @sig Number -> Number -> Number
 * @param {Number} a
 * @param {Number} b
 * @return {Number}
 * @see R.subtract
 * @example
 *
 *      R.add(2, 3);       //=>  5
 *      R.add(7)(10);      //=> 17
 */
var add = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function add(a, b) {
  return Number(a) + Number(b);
});
/* harmony default export */ __webpack_exports__["default"] = (add);

/***/ }),

/***/ "./node_modules/ramda/es/addIndex.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/addIndex.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");




/**
 * Creates a new list iteration function from an existing one by adding two new
 * parameters to its callback function: the current index, and the entire list.
 *
 * This would turn, for instance, [`R.map`](#map) function into one that
 * more closely resembles `Array.prototype.map`. Note that this will only work
 * for functions in which the iteration callback function is the first
 * parameter, and where the list is the last parameter. (This latter might be
 * unimportant if the list parameter is not used.)
 *
 * @func
 * @memberOf R
 * @since v0.15.0
 * @category Function
 * @category List
 * @sig ((a ... -> b) ... -> [a] -> *) -> ((a ..., Int, [a] -> b) ... -> [a] -> *)
 * @param {Function} fn A list iteration function that does not pass index or list to its callback
 * @return {Function} An altered list iteration function that passes (item, index, list) to its callback
 * @example
 *
 *      const mapIndexed = R.addIndex(R.map);
 *      mapIndexed((val, idx) => idx + '-' + val, ['f', 'o', 'o', 'b', 'a', 'r']);
 *      //=> ['0-f', '1-o', '2-o', '3-b', '4-a', '5-r']
 */
var addIndex = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function addIndex(fn) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_2__["default"])(fn.length, function () {
    var idx = 0;
    var origFn = arguments[0];
    var list = arguments[arguments.length - 1];
    var args = Array.prototype.slice.call(arguments, 0);
    args[0] = function () {
      var result = origFn.apply(this, Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])(arguments, [idx, list]));
      idx += 1;
      return result;
    };
    return fn.apply(this, args);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (addIndex);

/***/ }),

/***/ "./node_modules/ramda/es/adjust.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/adjust.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");



/**
 * Applies a function to the value at the given index of an array, returning a
 * new copy of the array with the element at the given index replaced with the
 * result of the function application.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category List
 * @sig Number -> (a -> a) -> [a] -> [a]
 * @param {Number} idx The index.
 * @param {Function} fn The function to apply.
 * @param {Array|Arguments} list An array-like object whose value
 *        at the supplied index will be replaced.
 * @return {Array} A copy of the supplied array-like object with
 *         the element at index `idx` replaced with the value
 *         returned by applying `fn` to the existing element.
 * @see R.update
 * @example
 *
 *      R.adjust(1, R.toUpper, ['a', 'b', 'c', 'd']);      //=> ['a', 'B', 'c', 'd']
 *      R.adjust(-1, R.toUpper, ['a', 'b', 'c', 'd']);     //=> ['a', 'b', 'c', 'D']
 * @symb R.adjust(-1, f, [a, b]) = [a, f(b)]
 * @symb R.adjust(0, f, [a, b]) = [f(a), b]
 */
var adjust = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function adjust(idx, fn, list) {
  if (idx >= list.length || idx < -list.length) {
    return list;
  }
  var start = idx < 0 ? list.length : 0;
  var _idx = start + idx;
  var _list = Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list);
  _list[_idx] = fn(list[_idx]);
  return _list;
});
/* harmony default export */ __webpack_exports__["default"] = (adjust);

/***/ }),

/***/ "./node_modules/ramda/es/all.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/all.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xall_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xall.js */ "./node_modules/ramda/es/internal/_xall.js");




/**
 * Returns `true` if all elements of the list match the predicate, `false` if
 * there are any that don't.
 *
 * Dispatches to the `all` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> Boolean
 * @param {Function} fn The predicate function.
 * @param {Array} list The array to consider.
 * @return {Boolean} `true` if the predicate is satisfied by every element, `false`
 *         otherwise.
 * @see R.any, R.none, R.transduce
 * @example
 *
 *      const equals3 = R.equals(3);
 *      R.all(equals3)([3, 3, 3, 3]); //=> true
 *      R.all(equals3)([3, 3, 1, 3]); //=> false
 */
var all = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['all'], _internal_xall_js__WEBPACK_IMPORTED_MODULE_2__["default"], function all(fn, list) {
  var idx = 0;
  while (idx < list.length) {
    if (!fn(list[idx])) {
      return false;
    }
    idx += 1;
  }
  return true;
}));
/* harmony default export */ __webpack_exports__["default"] = (all);

/***/ }),

/***/ "./node_modules/ramda/es/allPass.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/allPass.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./max.js */ "./node_modules/ramda/es/max.js");
/* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./pluck.js */ "./node_modules/ramda/es/pluck.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");






/**
 * Takes a list of predicates and returns a predicate that returns true for a
 * given list of arguments if every one of the provided predicates is satisfied
 * by those arguments.
 *
 * The function returned is a curried function whose arity matches that of the
 * highest-arity predicate.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Logic
 * @sig [(*... -> Boolean)] -> (*... -> Boolean)
 * @param {Array} predicates An array of predicates to check
 * @return {Function} The combined predicate
 * @see R.anyPass
 * @example
 *
 *      const isQueen = R.propEq('rank', 'Q');
 *      const isSpade = R.propEq('suit', '♠︎');
 *      const isQueenOfSpades = R.allPass([isQueen, isSpade]);
 *
 *      isQueenOfSpades({rank: 'Q', suit: '♣︎'}); //=> false
 *      isQueenOfSpades({rank: 'Q', suit: '♠︎'}); //=> true
 */
var allPass = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function allPass(preds) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_reduce_js__WEBPACK_IMPORTED_MODULE_4__["default"])(_max_js__WEBPACK_IMPORTED_MODULE_2__["default"], 0, Object(_pluck_js__WEBPACK_IMPORTED_MODULE_3__["default"])('length', preds)), function () {
    var idx = 0;
    var len = preds.length;
    while (idx < len) {
      if (!preds[idx].apply(this, arguments)) {
        return false;
      }
      idx += 1;
    }
    return true;
  });
});
/* harmony default export */ __webpack_exports__["default"] = (allPass);

/***/ }),

/***/ "./node_modules/ramda/es/always.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/always.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Returns a function that always returns the given value. Note that for
 * non-primitives the value returned is a reference to the original value.
 *
 * This function is known as `const`, `constant`, or `K` (for K combinator) in
 * other languages and libraries.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig a -> (* -> a)
 * @param {*} val The value to wrap in a function
 * @return {Function} A Function :: * -> val.
 * @example
 *
 *      const t = R.always('Tee');
 *      t(); //=> 'Tee'
 */
var always = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function always(val) {
  return function () {
    return val;
  };
});
/* harmony default export */ __webpack_exports__["default"] = (always);

/***/ }),

/***/ "./node_modules/ramda/es/and.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/and.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns `true` if both arguments are `true`; `false` otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Logic
 * @sig a -> b -> a | b
 * @param {Any} a
 * @param {Any} b
 * @return {Any} the first argument if it is falsy, otherwise the second argument.
 * @see R.both
 * @example
 *
 *      R.and(true, true); //=> true
 *      R.and(true, false); //=> false
 *      R.and(false, true); //=> false
 *      R.and(false, false); //=> false
 */
var and = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function and(a, b) {
  return a && b;
});
/* harmony default export */ __webpack_exports__["default"] = (and);

/***/ }),

/***/ "./node_modules/ramda/es/any.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/any.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xany_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xany.js */ "./node_modules/ramda/es/internal/_xany.js");




/**
 * Returns `true` if at least one of the elements of the list match the predicate,
 * `false` otherwise.
 *
 * Dispatches to the `any` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> Boolean
 * @param {Function} fn The predicate function.
 * @param {Array} list The array to consider.
 * @return {Boolean} `true` if the predicate is satisfied by at least one element, `false`
 *         otherwise.
 * @see R.all, R.none, R.transduce
 * @example
 *
 *      const lessThan0 = R.flip(R.lt)(0);
 *      const lessThan2 = R.flip(R.lt)(2);
 *      R.any(lessThan0)([1, 2]); //=> false
 *      R.any(lessThan2)([1, 2]); //=> true
 */
var any = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['any'], _internal_xany_js__WEBPACK_IMPORTED_MODULE_2__["default"], function any(fn, list) {
  var idx = 0;
  while (idx < list.length) {
    if (fn(list[idx])) {
      return true;
    }
    idx += 1;
  }
  return false;
}));
/* harmony default export */ __webpack_exports__["default"] = (any);

/***/ }),

/***/ "./node_modules/ramda/es/anyPass.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/anyPass.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./max.js */ "./node_modules/ramda/es/max.js");
/* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./pluck.js */ "./node_modules/ramda/es/pluck.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");






/**
 * Takes a list of predicates and returns a predicate that returns true for a
 * given list of arguments if at least one of the provided predicates is
 * satisfied by those arguments.
 *
 * The function returned is a curried function whose arity matches that of the
 * highest-arity predicate.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Logic
 * @sig [(*... -> Boolean)] -> (*... -> Boolean)
 * @param {Array} predicates An array of predicates to check
 * @return {Function} The combined predicate
 * @see R.allPass
 * @example
 *
 *      const isClub = R.propEq('suit', '♣');
 *      const isSpade = R.propEq('suit', '♠');
 *      const isBlackCard = R.anyPass([isClub, isSpade]);
 *
 *      isBlackCard({rank: '10', suit: '♣'}); //=> true
 *      isBlackCard({rank: 'Q', suit: '♠'}); //=> true
 *      isBlackCard({rank: 'Q', suit: '♦'}); //=> false
 */
var anyPass = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function anyPass(preds) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_reduce_js__WEBPACK_IMPORTED_MODULE_4__["default"])(_max_js__WEBPACK_IMPORTED_MODULE_2__["default"], 0, Object(_pluck_js__WEBPACK_IMPORTED_MODULE_3__["default"])('length', preds)), function () {
    var idx = 0;
    var len = preds.length;
    while (idx < len) {
      if (preds[idx].apply(this, arguments)) {
        return true;
      }
      idx += 1;
    }
    return false;
  });
});
/* harmony default export */ __webpack_exports__["default"] = (anyPass);

/***/ }),

/***/ "./node_modules/ramda/es/ap.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/ap.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");





/**
 * ap applies a list of functions to a list of values.
 *
 * Dispatches to the `ap` method of the second argument, if present. Also
 * treats curried functions as applicatives.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category Function
 * @sig [a -> b] -> [a] -> [b]
 * @sig Apply f => f (a -> b) -> f a -> f b
 * @sig (r -> a -> b) -> (r -> a) -> (r -> b)
 * @param {*} applyF
 * @param {*} applyX
 * @return {*}
 * @example
 *
 *      R.ap([R.multiply(2), R.add(3)], [1,2,3]); //=> [2, 4, 6, 4, 5, 6]
 *      R.ap([R.concat('tasty '), R.toUpper], ['pizza', 'salad']); //=> ["tasty pizza", "tasty salad", "PIZZA", "SALAD"]
 *
 *      // R.ap can also be used as S combinator
 *      // when only two functions are passed
 *      R.ap(R.concat, R.toUpper)('Ramda') //=> 'RamdaRAMDA'
 * @symb R.ap([f, g], [a, b]) = [f(a), f(b), g(a), g(b)]
 */
var ap = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function ap(applyF, applyX) {
  return typeof applyX['fantasy-land/ap'] === 'function' ? applyX['fantasy-land/ap'](applyF) : typeof applyF.ap === 'function' ? applyF.ap(applyX) : typeof applyF === 'function' ? function (x) {
    return applyF(x)(applyX(x));
  } : Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function (acc, f) {
    return Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])(acc, Object(_map_js__WEBPACK_IMPORTED_MODULE_3__["default"])(f, applyX));
  }, [], applyF);
});
/* harmony default export */ __webpack_exports__["default"] = (ap);

/***/ }),

/***/ "./node_modules/ramda/es/aperture.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/aperture.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_aperture_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_aperture.js */ "./node_modules/ramda/es/internal/_aperture.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xaperture_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_xaperture.js */ "./node_modules/ramda/es/internal/_xaperture.js");





/**
 * Returns a new list, composed of n-tuples of consecutive elements. If `n` is
 * greater than the length of the list, an empty list is returned.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category List
 * @sig Number -> [a] -> [[a]]
 * @param {Number} n The size of the tuples to create
 * @param {Array} list The list to split into `n`-length tuples
 * @return {Array} The resulting list of `n`-length tuples
 * @see R.transduce
 * @example
 *
 *      R.aperture(2, [1, 2, 3, 4, 5]); //=> [[1, 2], [2, 3], [3, 4], [4, 5]]
 *      R.aperture(3, [1, 2, 3, 4, 5]); //=> [[1, 2, 3], [2, 3, 4], [3, 4, 5]]
 *      R.aperture(7, [1, 2, 3, 4, 5]); //=> []
 */
var aperture = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_2__["default"])([], _internal_xaperture_js__WEBPACK_IMPORTED_MODULE_3__["default"], _internal_aperture_js__WEBPACK_IMPORTED_MODULE_0__["default"]));
/* harmony default export */ __webpack_exports__["default"] = (aperture);

/***/ }),

/***/ "./node_modules/ramda/es/append.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/append.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns a new list containing the contents of the given list, followed by
 * the given element.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig a -> [a] -> [a]
 * @param {*} el The element to add to the end of the new list.
 * @param {Array} list The list of elements to add a new item to.
 *        list.
 * @return {Array} A new list containing the elements of the old list followed by `el`.
 * @see R.prepend
 * @example
 *
 *      R.append('tests', ['write', 'more']); //=> ['write', 'more', 'tests']
 *      R.append('tests', []); //=> ['tests']
 *      R.append(['tests'], ['write', 'more']); //=> ['write', 'more', ['tests']]
 */
var append = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function append(el, list) {
  return Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list, [el]);
});
/* harmony default export */ __webpack_exports__["default"] = (append);

/***/ }),

/***/ "./node_modules/ramda/es/apply.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/apply.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Applies function `fn` to the argument list `args`. This is useful for
 * creating a fixed-arity function from a variadic function. `fn` should be a
 * bound function if context is significant.
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category Function
 * @sig (*... -> a) -> [*] -> a
 * @param {Function} fn The function which will be called with `args`
 * @param {Array} args The arguments to call `fn` with
 * @return {*} result The result, equivalent to `fn(...args)`
 * @see R.call, R.unapply
 * @example
 *
 *      const nums = [1, 2, 3, -99, 42, 6, 7];
 *      R.apply(Math.max, nums); //=> 42
 * @symb R.apply(f, [a, b, c]) = f(a, b, c)
 */
var apply = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function apply(fn, args) {
  return fn.apply(this, args);
});
/* harmony default export */ __webpack_exports__["default"] = (apply);

/***/ }),

/***/ "./node_modules/ramda/es/applySpec.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/applySpec.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _apply_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./apply.js */ "./node_modules/ramda/es/apply.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./max.js */ "./node_modules/ramda/es/max.js");
/* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./pluck.js */ "./node_modules/ramda/es/pluck.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");
/* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./values.js */ "./node_modules/ramda/es/values.js");









// Use custom mapValues function to avoid issues with specs that include a "map" key and R.map
// delegating calls to .map
function mapValues(fn, obj) {
  return Object(_keys_js__WEBPACK_IMPORTED_MODULE_6__["default"])(obj).reduce(function (acc, key) {
    acc[key] = fn(obj[key]);
    return acc;
  }, {});
}

/**
 * Given a spec object recursively mapping properties to functions, creates a
 * function producing an object of the same structure, by mapping each property
 * to the result of calling its associated function with the supplied arguments.
 *
 * @func
 * @memberOf R
 * @since v0.20.0
 * @category Function
 * @sig {k: ((a, b, ..., m) -> v)} -> ((a, b, ..., m) -> {k: v})
 * @param {Object} spec an object recursively mapping properties to functions for
 *        producing the values for these properties.
 * @return {Function} A function that returns an object of the same structure
 * as `spec', with each property set to the value returned by calling its
 * associated function with the supplied arguments.
 * @see R.converge, R.juxt
 * @example
 *
 *      const getMetrics = R.applySpec({
 *        sum: R.add,
 *        nested: { mul: R.multiply }
 *      });
 *      getMetrics(2, 4); // => { sum: 6, nested: { mul: 8 } }
 * @symb R.applySpec({ x: f, y: { z: g } })(a, b) = { x: f(a, b), y: { z: g(a, b) } }
 */
var applySpec = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function applySpec(spec) {
  spec = mapValues(function (v) {
    return typeof v == 'function' ? v : applySpec(v);
  }, spec);

  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_reduce_js__WEBPACK_IMPORTED_MODULE_5__["default"])(_max_js__WEBPACK_IMPORTED_MODULE_3__["default"], 0, Object(_pluck_js__WEBPACK_IMPORTED_MODULE_4__["default"])('length', Object(_values_js__WEBPACK_IMPORTED_MODULE_7__["default"])(spec))), function () {
    var args = arguments;
    return mapValues(function (f) {
      return Object(_apply_js__WEBPACK_IMPORTED_MODULE_1__["default"])(f, args);
    }, spec);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (applySpec);

/***/ }),

/***/ "./node_modules/ramda/es/applyTo.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/applyTo.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Takes a value and applies a function to it.
 *
 * This function is also known as the `thrush` combinator.
 *
 * @func
 * @memberOf R
 * @since v0.25.0
 * @category Function
 * @sig a -> (a -> b) -> b
 * @param {*} x The value
 * @param {Function} f The function to apply
 * @return {*} The result of applying `f` to `x`
 * @example
 *
 *      const t42 = R.applyTo(42);
 *      t42(R.identity); //=> 42
 *      t42(R.add(1)); //=> 43
 */
var applyTo = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function applyTo(x, f) {
  return f(x);
});
/* harmony default export */ __webpack_exports__["default"] = (applyTo);

/***/ }),

/***/ "./node_modules/ramda/es/ascend.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/ascend.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Makes an ascending comparator function out of a function that returns a value
 * that can be compared with `<` and `>`.
 *
 * @func
 * @memberOf R
 * @since v0.23.0
 * @category Function
 * @sig Ord b => (a -> b) -> a -> a -> Number
 * @param {Function} fn A function of arity one that returns a value that can be compared
 * @param {*} a The first item to be compared.
 * @param {*} b The second item to be compared.
 * @return {Number} `-1` if fn(a) < fn(b), `1` if fn(b) < fn(a), otherwise `0`
 * @see R.descend
 * @example
 *
 *      const byAge = R.ascend(R.prop('age'));
 *      const people = [
 *        { name: 'Emma', age: 70 },
 *        { name: 'Peter', age: 78 },
 *        { name: 'Mikhail', age: 62 },
 *      ];
 *      const peopleByYoungestFirst = R.sort(byAge, people);
 *        //=> [{ name: 'Mikhail', age: 62 },{ name: 'Emma', age: 70 }, { name: 'Peter', age: 78 }]
 */
var ascend = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function ascend(fn, a, b) {
  var aa = fn(a);
  var bb = fn(b);
  return aa < bb ? -1 : aa > bb ? 1 : 0;
});
/* harmony default export */ __webpack_exports__["default"] = (ascend);

/***/ }),

/***/ "./node_modules/ramda/es/assoc.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/assoc.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Makes a shallow clone of an object, setting or overriding the specified
 * property with the given value. Note that this copies and flattens prototype
 * properties onto the new object as well. All non-primitive properties are
 * copied by reference.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Object
 * @sig String -> a -> {k: v} -> {k: v}
 * @param {String} prop The property name to set
 * @param {*} val The new value
 * @param {Object} obj The object to clone
 * @return {Object} A new object equivalent to the original except for the changed property.
 * @see R.dissoc, R.pick
 * @example
 *
 *      R.assoc('c', 3, {a: 1, b: 2}); //=> {a: 1, b: 2, c: 3}
 */
var assoc = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function assoc(prop, val, obj) {
  var result = {};
  for (var p in obj) {
    result[p] = obj[p];
  }
  result[prop] = val;
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (assoc);

/***/ }),

/***/ "./node_modules/ramda/es/assocPath.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/assocPath.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");
/* harmony import */ var _internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _internal_isInteger_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_isInteger.js */ "./node_modules/ramda/es/internal/_isInteger.js");
/* harmony import */ var _assoc_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./assoc.js */ "./node_modules/ramda/es/assoc.js");
/* harmony import */ var _isNil_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./isNil.js */ "./node_modules/ramda/es/isNil.js");







/**
 * Makes a shallow clone of an object, setting or overriding the nodes required
 * to create the given path, and placing the specific value at the tail end of
 * that path. Note that this copies and flattens prototype properties onto the
 * new object as well. All non-primitive properties are copied by reference.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Object
 * @typedefn Idx = String | Int
 * @sig [Idx] -> a -> {a} -> {a}
 * @param {Array} path the path to set
 * @param {*} val The new value
 * @param {Object} obj The object to clone
 * @return {Object} A new object equivalent to the original except along the specified path.
 * @see R.dissocPath
 * @example
 *
 *      R.assocPath(['a', 'b', 'c'], 42, {a: {b: {c: 0}}}); //=> {a: {b: {c: 42}}}
 *
 *      // Any missing or non-object keys in path will be overridden
 *      R.assocPath(['a', 'b', 'c'], 42, {a: 5}); //=> {a: {b: {c: 42}}}
 */
var assocPath = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function assocPath(path, val, obj) {
  if (path.length === 0) {
    return val;
  }
  var idx = path[0];
  if (path.length > 1) {
    var nextObj = !Object(_isNil_js__WEBPACK_IMPORTED_MODULE_5__["default"])(obj) && Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(idx, obj) ? obj[idx] : Object(_internal_isInteger_js__WEBPACK_IMPORTED_MODULE_3__["default"])(path[1]) ? [] : {};
    val = assocPath(Array.prototype.slice.call(path, 1), val, nextObj);
  }
  if (Object(_internal_isInteger_js__WEBPACK_IMPORTED_MODULE_3__["default"])(idx) && Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj)) {
    var arr = [].concat(obj);
    arr[idx] = val;
    return arr;
  } else {
    return Object(_assoc_js__WEBPACK_IMPORTED_MODULE_4__["default"])(idx, val, obj);
  }
});
/* harmony default export */ __webpack_exports__["default"] = (assocPath);

/***/ }),

/***/ "./node_modules/ramda/es/binary.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/binary.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _nAry_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./nAry.js */ "./node_modules/ramda/es/nAry.js");



/**
 * Wraps a function of any arity (including nullary) in a function that accepts
 * exactly 2 parameters. Any extraneous parameters will not be passed to the
 * supplied function.
 *
 * @func
 * @memberOf R
 * @since v0.2.0
 * @category Function
 * @sig (* -> c) -> (a, b -> c)
 * @param {Function} fn The function to wrap.
 * @return {Function} A new function wrapping `fn`. The new function is guaranteed to be of
 *         arity 2.
 * @see R.nAry, R.unary
 * @example
 *
 *      const takesThreeArgs = function(a, b, c) {
 *        return [a, b, c];
 *      };
 *      takesThreeArgs.length; //=> 3
 *      takesThreeArgs(1, 2, 3); //=> [1, 2, 3]
 *
 *      const takesTwoArgs = R.binary(takesThreeArgs);
 *      takesTwoArgs.length; //=> 2
 *      // Only 2 arguments are passed to the wrapped function
 *      takesTwoArgs(1, 2, 3); //=> [1, 2, undefined]
 * @symb R.binary(f)(a, b, c) = f(a, b)
 */
var binary = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function binary(fn) {
  return Object(_nAry_js__WEBPACK_IMPORTED_MODULE_1__["default"])(2, fn);
});
/* harmony default export */ __webpack_exports__["default"] = (binary);

/***/ }),

/***/ "./node_modules/ramda/es/bind.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/bind.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Creates a function that is bound to a context.
 * Note: `R.bind` does not provide the additional argument-binding capabilities of
 * [Function.prototype.bind](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Function/bind).
 *
 * @func
 * @memberOf R
 * @since v0.6.0
 * @category Function
 * @category Object
 * @sig (* -> *) -> {*} -> (* -> *)
 * @param {Function} fn The function to bind to context
 * @param {Object} thisObj The context to bind `fn` to
 * @return {Function} A function that will execute in the context of `thisObj`.
 * @see R.partial
 * @example
 *
 *      const log = R.bind(console.log, console);
 *      R.pipe(R.assoc('a', 2), R.tap(log), R.assoc('a', 3))({a: 1}); //=> {a: 3}
 *      // logs {a: 2}
 * @symb R.bind(f, o)(a, b) = f.call(o, a, b)
 */
var bind = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function bind(fn, thisObj) {
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(fn.length, function () {
    return fn.apply(thisObj, arguments);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (bind);

/***/ }),

/***/ "./node_modules/ramda/es/both.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/both.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isFunction_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isFunction.js */ "./node_modules/ramda/es/internal/_isFunction.js");
/* harmony import */ var _and_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./and.js */ "./node_modules/ramda/es/and.js");
/* harmony import */ var _lift_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./lift.js */ "./node_modules/ramda/es/lift.js");





/**
 * A function which calls the two provided functions and returns the `&&`
 * of the results.
 * It returns the result of the first function if it is false-y and the result
 * of the second function otherwise. Note that this is short-circuited,
 * meaning that the second function will not be invoked if the first returns a
 * false-y value.
 *
 * In addition to functions, `R.both` also accepts any fantasy-land compatible
 * applicative functor.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category Logic
 * @sig (*... -> Boolean) -> (*... -> Boolean) -> (*... -> Boolean)
 * @param {Function} f A predicate
 * @param {Function} g Another predicate
 * @return {Function} a function that applies its arguments to `f` and `g` and `&&`s their outputs together.
 * @see R.and
 * @example
 *
 *      const gt10 = R.gt(R.__, 10)
 *      const lt20 = R.lt(R.__, 20)
 *      const f = R.both(gt10, lt20);
 *      f(15); //=> true
 *      f(30); //=> false
 *
 *      R.both(Maybe.Just(false), Maybe.Just(55)); // => Maybe.Just(false)
 *      R.both([false, false, 'a'], [11]); //=> [false, false, 11]
 */
var both = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function both(f, g) {
  return Object(_internal_isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(f) ? function _both() {
    return f.apply(this, arguments) && g.apply(this, arguments);
  } : Object(_lift_js__WEBPACK_IMPORTED_MODULE_3__["default"])(_and_js__WEBPACK_IMPORTED_MODULE_2__["default"])(f, g);
});
/* harmony default export */ __webpack_exports__["default"] = (both);

/***/ }),

/***/ "./node_modules/ramda/es/call.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/call.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./curry.js */ "./node_modules/ramda/es/curry.js");


/**
 * Returns the result of calling its first argument with the remaining
 * arguments. This is occasionally useful as a converging function for
 * [`R.converge`](#converge): the first branch can produce a function while the
 * remaining branches produce values to be passed to that function as its
 * arguments.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Function
 * @sig (*... -> a),*... -> a
 * @param {Function} fn The function to apply to the remaining arguments.
 * @param {...*} args Any number of positional arguments.
 * @return {*}
 * @see R.apply
 * @example
 *
 *      R.call(R.add, 1, 2); //=> 3
 *
 *      const indentN = R.pipe(R.repeat(' '),
 *                           R.join(''),
 *                           R.replace(/^(?!$)/gm));
 *
 *      const format = R.converge(R.call, [
 *                                  R.pipe(R.prop('indent'), indentN),
 *                                  R.prop('value')
 *                              ]);
 *
 *      format({indent: 2, value: 'foo\nbar\nbaz\n'}); //=> '  foo\n  bar\n  baz\n'
 * @symb R.call(f, a, b) = f(a, b)
 */
var call = /*#__PURE__*/Object(_curry_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function call(fn) {
  return fn.apply(this, Array.prototype.slice.call(arguments, 1));
});
/* harmony default export */ __webpack_exports__["default"] = (call);

/***/ }),

/***/ "./node_modules/ramda/es/chain.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/chain.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_makeFlat_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_makeFlat.js */ "./node_modules/ramda/es/internal/_makeFlat.js");
/* harmony import */ var _internal_xchain_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_xchain.js */ "./node_modules/ramda/es/internal/_xchain.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");






/**
 * `chain` maps a function over a list and concatenates the results. `chain`
 * is also known as `flatMap` in some libraries.
 *
 * Dispatches to the `chain` method of the second argument, if present,
 * according to the [FantasyLand Chain spec](https://github.com/fantasyland/fantasy-land#chain).
 *
 * If second argument is a function, `chain(f, g)(x)` is equivalent to `f(g(x), x)`.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category List
 * @sig Chain m => (a -> m b) -> m a -> m b
 * @param {Function} fn The function to map with
 * @param {Array} list The list to map over
 * @return {Array} The result of flat-mapping `list` with `fn`
 * @example
 *
 *      const duplicate = n => [n, n];
 *      R.chain(duplicate, [1, 2, 3]); //=> [1, 1, 2, 2, 3, 3]
 *
 *      R.chain(R.append, R.head)([1, 2, 3]); //=> [1, 2, 3, 1]
 */
var chain = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['fantasy-land/chain', 'chain'], _internal_xchain_js__WEBPACK_IMPORTED_MODULE_3__["default"], function chain(fn, monad) {
  if (typeof monad === 'function') {
    return function (x) {
      return fn(monad(x))(x);
    };
  }
  return Object(_internal_makeFlat_js__WEBPACK_IMPORTED_MODULE_2__["default"])(false)(Object(_map_js__WEBPACK_IMPORTED_MODULE_4__["default"])(fn, monad));
}));
/* harmony default export */ __webpack_exports__["default"] = (chain);

/***/ }),

/***/ "./node_modules/ramda/es/clamp.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/clamp.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Restricts a number to be within a range.
 *
 * Also works for other ordered types such as Strings and Dates.
 *
 * @func
 * @memberOf R
 * @since v0.20.0
 * @category Relation
 * @sig Ord a => a -> a -> a -> a
 * @param {Number} minimum The lower limit of the clamp (inclusive)
 * @param {Number} maximum The upper limit of the clamp (inclusive)
 * @param {Number} value Value to be clamped
 * @return {Number} Returns `minimum` when `val < minimum`, `maximum` when `val > maximum`, returns `val` otherwise
 * @example
 *
 *      R.clamp(1, 10, -5) // => 1
 *      R.clamp(1, 10, 15) // => 10
 *      R.clamp(1, 10, 4)  // => 4
 */
var clamp = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function clamp(min, max, value) {
  if (min > max) {
    throw new Error('min must not be greater than max in clamp(min, max, value)');
  }
  return value < min ? min : value > max ? max : value;
});
/* harmony default export */ __webpack_exports__["default"] = (clamp);

/***/ }),

/***/ "./node_modules/ramda/es/clone.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/clone.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_clone_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_clone.js */ "./node_modules/ramda/es/internal/_clone.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");



/**
 * Creates a deep copy of the value which may contain (nested) `Array`s and
 * `Object`s, `Number`s, `String`s, `Boolean`s and `Date`s. `Function`s are
 * assigned by reference rather than copied
 *
 * Dispatches to a `clone` method if present.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig {*} -> {*}
 * @param {*} value The object or array to clone
 * @return {*} A deeply cloned copy of `val`
 * @example
 *
 *      const objects = [{}, {}, {}];
 *      const objectsClone = R.clone(objects);
 *      objects === objectsClone; //=> false
 *      objects[0] === objectsClone[0]; //=> false
 */
var clone = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function clone(value) {
  return value != null && typeof value.clone === 'function' ? value.clone() : Object(_internal_clone_js__WEBPACK_IMPORTED_MODULE_0__["default"])(value, [], [], true);
});
/* harmony default export */ __webpack_exports__["default"] = (clone);

/***/ }),

/***/ "./node_modules/ramda/es/comparator.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/comparator.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Makes a comparator function out of a function that reports whether the first
 * element is less than the second.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig ((a, b) -> Boolean) -> ((a, b) -> Number)
 * @param {Function} pred A predicate function of arity two which will return `true` if the first argument
 * is less than the second, `false` otherwise
 * @return {Function} A Function :: a -> b -> Int that returns `-1` if a < b, `1` if b < a, otherwise `0`
 * @example
 *
 *      const byAge = R.comparator((a, b) => a.age < b.age);
 *      const people = [
 *        { name: 'Emma', age: 70 },
 *        { name: 'Peter', age: 78 },
 *        { name: 'Mikhail', age: 62 },
 *      ];
 *      const peopleByIncreasingAge = R.sort(byAge, people);
 *        //=> [{ name: 'Mikhail', age: 62 },{ name: 'Emma', age: 70 }, { name: 'Peter', age: 78 }]
 */
var comparator = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function comparator(pred) {
  return function (a, b) {
    return pred(a, b) ? -1 : pred(b, a) ? 1 : 0;
  };
});
/* harmony default export */ __webpack_exports__["default"] = (comparator);

/***/ }),

/***/ "./node_modules/ramda/es/complement.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/complement.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _lift_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./lift.js */ "./node_modules/ramda/es/lift.js");
/* harmony import */ var _not_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./not.js */ "./node_modules/ramda/es/not.js");



/**
 * Takes a function `f` and returns a function `g` such that if called with the same arguments
 * when `f` returns a "truthy" value, `g` returns `false` and when `f` returns a "falsy" value `g` returns `true`.
 *
 * `R.complement` may be applied to any functor
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category Logic
 * @sig (*... -> *) -> (*... -> Boolean)
 * @param {Function} f
 * @return {Function}
 * @see R.not
 * @example
 *
 *      const isNotNil = R.complement(R.isNil);
 *      isNil(null); //=> true
 *      isNotNil(null); //=> false
 *      isNil(7); //=> false
 *      isNotNil(7); //=> true
 */
var complement = /*#__PURE__*/Object(_lift_js__WEBPACK_IMPORTED_MODULE_0__["default"])(_not_js__WEBPACK_IMPORTED_MODULE_1__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (complement);

/***/ }),

/***/ "./node_modules/ramda/es/compose.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/compose.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return compose; });
/* harmony import */ var _pipe_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./pipe.js */ "./node_modules/ramda/es/pipe.js");
/* harmony import */ var _reverse_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reverse.js */ "./node_modules/ramda/es/reverse.js");



/**
 * Performs right-to-left function composition. The rightmost function may have
 * any arity; the remaining functions must be unary.
 *
 * **Note:** The result of compose is not automatically curried.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig ((y -> z), (x -> y), ..., (o -> p), ((a, b, ..., n) -> o)) -> ((a, b, ..., n) -> z)
 * @param {...Function} ...functions The functions to compose
 * @return {Function}
 * @see R.pipe
 * @example
 *
 *      const classyGreeting = (firstName, lastName) => "The name's " + lastName + ", " + firstName + " " + lastName
 *      const yellGreeting = R.compose(R.toUpper, classyGreeting);
 *      yellGreeting('James', 'Bond'); //=> "THE NAME'S BOND, JAMES BOND"
 *
 *      R.compose(Math.abs, R.add(1), R.multiply(2))(-4) //=> 7
 *
 * @symb R.compose(f, g, h)(a, b) = f(g(h(a, b)))
 */
function compose() {
  if (arguments.length === 0) {
    throw new Error('compose requires at least one argument');
  }
  return _pipe_js__WEBPACK_IMPORTED_MODULE_0__["default"].apply(this, Object(_reverse_js__WEBPACK_IMPORTED_MODULE_1__["default"])(arguments));
}

/***/ }),

/***/ "./node_modules/ramda/es/composeK.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/composeK.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return composeK; });
/* harmony import */ var _chain_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./chain.js */ "./node_modules/ramda/es/chain.js");
/* harmony import */ var _compose_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./compose.js */ "./node_modules/ramda/es/compose.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");




/**
 * Returns the right-to-left Kleisli composition of the provided functions,
 * each of which must return a value of a type supported by [`chain`](#chain).
 *
 * `R.composeK(h, g, f)` is equivalent to `R.compose(R.chain(h), R.chain(g), f)`.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Function
 * @sig Chain m => ((y -> m z), (x -> m y), ..., (a -> m b)) -> (a -> m z)
 * @param {...Function} ...functions The functions to compose
 * @return {Function}
 * @see R.pipeK
 * @deprecated since v0.26.0
 * @example
 *
 *       //  get :: String -> Object -> Maybe *
 *       const get = R.curry((propName, obj) => Maybe(obj[propName]))
 *
 *       //  getStateCode :: Maybe String -> Maybe String
 *       const getStateCode = R.composeK(
 *         R.compose(Maybe.of, R.toUpper),
 *         get('state'),
 *         get('address'),
 *         get('user'),
 *       );
 *       getStateCode({"user":{"address":{"state":"ny"}}}); //=> Maybe.Just("NY")
 *       getStateCode({}); //=> Maybe.Nothing()
 * @symb R.composeK(f, g, h)(a) = R.chain(f, R.chain(g, h(a)))
 */
function composeK() {
  if (arguments.length === 0) {
    throw new Error('composeK requires at least one argument');
  }
  var init = Array.prototype.slice.call(arguments);
  var last = init.pop();
  return Object(_compose_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_compose_js__WEBPACK_IMPORTED_MODULE_1__["default"].apply(this, Object(_map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_chain_js__WEBPACK_IMPORTED_MODULE_0__["default"], init)), last);
}

/***/ }),

/***/ "./node_modules/ramda/es/composeP.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/composeP.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return composeP; });
/* harmony import */ var _pipeP_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./pipeP.js */ "./node_modules/ramda/es/pipeP.js");
/* harmony import */ var _reverse_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reverse.js */ "./node_modules/ramda/es/reverse.js");



/**
 * Performs right-to-left composition of one or more Promise-returning
 * functions. The rightmost function may have any arity; the remaining
 * functions must be unary.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category Function
 * @sig ((y -> Promise z), (x -> Promise y), ..., (a -> Promise b)) -> (a -> Promise z)
 * @param {...Function} functions The functions to compose
 * @return {Function}
 * @see R.pipeP
 * @deprecated since v0.26.0
 * @example
 *
 *      const db = {
 *        users: {
 *          JOE: {
 *            name: 'Joe',
 *            followers: ['STEVE', 'SUZY']
 *          }
 *        }
 *      }
 *
 *      // We'll pretend to do a db lookup which returns a promise
 *      const lookupUser = (userId) => Promise.resolve(db.users[userId])
 *      const lookupFollowers = (user) => Promise.resolve(user.followers)
 *      lookupUser('JOE').then(lookupFollowers)
 *
 *      //  followersForUser :: String -> Promise [UserId]
 *      const followersForUser = R.composeP(lookupFollowers, lookupUser);
 *      followersForUser('JOE').then(followers => console.log('Followers:', followers))
 *      // Followers: ["STEVE","SUZY"]
 */
function composeP() {
  if (arguments.length === 0) {
    throw new Error('composeP requires at least one argument');
  }
  return _pipeP_js__WEBPACK_IMPORTED_MODULE_0__["default"].apply(this, Object(_reverse_js__WEBPACK_IMPORTED_MODULE_1__["default"])(arguments));
}

/***/ }),

/***/ "./node_modules/ramda/es/composeWith.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/composeWith.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _pipeWith_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./pipeWith.js */ "./node_modules/ramda/es/pipeWith.js");
/* harmony import */ var _reverse_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./reverse.js */ "./node_modules/ramda/es/reverse.js");




/**
 * Performs right-to-left function composition using transforming function. The rightmost function may have
 * any arity; the remaining functions must be unary.
 *
 * **Note:** The result of compose is not automatically curried.
 *
 * @func
 * @memberOf R
 * @category Function
 * @sig ((* -> *), [(y -> z), (x -> y), ..., (o -> p), ((a, b, ..., n) -> o)]) -> ((a, b, ..., n) -> z)
 * @param {...Function} ...functions The functions to compose
 * @return {Function}
 * @see R.compose, R.pipeWith
 * @example
 *
 *      const composeWhileNotNil = R.composeWith((f, res) => R.isNil(res) ? res : f(res));
 *
 *      composeWhileNotNil([R.inc, R.prop('age')])({age: 1}) //=> 2
 *      composeWhileNotNil([R.inc, R.prop('age')])({}) //=> undefined
 *
 * @symb R.composeWith(f)([g, h, i])(...args) = f(g, f(h, f(i, ...args)))
 */
var composeWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function composeWith(xf, list) {
  return _pipeWith_js__WEBPACK_IMPORTED_MODULE_1__["default"].apply(this, [xf, Object(_reverse_js__WEBPACK_IMPORTED_MODULE_2__["default"])(list)]);
});
/* harmony default export */ __webpack_exports__["default"] = (composeWith);

/***/ }),

/***/ "./node_modules/ramda/es/concat.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/concat.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isArray_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _internal_isFunction_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isFunction.js */ "./node_modules/ramda/es/internal/_isFunction.js");
/* harmony import */ var _internal_isString_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_isString.js */ "./node_modules/ramda/es/internal/_isString.js");
/* harmony import */ var _toString_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./toString.js */ "./node_modules/ramda/es/toString.js");






/**
 * Returns the result of concatenating the given lists or strings.
 *
 * Note: `R.concat` expects both arguments to be of the same type,
 * unlike the native `Array.prototype.concat` method. It will throw
 * an error if you `concat` an Array with a non-Array value.
 *
 * Dispatches to the `concat` method of the first argument, if present.
 * Can also concatenate two members of a [fantasy-land
 * compatible semigroup](https://github.com/fantasyland/fantasy-land#semigroup).
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [a] -> [a]
 * @sig String -> String -> String
 * @param {Array|String} firstList The first list
 * @param {Array|String} secondList The second list
 * @return {Array|String} A list consisting of the elements of `firstList` followed by the elements of
 * `secondList`.
 *
 * @example
 *
 *      R.concat('ABC', 'DEF'); // 'ABCDEF'
 *      R.concat([4, 5, 6], [1, 2, 3]); //=> [4, 5, 6, 1, 2, 3]
 *      R.concat([], []); //=> []
 */
var concat = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function concat(a, b) {
  if (Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(a)) {
    if (Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(b)) {
      return a.concat(b);
    }
    throw new TypeError(Object(_toString_js__WEBPACK_IMPORTED_MODULE_4__["default"])(b) + ' is not an array');
  }
  if (Object(_internal_isString_js__WEBPACK_IMPORTED_MODULE_3__["default"])(a)) {
    if (Object(_internal_isString_js__WEBPACK_IMPORTED_MODULE_3__["default"])(b)) {
      return a + b;
    }
    throw new TypeError(Object(_toString_js__WEBPACK_IMPORTED_MODULE_4__["default"])(b) + ' is not a string');
  }
  if (a != null && Object(_internal_isFunction_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a['fantasy-land/concat'])) {
    return a['fantasy-land/concat'](b);
  }
  if (a != null && Object(_internal_isFunction_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a.concat)) {
    return a.concat(b);
  }
  throw new TypeError(Object(_toString_js__WEBPACK_IMPORTED_MODULE_4__["default"])(a) + ' does not have a method named "concat" or "fantasy-land/concat"');
});
/* harmony default export */ __webpack_exports__["default"] = (concat);

/***/ }),

/***/ "./node_modules/ramda/es/cond.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/cond.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");
/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./max.js */ "./node_modules/ramda/es/max.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");






/**
 * Returns a function, `fn`, which encapsulates `if/else, if/else, ...` logic.
 * `R.cond` takes a list of [predicate, transformer] pairs. All of the arguments
 * to `fn` are applied to each of the predicates in turn until one returns a
 * "truthy" value, at which point `fn` returns the result of applying its
 * arguments to the corresponding transformer. If none of the predicates
 * matches, `fn` returns undefined.
 *
 * @func
 * @memberOf R
 * @since v0.6.0
 * @category Logic
 * @sig [[(*... -> Boolean),(*... -> *)]] -> (*... -> *)
 * @param {Array} pairs A list of [predicate, transformer]
 * @return {Function}
 * @see R.ifElse, R.unless, R.when
 * @example
 *
 *      const fn = R.cond([
 *        [R.equals(0),   R.always('water freezes at 0°C')],
 *        [R.equals(100), R.always('water boils at 100°C')],
 *        [R.T,           temp => 'nothing special happens at ' + temp + '°C']
 *      ]);
 *      fn(0); //=> 'water freezes at 0°C'
 *      fn(50); //=> 'nothing special happens at 50°C'
 *      fn(100); //=> 'water boils at 100°C'
 */
var cond = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function cond(pairs) {
  var arity = Object(_reduce_js__WEBPACK_IMPORTED_MODULE_4__["default"])(_max_js__WEBPACK_IMPORTED_MODULE_3__["default"], 0, Object(_map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function (pair) {
    return pair[0].length;
  }, pairs));
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(arity, function () {
    var idx = 0;
    while (idx < pairs.length) {
      if (pairs[idx][0].apply(this, arguments)) {
        return pairs[idx][1].apply(this, arguments);
      }
      idx += 1;
    }
  });
});
/* harmony default export */ __webpack_exports__["default"] = (cond);

/***/ }),

/***/ "./node_modules/ramda/es/construct.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/construct.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _constructN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./constructN.js */ "./node_modules/ramda/es/constructN.js");



/**
 * Wraps a constructor function inside a curried function that can be called
 * with the same arguments and returns the same type.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig (* -> {*}) -> (* -> {*})
 * @param {Function} fn The constructor function to wrap.
 * @return {Function} A wrapped, curried constructor function.
 * @see R.invoker
 * @example
 *
 *      // Constructor function
 *      function Animal(kind) {
 *        this.kind = kind;
 *      };
 *      Animal.prototype.sighting = function() {
 *        return "It's a " + this.kind + "!";
 *      }
 *
 *      const AnimalConstructor = R.construct(Animal)
 *
 *      // Notice we no longer need the 'new' keyword:
 *      AnimalConstructor('Pig'); //=> {"kind": "Pig", "sighting": function (){...}};
 *
 *      const animalTypes = ["Lion", "Tiger", "Bear"];
 *      const animalSighting = R.invoker(0, 'sighting');
 *      const sightNewAnimal = R.compose(animalSighting, AnimalConstructor);
 *      R.map(sightNewAnimal, animalTypes); //=> ["It's a Lion!", "It's a Tiger!", "It's a Bear!"]
 */
var construct = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function construct(Fn) {
  return Object(_constructN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Fn.length, Fn);
});
/* harmony default export */ __webpack_exports__["default"] = (construct);

/***/ }),

/***/ "./node_modules/ramda/es/constructN.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/constructN.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _curry_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curry.js */ "./node_modules/ramda/es/curry.js");
/* harmony import */ var _nAry_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./nAry.js */ "./node_modules/ramda/es/nAry.js");




/**
 * Wraps a constructor function inside a curried function that can be called
 * with the same arguments and returns the same type. The arity of the function
 * returned is specified to allow using variadic constructor functions.
 *
 * @func
 * @memberOf R
 * @since v0.4.0
 * @category Function
 * @sig Number -> (* -> {*}) -> (* -> {*})
 * @param {Number} n The arity of the constructor function.
 * @param {Function} Fn The constructor function to wrap.
 * @return {Function} A wrapped, curried constructor function.
 * @example
 *
 *      // Variadic Constructor function
 *      function Salad() {
 *        this.ingredients = arguments;
 *      }
 *
 *      Salad.prototype.recipe = function() {
 *        const instructions = R.map(ingredient => 'Add a dollop of ' + ingredient, this.ingredients);
 *        return R.join('\n', instructions);
 *      };
 *
 *      const ThreeLayerSalad = R.constructN(3, Salad);
 *
 *      // Notice we no longer need the 'new' keyword, and the constructor is curried for 3 arguments.
 *      const salad = ThreeLayerSalad('Mayonnaise')('Potato Chips')('Ketchup');
 *
 *      console.log(salad.recipe());
 *      // Add a dollop of Mayonnaise
 *      // Add a dollop of Potato Chips
 *      // Add a dollop of Ketchup
 */
var constructN = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function constructN(n, Fn) {
  if (n > 10) {
    throw new Error('Constructor with greater than ten arguments');
  }
  if (n === 0) {
    return function () {
      return new Fn();
    };
  }
  return Object(_curry_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_nAry_js__WEBPACK_IMPORTED_MODULE_2__["default"])(n, function ($0, $1, $2, $3, $4, $5, $6, $7, $8, $9) {
    switch (arguments.length) {
      case 1:
        return new Fn($0);
      case 2:
        return new Fn($0, $1);
      case 3:
        return new Fn($0, $1, $2);
      case 4:
        return new Fn($0, $1, $2, $3);
      case 5:
        return new Fn($0, $1, $2, $3, $4);
      case 6:
        return new Fn($0, $1, $2, $3, $4, $5);
      case 7:
        return new Fn($0, $1, $2, $3, $4, $5, $6);
      case 8:
        return new Fn($0, $1, $2, $3, $4, $5, $6, $7);
      case 9:
        return new Fn($0, $1, $2, $3, $4, $5, $6, $7, $8);
      case 10:
        return new Fn($0, $1, $2, $3, $4, $5, $6, $7, $8, $9);
    }
  }));
});
/* harmony default export */ __webpack_exports__["default"] = (constructN);

/***/ }),

/***/ "./node_modules/ramda/es/contains.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/contains.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includes_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includes.js */ "./node_modules/ramda/es/internal/_includes.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns `true` if the specified value is equal, in [`R.equals`](#equals)
 * terms, to at least one element of the given list; `false` otherwise.
 * Works also with strings.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig a -> [a] -> Boolean
 * @param {Object} a The item to compare against.
 * @param {Array} list The array to consider.
 * @return {Boolean} `true` if an equivalent item is in the list, `false` otherwise.
 * @see R.includes
 * @deprecated since v0.26.0
 * @example
 *
 *      R.contains(3, [1, 2, 3]); //=> true
 *      R.contains(4, [1, 2, 3]); //=> false
 *      R.contains({ name: 'Fred' }, [{ name: 'Fred' }]); //=> true
 *      R.contains([42], [[42]]); //=> true
 *      R.contains('ba', 'banana'); //=>true
 */
var contains = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_internal_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (contains);

/***/ }),

/***/ "./node_modules/ramda/es/converge.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/converge.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_map.js */ "./node_modules/ramda/es/internal/_map.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./max.js */ "./node_modules/ramda/es/max.js");
/* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./pluck.js */ "./node_modules/ramda/es/pluck.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");







/**
 * Accepts a converging function and a list of branching functions and returns
 * a new function. The arity of the new function is the same as the arity of
 * the longest branching function. When invoked, this new function is applied
 * to some arguments, and each branching function is applied to those same
 * arguments. The results of each branching function are passed as arguments
 * to the converging function to produce the return value.
 *
 * @func
 * @memberOf R
 * @since v0.4.2
 * @category Function
 * @sig ((x1, x2, ...) -> z) -> [((a, b, ...) -> x1), ((a, b, ...) -> x2), ...] -> (a -> b -> ... -> z)
 * @param {Function} after A function. `after` will be invoked with the return values of
 *        `fn1` and `fn2` as its arguments.
 * @param {Array} functions A list of functions.
 * @return {Function} A new function.
 * @see R.useWith
 * @example
 *
 *      const average = R.converge(R.divide, [R.sum, R.length])
 *      average([1, 2, 3, 4, 5, 6, 7]) //=> 4
 *
 *      const strangeConcat = R.converge(R.concat, [R.toUpper, R.toLower])
 *      strangeConcat("Yodel") //=> "YODELyodel"
 *
 * @symb R.converge(f, [g, h])(a, b) = f(g(a, b), h(a, b))
 */
var converge = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function converge(after, fns) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_reduce_js__WEBPACK_IMPORTED_MODULE_5__["default"])(_max_js__WEBPACK_IMPORTED_MODULE_3__["default"], 0, Object(_pluck_js__WEBPACK_IMPORTED_MODULE_4__["default"])('length', fns)), function () {
    var args = arguments;
    var context = this;
    return after.apply(context, Object(_internal_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (fn) {
      return fn.apply(context, args);
    }, fns));
  });
});
/* harmony default export */ __webpack_exports__["default"] = (converge);

/***/ }),

/***/ "./node_modules/ramda/es/countBy.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/countBy.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _reduceBy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduceBy.js */ "./node_modules/ramda/es/reduceBy.js");


/**
 * Counts the elements of a list according to how many match each value of a
 * key generated by the supplied function. Returns an object mapping the keys
 * produced by `fn` to the number of occurrences in the list. Note that all
 * keys are coerced to strings because of how JavaScript objects work.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig (a -> String) -> [a] -> {*}
 * @param {Function} fn The function used to map values to keys.
 * @param {Array} list The list to count elements from.
 * @return {Object} An object mapping keys to number of occurrences in the list.
 * @example
 *
 *      const numbers = [1.0, 1.1, 1.2, 2.0, 3.0, 2.2];
 *      R.countBy(Math.floor)(numbers);    //=> {'1': 3, '2': 2, '3': 1}
 *
 *      const letters = ['a', 'b', 'A', 'a', 'B', 'c'];
 *      R.countBy(R.toLower)(letters);   //=> {'a': 3, 'b': 2, 'c': 1}
 */
var countBy = /*#__PURE__*/Object(_reduceBy_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (acc, elem) {
  return acc + 1;
}, 0);
/* harmony default export */ __webpack_exports__["default"] = (countBy);

/***/ }),

/***/ "./node_modules/ramda/es/curry.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/curry.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");



/**
 * Returns a curried equivalent of the provided function. The curried function
 * has two unusual capabilities. First, its arguments needn't be provided one
 * at a time. If `f` is a ternary function and `g` is `R.curry(f)`, the
 * following are equivalent:
 *
 *   - `g(1)(2)(3)`
 *   - `g(1)(2, 3)`
 *   - `g(1, 2)(3)`
 *   - `g(1, 2, 3)`
 *
 * Secondly, the special placeholder value [`R.__`](#__) may be used to specify
 * "gaps", allowing partial application of any combination of arguments,
 * regardless of their positions. If `g` is as above and `_` is [`R.__`](#__),
 * the following are equivalent:
 *
 *   - `g(1, 2, 3)`
 *   - `g(_, 2, 3)(1)`
 *   - `g(_, _, 3)(1)(2)`
 *   - `g(_, _, 3)(1, 2)`
 *   - `g(_, 2)(1)(3)`
 *   - `g(_, 2)(1, 3)`
 *   - `g(_, 2)(_, 3)(1)`
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig (* -> a) -> (* -> a)
 * @param {Function} fn The function to curry.
 * @return {Function} A new, curried function.
 * @see R.curryN, R.partial
 * @example
 *
 *      const addFourNumbers = (a, b, c, d) => a + b + c + d;
 *
 *      const curriedAddFourNumbers = R.curry(addFourNumbers);
 *      const f = curriedAddFourNumbers(1, 2);
 *      const g = f(3);
 *      g(4); //=> 10
 */
var curry = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function curry(fn) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(fn.length, fn);
});
/* harmony default export */ __webpack_exports__["default"] = (curry);

/***/ }),

/***/ "./node_modules/ramda/es/curryN.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/curryN.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_curryN_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_curryN.js */ "./node_modules/ramda/es/internal/_curryN.js");





/**
 * Returns a curried equivalent of the provided function, with the specified
 * arity. The curried function has two unusual capabilities. First, its
 * arguments needn't be provided one at a time. If `g` is `R.curryN(3, f)`, the
 * following are equivalent:
 *
 *   - `g(1)(2)(3)`
 *   - `g(1)(2, 3)`
 *   - `g(1, 2)(3)`
 *   - `g(1, 2, 3)`
 *
 * Secondly, the special placeholder value [`R.__`](#__) may be used to specify
 * "gaps", allowing partial application of any combination of arguments,
 * regardless of their positions. If `g` is as above and `_` is [`R.__`](#__),
 * the following are equivalent:
 *
 *   - `g(1, 2, 3)`
 *   - `g(_, 2, 3)(1)`
 *   - `g(_, _, 3)(1)(2)`
 *   - `g(_, _, 3)(1, 2)`
 *   - `g(_, 2)(1)(3)`
 *   - `g(_, 2)(1, 3)`
 *   - `g(_, 2)(_, 3)(1)`
 *
 * @func
 * @memberOf R
 * @since v0.5.0
 * @category Function
 * @sig Number -> (* -> a) -> (* -> a)
 * @param {Number} length The arity for the returned function.
 * @param {Function} fn The function to curry.
 * @return {Function} A new, curried function.
 * @see R.curry
 * @example
 *
 *      const sumArgs = (...args) => R.sum(args);
 *
 *      const curriedAddFourNumbers = R.curryN(4, sumArgs);
 *      const f = curriedAddFourNumbers(1, 2);
 *      const g = f(3);
 *      g(4); //=> 10
 */
var curryN = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function curryN(length, fn) {
  if (length === 1) {
    return Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(fn);
  }
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(length, Object(_internal_curryN_js__WEBPACK_IMPORTED_MODULE_3__["default"])(length, [], fn));
});
/* harmony default export */ __webpack_exports__["default"] = (curryN);

/***/ }),

/***/ "./node_modules/ramda/es/dec.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/dec.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _add_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./add.js */ "./node_modules/ramda/es/add.js");


/**
 * Decrements its argument.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Math
 * @sig Number -> Number
 * @param {Number} n
 * @return {Number} n - 1
 * @see R.inc
 * @example
 *
 *      R.dec(42); //=> 41
 */
var dec = /*#__PURE__*/Object(_add_js__WEBPACK_IMPORTED_MODULE_0__["default"])(-1);
/* harmony default export */ __webpack_exports__["default"] = (dec);

/***/ }),

/***/ "./node_modules/ramda/es/defaultTo.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/defaultTo.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns the second argument if it is not `null`, `undefined` or `NaN`;
 * otherwise the first argument is returned.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category Logic
 * @sig a -> b -> a | b
 * @param {a} default The default value.
 * @param {b} val `val` will be returned instead of `default` unless `val` is `null`, `undefined` or `NaN`.
 * @return {*} The second value if it is not `null`, `undefined` or `NaN`, otherwise the default value
 * @example
 *
 *      const defaultTo42 = R.defaultTo(42);
 *
 *      defaultTo42(null);  //=> 42
 *      defaultTo42(undefined);  //=> 42
 *      defaultTo42(false);  //=> false
 *      defaultTo42('Ramda');  //=> 'Ramda'
 *      // parseInt('string') results in NaN
 *      defaultTo42(parseInt('string')); //=> 42
 */
var defaultTo = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function defaultTo(d, v) {
  return v == null || v !== v ? d : v;
});
/* harmony default export */ __webpack_exports__["default"] = (defaultTo);

/***/ }),

/***/ "./node_modules/ramda/es/descend.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/descend.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Makes a descending comparator function out of a function that returns a value
 * that can be compared with `<` and `>`.
 *
 * @func
 * @memberOf R
 * @since v0.23.0
 * @category Function
 * @sig Ord b => (a -> b) -> a -> a -> Number
 * @param {Function} fn A function of arity one that returns a value that can be compared
 * @param {*} a The first item to be compared.
 * @param {*} b The second item to be compared.
 * @return {Number} `-1` if fn(a) > fn(b), `1` if fn(b) > fn(a), otherwise `0`
 * @see R.ascend
 * @example
 *
 *      const byAge = R.descend(R.prop('age'));
 *      const people = [
 *        { name: 'Emma', age: 70 },
 *        { name: 'Peter', age: 78 },
 *        { name: 'Mikhail', age: 62 },
 *      ];
 *      const peopleByOldestFirst = R.sort(byAge, people);
 *        //=> [{ name: 'Peter', age: 78 }, { name: 'Emma', age: 70 }, { name: 'Mikhail', age: 62 }]
 */
var descend = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function descend(fn, a, b) {
  var aa = fn(a);
  var bb = fn(b);
  return aa > bb ? -1 : aa < bb ? 1 : 0;
});
/* harmony default export */ __webpack_exports__["default"] = (descend);

/***/ }),

/***/ "./node_modules/ramda/es/difference.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/difference.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_Set_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_Set.js */ "./node_modules/ramda/es/internal/_Set.js");



/**
 * Finds the set (i.e. no duplicates) of all elements in the first list not
 * contained in the second list. Objects and Arrays are compared in terms of
 * value equality, not reference equality.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig [*] -> [*] -> [*]
 * @param {Array} list1 The first list.
 * @param {Array} list2 The second list.
 * @return {Array} The elements in `list1` that are not in `list2`.
 * @see R.differenceWith, R.symmetricDifference, R.symmetricDifferenceWith, R.without
 * @example
 *
 *      R.difference([1,2,3,4], [7,6,5,4,3]); //=> [1,2]
 *      R.difference([7,6,5,4,3], [1,2,3,4]); //=> [7,6,5]
 *      R.difference([{a: 1}, {b: 2}], [{a: 1}, {c: 3}]) //=> [{b: 2}]
 */
var difference = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function difference(first, second) {
  var out = [];
  var idx = 0;
  var firstLen = first.length;
  var secondLen = second.length;
  var toFilterOut = new _internal_Set_js__WEBPACK_IMPORTED_MODULE_1__["default"]();

  for (var i = 0; i < secondLen; i += 1) {
    toFilterOut.add(second[i]);
  }

  while (idx < firstLen) {
    if (toFilterOut.add(first[idx])) {
      out[out.length] = first[idx];
    }
    idx += 1;
  }
  return out;
});
/* harmony default export */ __webpack_exports__["default"] = (difference);

/***/ }),

/***/ "./node_modules/ramda/es/differenceWith.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/differenceWith.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includesWith.js */ "./node_modules/ramda/es/internal/_includesWith.js");
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");



/**
 * Finds the set (i.e. no duplicates) of all elements in the first list not
 * contained in the second list. Duplication is determined according to the
 * value returned by applying the supplied predicate to two list elements.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig ((a, a) -> Boolean) -> [a] -> [a] -> [a]
 * @param {Function} pred A predicate used to test whether two items are equal.
 * @param {Array} list1 The first list.
 * @param {Array} list2 The second list.
 * @return {Array} The elements in `list1` that are not in `list2`.
 * @see R.difference, R.symmetricDifference, R.symmetricDifferenceWith
 * @example
 *
 *      const cmp = (x, y) => x.a === y.a;
 *      const l1 = [{a: 1}, {a: 2}, {a: 3}];
 *      const l2 = [{a: 3}, {a: 4}];
 *      R.differenceWith(cmp, l1, l2); //=> [{a: 1}, {a: 2}]
 */
var differenceWith = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function differenceWith(pred, first, second) {
  var out = [];
  var idx = 0;
  var firstLen = first.length;
  while (idx < firstLen) {
    if (!Object(_internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__["default"])(pred, first[idx], second) && !Object(_internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__["default"])(pred, first[idx], out)) {
      out.push(first[idx]);
    }
    idx += 1;
  }
  return out;
});
/* harmony default export */ __webpack_exports__["default"] = (differenceWith);

/***/ }),

/***/ "./node_modules/ramda/es/dissoc.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/dissoc.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns a new object that does not contain a `prop` property.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category Object
 * @sig String -> {k: v} -> {k: v}
 * @param {String} prop The name of the property to dissociate
 * @param {Object} obj The object to clone
 * @return {Object} A new object equivalent to the original but without the specified property
 * @see R.assoc, R.omit
 * @example
 *
 *      R.dissoc('b', {a: 1, b: 2, c: 3}); //=> {a: 1, c: 3}
 */
var dissoc = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function dissoc(prop, obj) {
  var result = {};
  for (var p in obj) {
    result[p] = obj[p];
  }
  delete result[prop];
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (dissoc);

/***/ }),

/***/ "./node_modules/ramda/es/dissocPath.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/dissocPath.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isInteger_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isInteger.js */ "./node_modules/ramda/es/internal/_isInteger.js");
/* harmony import */ var _internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _assoc_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./assoc.js */ "./node_modules/ramda/es/assoc.js");
/* harmony import */ var _dissoc_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./dissoc.js */ "./node_modules/ramda/es/dissoc.js");
/* harmony import */ var _remove_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./remove.js */ "./node_modules/ramda/es/remove.js");
/* harmony import */ var _update_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./update.js */ "./node_modules/ramda/es/update.js");








/**
 * Makes a shallow clone of an object, omitting the property at the given path.
 * Note that this copies and flattens prototype properties onto the new object
 * as well. All non-primitive properties are copied by reference.
 *
 * @func
 * @memberOf R
 * @since v0.11.0
 * @category Object
 * @typedefn Idx = String | Int
 * @sig [Idx] -> {k: v} -> {k: v}
 * @param {Array} path The path to the value to omit
 * @param {Object} obj The object to clone
 * @return {Object} A new object without the property at path
 * @see R.assocPath
 * @example
 *
 *      R.dissocPath(['a', 'b', 'c'], {a: {b: {c: 42}}}); //=> {a: {b: {}}}
 */
var dissocPath = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function dissocPath(path, obj) {
  switch (path.length) {
    case 0:
      return obj;
    case 1:
      return Object(_internal_isInteger_js__WEBPACK_IMPORTED_MODULE_1__["default"])(path[0]) && Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj) ? Object(_remove_js__WEBPACK_IMPORTED_MODULE_5__["default"])(path[0], 1, obj) : Object(_dissoc_js__WEBPACK_IMPORTED_MODULE_4__["default"])(path[0], obj);
    default:
      var head = path[0];
      var tail = Array.prototype.slice.call(path, 1);
      if (obj[head] == null) {
        return obj;
      } else if (Object(_internal_isInteger_js__WEBPACK_IMPORTED_MODULE_1__["default"])(head) && Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj)) {
        return Object(_update_js__WEBPACK_IMPORTED_MODULE_6__["default"])(head, dissocPath(tail, obj[head]), obj);
      } else {
        return Object(_assoc_js__WEBPACK_IMPORTED_MODULE_3__["default"])(head, dissocPath(tail, obj[head]), obj);
      }
  }
});
/* harmony default export */ __webpack_exports__["default"] = (dissocPath);

/***/ }),

/***/ "./node_modules/ramda/es/divide.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/divide.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Divides two numbers. Equivalent to `a / b`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Math
 * @sig Number -> Number -> Number
 * @param {Number} a The first value.
 * @param {Number} b The second value.
 * @return {Number} The result of `a / b`.
 * @see R.multiply
 * @example
 *
 *      R.divide(71, 100); //=> 0.71
 *
 *      const half = R.divide(R.__, 2);
 *      half(42); //=> 21
 *
 *      const reciprocal = R.divide(1);
 *      reciprocal(4);   //=> 0.25
 */
var divide = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function divide(a, b) {
  return a / b;
});
/* harmony default export */ __webpack_exports__["default"] = (divide);

/***/ }),

/***/ "./node_modules/ramda/es/drop.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/drop.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xdrop_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xdrop.js */ "./node_modules/ramda/es/internal/_xdrop.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");





/**
 * Returns all but the first `n` elements of the given list, string, or
 * transducer/transformer (or object with a `drop` method).
 *
 * Dispatches to the `drop` method of the second argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Number -> [a] -> [a]
 * @sig Number -> String -> String
 * @param {Number} n
 * @param {*} list
 * @return {*} A copy of list without the first `n` elements
 * @see R.take, R.transduce, R.dropLast, R.dropWhile
 * @example
 *
 *      R.drop(1, ['foo', 'bar', 'baz']); //=> ['bar', 'baz']
 *      R.drop(2, ['foo', 'bar', 'baz']); //=> ['baz']
 *      R.drop(3, ['foo', 'bar', 'baz']); //=> []
 *      R.drop(4, ['foo', 'bar', 'baz']); //=> []
 *      R.drop(3, 'ramda');               //=> 'da'
 */
var drop = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['drop'], _internal_xdrop_js__WEBPACK_IMPORTED_MODULE_2__["default"], function drop(n, xs) {
  return Object(_slice_js__WEBPACK_IMPORTED_MODULE_3__["default"])(Math.max(0, n), Infinity, xs);
}));
/* harmony default export */ __webpack_exports__["default"] = (drop);

/***/ }),

/***/ "./node_modules/ramda/es/dropLast.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/dropLast.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_dropLast_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_dropLast.js */ "./node_modules/ramda/es/internal/_dropLast.js");
/* harmony import */ var _internal_xdropLast_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_xdropLast.js */ "./node_modules/ramda/es/internal/_xdropLast.js");





/**
 * Returns a list containing all but the last `n` elements of the given `list`.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category List
 * @sig Number -> [a] -> [a]
 * @sig Number -> String -> String
 * @param {Number} n The number of elements of `list` to skip.
 * @param {Array} list The list of elements to consider.
 * @return {Array} A copy of the list with only the first `list.length - n` elements
 * @see R.takeLast, R.drop, R.dropWhile, R.dropLastWhile
 * @example
 *
 *      R.dropLast(1, ['foo', 'bar', 'baz']); //=> ['foo', 'bar']
 *      R.dropLast(2, ['foo', 'bar', 'baz']); //=> ['foo']
 *      R.dropLast(3, ['foo', 'bar', 'baz']); //=> []
 *      R.dropLast(4, ['foo', 'bar', 'baz']); //=> []
 *      R.dropLast(3, 'ramda');               //=> 'ra'
 */
var dropLast = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xdropLast_js__WEBPACK_IMPORTED_MODULE_3__["default"], _internal_dropLast_js__WEBPACK_IMPORTED_MODULE_2__["default"]));
/* harmony default export */ __webpack_exports__["default"] = (dropLast);

/***/ }),

/***/ "./node_modules/ramda/es/dropLastWhile.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/dropLastWhile.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_dropLastWhile_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_dropLastWhile.js */ "./node_modules/ramda/es/internal/_dropLastWhile.js");
/* harmony import */ var _internal_xdropLastWhile_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_xdropLastWhile.js */ "./node_modules/ramda/es/internal/_xdropLastWhile.js");





/**
 * Returns a new list excluding all the tailing elements of a given list which
 * satisfy the supplied predicate function. It passes each value from the right
 * to the supplied predicate function, skipping elements until the predicate
 * function returns a `falsy` value. The predicate function is applied to one argument:
 * *(value)*.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> [a]
 * @sig (a -> Boolean) -> String -> String
 * @param {Function} predicate The function to be called on each element
 * @param {Array} xs The collection to iterate over.
 * @return {Array} A new array without any trailing elements that return `falsy` values from the `predicate`.
 * @see R.takeLastWhile, R.addIndex, R.drop, R.dropWhile
 * @example
 *
 *      const lteThree = x => x <= 3;
 *
 *      R.dropLastWhile(lteThree, [1, 2, 3, 4, 3, 2, 1]); //=> [1, 2, 3, 4]
 *
 *      R.dropLastWhile(x => x !== 'd' , 'Ramda'); //=> 'Ramd'
 */
var dropLastWhile = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xdropLastWhile_js__WEBPACK_IMPORTED_MODULE_3__["default"], _internal_dropLastWhile_js__WEBPACK_IMPORTED_MODULE_2__["default"]));
/* harmony default export */ __webpack_exports__["default"] = (dropLastWhile);

/***/ }),

/***/ "./node_modules/ramda/es/dropRepeats.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/dropRepeats.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xdropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xdropRepeatsWith.js */ "./node_modules/ramda/es/internal/_xdropRepeatsWith.js");
/* harmony import */ var _dropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./dropRepeatsWith.js */ "./node_modules/ramda/es/dropRepeatsWith.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");






/**
 * Returns a new list without any consecutively repeating elements.
 * [`R.equals`](#equals) is used to determine equality.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category List
 * @sig [a] -> [a]
 * @param {Array} list The array to consider.
 * @return {Array} `list` without repeating elements.
 * @see R.transduce
 * @example
 *
 *     R.dropRepeats([1, 1, 1, 2, 3, 4, 4, 2, 2]); //=> [1, 2, 3, 4, 2]
 */
var dropRepeats = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], /*#__PURE__*/Object(_internal_xdropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_equals_js__WEBPACK_IMPORTED_MODULE_4__["default"]), /*#__PURE__*/Object(_dropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_3__["default"])(_equals_js__WEBPACK_IMPORTED_MODULE_4__["default"])));
/* harmony default export */ __webpack_exports__["default"] = (dropRepeats);

/***/ }),

/***/ "./node_modules/ramda/es/dropRepeatsWith.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/dropRepeatsWith.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xdropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xdropRepeatsWith.js */ "./node_modules/ramda/es/internal/_xdropRepeatsWith.js");
/* harmony import */ var _last_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./last.js */ "./node_modules/ramda/es/last.js");





/**
 * Returns a new list without any consecutively repeating elements. Equality is
 * determined by applying the supplied predicate to each pair of consecutive elements. The
 * first element in a series of equal elements will be preserved.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category List
 * @sig ((a, a) -> Boolean) -> [a] -> [a]
 * @param {Function} pred A predicate used to test whether two items are equal.
 * @param {Array} list The array to consider.
 * @return {Array} `list` without repeating elements.
 * @see R.transduce
 * @example
 *
 *      const l = [1, -1, 1, 3, 4, -4, -4, -5, 5, 3, 3];
 *      R.dropRepeatsWith(R.eqBy(Math.abs), l); //=> [1, 3, 4, -5, 3]
 */
var dropRepeatsWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xdropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_2__["default"], function dropRepeatsWith(pred, list) {
  var result = [];
  var idx = 1;
  var len = list.length;
  if (len !== 0) {
    result[0] = list[0];
    while (idx < len) {
      if (!pred(Object(_last_js__WEBPACK_IMPORTED_MODULE_3__["default"])(result), list[idx])) {
        result[result.length] = list[idx];
      }
      idx += 1;
    }
  }
  return result;
}));
/* harmony default export */ __webpack_exports__["default"] = (dropRepeatsWith);

/***/ }),

/***/ "./node_modules/ramda/es/dropWhile.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/dropWhile.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xdropWhile_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xdropWhile.js */ "./node_modules/ramda/es/internal/_xdropWhile.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");





/**
 * Returns a new list excluding the leading elements of a given list which
 * satisfy the supplied predicate function. It passes each value to the supplied
 * predicate function, skipping elements while the predicate function returns
 * `true`. The predicate function is applied to one argument: *(value)*.
 *
 * Dispatches to the `dropWhile` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> [a]
 * @sig (a -> Boolean) -> String -> String
 * @param {Function} fn The function called per iteration.
 * @param {Array} xs The collection to iterate over.
 * @return {Array} A new array.
 * @see R.takeWhile, R.transduce, R.addIndex
 * @example
 *
 *      const lteTwo = x => x <= 2;
 *
 *      R.dropWhile(lteTwo, [1, 2, 3, 4, 3, 2, 1]); //=> [3, 4, 3, 2, 1]
 *
 *      R.dropWhile(x => x !== 'd' , 'Ramda'); //=> 'da'
 */
var dropWhile = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['dropWhile'], _internal_xdropWhile_js__WEBPACK_IMPORTED_MODULE_2__["default"], function dropWhile(pred, xs) {
  var idx = 0;
  var len = xs.length;
  while (idx < len && pred(xs[idx])) {
    idx += 1;
  }
  return Object(_slice_js__WEBPACK_IMPORTED_MODULE_3__["default"])(idx, Infinity, xs);
}));
/* harmony default export */ __webpack_exports__["default"] = (dropWhile);

/***/ }),

/***/ "./node_modules/ramda/es/either.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/either.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isFunction_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isFunction.js */ "./node_modules/ramda/es/internal/_isFunction.js");
/* harmony import */ var _lift_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lift.js */ "./node_modules/ramda/es/lift.js");
/* harmony import */ var _or_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./or.js */ "./node_modules/ramda/es/or.js");





/**
 * A function wrapping calls to the two functions in an `||` operation,
 * returning the result of the first function if it is truth-y and the result
 * of the second function otherwise. Note that this is short-circuited,
 * meaning that the second function will not be invoked if the first returns a
 * truth-y value.
 *
 * In addition to functions, `R.either` also accepts any fantasy-land compatible
 * applicative functor.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category Logic
 * @sig (*... -> Boolean) -> (*... -> Boolean) -> (*... -> Boolean)
 * @param {Function} f a predicate
 * @param {Function} g another predicate
 * @return {Function} a function that applies its arguments to `f` and `g` and `||`s their outputs together.
 * @see R.or
 * @example
 *
 *      const gt10 = x => x > 10;
 *      const even = x => x % 2 === 0;
 *      const f = R.either(gt10, even);
 *      f(101); //=> true
 *      f(8); //=> true
 *
 *      R.either(Maybe.Just(false), Maybe.Just(55)); // => Maybe.Just(55)
 *      R.either([false, false, 'a'], [11]) // => [11, 11, "a"]
 */
var either = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function either(f, g) {
  return Object(_internal_isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(f) ? function _either() {
    return f.apply(this, arguments) || g.apply(this, arguments);
  } : Object(_lift_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_or_js__WEBPACK_IMPORTED_MODULE_3__["default"])(f, g);
});
/* harmony default export */ __webpack_exports__["default"] = (either);

/***/ }),

/***/ "./node_modules/ramda/es/empty.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/empty.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_isArguments_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isArguments.js */ "./node_modules/ramda/es/internal/_isArguments.js");
/* harmony import */ var _internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _internal_isObject_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_isObject.js */ "./node_modules/ramda/es/internal/_isObject.js");
/* harmony import */ var _internal_isString_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./internal/_isString.js */ "./node_modules/ramda/es/internal/_isString.js");






/**
 * Returns the empty value of its argument's type. Ramda defines the empty
 * value of Array (`[]`), Object (`{}`), String (`''`), and Arguments. Other
 * types are supported if they define `<Type>.empty`,
 * `<Type>.prototype.empty` or implement the
 * [FantasyLand Monoid spec](https://github.com/fantasyland/fantasy-land#monoid).
 *
 * Dispatches to the `empty` method of the first argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category Function
 * @sig a -> a
 * @param {*} x
 * @return {*}
 * @example
 *
 *      R.empty(Just(42));      //=> Nothing()
 *      R.empty([1, 2, 3]);     //=> []
 *      R.empty('unicorns');    //=> ''
 *      R.empty({x: 1, y: 2});  //=> {}
 */
var empty = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function empty(x) {
  return x != null && typeof x['fantasy-land/empty'] === 'function' ? x['fantasy-land/empty']() : x != null && x.constructor != null && typeof x.constructor['fantasy-land/empty'] === 'function' ? x.constructor['fantasy-land/empty']() : x != null && typeof x.empty === 'function' ? x.empty() : x != null && x.constructor != null && typeof x.constructor.empty === 'function' ? x.constructor.empty() : Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__["default"])(x) ? [] : Object(_internal_isString_js__WEBPACK_IMPORTED_MODULE_4__["default"])(x) ? '' : Object(_internal_isObject_js__WEBPACK_IMPORTED_MODULE_3__["default"])(x) ? {} : Object(_internal_isArguments_js__WEBPACK_IMPORTED_MODULE_1__["default"])(x) ? function () {
    return arguments;
  }() : void 0 // else
  ;
});
/* harmony default export */ __webpack_exports__["default"] = (empty);

/***/ }),

/***/ "./node_modules/ramda/es/endsWith.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/endsWith.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");
/* harmony import */ var _takeLast_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./takeLast.js */ "./node_modules/ramda/es/takeLast.js");




/**
 * Checks if a list ends with the provided sublist.
 *
 * Similarly, checks if a string ends with the provided substring.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category List
 * @sig [a] -> [a] -> Boolean
 * @sig String -> String -> Boolean
 * @param {*} suffix
 * @param {*} list
 * @return {Boolean}
 * @see R.startsWith
 * @example
 *
 *      R.endsWith('c', 'abc')                //=> true
 *      R.endsWith('b', 'abc')                //=> false
 *      R.endsWith(['c'], ['a', 'b', 'c'])    //=> true
 *      R.endsWith(['b'], ['a', 'b', 'c'])    //=> false
 */
var endsWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (suffix, list) {
  return Object(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_takeLast_js__WEBPACK_IMPORTED_MODULE_2__["default"])(suffix.length, list), suffix);
});
/* harmony default export */ __webpack_exports__["default"] = (endsWith);

/***/ }),

/***/ "./node_modules/ramda/es/eqBy.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/eqBy.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");



/**
 * Takes a function and two values in its domain and returns `true` if the
 * values map to the same value in the codomain; `false` otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.18.0
 * @category Relation
 * @sig (a -> b) -> a -> a -> Boolean
 * @param {Function} f
 * @param {*} x
 * @param {*} y
 * @return {Boolean}
 * @example
 *
 *      R.eqBy(Math.abs, 5, -5); //=> true
 */
var eqBy = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function eqBy(f, x, y) {
  return Object(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(f(x), f(y));
});
/* harmony default export */ __webpack_exports__["default"] = (eqBy);

/***/ }),

/***/ "./node_modules/ramda/es/eqProps.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/eqProps.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");



/**
 * Reports whether two objects have the same value, in [`R.equals`](#equals)
 * terms, for the specified property. Useful as a curried predicate.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig k -> {k: v} -> {k: v} -> Boolean
 * @param {String} prop The name of the property to compare
 * @param {Object} obj1
 * @param {Object} obj2
 * @return {Boolean}
 *
 * @example
 *
 *      const o1 = { a: 1, b: 2, c: 3, d: 4 };
 *      const o2 = { a: 10, b: 20, c: 3, d: 40 };
 *      R.eqProps('a', o1, o2); //=> false
 *      R.eqProps('c', o1, o2); //=> true
 */
var eqProps = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function eqProps(prop, obj1, obj2) {
  return Object(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj1[prop], obj2[prop]);
});
/* harmony default export */ __webpack_exports__["default"] = (eqProps);

/***/ }),

/***/ "./node_modules/ramda/es/equals.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/equals.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_equals.js */ "./node_modules/ramda/es/internal/_equals.js");



/**
 * Returns `true` if its arguments are equivalent, `false` otherwise. Handles
 * cyclical data structures.
 *
 * Dispatches symmetrically to the `equals` methods of both arguments, if
 * present.
 *
 * @func
 * @memberOf R
 * @since v0.15.0
 * @category Relation
 * @sig a -> b -> Boolean
 * @param {*} a
 * @param {*} b
 * @return {Boolean}
 * @example
 *
 *      R.equals(1, 1); //=> true
 *      R.equals(1, '1'); //=> false
 *      R.equals([1, 2, 3], [1, 2, 3]); //=> true
 *
 *      const a = {}; a.v = a;
 *      const b = {}; b.v = b;
 *      R.equals(a, b); //=> true
 */
var equals = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function equals(a, b) {
  return Object(_internal_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(a, b, [], []);
});
/* harmony default export */ __webpack_exports__["default"] = (equals);

/***/ }),

/***/ "./node_modules/ramda/es/evolve.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/evolve.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Creates a new object by recursively evolving a shallow copy of `object`,
 * according to the `transformation` functions. All non-primitive properties
 * are copied by reference.
 *
 * A `transformation` function will not be invoked if its corresponding key
 * does not exist in the evolved object.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Object
 * @sig {k: (v -> v)} -> {k: v} -> {k: v}
 * @param {Object} transformations The object specifying transformation functions to apply
 *        to the object.
 * @param {Object} object The object to be transformed.
 * @return {Object} The transformed object.
 * @example
 *
 *      const tomato = {firstName: '  Tomato ', data: {elapsed: 100, remaining: 1400}, id:123};
 *      const transformations = {
 *        firstName: R.trim,
 *        lastName: R.trim, // Will not get invoked.
 *        data: {elapsed: R.add(1), remaining: R.add(-1)}
 *      };
 *      R.evolve(transformations, tomato); //=> {firstName: 'Tomato', data: {elapsed: 101, remaining: 1399}, id:123}
 */
var evolve = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function evolve(transformations, object) {
  var result = object instanceof Array ? [] : {};
  var transformation, key, type;
  for (key in object) {
    transformation = transformations[key];
    type = typeof transformation;
    result[key] = type === 'function' ? transformation(object[key]) : transformation && type === 'object' ? evolve(transformation, object[key]) : object[key];
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (evolve);

/***/ }),

/***/ "./node_modules/ramda/es/filter.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/filter.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_filter_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_filter.js */ "./node_modules/ramda/es/internal/_filter.js");
/* harmony import */ var _internal_isObject_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_isObject.js */ "./node_modules/ramda/es/internal/_isObject.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _internal_xfilter_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./internal/_xfilter.js */ "./node_modules/ramda/es/internal/_xfilter.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");








/**
 * Takes a predicate and a `Filterable`, and returns a new filterable of the
 * same type containing the members of the given filterable which satisfy the
 * given predicate. Filterable objects include plain objects or any object
 * that has a filter method such as `Array`.
 *
 * Dispatches to the `filter` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Filterable f => (a -> Boolean) -> f a -> f a
 * @param {Function} pred
 * @param {Array} filterable
 * @return {Array} Filterable
 * @see R.reject, R.transduce, R.addIndex
 * @example
 *
 *      const isEven = n => n % 2 === 0;
 *
 *      R.filter(isEven, [1, 2, 3, 4]); //=> [2, 4]
 *
 *      R.filter(isEven, {a: 1, b: 2, c: 3, d: 4}); //=> {b: 2, d: 4}
 */
var filter = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['filter'], _internal_xfilter_js__WEBPACK_IMPORTED_MODULE_5__["default"], function (pred, filterable) {
  return Object(_internal_isObject_js__WEBPACK_IMPORTED_MODULE_3__["default"])(filterable) ? Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_4__["default"])(function (acc, key) {
    if (pred(filterable[key])) {
      acc[key] = filterable[key];
    }
    return acc;
  }, {}, Object(_keys_js__WEBPACK_IMPORTED_MODULE_6__["default"])(filterable)) :
  // else
  Object(_internal_filter_js__WEBPACK_IMPORTED_MODULE_2__["default"])(pred, filterable);
}));
/* harmony default export */ __webpack_exports__["default"] = (filter);

/***/ }),

/***/ "./node_modules/ramda/es/find.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/find.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xfind_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xfind.js */ "./node_modules/ramda/es/internal/_xfind.js");




/**
 * Returns the first element of the list which matches the predicate, or
 * `undefined` if no element matches.
 *
 * Dispatches to the `find` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> a | undefined
 * @param {Function} fn The predicate function used to determine if the element is the
 *        desired one.
 * @param {Array} list The array to consider.
 * @return {Object} The element found, or `undefined`.
 * @see R.transduce
 * @example
 *
 *      const xs = [{a: 1}, {a: 2}, {a: 3}];
 *      R.find(R.propEq('a', 2))(xs); //=> {a: 2}
 *      R.find(R.propEq('a', 4))(xs); //=> undefined
 */
var find = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['find'], _internal_xfind_js__WEBPACK_IMPORTED_MODULE_2__["default"], function find(fn, list) {
  var idx = 0;
  var len = list.length;
  while (idx < len) {
    if (fn(list[idx])) {
      return list[idx];
    }
    idx += 1;
  }
}));
/* harmony default export */ __webpack_exports__["default"] = (find);

/***/ }),

/***/ "./node_modules/ramda/es/findIndex.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/findIndex.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xfindIndex_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xfindIndex.js */ "./node_modules/ramda/es/internal/_xfindIndex.js");




/**
 * Returns the index of the first element of the list which matches the
 * predicate, or `-1` if no element matches.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category List
 * @sig (a -> Boolean) -> [a] -> Number
 * @param {Function} fn The predicate function used to determine if the element is the
 * desired one.
 * @param {Array} list The array to consider.
 * @return {Number} The index of the element found, or `-1`.
 * @see R.transduce
 * @example
 *
 *      const xs = [{a: 1}, {a: 2}, {a: 3}];
 *      R.findIndex(R.propEq('a', 2))(xs); //=> 1
 *      R.findIndex(R.propEq('a', 4))(xs); //=> -1
 */
var findIndex = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xfindIndex_js__WEBPACK_IMPORTED_MODULE_2__["default"], function findIndex(fn, list) {
  var idx = 0;
  var len = list.length;
  while (idx < len) {
    if (fn(list[idx])) {
      return idx;
    }
    idx += 1;
  }
  return -1;
}));
/* harmony default export */ __webpack_exports__["default"] = (findIndex);

/***/ }),

/***/ "./node_modules/ramda/es/findLast.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/findLast.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xfindLast_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xfindLast.js */ "./node_modules/ramda/es/internal/_xfindLast.js");




/**
 * Returns the last element of the list which matches the predicate, or
 * `undefined` if no element matches.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category List
 * @sig (a -> Boolean) -> [a] -> a | undefined
 * @param {Function} fn The predicate function used to determine if the element is the
 * desired one.
 * @param {Array} list The array to consider.
 * @return {Object} The element found, or `undefined`.
 * @see R.transduce
 * @example
 *
 *      const xs = [{a: 1, b: 0}, {a:1, b: 1}];
 *      R.findLast(R.propEq('a', 1))(xs); //=> {a: 1, b: 1}
 *      R.findLast(R.propEq('a', 4))(xs); //=> undefined
 */
var findLast = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xfindLast_js__WEBPACK_IMPORTED_MODULE_2__["default"], function findLast(fn, list) {
  var idx = list.length - 1;
  while (idx >= 0) {
    if (fn(list[idx])) {
      return list[idx];
    }
    idx -= 1;
  }
}));
/* harmony default export */ __webpack_exports__["default"] = (findLast);

/***/ }),

/***/ "./node_modules/ramda/es/findLastIndex.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/findLastIndex.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xfindLastIndex_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xfindLastIndex.js */ "./node_modules/ramda/es/internal/_xfindLastIndex.js");




/**
 * Returns the index of the last element of the list which matches the
 * predicate, or `-1` if no element matches.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category List
 * @sig (a -> Boolean) -> [a] -> Number
 * @param {Function} fn The predicate function used to determine if the element is the
 * desired one.
 * @param {Array} list The array to consider.
 * @return {Number} The index of the element found, or `-1`.
 * @see R.transduce
 * @example
 *
 *      const xs = [{a: 1, b: 0}, {a:1, b: 1}];
 *      R.findLastIndex(R.propEq('a', 1))(xs); //=> 1
 *      R.findLastIndex(R.propEq('a', 4))(xs); //=> -1
 */
var findLastIndex = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xfindLastIndex_js__WEBPACK_IMPORTED_MODULE_2__["default"], function findLastIndex(fn, list) {
  var idx = list.length - 1;
  while (idx >= 0) {
    if (fn(list[idx])) {
      return idx;
    }
    idx -= 1;
  }
  return -1;
}));
/* harmony default export */ __webpack_exports__["default"] = (findLastIndex);

/***/ }),

/***/ "./node_modules/ramda/es/flatten.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/flatten.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_makeFlat_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_makeFlat.js */ "./node_modules/ramda/es/internal/_makeFlat.js");



/**
 * Returns a new list by pulling every item out of it (and all its sub-arrays)
 * and putting them in a new array, depth-first.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [b]
 * @param {Array} list The array to consider.
 * @return {Array} The flattened list.
 * @see R.unnest
 * @example
 *
 *      R.flatten([1, 2, [3, 4], 5, [6, [7, 8, [9, [10, 11], 12]]]]);
 *      //=> [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
 */
var flatten = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_makeFlat_js__WEBPACK_IMPORTED_MODULE_1__["default"])(true));
/* harmony default export */ __webpack_exports__["default"] = (flatten);

/***/ }),

/***/ "./node_modules/ramda/es/flip.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/flip.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");



/**
 * Returns a new function much like the supplied one, except that the first two
 * arguments' order is reversed.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig ((a, b, c, ...) -> z) -> (b -> a -> c -> ... -> z)
 * @param {Function} fn The function to invoke with its first two parameters reversed.
 * @return {*} The result of invoking `fn` with its first two parameters' order reversed.
 * @example
 *
 *      const mergeThree = (a, b, c) => [].concat(a, b, c);
 *
 *      mergeThree(1, 2, 3); //=> [1, 2, 3]
 *
 *      R.flip(mergeThree)(1, 2, 3); //=> [2, 1, 3]
 * @symb R.flip(f)(a, b, c) = f(b, a, c)
 */
var flip = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function flip(fn) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(fn.length, function (a, b) {
    var args = Array.prototype.slice.call(arguments, 0);
    args[0] = b;
    args[1] = a;
    return fn.apply(this, args);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (flip);

/***/ }),

/***/ "./node_modules/ramda/es/forEach.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/forEach.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_checkForMethod.js */ "./node_modules/ramda/es/internal/_checkForMethod.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Iterate over an input `list`, calling a provided function `fn` for each
 * element in the list.
 *
 * `fn` receives one argument: *(value)*.
 *
 * Note: `R.forEach` does not skip deleted or unassigned indices (sparse
 * arrays), unlike the native `Array.prototype.forEach` method. For more
 * details on this behavior, see:
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/forEach#Description
 *
 * Also note that, unlike `Array.prototype.forEach`, Ramda's `forEach` returns
 * the original array. In some libraries this function is named `each`.
 *
 * Dispatches to the `forEach` method of the second argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category List
 * @sig (a -> *) -> [a] -> [a]
 * @param {Function} fn The function to invoke. Receives one argument, `value`.
 * @param {Array} list The list to iterate over.
 * @return {Array} The original list.
 * @see R.addIndex
 * @example
 *
 *      const printXPlusFive = x => console.log(x + 5);
 *      R.forEach(printXPlusFive, [1, 2, 3]); //=> [1, 2, 3]
 *      // logs 6
 *      // logs 7
 *      // logs 8
 * @symb R.forEach(f, [a, b, c]) = [a, b, c]
 */
var forEach = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__["default"])('forEach', function forEach(fn, list) {
  var len = list.length;
  var idx = 0;
  while (idx < len) {
    fn(list[idx]);
    idx += 1;
  }
  return list;
}));
/* harmony default export */ __webpack_exports__["default"] = (forEach);

/***/ }),

/***/ "./node_modules/ramda/es/forEachObjIndexed.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/forEachObjIndexed.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");



/**
 * Iterate over an input `object`, calling a provided function `fn` for each
 * key and value in the object.
 *
 * `fn` receives three argument: *(value, key, obj)*.
 *
 * @func
 * @memberOf R
 * @since v0.23.0
 * @category Object
 * @sig ((a, String, StrMap a) -> Any) -> StrMap a -> StrMap a
 * @param {Function} fn The function to invoke. Receives three argument, `value`, `key`, `obj`.
 * @param {Object} obj The object to iterate over.
 * @return {Object} The original object.
 * @example
 *
 *      const printKeyConcatValue = (value, key) => console.log(key + ':' + value);
 *      R.forEachObjIndexed(printKeyConcatValue, {x: 1, y: 2}); //=> {x: 1, y: 2}
 *      // logs x:1
 *      // logs y:2
 * @symb R.forEachObjIndexed(f, {x: a, y: b}) = {x: a, y: b}
 */
var forEachObjIndexed = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function forEachObjIndexed(fn, obj) {
  var keyList = Object(_keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj);
  var idx = 0;
  while (idx < keyList.length) {
    var key = keyList[idx];
    fn(obj[key], key, obj);
    idx += 1;
  }
  return obj;
});
/* harmony default export */ __webpack_exports__["default"] = (forEachObjIndexed);

/***/ }),

/***/ "./node_modules/ramda/es/fromPairs.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/fromPairs.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Creates a new object from a list key-value pairs. If a key appears in
 * multiple pairs, the rightmost pair is included in the object.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category List
 * @sig [[k,v]] -> {k: v}
 * @param {Array} pairs An array of two-element arrays that will be the keys and values of the output object.
 * @return {Object} The object made by pairing up `keys` and `values`.
 * @see R.toPairs, R.pair
 * @example
 *
 *      R.fromPairs([['a', 1], ['b', 2], ['c', 3]]); //=> {a: 1, b: 2, c: 3}
 */
var fromPairs = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function fromPairs(pairs) {
  var result = {};
  var idx = 0;
  while (idx < pairs.length) {
    result[pairs[idx][0]] = pairs[idx][1];
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (fromPairs);

/***/ }),

/***/ "./node_modules/ramda/es/groupBy.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/groupBy.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_checkForMethod.js */ "./node_modules/ramda/es/internal/_checkForMethod.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduceBy_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./reduceBy.js */ "./node_modules/ramda/es/reduceBy.js");




/**
 * Splits a list into sub-lists stored in an object, based on the result of
 * calling a String-returning function on each element, and grouping the
 * results according to values returned.
 *
 * Dispatches to the `groupBy` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig (a -> String) -> [a] -> {String: [a]}
 * @param {Function} fn Function :: a -> String
 * @param {Array} list The array to group
 * @return {Object} An object with the output of `fn` for keys, mapped to arrays of elements
 *         that produced that key when passed to `fn`.
 * @see R.reduceBy, R.transduce
 * @example
 *
 *      const byGrade = R.groupBy(function(student) {
 *        const score = student.score;
 *        return score < 65 ? 'F' :
 *               score < 70 ? 'D' :
 *               score < 80 ? 'C' :
 *               score < 90 ? 'B' : 'A';
 *      });
 *      const students = [{name: 'Abby', score: 84},
 *                      {name: 'Eddy', score: 58},
 *                      // ...
 *                      {name: 'Jack', score: 69}];
 *      byGrade(students);
 *      // {
 *      //   'A': [{name: 'Dianne', score: 99}],
 *      //   'B': [{name: 'Abby', score: 84}]
 *      //   // ...,
 *      //   'F': [{name: 'Eddy', score: 58}]
 *      // }
 */
var groupBy = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__["default"])('groupBy', /*#__PURE__*/Object(_reduceBy_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function (acc, item) {
  if (acc == null) {
    acc = [];
  }
  acc.push(item);
  return acc;
}, null)));
/* harmony default export */ __webpack_exports__["default"] = (groupBy);

/***/ }),

/***/ "./node_modules/ramda/es/groupWith.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/groupWith.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Takes a list and returns a list of lists where each sublist's elements are
 * all satisfied pairwise comparison according to the provided function.
 * Only adjacent elements are passed to the comparison function.
 *
 * @func
 * @memberOf R
 * @since v0.21.0
 * @category List
 * @sig ((a, a) → Boolean) → [a] → [[a]]
 * @param {Function} fn Function for determining whether two given (adjacent)
 *        elements should be in the same group
 * @param {Array} list The array to group. Also accepts a string, which will be
 *        treated as a list of characters.
 * @return {List} A list that contains sublists of elements,
 *         whose concatenations are equal to the original list.
 * @example
 *
 * R.groupWith(R.equals, [0, 1, 1, 2, 3, 5, 8, 13, 21])
 * //=> [[0], [1, 1], [2], [3], [5], [8], [13], [21]]
 *
 * R.groupWith((a, b) => a + 1 === b, [0, 1, 1, 2, 3, 5, 8, 13, 21])
 * //=> [[0, 1], [1, 2, 3], [5], [8], [13], [21]]
 *
 * R.groupWith((a, b) => a % 2 === b % 2, [0, 1, 1, 2, 3, 5, 8, 13, 21])
 * //=> [[0], [1, 1], [2], [3, 5], [8], [13, 21]]
 *
 * R.groupWith(R.eqBy(isVowel), 'aestiou')
 * //=> ['ae', 'st', 'iou']
 */
var groupWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (fn, list) {
  var res = [];
  var idx = 0;
  var len = list.length;
  while (idx < len) {
    var nextidx = idx + 1;
    while (nextidx < len && fn(list[nextidx - 1], list[nextidx])) {
      nextidx += 1;
    }
    res.push(list.slice(idx, nextidx));
    idx = nextidx;
  }
  return res;
});
/* harmony default export */ __webpack_exports__["default"] = (groupWith);

/***/ }),

/***/ "./node_modules/ramda/es/gt.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/gt.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns `true` if the first argument is greater than the second; `false`
 * otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord a => a -> a -> Boolean
 * @param {*} a
 * @param {*} b
 * @return {Boolean}
 * @see R.lt
 * @example
 *
 *      R.gt(2, 1); //=> true
 *      R.gt(2, 2); //=> false
 *      R.gt(2, 3); //=> false
 *      R.gt('a', 'z'); //=> false
 *      R.gt('z', 'a'); //=> true
 */
var gt = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function gt(a, b) {
  return a > b;
});
/* harmony default export */ __webpack_exports__["default"] = (gt);

/***/ }),

/***/ "./node_modules/ramda/es/gte.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/gte.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns `true` if the first argument is greater than or equal to the second;
 * `false` otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord a => a -> a -> Boolean
 * @param {Number} a
 * @param {Number} b
 * @return {Boolean}
 * @see R.lte
 * @example
 *
 *      R.gte(2, 1); //=> true
 *      R.gte(2, 2); //=> true
 *      R.gte(2, 3); //=> false
 *      R.gte('a', 'z'); //=> false
 *      R.gte('z', 'a'); //=> true
 */
var gte = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function gte(a, b) {
  return a >= b;
});
/* harmony default export */ __webpack_exports__["default"] = (gte);

/***/ }),

/***/ "./node_modules/ramda/es/has.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/has.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _hasPath_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./hasPath.js */ "./node_modules/ramda/es/hasPath.js");



/**
 * Returns whether or not an object has an own property with the specified name
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category Object
 * @sig s -> {s: x} -> Boolean
 * @param {String} prop The name of the property to check for.
 * @param {Object} obj The object to query.
 * @return {Boolean} Whether the property exists.
 * @example
 *
 *      const hasName = R.has('name');
 *      hasName({name: 'alice'});   //=> true
 *      hasName({name: 'bob'});     //=> true
 *      hasName({});                //=> false
 *
 *      const point = {x: 0, y: 0};
 *      const pointHas = R.has(R.__, point);
 *      pointHas('x');  //=> true
 *      pointHas('y');  //=> true
 *      pointHas('z');  //=> false
 */
var has = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function has(prop, obj) {
  return Object(_hasPath_js__WEBPACK_IMPORTED_MODULE_1__["default"])([prop], obj);
});
/* harmony default export */ __webpack_exports__["default"] = (has);

/***/ }),

/***/ "./node_modules/ramda/es/hasIn.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/hasIn.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns whether or not an object or its prototype chain has a property with
 * the specified name
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category Object
 * @sig s -> {s: x} -> Boolean
 * @param {String} prop The name of the property to check for.
 * @param {Object} obj The object to query.
 * @return {Boolean} Whether the property exists.
 * @example
 *
 *      function Rectangle(width, height) {
 *        this.width = width;
 *        this.height = height;
 *      }
 *      Rectangle.prototype.area = function() {
 *        return this.width * this.height;
 *      };
 *
 *      const square = new Rectangle(2, 2);
 *      R.hasIn('width', square);  //=> true
 *      R.hasIn('area', square);  //=> true
 */
var hasIn = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function hasIn(prop, obj) {
  return prop in obj;
});
/* harmony default export */ __webpack_exports__["default"] = (hasIn);

/***/ }),

/***/ "./node_modules/ramda/es/hasPath.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/hasPath.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");



/**
 * Returns whether or not a path exists in an object. Only the object's
 * own properties are checked.
 *
 * @func
 * @memberOf R
 * @since v0.26.0
 * @category Object
 * @typedefn Idx = String | Int
 * @sig [Idx] -> {a} -> Boolean
 * @param {Array} path The path to use.
 * @param {Object} obj The object to check the path in.
 * @return {Boolean} Whether the path exists.
 * @see R.has
 * @example
 *
 *      R.hasPath(['a', 'b'], {a: {b: 2}});         // => true
 *      R.hasPath(['a', 'b'], {a: {b: undefined}}); // => true
 *      R.hasPath(['a', 'b'], {a: {c: 2}});         // => false
 *      R.hasPath(['a', 'b'], {});                  // => false
 */
var hasPath = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function hasPath(_path, obj) {
  if (_path.length === 0) {
    return false;
  }
  var val = obj;
  var idx = 0;
  while (idx < _path.length) {
    if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_path[idx], val)) {
      val = val[_path[idx]];
      idx += 1;
    } else {
      return false;
    }
  }
  return true;
});
/* harmony default export */ __webpack_exports__["default"] = (hasPath);

/***/ }),

/***/ "./node_modules/ramda/es/head.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/head.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _nth_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./nth.js */ "./node_modules/ramda/es/nth.js");


/**
 * Returns the first element of the given list or string. In some libraries
 * this function is named `first`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> a | Undefined
 * @sig String -> String
 * @param {Array|String} list
 * @return {*}
 * @see R.tail, R.init, R.last
 * @example
 *
 *      R.head(['fi', 'fo', 'fum']); //=> 'fi'
 *      R.head([]); //=> undefined
 *
 *      R.head('abc'); //=> 'a'
 *      R.head(''); //=> ''
 */
var head = /*#__PURE__*/Object(_nth_js__WEBPACK_IMPORTED_MODULE_0__["default"])(0);
/* harmony default export */ __webpack_exports__["default"] = (head);

/***/ }),

/***/ "./node_modules/ramda/es/identical.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/identical.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_objectIs_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_objectIs.js */ "./node_modules/ramda/es/internal/_objectIs.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns true if its arguments are identical, false otherwise. Values are
 * identical if they reference the same memory. `NaN` is identical to `NaN`;
 * `0` and `-0` are not identical.
 *
 * Note this is merely a curried version of ES6 `Object.is`.
 *
 * @func
 * @memberOf R
 * @since v0.15.0
 * @category Relation
 * @sig a -> a -> Boolean
 * @param {*} a
 * @param {*} b
 * @return {Boolean}
 * @example
 *
 *      const o = {};
 *      R.identical(o, o); //=> true
 *      R.identical(1, 1); //=> true
 *      R.identical(1, '1'); //=> false
 *      R.identical([], []); //=> false
 *      R.identical(0, -0); //=> false
 *      R.identical(NaN, NaN); //=> true
 */
var identical = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_internal_objectIs_js__WEBPACK_IMPORTED_MODULE_0__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (identical);

/***/ }),

/***/ "./node_modules/ramda/es/identity.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/identity.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_identity_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_identity.js */ "./node_modules/ramda/es/internal/_identity.js");



/**
 * A function that does nothing but return the parameter supplied to it. Good
 * as a default or placeholder function.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig a -> a
 * @param {*} x The value to return.
 * @return {*} The input value, `x`.
 * @example
 *
 *      R.identity(1); //=> 1
 *
 *      const obj = {};
 *      R.identity(obj) === obj; //=> true
 * @symb R.identity(a) = a
 */
var identity = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(_internal_identity_js__WEBPACK_IMPORTED_MODULE_1__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (identity);

/***/ }),

/***/ "./node_modules/ramda/es/ifElse.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/ifElse.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");



/**
 * Creates a function that will process either the `onTrue` or the `onFalse`
 * function depending upon the result of the `condition` predicate.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Logic
 * @sig (*... -> Boolean) -> (*... -> *) -> (*... -> *) -> (*... -> *)
 * @param {Function} condition A predicate function
 * @param {Function} onTrue A function to invoke when the `condition` evaluates to a truthy value.
 * @param {Function} onFalse A function to invoke when the `condition` evaluates to a falsy value.
 * @return {Function} A new function that will process either the `onTrue` or the `onFalse`
 *                    function depending upon the result of the `condition` predicate.
 * @see R.unless, R.when, R.cond
 * @example
 *
 *      const incCount = R.ifElse(
 *        R.has('count'),
 *        R.over(R.lensProp('count'), R.inc),
 *        R.assoc('count', 1)
 *      );
 *      incCount({});           //=> { count: 1 }
 *      incCount({ count: 1 }); //=> { count: 2 }
 */
var ifElse = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function ifElse(condition, onTrue, onFalse) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Math.max(condition.length, onTrue.length, onFalse.length), function _ifElse() {
    return condition.apply(this, arguments) ? onTrue.apply(this, arguments) : onFalse.apply(this, arguments);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (ifElse);

/***/ }),

/***/ "./node_modules/ramda/es/inc.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/inc.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _add_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./add.js */ "./node_modules/ramda/es/add.js");


/**
 * Increments its argument.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Math
 * @sig Number -> Number
 * @param {Number} n
 * @return {Number} n + 1
 * @see R.dec
 * @example
 *
 *      R.inc(42); //=> 43
 */
var inc = /*#__PURE__*/Object(_add_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1);
/* harmony default export */ __webpack_exports__["default"] = (inc);

/***/ }),

/***/ "./node_modules/ramda/es/includes.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/includes.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includes_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includes.js */ "./node_modules/ramda/es/internal/_includes.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns `true` if the specified value is equal, in [`R.equals`](#equals)
 * terms, to at least one element of the given list; `false` otherwise.
 * Works also with strings.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig a -> [a] -> Boolean
 * @param {Object} a The item to compare against.
 * @param {Array} list The array to consider.
 * @return {Boolean} `true` if an equivalent item is in the list, `false` otherwise.
 * @see R.any
 * @example
 *
 *      R.includes(3, [1, 2, 3]); //=> true
 *      R.includes(4, [1, 2, 3]); //=> false
 *      R.includes({ name: 'Fred' }, [{ name: 'Fred' }]); //=> true
 *      R.includes([42], [[42]]); //=> true
 *      R.includes('ba', 'banana'); //=>true
 */
var includes = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_internal_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (includes);

/***/ }),

/***/ "./node_modules/ramda/es/index.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/index.js ***!
  \****************************************/
/*! exports provided: F, T, __, add, addIndex, adjust, all, allPass, always, and, any, anyPass, ap, aperture, append, apply, applySpec, applyTo, ascend, assoc, assocPath, binary, bind, both, call, chain, clamp, clone, comparator, complement, compose, composeK, composeP, composeWith, concat, cond, construct, constructN, contains, converge, countBy, curry, curryN, dec, defaultTo, descend, difference, differenceWith, dissoc, dissocPath, divide, drop, dropLast, dropLastWhile, dropRepeats, dropRepeatsWith, dropWhile, either, empty, endsWith, eqBy, eqProps, equals, evolve, filter, find, findIndex, findLast, findLastIndex, flatten, flip, forEach, forEachObjIndexed, fromPairs, groupBy, groupWith, gt, gte, has, hasIn, hasPath, head, identical, identity, ifElse, inc, includes, indexBy, indexOf, init, innerJoin, insert, insertAll, intersection, intersperse, into, invert, invertObj, invoker, is, isEmpty, isNil, join, juxt, keys, keysIn, last, lastIndexOf, length, lens, lensIndex, lensPath, lensProp, lift, liftN, lt, lte, map, mapAccum, mapAccumRight, mapObjIndexed, match, mathMod, max, maxBy, mean, median, memoizeWith, merge, mergeAll, mergeDeepLeft, mergeDeepRight, mergeDeepWith, mergeDeepWithKey, mergeLeft, mergeRight, mergeWith, mergeWithKey, min, minBy, modulo, move, multiply, nAry, negate, none, not, nth, nthArg, o, objOf, of, omit, once, or, otherwise, over, pair, partial, partialRight, partition, path, pathEq, pathOr, pathSatisfies, pick, pickAll, pickBy, pipe, pipeK, pipeP, pipeWith, pluck, prepend, product, project, prop, propEq, propIs, propOr, propSatisfies, props, range, reduce, reduceBy, reduceRight, reduceWhile, reduced, reject, remove, repeat, replace, reverse, scan, sequence, set, slice, sort, sortBy, sortWith, split, splitAt, splitEvery, splitWhen, startsWith, subtract, sum, symmetricDifference, symmetricDifferenceWith, tail, take, takeLast, takeLastWhile, takeWhile, tap, test, then, times, toLower, toPairs, toPairsIn, toString, toUpper, transduce, transpose, traverse, trim, tryCatch, type, unapply, unary, uncurryN, unfold, union, unionWith, uniq, uniqBy, uniqWith, unless, unnest, until, update, useWith, values, valuesIn, view, when, where, whereEq, without, xprod, zip, zipObj, zipWith, thunkify */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _F_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./F.js */ "./node_modules/ramda/es/F.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "F", function() { return _F_js__WEBPACK_IMPORTED_MODULE_0__["default"]; });

/* harmony import */ var _T_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./T.js */ "./node_modules/ramda/es/T.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "T", function() { return _T_js__WEBPACK_IMPORTED_MODULE_1__["default"]; });

/* harmony import */ var _js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./__.js */ "./node_modules/ramda/es/__.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "__", function() { return _js__WEBPACK_IMPORTED_MODULE_2__["default"]; });

/* harmony import */ var _add_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./add.js */ "./node_modules/ramda/es/add.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "add", function() { return _add_js__WEBPACK_IMPORTED_MODULE_3__["default"]; });

/* harmony import */ var _addIndex_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./addIndex.js */ "./node_modules/ramda/es/addIndex.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "addIndex", function() { return _addIndex_js__WEBPACK_IMPORTED_MODULE_4__["default"]; });

/* harmony import */ var _adjust_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./adjust.js */ "./node_modules/ramda/es/adjust.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "adjust", function() { return _adjust_js__WEBPACK_IMPORTED_MODULE_5__["default"]; });

/* harmony import */ var _all_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./all.js */ "./node_modules/ramda/es/all.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "all", function() { return _all_js__WEBPACK_IMPORTED_MODULE_6__["default"]; });

/* harmony import */ var _allPass_js__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./allPass.js */ "./node_modules/ramda/es/allPass.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "allPass", function() { return _allPass_js__WEBPACK_IMPORTED_MODULE_7__["default"]; });

/* harmony import */ var _always_js__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./always.js */ "./node_modules/ramda/es/always.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "always", function() { return _always_js__WEBPACK_IMPORTED_MODULE_8__["default"]; });

/* harmony import */ var _and_js__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./and.js */ "./node_modules/ramda/es/and.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "and", function() { return _and_js__WEBPACK_IMPORTED_MODULE_9__["default"]; });

/* harmony import */ var _any_js__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./any.js */ "./node_modules/ramda/es/any.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "any", function() { return _any_js__WEBPACK_IMPORTED_MODULE_10__["default"]; });

/* harmony import */ var _anyPass_js__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./anyPass.js */ "./node_modules/ramda/es/anyPass.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "anyPass", function() { return _anyPass_js__WEBPACK_IMPORTED_MODULE_11__["default"]; });

/* harmony import */ var _ap_js__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./ap.js */ "./node_modules/ramda/es/ap.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ap", function() { return _ap_js__WEBPACK_IMPORTED_MODULE_12__["default"]; });

/* harmony import */ var _aperture_js__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./aperture.js */ "./node_modules/ramda/es/aperture.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "aperture", function() { return _aperture_js__WEBPACK_IMPORTED_MODULE_13__["default"]; });

/* harmony import */ var _append_js__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./append.js */ "./node_modules/ramda/es/append.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "append", function() { return _append_js__WEBPACK_IMPORTED_MODULE_14__["default"]; });

/* harmony import */ var _apply_js__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./apply.js */ "./node_modules/ramda/es/apply.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "apply", function() { return _apply_js__WEBPACK_IMPORTED_MODULE_15__["default"]; });

/* harmony import */ var _applySpec_js__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./applySpec.js */ "./node_modules/ramda/es/applySpec.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "applySpec", function() { return _applySpec_js__WEBPACK_IMPORTED_MODULE_16__["default"]; });

/* harmony import */ var _applyTo_js__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./applyTo.js */ "./node_modules/ramda/es/applyTo.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "applyTo", function() { return _applyTo_js__WEBPACK_IMPORTED_MODULE_17__["default"]; });

/* harmony import */ var _ascend_js__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./ascend.js */ "./node_modules/ramda/es/ascend.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ascend", function() { return _ascend_js__WEBPACK_IMPORTED_MODULE_18__["default"]; });

/* harmony import */ var _assoc_js__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./assoc.js */ "./node_modules/ramda/es/assoc.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "assoc", function() { return _assoc_js__WEBPACK_IMPORTED_MODULE_19__["default"]; });

/* harmony import */ var _assocPath_js__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./assocPath.js */ "./node_modules/ramda/es/assocPath.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "assocPath", function() { return _assocPath_js__WEBPACK_IMPORTED_MODULE_20__["default"]; });

/* harmony import */ var _binary_js__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./binary.js */ "./node_modules/ramda/es/binary.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "binary", function() { return _binary_js__WEBPACK_IMPORTED_MODULE_21__["default"]; });

/* harmony import */ var _bind_js__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./bind.js */ "./node_modules/ramda/es/bind.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "bind", function() { return _bind_js__WEBPACK_IMPORTED_MODULE_22__["default"]; });

/* harmony import */ var _both_js__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./both.js */ "./node_modules/ramda/es/both.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "both", function() { return _both_js__WEBPACK_IMPORTED_MODULE_23__["default"]; });

/* harmony import */ var _call_js__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./call.js */ "./node_modules/ramda/es/call.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "call", function() { return _call_js__WEBPACK_IMPORTED_MODULE_24__["default"]; });

/* harmony import */ var _chain_js__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./chain.js */ "./node_modules/ramda/es/chain.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "chain", function() { return _chain_js__WEBPACK_IMPORTED_MODULE_25__["default"]; });

/* harmony import */ var _clamp_js__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./clamp.js */ "./node_modules/ramda/es/clamp.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "clamp", function() { return _clamp_js__WEBPACK_IMPORTED_MODULE_26__["default"]; });

/* harmony import */ var _clone_js__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./clone.js */ "./node_modules/ramda/es/clone.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "clone", function() { return _clone_js__WEBPACK_IMPORTED_MODULE_27__["default"]; });

/* harmony import */ var _comparator_js__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./comparator.js */ "./node_modules/ramda/es/comparator.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "comparator", function() { return _comparator_js__WEBPACK_IMPORTED_MODULE_28__["default"]; });

/* harmony import */ var _complement_js__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./complement.js */ "./node_modules/ramda/es/complement.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "complement", function() { return _complement_js__WEBPACK_IMPORTED_MODULE_29__["default"]; });

/* harmony import */ var _compose_js__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ./compose.js */ "./node_modules/ramda/es/compose.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "compose", function() { return _compose_js__WEBPACK_IMPORTED_MODULE_30__["default"]; });

/* harmony import */ var _composeK_js__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ./composeK.js */ "./node_modules/ramda/es/composeK.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "composeK", function() { return _composeK_js__WEBPACK_IMPORTED_MODULE_31__["default"]; });

/* harmony import */ var _composeP_js__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ./composeP.js */ "./node_modules/ramda/es/composeP.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "composeP", function() { return _composeP_js__WEBPACK_IMPORTED_MODULE_32__["default"]; });

/* harmony import */ var _composeWith_js__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ./composeWith.js */ "./node_modules/ramda/es/composeWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "composeWith", function() { return _composeWith_js__WEBPACK_IMPORTED_MODULE_33__["default"]; });

/* harmony import */ var _concat_js__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! ./concat.js */ "./node_modules/ramda/es/concat.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "concat", function() { return _concat_js__WEBPACK_IMPORTED_MODULE_34__["default"]; });

/* harmony import */ var _cond_js__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! ./cond.js */ "./node_modules/ramda/es/cond.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "cond", function() { return _cond_js__WEBPACK_IMPORTED_MODULE_35__["default"]; });

/* harmony import */ var _construct_js__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! ./construct.js */ "./node_modules/ramda/es/construct.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "construct", function() { return _construct_js__WEBPACK_IMPORTED_MODULE_36__["default"]; });

/* harmony import */ var _constructN_js__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! ./constructN.js */ "./node_modules/ramda/es/constructN.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "constructN", function() { return _constructN_js__WEBPACK_IMPORTED_MODULE_37__["default"]; });

/* harmony import */ var _contains_js__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(/*! ./contains.js */ "./node_modules/ramda/es/contains.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "contains", function() { return _contains_js__WEBPACK_IMPORTED_MODULE_38__["default"]; });

/* harmony import */ var _converge_js__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(/*! ./converge.js */ "./node_modules/ramda/es/converge.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "converge", function() { return _converge_js__WEBPACK_IMPORTED_MODULE_39__["default"]; });

/* harmony import */ var _countBy_js__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(/*! ./countBy.js */ "./node_modules/ramda/es/countBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "countBy", function() { return _countBy_js__WEBPACK_IMPORTED_MODULE_40__["default"]; });

/* harmony import */ var _curry_js__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(/*! ./curry.js */ "./node_modules/ramda/es/curry.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "curry", function() { return _curry_js__WEBPACK_IMPORTED_MODULE_41__["default"]; });

/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "curryN", function() { return _curryN_js__WEBPACK_IMPORTED_MODULE_42__["default"]; });

/* harmony import */ var _dec_js__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(/*! ./dec.js */ "./node_modules/ramda/es/dec.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dec", function() { return _dec_js__WEBPACK_IMPORTED_MODULE_43__["default"]; });

/* harmony import */ var _defaultTo_js__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(/*! ./defaultTo.js */ "./node_modules/ramda/es/defaultTo.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "defaultTo", function() { return _defaultTo_js__WEBPACK_IMPORTED_MODULE_44__["default"]; });

/* harmony import */ var _descend_js__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(/*! ./descend.js */ "./node_modules/ramda/es/descend.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "descend", function() { return _descend_js__WEBPACK_IMPORTED_MODULE_45__["default"]; });

/* harmony import */ var _difference_js__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(/*! ./difference.js */ "./node_modules/ramda/es/difference.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "difference", function() { return _difference_js__WEBPACK_IMPORTED_MODULE_46__["default"]; });

/* harmony import */ var _differenceWith_js__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(/*! ./differenceWith.js */ "./node_modules/ramda/es/differenceWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "differenceWith", function() { return _differenceWith_js__WEBPACK_IMPORTED_MODULE_47__["default"]; });

/* harmony import */ var _dissoc_js__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(/*! ./dissoc.js */ "./node_modules/ramda/es/dissoc.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dissoc", function() { return _dissoc_js__WEBPACK_IMPORTED_MODULE_48__["default"]; });

/* harmony import */ var _dissocPath_js__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(/*! ./dissocPath.js */ "./node_modules/ramda/es/dissocPath.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dissocPath", function() { return _dissocPath_js__WEBPACK_IMPORTED_MODULE_49__["default"]; });

/* harmony import */ var _divide_js__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(/*! ./divide.js */ "./node_modules/ramda/es/divide.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "divide", function() { return _divide_js__WEBPACK_IMPORTED_MODULE_50__["default"]; });

/* harmony import */ var _drop_js__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(/*! ./drop.js */ "./node_modules/ramda/es/drop.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "drop", function() { return _drop_js__WEBPACK_IMPORTED_MODULE_51__["default"]; });

/* harmony import */ var _dropLast_js__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(/*! ./dropLast.js */ "./node_modules/ramda/es/dropLast.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dropLast", function() { return _dropLast_js__WEBPACK_IMPORTED_MODULE_52__["default"]; });

/* harmony import */ var _dropLastWhile_js__WEBPACK_IMPORTED_MODULE_53__ = __webpack_require__(/*! ./dropLastWhile.js */ "./node_modules/ramda/es/dropLastWhile.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dropLastWhile", function() { return _dropLastWhile_js__WEBPACK_IMPORTED_MODULE_53__["default"]; });

/* harmony import */ var _dropRepeats_js__WEBPACK_IMPORTED_MODULE_54__ = __webpack_require__(/*! ./dropRepeats.js */ "./node_modules/ramda/es/dropRepeats.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dropRepeats", function() { return _dropRepeats_js__WEBPACK_IMPORTED_MODULE_54__["default"]; });

/* harmony import */ var _dropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_55__ = __webpack_require__(/*! ./dropRepeatsWith.js */ "./node_modules/ramda/es/dropRepeatsWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dropRepeatsWith", function() { return _dropRepeatsWith_js__WEBPACK_IMPORTED_MODULE_55__["default"]; });

/* harmony import */ var _dropWhile_js__WEBPACK_IMPORTED_MODULE_56__ = __webpack_require__(/*! ./dropWhile.js */ "./node_modules/ramda/es/dropWhile.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "dropWhile", function() { return _dropWhile_js__WEBPACK_IMPORTED_MODULE_56__["default"]; });

/* harmony import */ var _either_js__WEBPACK_IMPORTED_MODULE_57__ = __webpack_require__(/*! ./either.js */ "./node_modules/ramda/es/either.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "either", function() { return _either_js__WEBPACK_IMPORTED_MODULE_57__["default"]; });

/* harmony import */ var _empty_js__WEBPACK_IMPORTED_MODULE_58__ = __webpack_require__(/*! ./empty.js */ "./node_modules/ramda/es/empty.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "empty", function() { return _empty_js__WEBPACK_IMPORTED_MODULE_58__["default"]; });

/* harmony import */ var _endsWith_js__WEBPACK_IMPORTED_MODULE_59__ = __webpack_require__(/*! ./endsWith.js */ "./node_modules/ramda/es/endsWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "endsWith", function() { return _endsWith_js__WEBPACK_IMPORTED_MODULE_59__["default"]; });

/* harmony import */ var _eqBy_js__WEBPACK_IMPORTED_MODULE_60__ = __webpack_require__(/*! ./eqBy.js */ "./node_modules/ramda/es/eqBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "eqBy", function() { return _eqBy_js__WEBPACK_IMPORTED_MODULE_60__["default"]; });

/* harmony import */ var _eqProps_js__WEBPACK_IMPORTED_MODULE_61__ = __webpack_require__(/*! ./eqProps.js */ "./node_modules/ramda/es/eqProps.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "eqProps", function() { return _eqProps_js__WEBPACK_IMPORTED_MODULE_61__["default"]; });

/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_62__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "equals", function() { return _equals_js__WEBPACK_IMPORTED_MODULE_62__["default"]; });

/* harmony import */ var _evolve_js__WEBPACK_IMPORTED_MODULE_63__ = __webpack_require__(/*! ./evolve.js */ "./node_modules/ramda/es/evolve.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "evolve", function() { return _evolve_js__WEBPACK_IMPORTED_MODULE_63__["default"]; });

/* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_64__ = __webpack_require__(/*! ./filter.js */ "./node_modules/ramda/es/filter.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "filter", function() { return _filter_js__WEBPACK_IMPORTED_MODULE_64__["default"]; });

/* harmony import */ var _find_js__WEBPACK_IMPORTED_MODULE_65__ = __webpack_require__(/*! ./find.js */ "./node_modules/ramda/es/find.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "find", function() { return _find_js__WEBPACK_IMPORTED_MODULE_65__["default"]; });

/* harmony import */ var _findIndex_js__WEBPACK_IMPORTED_MODULE_66__ = __webpack_require__(/*! ./findIndex.js */ "./node_modules/ramda/es/findIndex.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "findIndex", function() { return _findIndex_js__WEBPACK_IMPORTED_MODULE_66__["default"]; });

/* harmony import */ var _findLast_js__WEBPACK_IMPORTED_MODULE_67__ = __webpack_require__(/*! ./findLast.js */ "./node_modules/ramda/es/findLast.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "findLast", function() { return _findLast_js__WEBPACK_IMPORTED_MODULE_67__["default"]; });

/* harmony import */ var _findLastIndex_js__WEBPACK_IMPORTED_MODULE_68__ = __webpack_require__(/*! ./findLastIndex.js */ "./node_modules/ramda/es/findLastIndex.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "findLastIndex", function() { return _findLastIndex_js__WEBPACK_IMPORTED_MODULE_68__["default"]; });

/* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_69__ = __webpack_require__(/*! ./flatten.js */ "./node_modules/ramda/es/flatten.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "flatten", function() { return _flatten_js__WEBPACK_IMPORTED_MODULE_69__["default"]; });

/* harmony import */ var _flip_js__WEBPACK_IMPORTED_MODULE_70__ = __webpack_require__(/*! ./flip.js */ "./node_modules/ramda/es/flip.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "flip", function() { return _flip_js__WEBPACK_IMPORTED_MODULE_70__["default"]; });

/* harmony import */ var _forEach_js__WEBPACK_IMPORTED_MODULE_71__ = __webpack_require__(/*! ./forEach.js */ "./node_modules/ramda/es/forEach.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "forEach", function() { return _forEach_js__WEBPACK_IMPORTED_MODULE_71__["default"]; });

/* harmony import */ var _forEachObjIndexed_js__WEBPACK_IMPORTED_MODULE_72__ = __webpack_require__(/*! ./forEachObjIndexed.js */ "./node_modules/ramda/es/forEachObjIndexed.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "forEachObjIndexed", function() { return _forEachObjIndexed_js__WEBPACK_IMPORTED_MODULE_72__["default"]; });

/* harmony import */ var _fromPairs_js__WEBPACK_IMPORTED_MODULE_73__ = __webpack_require__(/*! ./fromPairs.js */ "./node_modules/ramda/es/fromPairs.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "fromPairs", function() { return _fromPairs_js__WEBPACK_IMPORTED_MODULE_73__["default"]; });

/* harmony import */ var _groupBy_js__WEBPACK_IMPORTED_MODULE_74__ = __webpack_require__(/*! ./groupBy.js */ "./node_modules/ramda/es/groupBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "groupBy", function() { return _groupBy_js__WEBPACK_IMPORTED_MODULE_74__["default"]; });

/* harmony import */ var _groupWith_js__WEBPACK_IMPORTED_MODULE_75__ = __webpack_require__(/*! ./groupWith.js */ "./node_modules/ramda/es/groupWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "groupWith", function() { return _groupWith_js__WEBPACK_IMPORTED_MODULE_75__["default"]; });

/* harmony import */ var _gt_js__WEBPACK_IMPORTED_MODULE_76__ = __webpack_require__(/*! ./gt.js */ "./node_modules/ramda/es/gt.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "gt", function() { return _gt_js__WEBPACK_IMPORTED_MODULE_76__["default"]; });

/* harmony import */ var _gte_js__WEBPACK_IMPORTED_MODULE_77__ = __webpack_require__(/*! ./gte.js */ "./node_modules/ramda/es/gte.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "gte", function() { return _gte_js__WEBPACK_IMPORTED_MODULE_77__["default"]; });

/* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_78__ = __webpack_require__(/*! ./has.js */ "./node_modules/ramda/es/has.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "has", function() { return _has_js__WEBPACK_IMPORTED_MODULE_78__["default"]; });

/* harmony import */ var _hasIn_js__WEBPACK_IMPORTED_MODULE_79__ = __webpack_require__(/*! ./hasIn.js */ "./node_modules/ramda/es/hasIn.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "hasIn", function() { return _hasIn_js__WEBPACK_IMPORTED_MODULE_79__["default"]; });

/* harmony import */ var _hasPath_js__WEBPACK_IMPORTED_MODULE_80__ = __webpack_require__(/*! ./hasPath.js */ "./node_modules/ramda/es/hasPath.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "hasPath", function() { return _hasPath_js__WEBPACK_IMPORTED_MODULE_80__["default"]; });

/* harmony import */ var _head_js__WEBPACK_IMPORTED_MODULE_81__ = __webpack_require__(/*! ./head.js */ "./node_modules/ramda/es/head.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "head", function() { return _head_js__WEBPACK_IMPORTED_MODULE_81__["default"]; });

/* harmony import */ var _identical_js__WEBPACK_IMPORTED_MODULE_82__ = __webpack_require__(/*! ./identical.js */ "./node_modules/ramda/es/identical.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "identical", function() { return _identical_js__WEBPACK_IMPORTED_MODULE_82__["default"]; });

/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_83__ = __webpack_require__(/*! ./identity.js */ "./node_modules/ramda/es/identity.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "identity", function() { return _identity_js__WEBPACK_IMPORTED_MODULE_83__["default"]; });

/* harmony import */ var _ifElse_js__WEBPACK_IMPORTED_MODULE_84__ = __webpack_require__(/*! ./ifElse.js */ "./node_modules/ramda/es/ifElse.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ifElse", function() { return _ifElse_js__WEBPACK_IMPORTED_MODULE_84__["default"]; });

/* harmony import */ var _inc_js__WEBPACK_IMPORTED_MODULE_85__ = __webpack_require__(/*! ./inc.js */ "./node_modules/ramda/es/inc.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "inc", function() { return _inc_js__WEBPACK_IMPORTED_MODULE_85__["default"]; });

/* harmony import */ var _includes_js__WEBPACK_IMPORTED_MODULE_86__ = __webpack_require__(/*! ./includes.js */ "./node_modules/ramda/es/includes.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "includes", function() { return _includes_js__WEBPACK_IMPORTED_MODULE_86__["default"]; });

/* harmony import */ var _indexBy_js__WEBPACK_IMPORTED_MODULE_87__ = __webpack_require__(/*! ./indexBy.js */ "./node_modules/ramda/es/indexBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "indexBy", function() { return _indexBy_js__WEBPACK_IMPORTED_MODULE_87__["default"]; });

/* harmony import */ var _indexOf_js__WEBPACK_IMPORTED_MODULE_88__ = __webpack_require__(/*! ./indexOf.js */ "./node_modules/ramda/es/indexOf.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "indexOf", function() { return _indexOf_js__WEBPACK_IMPORTED_MODULE_88__["default"]; });

/* harmony import */ var _init_js__WEBPACK_IMPORTED_MODULE_89__ = __webpack_require__(/*! ./init.js */ "./node_modules/ramda/es/init.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "init", function() { return _init_js__WEBPACK_IMPORTED_MODULE_89__["default"]; });

/* harmony import */ var _innerJoin_js__WEBPACK_IMPORTED_MODULE_90__ = __webpack_require__(/*! ./innerJoin.js */ "./node_modules/ramda/es/innerJoin.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "innerJoin", function() { return _innerJoin_js__WEBPACK_IMPORTED_MODULE_90__["default"]; });

/* harmony import */ var _insert_js__WEBPACK_IMPORTED_MODULE_91__ = __webpack_require__(/*! ./insert.js */ "./node_modules/ramda/es/insert.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "insert", function() { return _insert_js__WEBPACK_IMPORTED_MODULE_91__["default"]; });

/* harmony import */ var _insertAll_js__WEBPACK_IMPORTED_MODULE_92__ = __webpack_require__(/*! ./insertAll.js */ "./node_modules/ramda/es/insertAll.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "insertAll", function() { return _insertAll_js__WEBPACK_IMPORTED_MODULE_92__["default"]; });

/* harmony import */ var _intersection_js__WEBPACK_IMPORTED_MODULE_93__ = __webpack_require__(/*! ./intersection.js */ "./node_modules/ramda/es/intersection.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "intersection", function() { return _intersection_js__WEBPACK_IMPORTED_MODULE_93__["default"]; });

/* harmony import */ var _intersperse_js__WEBPACK_IMPORTED_MODULE_94__ = __webpack_require__(/*! ./intersperse.js */ "./node_modules/ramda/es/intersperse.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "intersperse", function() { return _intersperse_js__WEBPACK_IMPORTED_MODULE_94__["default"]; });

/* harmony import */ var _into_js__WEBPACK_IMPORTED_MODULE_95__ = __webpack_require__(/*! ./into.js */ "./node_modules/ramda/es/into.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "into", function() { return _into_js__WEBPACK_IMPORTED_MODULE_95__["default"]; });

/* harmony import */ var _invert_js__WEBPACK_IMPORTED_MODULE_96__ = __webpack_require__(/*! ./invert.js */ "./node_modules/ramda/es/invert.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "invert", function() { return _invert_js__WEBPACK_IMPORTED_MODULE_96__["default"]; });

/* harmony import */ var _invertObj_js__WEBPACK_IMPORTED_MODULE_97__ = __webpack_require__(/*! ./invertObj.js */ "./node_modules/ramda/es/invertObj.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "invertObj", function() { return _invertObj_js__WEBPACK_IMPORTED_MODULE_97__["default"]; });

/* harmony import */ var _invoker_js__WEBPACK_IMPORTED_MODULE_98__ = __webpack_require__(/*! ./invoker.js */ "./node_modules/ramda/es/invoker.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "invoker", function() { return _invoker_js__WEBPACK_IMPORTED_MODULE_98__["default"]; });

/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_99__ = __webpack_require__(/*! ./is.js */ "./node_modules/ramda/es/is.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "is", function() { return _is_js__WEBPACK_IMPORTED_MODULE_99__["default"]; });

/* harmony import */ var _isEmpty_js__WEBPACK_IMPORTED_MODULE_100__ = __webpack_require__(/*! ./isEmpty.js */ "./node_modules/ramda/es/isEmpty.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "isEmpty", function() { return _isEmpty_js__WEBPACK_IMPORTED_MODULE_100__["default"]; });

/* harmony import */ var _isNil_js__WEBPACK_IMPORTED_MODULE_101__ = __webpack_require__(/*! ./isNil.js */ "./node_modules/ramda/es/isNil.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "isNil", function() { return _isNil_js__WEBPACK_IMPORTED_MODULE_101__["default"]; });

/* harmony import */ var _join_js__WEBPACK_IMPORTED_MODULE_102__ = __webpack_require__(/*! ./join.js */ "./node_modules/ramda/es/join.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "join", function() { return _join_js__WEBPACK_IMPORTED_MODULE_102__["default"]; });

/* harmony import */ var _juxt_js__WEBPACK_IMPORTED_MODULE_103__ = __webpack_require__(/*! ./juxt.js */ "./node_modules/ramda/es/juxt.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "juxt", function() { return _juxt_js__WEBPACK_IMPORTED_MODULE_103__["default"]; });

/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_104__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "keys", function() { return _keys_js__WEBPACK_IMPORTED_MODULE_104__["default"]; });

/* harmony import */ var _keysIn_js__WEBPACK_IMPORTED_MODULE_105__ = __webpack_require__(/*! ./keysIn.js */ "./node_modules/ramda/es/keysIn.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "keysIn", function() { return _keysIn_js__WEBPACK_IMPORTED_MODULE_105__["default"]; });

/* harmony import */ var _last_js__WEBPACK_IMPORTED_MODULE_106__ = __webpack_require__(/*! ./last.js */ "./node_modules/ramda/es/last.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "last", function() { return _last_js__WEBPACK_IMPORTED_MODULE_106__["default"]; });

/* harmony import */ var _lastIndexOf_js__WEBPACK_IMPORTED_MODULE_107__ = __webpack_require__(/*! ./lastIndexOf.js */ "./node_modules/ramda/es/lastIndexOf.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lastIndexOf", function() { return _lastIndexOf_js__WEBPACK_IMPORTED_MODULE_107__["default"]; });

/* harmony import */ var _length_js__WEBPACK_IMPORTED_MODULE_108__ = __webpack_require__(/*! ./length.js */ "./node_modules/ramda/es/length.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "length", function() { return _length_js__WEBPACK_IMPORTED_MODULE_108__["default"]; });

/* harmony import */ var _lens_js__WEBPACK_IMPORTED_MODULE_109__ = __webpack_require__(/*! ./lens.js */ "./node_modules/ramda/es/lens.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lens", function() { return _lens_js__WEBPACK_IMPORTED_MODULE_109__["default"]; });

/* harmony import */ var _lensIndex_js__WEBPACK_IMPORTED_MODULE_110__ = __webpack_require__(/*! ./lensIndex.js */ "./node_modules/ramda/es/lensIndex.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lensIndex", function() { return _lensIndex_js__WEBPACK_IMPORTED_MODULE_110__["default"]; });

/* harmony import */ var _lensPath_js__WEBPACK_IMPORTED_MODULE_111__ = __webpack_require__(/*! ./lensPath.js */ "./node_modules/ramda/es/lensPath.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lensPath", function() { return _lensPath_js__WEBPACK_IMPORTED_MODULE_111__["default"]; });

/* harmony import */ var _lensProp_js__WEBPACK_IMPORTED_MODULE_112__ = __webpack_require__(/*! ./lensProp.js */ "./node_modules/ramda/es/lensProp.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lensProp", function() { return _lensProp_js__WEBPACK_IMPORTED_MODULE_112__["default"]; });

/* harmony import */ var _lift_js__WEBPACK_IMPORTED_MODULE_113__ = __webpack_require__(/*! ./lift.js */ "./node_modules/ramda/es/lift.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lift", function() { return _lift_js__WEBPACK_IMPORTED_MODULE_113__["default"]; });

/* harmony import */ var _liftN_js__WEBPACK_IMPORTED_MODULE_114__ = __webpack_require__(/*! ./liftN.js */ "./node_modules/ramda/es/liftN.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "liftN", function() { return _liftN_js__WEBPACK_IMPORTED_MODULE_114__["default"]; });

/* harmony import */ var _lt_js__WEBPACK_IMPORTED_MODULE_115__ = __webpack_require__(/*! ./lt.js */ "./node_modules/ramda/es/lt.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lt", function() { return _lt_js__WEBPACK_IMPORTED_MODULE_115__["default"]; });

/* harmony import */ var _lte_js__WEBPACK_IMPORTED_MODULE_116__ = __webpack_require__(/*! ./lte.js */ "./node_modules/ramda/es/lte.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "lte", function() { return _lte_js__WEBPACK_IMPORTED_MODULE_116__["default"]; });

/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_117__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "map", function() { return _map_js__WEBPACK_IMPORTED_MODULE_117__["default"]; });

/* harmony import */ var _mapAccum_js__WEBPACK_IMPORTED_MODULE_118__ = __webpack_require__(/*! ./mapAccum.js */ "./node_modules/ramda/es/mapAccum.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mapAccum", function() { return _mapAccum_js__WEBPACK_IMPORTED_MODULE_118__["default"]; });

/* harmony import */ var _mapAccumRight_js__WEBPACK_IMPORTED_MODULE_119__ = __webpack_require__(/*! ./mapAccumRight.js */ "./node_modules/ramda/es/mapAccumRight.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mapAccumRight", function() { return _mapAccumRight_js__WEBPACK_IMPORTED_MODULE_119__["default"]; });

/* harmony import */ var _mapObjIndexed_js__WEBPACK_IMPORTED_MODULE_120__ = __webpack_require__(/*! ./mapObjIndexed.js */ "./node_modules/ramda/es/mapObjIndexed.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mapObjIndexed", function() { return _mapObjIndexed_js__WEBPACK_IMPORTED_MODULE_120__["default"]; });

/* harmony import */ var _match_js__WEBPACK_IMPORTED_MODULE_121__ = __webpack_require__(/*! ./match.js */ "./node_modules/ramda/es/match.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "match", function() { return _match_js__WEBPACK_IMPORTED_MODULE_121__["default"]; });

/* harmony import */ var _mathMod_js__WEBPACK_IMPORTED_MODULE_122__ = __webpack_require__(/*! ./mathMod.js */ "./node_modules/ramda/es/mathMod.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mathMod", function() { return _mathMod_js__WEBPACK_IMPORTED_MODULE_122__["default"]; });

/* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_123__ = __webpack_require__(/*! ./max.js */ "./node_modules/ramda/es/max.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "max", function() { return _max_js__WEBPACK_IMPORTED_MODULE_123__["default"]; });

/* harmony import */ var _maxBy_js__WEBPACK_IMPORTED_MODULE_124__ = __webpack_require__(/*! ./maxBy.js */ "./node_modules/ramda/es/maxBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "maxBy", function() { return _maxBy_js__WEBPACK_IMPORTED_MODULE_124__["default"]; });

/* harmony import */ var _mean_js__WEBPACK_IMPORTED_MODULE_125__ = __webpack_require__(/*! ./mean.js */ "./node_modules/ramda/es/mean.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mean", function() { return _mean_js__WEBPACK_IMPORTED_MODULE_125__["default"]; });

/* harmony import */ var _median_js__WEBPACK_IMPORTED_MODULE_126__ = __webpack_require__(/*! ./median.js */ "./node_modules/ramda/es/median.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "median", function() { return _median_js__WEBPACK_IMPORTED_MODULE_126__["default"]; });

/* harmony import */ var _memoizeWith_js__WEBPACK_IMPORTED_MODULE_127__ = __webpack_require__(/*! ./memoizeWith.js */ "./node_modules/ramda/es/memoizeWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "memoizeWith", function() { return _memoizeWith_js__WEBPACK_IMPORTED_MODULE_127__["default"]; });

/* harmony import */ var _merge_js__WEBPACK_IMPORTED_MODULE_128__ = __webpack_require__(/*! ./merge.js */ "./node_modules/ramda/es/merge.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "merge", function() { return _merge_js__WEBPACK_IMPORTED_MODULE_128__["default"]; });

/* harmony import */ var _mergeAll_js__WEBPACK_IMPORTED_MODULE_129__ = __webpack_require__(/*! ./mergeAll.js */ "./node_modules/ramda/es/mergeAll.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeAll", function() { return _mergeAll_js__WEBPACK_IMPORTED_MODULE_129__["default"]; });

/* harmony import */ var _mergeDeepLeft_js__WEBPACK_IMPORTED_MODULE_130__ = __webpack_require__(/*! ./mergeDeepLeft.js */ "./node_modules/ramda/es/mergeDeepLeft.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeDeepLeft", function() { return _mergeDeepLeft_js__WEBPACK_IMPORTED_MODULE_130__["default"]; });

/* harmony import */ var _mergeDeepRight_js__WEBPACK_IMPORTED_MODULE_131__ = __webpack_require__(/*! ./mergeDeepRight.js */ "./node_modules/ramda/es/mergeDeepRight.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeDeepRight", function() { return _mergeDeepRight_js__WEBPACK_IMPORTED_MODULE_131__["default"]; });

/* harmony import */ var _mergeDeepWith_js__WEBPACK_IMPORTED_MODULE_132__ = __webpack_require__(/*! ./mergeDeepWith.js */ "./node_modules/ramda/es/mergeDeepWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeDeepWith", function() { return _mergeDeepWith_js__WEBPACK_IMPORTED_MODULE_132__["default"]; });

/* harmony import */ var _mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_133__ = __webpack_require__(/*! ./mergeDeepWithKey.js */ "./node_modules/ramda/es/mergeDeepWithKey.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeDeepWithKey", function() { return _mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_133__["default"]; });

/* harmony import */ var _mergeLeft_js__WEBPACK_IMPORTED_MODULE_134__ = __webpack_require__(/*! ./mergeLeft.js */ "./node_modules/ramda/es/mergeLeft.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeLeft", function() { return _mergeLeft_js__WEBPACK_IMPORTED_MODULE_134__["default"]; });

/* harmony import */ var _mergeRight_js__WEBPACK_IMPORTED_MODULE_135__ = __webpack_require__(/*! ./mergeRight.js */ "./node_modules/ramda/es/mergeRight.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeRight", function() { return _mergeRight_js__WEBPACK_IMPORTED_MODULE_135__["default"]; });

/* harmony import */ var _mergeWith_js__WEBPACK_IMPORTED_MODULE_136__ = __webpack_require__(/*! ./mergeWith.js */ "./node_modules/ramda/es/mergeWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeWith", function() { return _mergeWith_js__WEBPACK_IMPORTED_MODULE_136__["default"]; });

/* harmony import */ var _mergeWithKey_js__WEBPACK_IMPORTED_MODULE_137__ = __webpack_require__(/*! ./mergeWithKey.js */ "./node_modules/ramda/es/mergeWithKey.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "mergeWithKey", function() { return _mergeWithKey_js__WEBPACK_IMPORTED_MODULE_137__["default"]; });

/* harmony import */ var _min_js__WEBPACK_IMPORTED_MODULE_138__ = __webpack_require__(/*! ./min.js */ "./node_modules/ramda/es/min.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "min", function() { return _min_js__WEBPACK_IMPORTED_MODULE_138__["default"]; });

/* harmony import */ var _minBy_js__WEBPACK_IMPORTED_MODULE_139__ = __webpack_require__(/*! ./minBy.js */ "./node_modules/ramda/es/minBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "minBy", function() { return _minBy_js__WEBPACK_IMPORTED_MODULE_139__["default"]; });

/* harmony import */ var _modulo_js__WEBPACK_IMPORTED_MODULE_140__ = __webpack_require__(/*! ./modulo.js */ "./node_modules/ramda/es/modulo.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "modulo", function() { return _modulo_js__WEBPACK_IMPORTED_MODULE_140__["default"]; });

/* harmony import */ var _move_js__WEBPACK_IMPORTED_MODULE_141__ = __webpack_require__(/*! ./move.js */ "./node_modules/ramda/es/move.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "move", function() { return _move_js__WEBPACK_IMPORTED_MODULE_141__["default"]; });

/* harmony import */ var _multiply_js__WEBPACK_IMPORTED_MODULE_142__ = __webpack_require__(/*! ./multiply.js */ "./node_modules/ramda/es/multiply.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "multiply", function() { return _multiply_js__WEBPACK_IMPORTED_MODULE_142__["default"]; });

/* harmony import */ var _nAry_js__WEBPACK_IMPORTED_MODULE_143__ = __webpack_require__(/*! ./nAry.js */ "./node_modules/ramda/es/nAry.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "nAry", function() { return _nAry_js__WEBPACK_IMPORTED_MODULE_143__["default"]; });

/* harmony import */ var _negate_js__WEBPACK_IMPORTED_MODULE_144__ = __webpack_require__(/*! ./negate.js */ "./node_modules/ramda/es/negate.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "negate", function() { return _negate_js__WEBPACK_IMPORTED_MODULE_144__["default"]; });

/* harmony import */ var _none_js__WEBPACK_IMPORTED_MODULE_145__ = __webpack_require__(/*! ./none.js */ "./node_modules/ramda/es/none.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "none", function() { return _none_js__WEBPACK_IMPORTED_MODULE_145__["default"]; });

/* harmony import */ var _not_js__WEBPACK_IMPORTED_MODULE_146__ = __webpack_require__(/*! ./not.js */ "./node_modules/ramda/es/not.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "not", function() { return _not_js__WEBPACK_IMPORTED_MODULE_146__["default"]; });

/* harmony import */ var _nth_js__WEBPACK_IMPORTED_MODULE_147__ = __webpack_require__(/*! ./nth.js */ "./node_modules/ramda/es/nth.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "nth", function() { return _nth_js__WEBPACK_IMPORTED_MODULE_147__["default"]; });

/* harmony import */ var _nthArg_js__WEBPACK_IMPORTED_MODULE_148__ = __webpack_require__(/*! ./nthArg.js */ "./node_modules/ramda/es/nthArg.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "nthArg", function() { return _nthArg_js__WEBPACK_IMPORTED_MODULE_148__["default"]; });

/* harmony import */ var _o_js__WEBPACK_IMPORTED_MODULE_149__ = __webpack_require__(/*! ./o.js */ "./node_modules/ramda/es/o.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "o", function() { return _o_js__WEBPACK_IMPORTED_MODULE_149__["default"]; });

/* harmony import */ var _objOf_js__WEBPACK_IMPORTED_MODULE_150__ = __webpack_require__(/*! ./objOf.js */ "./node_modules/ramda/es/objOf.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "objOf", function() { return _objOf_js__WEBPACK_IMPORTED_MODULE_150__["default"]; });

/* harmony import */ var _of_js__WEBPACK_IMPORTED_MODULE_151__ = __webpack_require__(/*! ./of.js */ "./node_modules/ramda/es/of.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "of", function() { return _of_js__WEBPACK_IMPORTED_MODULE_151__["default"]; });

/* harmony import */ var _omit_js__WEBPACK_IMPORTED_MODULE_152__ = __webpack_require__(/*! ./omit.js */ "./node_modules/ramda/es/omit.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "omit", function() { return _omit_js__WEBPACK_IMPORTED_MODULE_152__["default"]; });

/* harmony import */ var _once_js__WEBPACK_IMPORTED_MODULE_153__ = __webpack_require__(/*! ./once.js */ "./node_modules/ramda/es/once.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "once", function() { return _once_js__WEBPACK_IMPORTED_MODULE_153__["default"]; });

/* harmony import */ var _or_js__WEBPACK_IMPORTED_MODULE_154__ = __webpack_require__(/*! ./or.js */ "./node_modules/ramda/es/or.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "or", function() { return _or_js__WEBPACK_IMPORTED_MODULE_154__["default"]; });

/* harmony import */ var _otherwise_js__WEBPACK_IMPORTED_MODULE_155__ = __webpack_require__(/*! ./otherwise.js */ "./node_modules/ramda/es/otherwise.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "otherwise", function() { return _otherwise_js__WEBPACK_IMPORTED_MODULE_155__["default"]; });

/* harmony import */ var _over_js__WEBPACK_IMPORTED_MODULE_156__ = __webpack_require__(/*! ./over.js */ "./node_modules/ramda/es/over.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "over", function() { return _over_js__WEBPACK_IMPORTED_MODULE_156__["default"]; });

/* harmony import */ var _pair_js__WEBPACK_IMPORTED_MODULE_157__ = __webpack_require__(/*! ./pair.js */ "./node_modules/ramda/es/pair.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pair", function() { return _pair_js__WEBPACK_IMPORTED_MODULE_157__["default"]; });

/* harmony import */ var _partial_js__WEBPACK_IMPORTED_MODULE_158__ = __webpack_require__(/*! ./partial.js */ "./node_modules/ramda/es/partial.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "partial", function() { return _partial_js__WEBPACK_IMPORTED_MODULE_158__["default"]; });

/* harmony import */ var _partialRight_js__WEBPACK_IMPORTED_MODULE_159__ = __webpack_require__(/*! ./partialRight.js */ "./node_modules/ramda/es/partialRight.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "partialRight", function() { return _partialRight_js__WEBPACK_IMPORTED_MODULE_159__["default"]; });

/* harmony import */ var _partition_js__WEBPACK_IMPORTED_MODULE_160__ = __webpack_require__(/*! ./partition.js */ "./node_modules/ramda/es/partition.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "partition", function() { return _partition_js__WEBPACK_IMPORTED_MODULE_160__["default"]; });

/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_161__ = __webpack_require__(/*! ./path.js */ "./node_modules/ramda/es/path.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "path", function() { return _path_js__WEBPACK_IMPORTED_MODULE_161__["default"]; });

/* harmony import */ var _pathEq_js__WEBPACK_IMPORTED_MODULE_162__ = __webpack_require__(/*! ./pathEq.js */ "./node_modules/ramda/es/pathEq.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pathEq", function() { return _pathEq_js__WEBPACK_IMPORTED_MODULE_162__["default"]; });

/* harmony import */ var _pathOr_js__WEBPACK_IMPORTED_MODULE_163__ = __webpack_require__(/*! ./pathOr.js */ "./node_modules/ramda/es/pathOr.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pathOr", function() { return _pathOr_js__WEBPACK_IMPORTED_MODULE_163__["default"]; });

/* harmony import */ var _pathSatisfies_js__WEBPACK_IMPORTED_MODULE_164__ = __webpack_require__(/*! ./pathSatisfies.js */ "./node_modules/ramda/es/pathSatisfies.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pathSatisfies", function() { return _pathSatisfies_js__WEBPACK_IMPORTED_MODULE_164__["default"]; });

/* harmony import */ var _pick_js__WEBPACK_IMPORTED_MODULE_165__ = __webpack_require__(/*! ./pick.js */ "./node_modules/ramda/es/pick.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pick", function() { return _pick_js__WEBPACK_IMPORTED_MODULE_165__["default"]; });

/* harmony import */ var _pickAll_js__WEBPACK_IMPORTED_MODULE_166__ = __webpack_require__(/*! ./pickAll.js */ "./node_modules/ramda/es/pickAll.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pickAll", function() { return _pickAll_js__WEBPACK_IMPORTED_MODULE_166__["default"]; });

/* harmony import */ var _pickBy_js__WEBPACK_IMPORTED_MODULE_167__ = __webpack_require__(/*! ./pickBy.js */ "./node_modules/ramda/es/pickBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pickBy", function() { return _pickBy_js__WEBPACK_IMPORTED_MODULE_167__["default"]; });

/* harmony import */ var _pipe_js__WEBPACK_IMPORTED_MODULE_168__ = __webpack_require__(/*! ./pipe.js */ "./node_modules/ramda/es/pipe.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pipe", function() { return _pipe_js__WEBPACK_IMPORTED_MODULE_168__["default"]; });

/* harmony import */ var _pipeK_js__WEBPACK_IMPORTED_MODULE_169__ = __webpack_require__(/*! ./pipeK.js */ "./node_modules/ramda/es/pipeK.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pipeK", function() { return _pipeK_js__WEBPACK_IMPORTED_MODULE_169__["default"]; });

/* harmony import */ var _pipeP_js__WEBPACK_IMPORTED_MODULE_170__ = __webpack_require__(/*! ./pipeP.js */ "./node_modules/ramda/es/pipeP.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pipeP", function() { return _pipeP_js__WEBPACK_IMPORTED_MODULE_170__["default"]; });

/* harmony import */ var _pipeWith_js__WEBPACK_IMPORTED_MODULE_171__ = __webpack_require__(/*! ./pipeWith.js */ "./node_modules/ramda/es/pipeWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pipeWith", function() { return _pipeWith_js__WEBPACK_IMPORTED_MODULE_171__["default"]; });

/* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_172__ = __webpack_require__(/*! ./pluck.js */ "./node_modules/ramda/es/pluck.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "pluck", function() { return _pluck_js__WEBPACK_IMPORTED_MODULE_172__["default"]; });

/* harmony import */ var _prepend_js__WEBPACK_IMPORTED_MODULE_173__ = __webpack_require__(/*! ./prepend.js */ "./node_modules/ramda/es/prepend.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "prepend", function() { return _prepend_js__WEBPACK_IMPORTED_MODULE_173__["default"]; });

/* harmony import */ var _product_js__WEBPACK_IMPORTED_MODULE_174__ = __webpack_require__(/*! ./product.js */ "./node_modules/ramda/es/product.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "product", function() { return _product_js__WEBPACK_IMPORTED_MODULE_174__["default"]; });

/* harmony import */ var _project_js__WEBPACK_IMPORTED_MODULE_175__ = __webpack_require__(/*! ./project.js */ "./node_modules/ramda/es/project.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "project", function() { return _project_js__WEBPACK_IMPORTED_MODULE_175__["default"]; });

/* harmony import */ var _prop_js__WEBPACK_IMPORTED_MODULE_176__ = __webpack_require__(/*! ./prop.js */ "./node_modules/ramda/es/prop.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "prop", function() { return _prop_js__WEBPACK_IMPORTED_MODULE_176__["default"]; });

/* harmony import */ var _propEq_js__WEBPACK_IMPORTED_MODULE_177__ = __webpack_require__(/*! ./propEq.js */ "./node_modules/ramda/es/propEq.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "propEq", function() { return _propEq_js__WEBPACK_IMPORTED_MODULE_177__["default"]; });

/* harmony import */ var _propIs_js__WEBPACK_IMPORTED_MODULE_178__ = __webpack_require__(/*! ./propIs.js */ "./node_modules/ramda/es/propIs.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "propIs", function() { return _propIs_js__WEBPACK_IMPORTED_MODULE_178__["default"]; });

/* harmony import */ var _propOr_js__WEBPACK_IMPORTED_MODULE_179__ = __webpack_require__(/*! ./propOr.js */ "./node_modules/ramda/es/propOr.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "propOr", function() { return _propOr_js__WEBPACK_IMPORTED_MODULE_179__["default"]; });

/* harmony import */ var _propSatisfies_js__WEBPACK_IMPORTED_MODULE_180__ = __webpack_require__(/*! ./propSatisfies.js */ "./node_modules/ramda/es/propSatisfies.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "propSatisfies", function() { return _propSatisfies_js__WEBPACK_IMPORTED_MODULE_180__["default"]; });

/* harmony import */ var _props_js__WEBPACK_IMPORTED_MODULE_181__ = __webpack_require__(/*! ./props.js */ "./node_modules/ramda/es/props.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "props", function() { return _props_js__WEBPACK_IMPORTED_MODULE_181__["default"]; });

/* harmony import */ var _range_js__WEBPACK_IMPORTED_MODULE_182__ = __webpack_require__(/*! ./range.js */ "./node_modules/ramda/es/range.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "range", function() { return _range_js__WEBPACK_IMPORTED_MODULE_182__["default"]; });

/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_183__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reduce", function() { return _reduce_js__WEBPACK_IMPORTED_MODULE_183__["default"]; });

/* harmony import */ var _reduceBy_js__WEBPACK_IMPORTED_MODULE_184__ = __webpack_require__(/*! ./reduceBy.js */ "./node_modules/ramda/es/reduceBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reduceBy", function() { return _reduceBy_js__WEBPACK_IMPORTED_MODULE_184__["default"]; });

/* harmony import */ var _reduceRight_js__WEBPACK_IMPORTED_MODULE_185__ = __webpack_require__(/*! ./reduceRight.js */ "./node_modules/ramda/es/reduceRight.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reduceRight", function() { return _reduceRight_js__WEBPACK_IMPORTED_MODULE_185__["default"]; });

/* harmony import */ var _reduceWhile_js__WEBPACK_IMPORTED_MODULE_186__ = __webpack_require__(/*! ./reduceWhile.js */ "./node_modules/ramda/es/reduceWhile.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reduceWhile", function() { return _reduceWhile_js__WEBPACK_IMPORTED_MODULE_186__["default"]; });

/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_187__ = __webpack_require__(/*! ./reduced.js */ "./node_modules/ramda/es/reduced.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reduced", function() { return _reduced_js__WEBPACK_IMPORTED_MODULE_187__["default"]; });

/* harmony import */ var _reject_js__WEBPACK_IMPORTED_MODULE_188__ = __webpack_require__(/*! ./reject.js */ "./node_modules/ramda/es/reject.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reject", function() { return _reject_js__WEBPACK_IMPORTED_MODULE_188__["default"]; });

/* harmony import */ var _remove_js__WEBPACK_IMPORTED_MODULE_189__ = __webpack_require__(/*! ./remove.js */ "./node_modules/ramda/es/remove.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "remove", function() { return _remove_js__WEBPACK_IMPORTED_MODULE_189__["default"]; });

/* harmony import */ var _repeat_js__WEBPACK_IMPORTED_MODULE_190__ = __webpack_require__(/*! ./repeat.js */ "./node_modules/ramda/es/repeat.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "repeat", function() { return _repeat_js__WEBPACK_IMPORTED_MODULE_190__["default"]; });

/* harmony import */ var _replace_js__WEBPACK_IMPORTED_MODULE_191__ = __webpack_require__(/*! ./replace.js */ "./node_modules/ramda/es/replace.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "replace", function() { return _replace_js__WEBPACK_IMPORTED_MODULE_191__["default"]; });

/* harmony import */ var _reverse_js__WEBPACK_IMPORTED_MODULE_192__ = __webpack_require__(/*! ./reverse.js */ "./node_modules/ramda/es/reverse.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "reverse", function() { return _reverse_js__WEBPACK_IMPORTED_MODULE_192__["default"]; });

/* harmony import */ var _scan_js__WEBPACK_IMPORTED_MODULE_193__ = __webpack_require__(/*! ./scan.js */ "./node_modules/ramda/es/scan.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "scan", function() { return _scan_js__WEBPACK_IMPORTED_MODULE_193__["default"]; });

/* harmony import */ var _sequence_js__WEBPACK_IMPORTED_MODULE_194__ = __webpack_require__(/*! ./sequence.js */ "./node_modules/ramda/es/sequence.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sequence", function() { return _sequence_js__WEBPACK_IMPORTED_MODULE_194__["default"]; });

/* harmony import */ var _set_js__WEBPACK_IMPORTED_MODULE_195__ = __webpack_require__(/*! ./set.js */ "./node_modules/ramda/es/set.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "set", function() { return _set_js__WEBPACK_IMPORTED_MODULE_195__["default"]; });

/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_196__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "slice", function() { return _slice_js__WEBPACK_IMPORTED_MODULE_196__["default"]; });

/* harmony import */ var _sort_js__WEBPACK_IMPORTED_MODULE_197__ = __webpack_require__(/*! ./sort.js */ "./node_modules/ramda/es/sort.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sort", function() { return _sort_js__WEBPACK_IMPORTED_MODULE_197__["default"]; });

/* harmony import */ var _sortBy_js__WEBPACK_IMPORTED_MODULE_198__ = __webpack_require__(/*! ./sortBy.js */ "./node_modules/ramda/es/sortBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sortBy", function() { return _sortBy_js__WEBPACK_IMPORTED_MODULE_198__["default"]; });

/* harmony import */ var _sortWith_js__WEBPACK_IMPORTED_MODULE_199__ = __webpack_require__(/*! ./sortWith.js */ "./node_modules/ramda/es/sortWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sortWith", function() { return _sortWith_js__WEBPACK_IMPORTED_MODULE_199__["default"]; });

/* harmony import */ var _split_js__WEBPACK_IMPORTED_MODULE_200__ = __webpack_require__(/*! ./split.js */ "./node_modules/ramda/es/split.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "split", function() { return _split_js__WEBPACK_IMPORTED_MODULE_200__["default"]; });

/* harmony import */ var _splitAt_js__WEBPACK_IMPORTED_MODULE_201__ = __webpack_require__(/*! ./splitAt.js */ "./node_modules/ramda/es/splitAt.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "splitAt", function() { return _splitAt_js__WEBPACK_IMPORTED_MODULE_201__["default"]; });

/* harmony import */ var _splitEvery_js__WEBPACK_IMPORTED_MODULE_202__ = __webpack_require__(/*! ./splitEvery.js */ "./node_modules/ramda/es/splitEvery.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "splitEvery", function() { return _splitEvery_js__WEBPACK_IMPORTED_MODULE_202__["default"]; });

/* harmony import */ var _splitWhen_js__WEBPACK_IMPORTED_MODULE_203__ = __webpack_require__(/*! ./splitWhen.js */ "./node_modules/ramda/es/splitWhen.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "splitWhen", function() { return _splitWhen_js__WEBPACK_IMPORTED_MODULE_203__["default"]; });

/* harmony import */ var _startsWith_js__WEBPACK_IMPORTED_MODULE_204__ = __webpack_require__(/*! ./startsWith.js */ "./node_modules/ramda/es/startsWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "startsWith", function() { return _startsWith_js__WEBPACK_IMPORTED_MODULE_204__["default"]; });

/* harmony import */ var _subtract_js__WEBPACK_IMPORTED_MODULE_205__ = __webpack_require__(/*! ./subtract.js */ "./node_modules/ramda/es/subtract.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "subtract", function() { return _subtract_js__WEBPACK_IMPORTED_MODULE_205__["default"]; });

/* harmony import */ var _sum_js__WEBPACK_IMPORTED_MODULE_206__ = __webpack_require__(/*! ./sum.js */ "./node_modules/ramda/es/sum.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "sum", function() { return _sum_js__WEBPACK_IMPORTED_MODULE_206__["default"]; });

/* harmony import */ var _symmetricDifference_js__WEBPACK_IMPORTED_MODULE_207__ = __webpack_require__(/*! ./symmetricDifference.js */ "./node_modules/ramda/es/symmetricDifference.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "symmetricDifference", function() { return _symmetricDifference_js__WEBPACK_IMPORTED_MODULE_207__["default"]; });

/* harmony import */ var _symmetricDifferenceWith_js__WEBPACK_IMPORTED_MODULE_208__ = __webpack_require__(/*! ./symmetricDifferenceWith.js */ "./node_modules/ramda/es/symmetricDifferenceWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "symmetricDifferenceWith", function() { return _symmetricDifferenceWith_js__WEBPACK_IMPORTED_MODULE_208__["default"]; });

/* harmony import */ var _tail_js__WEBPACK_IMPORTED_MODULE_209__ = __webpack_require__(/*! ./tail.js */ "./node_modules/ramda/es/tail.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "tail", function() { return _tail_js__WEBPACK_IMPORTED_MODULE_209__["default"]; });

/* harmony import */ var _take_js__WEBPACK_IMPORTED_MODULE_210__ = __webpack_require__(/*! ./take.js */ "./node_modules/ramda/es/take.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "take", function() { return _take_js__WEBPACK_IMPORTED_MODULE_210__["default"]; });

/* harmony import */ var _takeLast_js__WEBPACK_IMPORTED_MODULE_211__ = __webpack_require__(/*! ./takeLast.js */ "./node_modules/ramda/es/takeLast.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "takeLast", function() { return _takeLast_js__WEBPACK_IMPORTED_MODULE_211__["default"]; });

/* harmony import */ var _takeLastWhile_js__WEBPACK_IMPORTED_MODULE_212__ = __webpack_require__(/*! ./takeLastWhile.js */ "./node_modules/ramda/es/takeLastWhile.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "takeLastWhile", function() { return _takeLastWhile_js__WEBPACK_IMPORTED_MODULE_212__["default"]; });

/* harmony import */ var _takeWhile_js__WEBPACK_IMPORTED_MODULE_213__ = __webpack_require__(/*! ./takeWhile.js */ "./node_modules/ramda/es/takeWhile.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "takeWhile", function() { return _takeWhile_js__WEBPACK_IMPORTED_MODULE_213__["default"]; });

/* harmony import */ var _tap_js__WEBPACK_IMPORTED_MODULE_214__ = __webpack_require__(/*! ./tap.js */ "./node_modules/ramda/es/tap.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "tap", function() { return _tap_js__WEBPACK_IMPORTED_MODULE_214__["default"]; });

/* harmony import */ var _test_js__WEBPACK_IMPORTED_MODULE_215__ = __webpack_require__(/*! ./test.js */ "./node_modules/ramda/es/test.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "test", function() { return _test_js__WEBPACK_IMPORTED_MODULE_215__["default"]; });

/* harmony import */ var _then_js__WEBPACK_IMPORTED_MODULE_216__ = __webpack_require__(/*! ./then.js */ "./node_modules/ramda/es/then.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "then", function() { return _then_js__WEBPACK_IMPORTED_MODULE_216__["default"]; });

/* harmony import */ var _times_js__WEBPACK_IMPORTED_MODULE_217__ = __webpack_require__(/*! ./times.js */ "./node_modules/ramda/es/times.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "times", function() { return _times_js__WEBPACK_IMPORTED_MODULE_217__["default"]; });

/* harmony import */ var _toLower_js__WEBPACK_IMPORTED_MODULE_218__ = __webpack_require__(/*! ./toLower.js */ "./node_modules/ramda/es/toLower.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "toLower", function() { return _toLower_js__WEBPACK_IMPORTED_MODULE_218__["default"]; });

/* harmony import */ var _toPairs_js__WEBPACK_IMPORTED_MODULE_219__ = __webpack_require__(/*! ./toPairs.js */ "./node_modules/ramda/es/toPairs.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "toPairs", function() { return _toPairs_js__WEBPACK_IMPORTED_MODULE_219__["default"]; });

/* harmony import */ var _toPairsIn_js__WEBPACK_IMPORTED_MODULE_220__ = __webpack_require__(/*! ./toPairsIn.js */ "./node_modules/ramda/es/toPairsIn.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "toPairsIn", function() { return _toPairsIn_js__WEBPACK_IMPORTED_MODULE_220__["default"]; });

/* harmony import */ var _toString_js__WEBPACK_IMPORTED_MODULE_221__ = __webpack_require__(/*! ./toString.js */ "./node_modules/ramda/es/toString.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "toString", function() { return _toString_js__WEBPACK_IMPORTED_MODULE_221__["default"]; });

/* harmony import */ var _toUpper_js__WEBPACK_IMPORTED_MODULE_222__ = __webpack_require__(/*! ./toUpper.js */ "./node_modules/ramda/es/toUpper.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "toUpper", function() { return _toUpper_js__WEBPACK_IMPORTED_MODULE_222__["default"]; });

/* harmony import */ var _transduce_js__WEBPACK_IMPORTED_MODULE_223__ = __webpack_require__(/*! ./transduce.js */ "./node_modules/ramda/es/transduce.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "transduce", function() { return _transduce_js__WEBPACK_IMPORTED_MODULE_223__["default"]; });

/* harmony import */ var _transpose_js__WEBPACK_IMPORTED_MODULE_224__ = __webpack_require__(/*! ./transpose.js */ "./node_modules/ramda/es/transpose.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "transpose", function() { return _transpose_js__WEBPACK_IMPORTED_MODULE_224__["default"]; });

/* harmony import */ var _traverse_js__WEBPACK_IMPORTED_MODULE_225__ = __webpack_require__(/*! ./traverse.js */ "./node_modules/ramda/es/traverse.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "traverse", function() { return _traverse_js__WEBPACK_IMPORTED_MODULE_225__["default"]; });

/* harmony import */ var _trim_js__WEBPACK_IMPORTED_MODULE_226__ = __webpack_require__(/*! ./trim.js */ "./node_modules/ramda/es/trim.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "trim", function() { return _trim_js__WEBPACK_IMPORTED_MODULE_226__["default"]; });

/* harmony import */ var _tryCatch_js__WEBPACK_IMPORTED_MODULE_227__ = __webpack_require__(/*! ./tryCatch.js */ "./node_modules/ramda/es/tryCatch.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "tryCatch", function() { return _tryCatch_js__WEBPACK_IMPORTED_MODULE_227__["default"]; });

/* harmony import */ var _type_js__WEBPACK_IMPORTED_MODULE_228__ = __webpack_require__(/*! ./type.js */ "./node_modules/ramda/es/type.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "type", function() { return _type_js__WEBPACK_IMPORTED_MODULE_228__["default"]; });

/* harmony import */ var _unapply_js__WEBPACK_IMPORTED_MODULE_229__ = __webpack_require__(/*! ./unapply.js */ "./node_modules/ramda/es/unapply.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "unapply", function() { return _unapply_js__WEBPACK_IMPORTED_MODULE_229__["default"]; });

/* harmony import */ var _unary_js__WEBPACK_IMPORTED_MODULE_230__ = __webpack_require__(/*! ./unary.js */ "./node_modules/ramda/es/unary.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "unary", function() { return _unary_js__WEBPACK_IMPORTED_MODULE_230__["default"]; });

/* harmony import */ var _uncurryN_js__WEBPACK_IMPORTED_MODULE_231__ = __webpack_require__(/*! ./uncurryN.js */ "./node_modules/ramda/es/uncurryN.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "uncurryN", function() { return _uncurryN_js__WEBPACK_IMPORTED_MODULE_231__["default"]; });

/* harmony import */ var _unfold_js__WEBPACK_IMPORTED_MODULE_232__ = __webpack_require__(/*! ./unfold.js */ "./node_modules/ramda/es/unfold.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "unfold", function() { return _unfold_js__WEBPACK_IMPORTED_MODULE_232__["default"]; });

/* harmony import */ var _union_js__WEBPACK_IMPORTED_MODULE_233__ = __webpack_require__(/*! ./union.js */ "./node_modules/ramda/es/union.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "union", function() { return _union_js__WEBPACK_IMPORTED_MODULE_233__["default"]; });

/* harmony import */ var _unionWith_js__WEBPACK_IMPORTED_MODULE_234__ = __webpack_require__(/*! ./unionWith.js */ "./node_modules/ramda/es/unionWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "unionWith", function() { return _unionWith_js__WEBPACK_IMPORTED_MODULE_234__["default"]; });

/* harmony import */ var _uniq_js__WEBPACK_IMPORTED_MODULE_235__ = __webpack_require__(/*! ./uniq.js */ "./node_modules/ramda/es/uniq.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "uniq", function() { return _uniq_js__WEBPACK_IMPORTED_MODULE_235__["default"]; });

/* harmony import */ var _uniqBy_js__WEBPACK_IMPORTED_MODULE_236__ = __webpack_require__(/*! ./uniqBy.js */ "./node_modules/ramda/es/uniqBy.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "uniqBy", function() { return _uniqBy_js__WEBPACK_IMPORTED_MODULE_236__["default"]; });

/* harmony import */ var _uniqWith_js__WEBPACK_IMPORTED_MODULE_237__ = __webpack_require__(/*! ./uniqWith.js */ "./node_modules/ramda/es/uniqWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "uniqWith", function() { return _uniqWith_js__WEBPACK_IMPORTED_MODULE_237__["default"]; });

/* harmony import */ var _unless_js__WEBPACK_IMPORTED_MODULE_238__ = __webpack_require__(/*! ./unless.js */ "./node_modules/ramda/es/unless.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "unless", function() { return _unless_js__WEBPACK_IMPORTED_MODULE_238__["default"]; });

/* harmony import */ var _unnest_js__WEBPACK_IMPORTED_MODULE_239__ = __webpack_require__(/*! ./unnest.js */ "./node_modules/ramda/es/unnest.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "unnest", function() { return _unnest_js__WEBPACK_IMPORTED_MODULE_239__["default"]; });

/* harmony import */ var _until_js__WEBPACK_IMPORTED_MODULE_240__ = __webpack_require__(/*! ./until.js */ "./node_modules/ramda/es/until.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "until", function() { return _until_js__WEBPACK_IMPORTED_MODULE_240__["default"]; });

/* harmony import */ var _update_js__WEBPACK_IMPORTED_MODULE_241__ = __webpack_require__(/*! ./update.js */ "./node_modules/ramda/es/update.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "update", function() { return _update_js__WEBPACK_IMPORTED_MODULE_241__["default"]; });

/* harmony import */ var _useWith_js__WEBPACK_IMPORTED_MODULE_242__ = __webpack_require__(/*! ./useWith.js */ "./node_modules/ramda/es/useWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "useWith", function() { return _useWith_js__WEBPACK_IMPORTED_MODULE_242__["default"]; });

/* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_243__ = __webpack_require__(/*! ./values.js */ "./node_modules/ramda/es/values.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "values", function() { return _values_js__WEBPACK_IMPORTED_MODULE_243__["default"]; });

/* harmony import */ var _valuesIn_js__WEBPACK_IMPORTED_MODULE_244__ = __webpack_require__(/*! ./valuesIn.js */ "./node_modules/ramda/es/valuesIn.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "valuesIn", function() { return _valuesIn_js__WEBPACK_IMPORTED_MODULE_244__["default"]; });

/* harmony import */ var _view_js__WEBPACK_IMPORTED_MODULE_245__ = __webpack_require__(/*! ./view.js */ "./node_modules/ramda/es/view.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "view", function() { return _view_js__WEBPACK_IMPORTED_MODULE_245__["default"]; });

/* harmony import */ var _when_js__WEBPACK_IMPORTED_MODULE_246__ = __webpack_require__(/*! ./when.js */ "./node_modules/ramda/es/when.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "when", function() { return _when_js__WEBPACK_IMPORTED_MODULE_246__["default"]; });

/* harmony import */ var _where_js__WEBPACK_IMPORTED_MODULE_247__ = __webpack_require__(/*! ./where.js */ "./node_modules/ramda/es/where.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "where", function() { return _where_js__WEBPACK_IMPORTED_MODULE_247__["default"]; });

/* harmony import */ var _whereEq_js__WEBPACK_IMPORTED_MODULE_248__ = __webpack_require__(/*! ./whereEq.js */ "./node_modules/ramda/es/whereEq.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "whereEq", function() { return _whereEq_js__WEBPACK_IMPORTED_MODULE_248__["default"]; });

/* harmony import */ var _without_js__WEBPACK_IMPORTED_MODULE_249__ = __webpack_require__(/*! ./without.js */ "./node_modules/ramda/es/without.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "without", function() { return _without_js__WEBPACK_IMPORTED_MODULE_249__["default"]; });

/* harmony import */ var _xprod_js__WEBPACK_IMPORTED_MODULE_250__ = __webpack_require__(/*! ./xprod.js */ "./node_modules/ramda/es/xprod.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "xprod", function() { return _xprod_js__WEBPACK_IMPORTED_MODULE_250__["default"]; });

/* harmony import */ var _zip_js__WEBPACK_IMPORTED_MODULE_251__ = __webpack_require__(/*! ./zip.js */ "./node_modules/ramda/es/zip.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "zip", function() { return _zip_js__WEBPACK_IMPORTED_MODULE_251__["default"]; });

/* harmony import */ var _zipObj_js__WEBPACK_IMPORTED_MODULE_252__ = __webpack_require__(/*! ./zipObj.js */ "./node_modules/ramda/es/zipObj.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "zipObj", function() { return _zipObj_js__WEBPACK_IMPORTED_MODULE_252__["default"]; });

/* harmony import */ var _zipWith_js__WEBPACK_IMPORTED_MODULE_253__ = __webpack_require__(/*! ./zipWith.js */ "./node_modules/ramda/es/zipWith.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "zipWith", function() { return _zipWith_js__WEBPACK_IMPORTED_MODULE_253__["default"]; });

/* harmony import */ var _thunkify_js__WEBPACK_IMPORTED_MODULE_254__ = __webpack_require__(/*! ./thunkify.js */ "./node_modules/ramda/es/thunkify.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "thunkify", function() { return _thunkify_js__WEBPACK_IMPORTED_MODULE_254__["default"]; });

































































































































































































































































/***/ }),

/***/ "./node_modules/ramda/es/indexBy.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/indexBy.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _reduceBy_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./reduceBy.js */ "./node_modules/ramda/es/reduceBy.js");


/**
 * Given a function that generates a key, turns a list of objects into an
 * object indexing the objects by the given key. Note that if multiple
 * objects generate the same value for the indexing key only the last value
 * will be included in the generated object.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig (a -> String) -> [{k: v}] -> {k: {k: v}}
 * @param {Function} fn Function :: a -> String
 * @param {Array} array The array of objects to index
 * @return {Object} An object indexing each array element by the given property.
 * @example
 *
 *      const list = [{id: 'xyz', title: 'A'}, {id: 'abc', title: 'B'}];
 *      R.indexBy(R.prop('id'), list);
 *      //=> {abc: {id: 'abc', title: 'B'}, xyz: {id: 'xyz', title: 'A'}}
 */
var indexBy = /*#__PURE__*/Object(_reduceBy_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (acc, elem) {
  return elem;
}, null);
/* harmony default export */ __webpack_exports__["default"] = (indexBy);

/***/ }),

/***/ "./node_modules/ramda/es/indexOf.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/indexOf.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_indexOf_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_indexOf.js */ "./node_modules/ramda/es/internal/_indexOf.js");
/* harmony import */ var _internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");




/**
 * Returns the position of the first occurrence of an item in an array, or -1
 * if the item is not included in the array. [`R.equals`](#equals) is used to
 * determine equality.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig a -> [a] -> Number
 * @param {*} target The item to find.
 * @param {Array} xs The array to search in.
 * @return {Number} the index of the target, or -1 if the target is not found.
 * @see R.lastIndexOf
 * @example
 *
 *      R.indexOf(3, [1,2,3,4]); //=> 2
 *      R.indexOf(10, [1,2,3,4]); //=> -1
 */
var indexOf = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function indexOf(target, xs) {
  return typeof xs.indexOf === 'function' && !Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_2__["default"])(xs) ? xs.indexOf(target) : Object(_internal_indexOf_js__WEBPACK_IMPORTED_MODULE_1__["default"])(xs, target, 0);
});
/* harmony default export */ __webpack_exports__["default"] = (indexOf);

/***/ }),

/***/ "./node_modules/ramda/es/init.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/init.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");


/**
 * Returns all but the last element of the given list or string.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category List
 * @sig [a] -> [a]
 * @sig String -> String
 * @param {*} list
 * @return {*}
 * @see R.last, R.head, R.tail
 * @example
 *
 *      R.init([1, 2, 3]);  //=> [1, 2]
 *      R.init([1, 2]);     //=> [1]
 *      R.init([1]);        //=> []
 *      R.init([]);         //=> []
 *
 *      R.init('abc');  //=> 'ab'
 *      R.init('ab');   //=> 'a'
 *      R.init('a');    //=> ''
 *      R.init('');     //=> ''
 */
var init = /*#__PURE__*/Object(_slice_js__WEBPACK_IMPORTED_MODULE_0__["default"])(0, -1);
/* harmony default export */ __webpack_exports__["default"] = (init);

/***/ }),

/***/ "./node_modules/ramda/es/innerJoin.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/innerJoin.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includesWith.js */ "./node_modules/ramda/es/internal/_includesWith.js");
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _internal_filter_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_filter.js */ "./node_modules/ramda/es/internal/_filter.js");




/**
 * Takes a predicate `pred`, a list `xs`, and a list `ys`, and returns a list
 * `xs'` comprising each of the elements of `xs` which is equal to one or more
 * elements of `ys` according to `pred`.
 *
 * `pred` must be a binary function expecting an element from each list.
 *
 * `xs`, `ys`, and `xs'` are treated as sets, semantically, so ordering should
 * not be significant, but since `xs'` is ordered the implementation guarantees
 * that its values are in the same order as they appear in `xs`. Duplicates are
 * not removed, so `xs'` may contain duplicates if `xs` contains duplicates.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Relation
 * @sig ((a, b) -> Boolean) -> [a] -> [b] -> [a]
 * @param {Function} pred
 * @param {Array} xs
 * @param {Array} ys
 * @return {Array}
 * @see R.intersection
 * @example
 *
 *      R.innerJoin(
 *        (record, id) => record.id === id,
 *        [{id: 824, name: 'Richie Furay'},
 *         {id: 956, name: 'Dewey Martin'},
 *         {id: 313, name: 'Bruce Palmer'},
 *         {id: 456, name: 'Stephen Stills'},
 *         {id: 177, name: 'Neil Young'}],
 *        [177, 456, 999]
 *      );
 *      //=> [{id: 456, name: 'Stephen Stills'}, {id: 177, name: 'Neil Young'}]
 */
var innerJoin = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function innerJoin(pred, xs, ys) {
  return Object(_internal_filter_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function (x) {
    return Object(_internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__["default"])(pred, x, ys);
  }, xs);
});
/* harmony default export */ __webpack_exports__["default"] = (innerJoin);

/***/ }),

/***/ "./node_modules/ramda/es/insert.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/insert.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Inserts the supplied element into the list, at the specified `index`. _Note that

 * this is not destructive_: it returns a copy of the list with the changes.
 * <small>No lists have been harmed in the application of this function.</small>
 *
 * @func
 * @memberOf R
 * @since v0.2.2
 * @category List
 * @sig Number -> a -> [a] -> [a]
 * @param {Number} index The position to insert the element
 * @param {*} elt The element to insert into the Array
 * @param {Array} list The list to insert into
 * @return {Array} A new Array with `elt` inserted at `index`.
 * @example
 *
 *      R.insert(2, 'x', [1,2,3,4]); //=> [1,2,'x',3,4]
 */
var insert = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function insert(idx, elt, list) {
  idx = idx < list.length && idx >= 0 ? idx : list.length;
  var result = Array.prototype.slice.call(list, 0);
  result.splice(idx, 0, elt);
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (insert);

/***/ }),

/***/ "./node_modules/ramda/es/insertAll.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/insertAll.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Inserts the sub-list into the list, at the specified `index`. _Note that this is not
 * destructive_: it returns a copy of the list with the changes.
 * <small>No lists have been harmed in the application of this function.</small>
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category List
 * @sig Number -> [a] -> [a] -> [a]
 * @param {Number} index The position to insert the sub-list
 * @param {Array} elts The sub-list to insert into the Array
 * @param {Array} list The list to insert the sub-list into
 * @return {Array} A new Array with `elts` inserted starting at `index`.
 * @example
 *
 *      R.insertAll(2, ['x','y','z'], [1,2,3,4]); //=> [1,2,'x','y','z',3,4]
 */
var insertAll = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function insertAll(idx, elts, list) {
  idx = idx < list.length && idx >= 0 ? idx : list.length;
  return [].concat(Array.prototype.slice.call(list, 0, idx), elts, Array.prototype.slice.call(list, idx));
});
/* harmony default export */ __webpack_exports__["default"] = (insertAll);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_Set.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/internal/_Set.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _includes_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_includes.js */ "./node_modules/ramda/es/internal/_includes.js");


var _Set = /*#__PURE__*/function () {
  function _Set() {
    /* globals Set */
    this._nativeSet = typeof Set === 'function' ? new Set() : null;
    this._items = {};
  }

  // until we figure out why jsdoc chokes on this
  // @param item The item to add to the Set
  // @returns {boolean} true if the item did not exist prior, otherwise false
  //
  _Set.prototype.add = function (item) {
    return !hasOrAdd(item, true, this);
  };

  //
  // @param item The item to check for existence in the Set
  // @returns {boolean} true if the item exists in the Set, otherwise false
  //
  _Set.prototype.has = function (item) {
    return hasOrAdd(item, false, this);
  };

  //
  // Combines the logic for checking whether an item is a member of the set and
  // for adding a new item to the set.
  //
  // @param item       The item to check or add to the Set instance.
  // @param shouldAdd  If true, the item will be added to the set if it doesn't
  //                   already exist.
  // @param set        The set instance to check or add to.
  // @return {boolean} true if the item already existed, otherwise false.
  //
  return _Set;
}();

function hasOrAdd(item, shouldAdd, set) {
  var type = typeof item;
  var prevSize, newSize;
  switch (type) {
    case 'string':
    case 'number':
      // distinguish between +0 and -0
      if (item === 0 && 1 / item === -Infinity) {
        if (set._items['-0']) {
          return true;
        } else {
          if (shouldAdd) {
            set._items['-0'] = true;
          }
          return false;
        }
      }
      // these types can all utilise the native Set
      if (set._nativeSet !== null) {
        if (shouldAdd) {
          prevSize = set._nativeSet.size;
          set._nativeSet.add(item);
          newSize = set._nativeSet.size;
          return newSize === prevSize;
        } else {
          return set._nativeSet.has(item);
        }
      } else {
        if (!(type in set._items)) {
          if (shouldAdd) {
            set._items[type] = {};
            set._items[type][item] = true;
          }
          return false;
        } else if (item in set._items[type]) {
          return true;
        } else {
          if (shouldAdd) {
            set._items[type][item] = true;
          }
          return false;
        }
      }

    case 'boolean':
      // set._items['boolean'] holds a two element array
      // representing [ falseExists, trueExists ]
      if (type in set._items) {
        var bIdx = item ? 1 : 0;
        if (set._items[type][bIdx]) {
          return true;
        } else {
          if (shouldAdd) {
            set._items[type][bIdx] = true;
          }
          return false;
        }
      } else {
        if (shouldAdd) {
          set._items[type] = item ? [false, true] : [true, false];
        }
        return false;
      }

    case 'function':
      // compare functions for reference equality
      if (set._nativeSet !== null) {
        if (shouldAdd) {
          prevSize = set._nativeSet.size;
          set._nativeSet.add(item);
          newSize = set._nativeSet.size;
          return newSize === prevSize;
        } else {
          return set._nativeSet.has(item);
        }
      } else {
        if (!(type in set._items)) {
          if (shouldAdd) {
            set._items[type] = [item];
          }
          return false;
        }
        if (!Object(_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"])(item, set._items[type])) {
          if (shouldAdd) {
            set._items[type].push(item);
          }
          return false;
        }
        return true;
      }

    case 'undefined':
      if (set._items[type]) {
        return true;
      } else {
        if (shouldAdd) {
          set._items[type] = true;
        }
        return false;
      }

    case 'object':
      if (item === null) {
        if (!set._items['null']) {
          if (shouldAdd) {
            set._items['null'] = true;
          }
          return false;
        }
        return true;
      }
    /* falls through */
    default:
      // reduce the search size of heterogeneous sets by creating buckets
      // for each type.
      type = Object.prototype.toString.call(item);
      if (!(type in set._items)) {
        if (shouldAdd) {
          set._items[type] = [item];
        }
        return false;
      }
      // scan through all previously applied items
      if (!Object(_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"])(item, set._items[type])) {
        if (shouldAdd) {
          set._items[type].push(item);
        }
        return false;
      }
      return true;
  }
}

// A simple Set type that honours R.equals semantics
/* harmony default export */ __webpack_exports__["default"] = (_Set);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_aperture.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_aperture.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _aperture; });
function _aperture(n, list) {
  var idx = 0;
  var limit = list.length - (n - 1);
  var acc = new Array(limit >= 0 ? limit : 0);
  while (idx < limit) {
    acc[idx] = Array.prototype.slice.call(list, idx, idx + n);
    idx += 1;
  }
  return acc;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_arity.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_arity.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _arity; });
function _arity(n, fn) {
  /* eslint-disable no-unused-vars */
  switch (n) {
    case 0:
      return function () {
        return fn.apply(this, arguments);
      };
    case 1:
      return function (a0) {
        return fn.apply(this, arguments);
      };
    case 2:
      return function (a0, a1) {
        return fn.apply(this, arguments);
      };
    case 3:
      return function (a0, a1, a2) {
        return fn.apply(this, arguments);
      };
    case 4:
      return function (a0, a1, a2, a3) {
        return fn.apply(this, arguments);
      };
    case 5:
      return function (a0, a1, a2, a3, a4) {
        return fn.apply(this, arguments);
      };
    case 6:
      return function (a0, a1, a2, a3, a4, a5) {
        return fn.apply(this, arguments);
      };
    case 7:
      return function (a0, a1, a2, a3, a4, a5, a6) {
        return fn.apply(this, arguments);
      };
    case 8:
      return function (a0, a1, a2, a3, a4, a5, a6, a7) {
        return fn.apply(this, arguments);
      };
    case 9:
      return function (a0, a1, a2, a3, a4, a5, a6, a7, a8) {
        return fn.apply(this, arguments);
      };
    case 10:
      return function (a0, a1, a2, a3, a4, a5, a6, a7, a8, a9) {
        return fn.apply(this, arguments);
      };
    default:
      throw new Error('First argument to _arity must be a non-negative integer no greater than ten');
  }
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_arrayFromIterator.js":
/*!**************************************************************!*\
  !*** ./node_modules/ramda/es/internal/_arrayFromIterator.js ***!
  \**************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _arrayFromIterator; });
function _arrayFromIterator(iter) {
  var list = [];
  var next;
  while (!(next = iter.next()).done) {
    list.push(next.value);
  }
  return list;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_assertPromise.js":
/*!**********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_assertPromise.js ***!
  \**********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _assertPromise; });
/* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_isFunction.js */ "./node_modules/ramda/es/internal/_isFunction.js");
/* harmony import */ var _toString_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_toString.js */ "./node_modules/ramda/es/internal/_toString.js");



function _assertPromise(name, p) {
  if (p == null || !Object(_isFunction_js__WEBPACK_IMPORTED_MODULE_0__["default"])(p.then)) {
    throw new TypeError('`' + name + '` expected a Promise, received ' + Object(_toString_js__WEBPACK_IMPORTED_MODULE_1__["default"])(p, []));
  }
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_checkForMethod.js":
/*!***********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_checkForMethod.js ***!
  \***********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _checkForMethod; });
/* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");


/**
 * This checks whether a function has a [methodname] function. If it isn't an
 * array it will execute that function otherwise it will default to the ramda
 * implementation.
 *
 * @private
 * @param {Function} fn ramda implemtation
 * @param {String} methodname property to check for a custom implementation
 * @return {Object} Whatever the return value of the method is.
 */
function _checkForMethod(methodname, fn) {
  return function () {
    var length = arguments.length;
    if (length === 0) {
      return fn();
    }
    var obj = arguments[length - 1];
    return Object(_isArray_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj) || typeof obj[methodname] !== 'function' ? fn.apply(this, arguments) : obj[methodname].apply(obj, Array.prototype.slice.call(arguments, 0, length - 1));
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_clone.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_clone.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _clone; });
/* harmony import */ var _cloneRegExp_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_cloneRegExp.js */ "./node_modules/ramda/es/internal/_cloneRegExp.js");
/* harmony import */ var _type_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../type.js */ "./node_modules/ramda/es/type.js");



/**
 * Copies an object.
 *
 * @private
 * @param {*} value The value to be copied
 * @param {Array} refFrom Array containing the source references
 * @param {Array} refTo Array containing the copied source references
 * @param {Boolean} deep Whether or not to perform deep cloning.
 * @return {*} The copied value.
 */
function _clone(value, refFrom, refTo, deep) {
  var copy = function copy(copiedValue) {
    var len = refFrom.length;
    var idx = 0;
    while (idx < len) {
      if (value === refFrom[idx]) {
        return refTo[idx];
      }
      idx += 1;
    }
    refFrom[idx + 1] = value;
    refTo[idx + 1] = copiedValue;
    for (var key in value) {
      copiedValue[key] = deep ? _clone(value[key], refFrom, refTo, true) : value[key];
    }
    return copiedValue;
  };
  switch (Object(_type_js__WEBPACK_IMPORTED_MODULE_1__["default"])(value)) {
    case 'Object':
      return copy({});
    case 'Array':
      return copy([]);
    case 'Date':
      return new Date(value.valueOf());
    case 'RegExp':
      return Object(_cloneRegExp_js__WEBPACK_IMPORTED_MODULE_0__["default"])(value);
    default:
      return value;
  }
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_cloneRegExp.js":
/*!********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_cloneRegExp.js ***!
  \********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _cloneRegExp; });
function _cloneRegExp(pattern) {
                                  return new RegExp(pattern.source, (pattern.global ? 'g' : '') + (pattern.ignoreCase ? 'i' : '') + (pattern.multiline ? 'm' : '') + (pattern.sticky ? 'y' : '') + (pattern.unicode ? 'u' : ''));
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_complement.js":
/*!*******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_complement.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _complement; });
function _complement(f) {
  return function () {
    return !f.apply(this, arguments);
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_concat.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_concat.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _concat; });
/**
 * Private `concat` function to merge two array-like objects.
 *
 * @private
 * @param {Array|Arguments} [set1=[]] An array-like object.
 * @param {Array|Arguments} [set2=[]] An array-like object.
 * @return {Array} A new, merged array.
 * @example
 *
 *      _concat([4, 5, 6], [1, 2, 3]); //=> [4, 5, 6, 1, 2, 3]
 */
function _concat(set1, set2) {
  set1 = set1 || [];
  set2 = set2 || [];
  var idx;
  var len1 = set1.length;
  var len2 = set2.length;
  var result = [];

  idx = 0;
  while (idx < len1) {
    result[result.length] = set1[idx];
    idx += 1;
  }
  idx = 0;
  while (idx < len2) {
    result[result.length] = set2[idx];
    idx += 1;
  }
  return result;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_createPartialApplicator.js":
/*!********************************************************************!*\
  !*** ./node_modules/ramda/es/internal/_createPartialApplicator.js ***!
  \********************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _createPartialApplicator; });
/* harmony import */ var _arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



function _createPartialApplicator(concat) {
  return Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (fn, args) {
    return Object(_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(Math.max(0, fn.length - args.length), function () {
      return fn.apply(this, concat(args, arguments));
    });
  });
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_curry1.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_curry1.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _curry1; });
/* harmony import */ var _isPlaceholder_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_isPlaceholder.js */ "./node_modules/ramda/es/internal/_isPlaceholder.js");


/**
 * Optimized internal one-arity curry function.
 *
 * @private
 * @category Function
 * @param {Function} fn The function to curry.
 * @return {Function} The curried function.
 */
function _curry1(fn) {
  return function f1(a) {
    if (arguments.length === 0 || Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_0__["default"])(a)) {
      return f1;
    } else {
      return fn.apply(this, arguments);
    }
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_curry2.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_curry2.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _curry2; });
/* harmony import */ var _curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_isPlaceholder.js */ "./node_modules/ramda/es/internal/_isPlaceholder.js");



/**
 * Optimized internal two-arity curry function.
 *
 * @private
 * @category Function
 * @param {Function} fn The function to curry.
 * @return {Function} The curried function.
 */
function _curry2(fn) {
  return function f2(a, b) {
    switch (arguments.length) {
      case 0:
        return f2;
      case 1:
        return Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(a) ? f2 : Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_b) {
          return fn(a, _b);
        });
      default:
        return Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(a) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(b) ? f2 : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(a) ? Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_a) {
          return fn(_a, b);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(b) ? Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_b) {
          return fn(a, _b);
        }) : fn(a, b);
    }
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_curry3.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_curry3.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _curry3; });
/* harmony import */ var _curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_isPlaceholder.js */ "./node_modules/ramda/es/internal/_isPlaceholder.js");




/**
 * Optimized internal three-arity curry function.
 *
 * @private
 * @category Function
 * @param {Function} fn The function to curry.
 * @return {Function} The curried function.
 */
function _curry3(fn) {
  return function f3(a, b, c) {
    switch (arguments.length) {
      case 0:
        return f3;
      case 1:
        return Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) ? f3 : Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_b, _c) {
          return fn(a, _b, _c);
        });
      case 2:
        return Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b) ? f3 : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) ? Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_a, _c) {
          return fn(_a, b, _c);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b) ? Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_b, _c) {
          return fn(a, _b, _c);
        }) : Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_c) {
          return fn(a, b, _c);
        });
      default:
        return Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(c) ? f3 : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b) ? Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_a, _b) {
          return fn(_a, _b, c);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(c) ? Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_a, _c) {
          return fn(_a, b, _c);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b) && Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(c) ? Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_b, _c) {
          return fn(a, _b, _c);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a) ? Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_a) {
          return fn(_a, b, c);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b) ? Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_b) {
          return fn(a, _b, c);
        }) : Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(c) ? Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (_c) {
          return fn(a, b, _c);
        }) : fn(a, b, c);
    }
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_curryN.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_curryN.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _curryN; });
/* harmony import */ var _arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_isPlaceholder.js */ "./node_modules/ramda/es/internal/_isPlaceholder.js");



/**
 * Internal curryN function.
 *
 * @private
 * @category Function
 * @param {Number} length The arity of the curried function.
 * @param {Array} received An array of arguments received thus far.
 * @param {Function} fn The function to curry.
 * @return {Function} The curried function.
 */
function _curryN(length, received, fn) {
  return function () {
    var combined = [];
    var argsIdx = 0;
    var left = length;
    var combinedIdx = 0;
    while (combinedIdx < received.length || argsIdx < arguments.length) {
      var result;
      if (combinedIdx < received.length && (!Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(received[combinedIdx]) || argsIdx >= arguments.length)) {
        result = received[combinedIdx];
      } else {
        result = arguments[argsIdx];
        argsIdx += 1;
      }
      combined[combinedIdx] = result;
      if (!Object(_isPlaceholder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(result)) {
        left -= 1;
      }
      combinedIdx += 1;
    }
    return left <= 0 ? fn.apply(this, combined) : Object(_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(left, _curryN(length, combined, fn));
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_dispatchable.js":
/*!*********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_dispatchable.js ***!
  \*********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _dispatchable; });
/* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _isTransformer_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_isTransformer.js */ "./node_modules/ramda/es/internal/_isTransformer.js");



/**
 * Returns a function that dispatches with different strategies based on the
 * object in list position (last argument). If it is an array, executes [fn].
 * Otherwise, if it has a function with one of the given method names, it will
 * execute that function (functor case). Otherwise, if it is a transformer,
 * uses transducer [xf] to return a new transformer (transducer case).
 * Otherwise, it will default to executing [fn].
 *
 * @private
 * @param {Array} methodNames properties to check for a custom implementation
 * @param {Function} xf transducer to initialize if object is transformer
 * @param {Function} fn default ramda implementation
 * @return {Function} A function that dispatches on object in list position
 */
function _dispatchable(methodNames, xf, fn) {
  return function () {
    if (arguments.length === 0) {
      return fn();
    }
    var args = Array.prototype.slice.call(arguments, 0);
    var obj = args.pop();
    if (!Object(_isArray_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj)) {
      var idx = 0;
      while (idx < methodNames.length) {
        if (typeof obj[methodNames[idx]] === 'function') {
          return obj[methodNames[idx]].apply(obj, args);
        }
        idx += 1;
      }
      if (Object(_isTransformer_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj)) {
        var transducer = xf.apply(null, args);
        return transducer(obj);
      }
    }
    return fn.apply(this, arguments);
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_dropLast.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_dropLast.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return dropLast; });
/* harmony import */ var _take_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../take.js */ "./node_modules/ramda/es/take.js");


function dropLast(n, xs) {
  return Object(_take_js__WEBPACK_IMPORTED_MODULE_0__["default"])(n < xs.length ? xs.length - n : 0, xs);
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_dropLastWhile.js":
/*!**********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_dropLastWhile.js ***!
  \**********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return dropLastWhile; });
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../slice.js */ "./node_modules/ramda/es/slice.js");


function dropLastWhile(pred, xs) {
  var idx = xs.length - 1;
  while (idx >= 0 && pred(xs[idx])) {
    idx -= 1;
  }
  return Object(_slice_js__WEBPACK_IMPORTED_MODULE_0__["default"])(0, idx + 1, xs);
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_equals.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_equals.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _equals; });
/* harmony import */ var _arrayFromIterator_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_arrayFromIterator.js */ "./node_modules/ramda/es/internal/_arrayFromIterator.js");
/* harmony import */ var _includesWith_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_includesWith.js */ "./node_modules/ramda/es/internal/_includesWith.js");
/* harmony import */ var _functionName_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_functionName.js */ "./node_modules/ramda/es/internal/_functionName.js");
/* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./_has.js */ "./node_modules/ramda/es/internal/_has.js");
/* harmony import */ var _objectIs_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./_objectIs.js */ "./node_modules/ramda/es/internal/_objectIs.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../keys.js */ "./node_modules/ramda/es/keys.js");
/* harmony import */ var _type_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ../type.js */ "./node_modules/ramda/es/type.js");








/**
 * private _uniqContentEquals function.
 * That function is checking equality of 2 iterator contents with 2 assumptions
 * - iterators lengths are the same
 * - iterators values are unique
 *
 * false-positive result will be returned for comparision of, e.g.
 * - [1,2,3] and [1,2,3,4]
 * - [1,1,1] and [1,2,3]
 * */

function _uniqContentEquals(aIterator, bIterator, stackA, stackB) {
  var a = Object(_arrayFromIterator_js__WEBPACK_IMPORTED_MODULE_0__["default"])(aIterator);
  var b = Object(_arrayFromIterator_js__WEBPACK_IMPORTED_MODULE_0__["default"])(bIterator);

  function eq(_a, _b) {
    return _equals(_a, _b, stackA.slice(), stackB.slice());
  }

  // if *a* array contains any element that is not included in *b*
  return !Object(_includesWith_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (b, aItem) {
    return !Object(_includesWith_js__WEBPACK_IMPORTED_MODULE_1__["default"])(eq, aItem, b);
  }, b, a);
}

function _equals(a, b, stackA, stackB) {
  if (Object(_objectIs_js__WEBPACK_IMPORTED_MODULE_4__["default"])(a, b)) {
    return true;
  }

  var typeA = Object(_type_js__WEBPACK_IMPORTED_MODULE_6__["default"])(a);

  if (typeA !== Object(_type_js__WEBPACK_IMPORTED_MODULE_6__["default"])(b)) {
    return false;
  }

  if (a == null || b == null) {
    return false;
  }

  if (typeof a['fantasy-land/equals'] === 'function' || typeof b['fantasy-land/equals'] === 'function') {
    return typeof a['fantasy-land/equals'] === 'function' && a['fantasy-land/equals'](b) && typeof b['fantasy-land/equals'] === 'function' && b['fantasy-land/equals'](a);
  }

  if (typeof a.equals === 'function' || typeof b.equals === 'function') {
    return typeof a.equals === 'function' && a.equals(b) && typeof b.equals === 'function' && b.equals(a);
  }

  switch (typeA) {
    case 'Arguments':
    case 'Array':
    case 'Object':
      if (typeof a.constructor === 'function' && Object(_functionName_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a.constructor) === 'Promise') {
        return a === b;
      }
      break;
    case 'Boolean':
    case 'Number':
    case 'String':
      if (!(typeof a === typeof b && Object(_objectIs_js__WEBPACK_IMPORTED_MODULE_4__["default"])(a.valueOf(), b.valueOf()))) {
        return false;
      }
      break;
    case 'Date':
      if (!Object(_objectIs_js__WEBPACK_IMPORTED_MODULE_4__["default"])(a.valueOf(), b.valueOf())) {
        return false;
      }
      break;
    case 'Error':
      return a.name === b.name && a.message === b.message;
    case 'RegExp':
      if (!(a.source === b.source && a.global === b.global && a.ignoreCase === b.ignoreCase && a.multiline === b.multiline && a.sticky === b.sticky && a.unicode === b.unicode)) {
        return false;
      }
      break;
  }

  var idx = stackA.length - 1;
  while (idx >= 0) {
    if (stackA[idx] === a) {
      return stackB[idx] === b;
    }
    idx -= 1;
  }

  switch (typeA) {
    case 'Map':
      if (a.size !== b.size) {
        return false;
      }

      return _uniqContentEquals(a.entries(), b.entries(), stackA.concat([a]), stackB.concat([b]));
    case 'Set':
      if (a.size !== b.size) {
        return false;
      }

      return _uniqContentEquals(a.values(), b.values(), stackA.concat([a]), stackB.concat([b]));
    case 'Arguments':
    case 'Array':
    case 'Object':
    case 'Boolean':
    case 'Number':
    case 'String':
    case 'Date':
    case 'Error':
    case 'RegExp':
    case 'Int8Array':
    case 'Uint8Array':
    case 'Uint8ClampedArray':
    case 'Int16Array':
    case 'Uint16Array':
    case 'Int32Array':
    case 'Uint32Array':
    case 'Float32Array':
    case 'Float64Array':
    case 'ArrayBuffer':
      break;
    default:
      // Values of other types are only equal if identical.
      return false;
  }

  var keysA = Object(_keys_js__WEBPACK_IMPORTED_MODULE_5__["default"])(a);
  if (keysA.length !== Object(_keys_js__WEBPACK_IMPORTED_MODULE_5__["default"])(b).length) {
    return false;
  }

  var extendedStackA = stackA.concat([a]);
  var extendedStackB = stackB.concat([b]);

  idx = keysA.length - 1;
  while (idx >= 0) {
    var key = keysA[idx];
    if (!(Object(_has_js__WEBPACK_IMPORTED_MODULE_3__["default"])(key, b) && _equals(b[key], a[key], extendedStackA, extendedStackB))) {
      return false;
    }
    idx -= 1;
  }
  return true;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_filter.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_filter.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _filter; });
function _filter(fn, list) {
  var idx = 0;
  var len = list.length;
  var result = [];

  while (idx < len) {
    if (fn(list[idx])) {
      result[result.length] = list[idx];
    }
    idx += 1;
  }
  return result;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_flatCat.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_flatCat.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _forceReduced_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_forceReduced.js */ "./node_modules/ramda/es/internal/_forceReduced.js");
/* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_isArrayLike.js */ "./node_modules/ramda/es/internal/_isArrayLike.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");





var preservingReduced = function (xf) {
  return {
    '@@transducer/init': _xfBase_js__WEBPACK_IMPORTED_MODULE_3__["default"].init,
    '@@transducer/result': function (result) {
      return xf['@@transducer/result'](result);
    },
    '@@transducer/step': function (result, input) {
      var ret = xf['@@transducer/step'](result, input);
      return ret['@@transducer/reduced'] ? Object(_forceReduced_js__WEBPACK_IMPORTED_MODULE_0__["default"])(ret) : ret;
    }
  };
};

var _flatCat = function _xcat(xf) {
  var rxf = preservingReduced(xf);
  return {
    '@@transducer/init': _xfBase_js__WEBPACK_IMPORTED_MODULE_3__["default"].init,
    '@@transducer/result': function (result) {
      return rxf['@@transducer/result'](result);
    },
    '@@transducer/step': function (result, input) {
      return !Object(_isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__["default"])(input) ? Object(_reduce_js__WEBPACK_IMPORTED_MODULE_2__["default"])(rxf, result, [input]) : Object(_reduce_js__WEBPACK_IMPORTED_MODULE_2__["default"])(rxf, result, input);
    }
  };
};

/* harmony default export */ __webpack_exports__["default"] = (_flatCat);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_forceReduced.js":
/*!*********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_forceReduced.js ***!
  \*********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _forceReduced; });
function _forceReduced(x) {
  return {
    '@@transducer/value': x,
    '@@transducer/reduced': true
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_functionName.js":
/*!*********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_functionName.js ***!
  \*********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _functionName; });
function _functionName(f) {
  // String(x => x) evaluates to "x => x", so the pattern may not match.
  var match = String(f).match(/^function (\w*)/);
  return match == null ? '' : match[1];
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_has.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/internal/_has.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _has; });
function _has(prop, obj) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_identity.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_identity.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _identity; });
function _identity(x) {
  return x;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_includes.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_includes.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _includes; });
/* harmony import */ var _indexOf_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_indexOf.js */ "./node_modules/ramda/es/internal/_indexOf.js");


function _includes(a, list) {
  return Object(_indexOf_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list, a, 0) >= 0;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_includesWith.js":
/*!*********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_includesWith.js ***!
  \*********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _includesWith; });
function _includesWith(pred, x, list) {
  var idx = 0;
  var len = list.length;

  while (idx < len) {
    if (pred(x, list[idx])) {
      return true;
    }
    idx += 1;
  }
  return false;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_indexOf.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_indexOf.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _indexOf; });
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../equals.js */ "./node_modules/ramda/es/equals.js");


function _indexOf(list, a, idx) {
  var inf, item;
  // Array.prototype.indexOf doesn't exist below IE9
  if (typeof list.indexOf === 'function') {
    switch (typeof a) {
      case 'number':
        if (a === 0) {
          // manually crawl the list to distinguish between +0 and -0
          inf = 1 / a;
          while (idx < list.length) {
            item = list[idx];
            if (item === 0 && 1 / item === inf) {
              return idx;
            }
            idx += 1;
          }
          return -1;
        } else if (a !== a) {
          // NaN
          while (idx < list.length) {
            item = list[idx];
            if (typeof item === 'number' && item !== item) {
              return idx;
            }
            idx += 1;
          }
          return -1;
        }
        // non-zero numbers can utilise Set
        return list.indexOf(a, idx);

      // all these types can utilise Set
      case 'string':
      case 'boolean':
      case 'function':
      case 'undefined':
        return list.indexOf(a, idx);

      case 'object':
        if (a === null) {
          // null can utilise Set
          return list.indexOf(a, idx);
        }
    }
  }
  // anything else not covered above, defer to R.equals
  while (idx < list.length) {
    if (Object(_equals_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list[idx], a)) {
      return idx;
    }
    idx += 1;
  }
  return -1;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isArguments.js":
/*!********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isArguments.js ***!
  \********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_has.js */ "./node_modules/ramda/es/internal/_has.js");


var toString = Object.prototype.toString;
var _isArguments = /*#__PURE__*/function () {
  return toString.call(arguments) === '[object Arguments]' ? function _isArguments(x) {
    return toString.call(x) === '[object Arguments]';
  } : function _isArguments(x) {
    return Object(_has_js__WEBPACK_IMPORTED_MODULE_0__["default"])('callee', x);
  };
}();

/* harmony default export */ __webpack_exports__["default"] = (_isArguments);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isArray.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isArray.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/**
 * Tests whether or not an object is an array.
 *
 * @private
 * @param {*} val The object to test.
 * @return {Boolean} `true` if `val` is an array, `false` otherwise.
 * @example
 *
 *      _isArray([]); //=> true
 *      _isArray(null); //=> false
 *      _isArray({}); //=> false
 */
/* harmony default export */ __webpack_exports__["default"] = (Array.isArray || function _isArray(val) {
  return val != null && val.length >= 0 && Object.prototype.toString.call(val) === '[object Array]';
});

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isArrayLike.js":
/*!********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isArrayLike.js ***!
  \********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _isString_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_isString.js */ "./node_modules/ramda/es/internal/_isString.js");




/**
 * Tests whether or not an object is similar to an array.
 *
 * @private
 * @category Type
 * @category List
 * @sig * -> Boolean
 * @param {*} x The object to test.
 * @return {Boolean} `true` if `x` has a numeric length property and extreme indices defined; `false` otherwise.
 * @example
 *
 *      _isArrayLike([]); //=> true
 *      _isArrayLike(true); //=> false
 *      _isArrayLike({}); //=> false
 *      _isArrayLike({length: 10}); //=> false
 *      _isArrayLike({0: 'zero', 9: 'nine', length: 10}); //=> true
 */
var _isArrayLike = /*#__PURE__*/Object(_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function isArrayLike(x) {
  if (Object(_isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(x)) {
    return true;
  }
  if (!x) {
    return false;
  }
  if (typeof x !== 'object') {
    return false;
  }
  if (Object(_isString_js__WEBPACK_IMPORTED_MODULE_2__["default"])(x)) {
    return false;
  }
  if (x.nodeType === 1) {
    return !!x.length;
  }
  if (x.length === 0) {
    return true;
  }
  if (x.length > 0) {
    return x.hasOwnProperty(0) && x.hasOwnProperty(x.length - 1);
  }
  return false;
});
/* harmony default export */ __webpack_exports__["default"] = (_isArrayLike);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isFunction.js":
/*!*******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isFunction.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isFunction; });
function _isFunction(x) {
  return Object.prototype.toString.call(x) === '[object Function]';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isInteger.js":
/*!******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isInteger.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/**
 * Determine if the passed argument is an integer.
 *
 * @private
 * @param {*} n
 * @category Type
 * @return {Boolean}
 */
/* harmony default export */ __webpack_exports__["default"] = (Number.isInteger || function _isInteger(n) {
  return n << 0 === n;
});

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isNumber.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isNumber.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isNumber; });
function _isNumber(x) {
  return Object.prototype.toString.call(x) === '[object Number]';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isObject.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isObject.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isObject; });
function _isObject(x) {
  return Object.prototype.toString.call(x) === '[object Object]';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isPlaceholder.js":
/*!**********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isPlaceholder.js ***!
  \**********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isPlaceholder; });
function _isPlaceholder(a) {
       return a != null && typeof a === 'object' && a['@@functional/placeholder'] === true;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isRegExp.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isRegExp.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isRegExp; });
function _isRegExp(x) {
  return Object.prototype.toString.call(x) === '[object RegExp]';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isString.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isString.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isString; });
function _isString(x) {
  return Object.prototype.toString.call(x) === '[object String]';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_isTransformer.js":
/*!**********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_isTransformer.js ***!
  \**********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _isTransformer; });
function _isTransformer(obj) {
  return obj != null && typeof obj['@@transducer/step'] === 'function';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_makeFlat.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_makeFlat.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _makeFlat; });
/* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_isArrayLike.js */ "./node_modules/ramda/es/internal/_isArrayLike.js");


/**
 * `_makeFlat` is a helper function that returns a one-level or fully recursive
 * function based on the flag passed in.
 *
 * @private
 */
function _makeFlat(recursive) {
  return function flatt(list) {
    var value, jlen, j;
    var result = [];
    var idx = 0;
    var ilen = list.length;

    while (idx < ilen) {
      if (Object(_isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list[idx])) {
        value = recursive ? flatt(list[idx]) : list[idx];
        j = 0;
        jlen = value.length;
        while (j < jlen) {
          result[result.length] = value[j];
          j += 1;
        }
      } else {
        result[result.length] = list[idx];
      }
      idx += 1;
    }
    return result;
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_map.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/internal/_map.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _map; });
function _map(fn, functor) {
  var idx = 0;
  var len = functor.length;
  var result = Array(len);
  while (idx < len) {
    result[idx] = fn(functor[idx]);
    idx += 1;
  }
  return result;
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_objectAssign.js":
/*!*********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_objectAssign.js ***!
  \*********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_has.js */ "./node_modules/ramda/es/internal/_has.js");


// Based on https://developer.mozilla.org/en/docs/Web/JavaScript/Reference/Global_Objects/Object/assign
function _objectAssign(target) {
  if (target == null) {
    throw new TypeError('Cannot convert undefined or null to object');
  }

  var output = Object(target);
  var idx = 1;
  var length = arguments.length;
  while (idx < length) {
    var source = arguments[idx];
    if (source != null) {
      for (var nextKey in source) {
        if (Object(_has_js__WEBPACK_IMPORTED_MODULE_0__["default"])(nextKey, source)) {
          output[nextKey] = source[nextKey];
        }
      }
    }
    idx += 1;
  }
  return output;
}

/* harmony default export */ __webpack_exports__["default"] = (typeof Object.assign === 'function' ? Object.assign : _objectAssign);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_objectIs.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_objectIs.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
// Based on https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/is
function _objectIs(a, b) {
  // SameValue algorithm
  if (a === b) {
    // Steps 1-5, 7-10
    // Steps 6.b-6.e: +0 != -0
    return a !== 0 || 1 / a === 1 / b;
  } else {
    // Step 6.a: NaN == NaN
    return a !== a && b !== b;
  }
}

/* harmony default export */ __webpack_exports__["default"] = (typeof Object.is === 'function' ? Object.is : _objectIs);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_of.js":
/*!***********************************************!*\
  !*** ./node_modules/ramda/es/internal/_of.js ***!
  \***********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _of; });
function _of(x) {
  return [x];
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_pipe.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/internal/_pipe.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _pipe; });
function _pipe(f, g) {
  return function () {
    return g.call(this, f.apply(this, arguments));
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_pipeP.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_pipeP.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _pipeP; });
function _pipeP(f, g) {
  return function () {
    var ctx = this;
    return f.apply(ctx, arguments).then(function (x) {
      return g.call(ctx, x);
    });
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_quote.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_quote.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _quote; });
function _quote(s) {
  var escaped = s.replace(/\\/g, '\\\\').replace(/[\b]/g, '\\b') // \b matches word boundary; [\b] matches backspace
  .replace(/\f/g, '\\f').replace(/\n/g, '\\n').replace(/\r/g, '\\r').replace(/\t/g, '\\t').replace(/\v/g, '\\v').replace(/\0/g, '\\0');

  return '"' + escaped.replace(/"/g, '\\"') + '"';
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_reduce.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_reduce.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _reduce; });
/* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_isArrayLike.js */ "./node_modules/ramda/es/internal/_isArrayLike.js");
/* harmony import */ var _xwrap_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xwrap.js */ "./node_modules/ramda/es/internal/_xwrap.js");
/* harmony import */ var _bind_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../bind.js */ "./node_modules/ramda/es/bind.js");




function _arrayReduce(xf, acc, list) {
  var idx = 0;
  var len = list.length;
  while (idx < len) {
    acc = xf['@@transducer/step'](acc, list[idx]);
    if (acc && acc['@@transducer/reduced']) {
      acc = acc['@@transducer/value'];
      break;
    }
    idx += 1;
  }
  return xf['@@transducer/result'](acc);
}

function _iterableReduce(xf, acc, iter) {
  var step = iter.next();
  while (!step.done) {
    acc = xf['@@transducer/step'](acc, step.value);
    if (acc && acc['@@transducer/reduced']) {
      acc = acc['@@transducer/value'];
      break;
    }
    step = iter.next();
  }
  return xf['@@transducer/result'](acc);
}

function _methodReduce(xf, acc, obj, methodName) {
  return xf['@@transducer/result'](obj[methodName](Object(_bind_js__WEBPACK_IMPORTED_MODULE_2__["default"])(xf['@@transducer/step'], xf), acc));
}

var symIterator = typeof Symbol !== 'undefined' ? Symbol.iterator : '@@iterator';

function _reduce(fn, acc, list) {
  if (typeof fn === 'function') {
    fn = Object(_xwrap_js__WEBPACK_IMPORTED_MODULE_1__["default"])(fn);
  }
  if (Object(_isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list)) {
    return _arrayReduce(fn, acc, list);
  }
  if (typeof list['fantasy-land/reduce'] === 'function') {
    return _methodReduce(fn, acc, list, 'fantasy-land/reduce');
  }
  if (list[symIterator] != null) {
    return _iterableReduce(fn, acc, list[symIterator]());
  }
  if (typeof list.next === 'function') {
    return _iterableReduce(fn, acc, list);
  }
  if (typeof list.reduce === 'function') {
    return _methodReduce(fn, acc, list, 'reduce');
  }

  throw new TypeError('reduce: list must be array or iterable');
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_reduced.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_reduced.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _reduced; });
function _reduced(x) {
  return x && x['@@transducer/reduced'] ? x : {
    '@@transducer/value': x,
    '@@transducer/reduced': true
  };
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_stepCat.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_stepCat.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _stepCat; });
/* harmony import */ var _objectAssign_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_objectAssign.js */ "./node_modules/ramda/es/internal/_objectAssign.js");
/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_identity.js */ "./node_modules/ramda/es/internal/_identity.js");
/* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_isArrayLike.js */ "./node_modules/ramda/es/internal/_isArrayLike.js");
/* harmony import */ var _isTransformer_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./_isTransformer.js */ "./node_modules/ramda/es/internal/_isTransformer.js");
/* harmony import */ var _objOf_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../objOf.js */ "./node_modules/ramda/es/objOf.js");






var _stepCatArray = {
  '@@transducer/init': Array,
  '@@transducer/step': function (xs, x) {
    xs.push(x);
    return xs;
  },
  '@@transducer/result': _identity_js__WEBPACK_IMPORTED_MODULE_1__["default"]
};
var _stepCatString = {
  '@@transducer/init': String,
  '@@transducer/step': function (a, b) {
    return a + b;
  },
  '@@transducer/result': _identity_js__WEBPACK_IMPORTED_MODULE_1__["default"]
};
var _stepCatObject = {
  '@@transducer/init': Object,
  '@@transducer/step': function (result, input) {
    return Object(_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__["default"])(result, Object(_isArrayLike_js__WEBPACK_IMPORTED_MODULE_2__["default"])(input) ? Object(_objOf_js__WEBPACK_IMPORTED_MODULE_4__["default"])(input[0], input[1]) : input);
  },
  '@@transducer/result': _identity_js__WEBPACK_IMPORTED_MODULE_1__["default"]
};

function _stepCat(obj) {
  if (Object(_isTransformer_js__WEBPACK_IMPORTED_MODULE_3__["default"])(obj)) {
    return obj;
  }
  if (Object(_isArrayLike_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj)) {
    return _stepCatArray;
  }
  if (typeof obj === 'string') {
    return _stepCatString;
  }
  if (typeof obj === 'object') {
    return _stepCatObject;
  }
  throw new Error('Cannot create transformer for ' + obj);
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_toISOString.js":
/*!********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_toISOString.js ***!
  \********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/**
 * Polyfill from <https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString>.
 */
var pad = function pad(n) {
  return (n < 10 ? '0' : '') + n;
};

var _toISOString = typeof Date.prototype.toISOString === 'function' ? function _toISOString(d) {
  return d.toISOString();
} : function _toISOString(d) {
  return d.getUTCFullYear() + '-' + pad(d.getUTCMonth() + 1) + '-' + pad(d.getUTCDate()) + 'T' + pad(d.getUTCHours()) + ':' + pad(d.getUTCMinutes()) + ':' + pad(d.getUTCSeconds()) + '.' + (d.getUTCMilliseconds() / 1000).toFixed(3).slice(2, 5) + 'Z';
};

/* harmony default export */ __webpack_exports__["default"] = (_toISOString);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_toString.js":
/*!*****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_toString.js ***!
  \*****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _toString; });
/* harmony import */ var _includes_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_includes.js */ "./node_modules/ramda/es/internal/_includes.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_map.js */ "./node_modules/ramda/es/internal/_map.js");
/* harmony import */ var _quote_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_quote.js */ "./node_modules/ramda/es/internal/_quote.js");
/* harmony import */ var _toISOString_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./_toISOString.js */ "./node_modules/ramda/es/internal/_toISOString.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../keys.js */ "./node_modules/ramda/es/keys.js");
/* harmony import */ var _reject_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ../reject.js */ "./node_modules/ramda/es/reject.js");







function _toString(x, seen) {
  var recur = function recur(y) {
    var xs = seen.concat([x]);
    return Object(_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"])(y, xs) ? '<Circular>' : _toString(y, xs);
  };

  //  mapPairs :: (Object, [String]) -> [String]
  var mapPairs = function (obj, keys) {
    return Object(_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (k) {
      return Object(_quote_js__WEBPACK_IMPORTED_MODULE_2__["default"])(k) + ': ' + recur(obj[k]);
    }, keys.slice().sort());
  };

  switch (Object.prototype.toString.call(x)) {
    case '[object Arguments]':
      return '(function() { return arguments; }(' + Object(_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(recur, x).join(', ') + '))';
    case '[object Array]':
      return '[' + Object(_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(recur, x).concat(mapPairs(x, Object(_reject_js__WEBPACK_IMPORTED_MODULE_5__["default"])(function (k) {
        return (/^\d+$/.test(k)
        );
      }, Object(_keys_js__WEBPACK_IMPORTED_MODULE_4__["default"])(x)))).join(', ') + ']';
    case '[object Boolean]':
      return typeof x === 'object' ? 'new Boolean(' + recur(x.valueOf()) + ')' : x.toString();
    case '[object Date]':
      return 'new Date(' + (isNaN(x.valueOf()) ? recur(NaN) : Object(_quote_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_toISOString_js__WEBPACK_IMPORTED_MODULE_3__["default"])(x))) + ')';
    case '[object Null]':
      return 'null';
    case '[object Number]':
      return typeof x === 'object' ? 'new Number(' + recur(x.valueOf()) + ')' : 1 / x === -Infinity ? '-0' : x.toString(10);
    case '[object String]':
      return typeof x === 'object' ? 'new String(' + recur(x.valueOf()) + ')' : Object(_quote_js__WEBPACK_IMPORTED_MODULE_2__["default"])(x);
    case '[object Undefined]':
      return 'undefined';
    default:
      if (typeof x.toString === 'function') {
        var repr = x.toString();
        if (repr !== '[object Object]') {
          return repr;
        }
      }
      return '{' + mapPairs(x, Object(_keys_js__WEBPACK_IMPORTED_MODULE_4__["default"])(x)).join(', ') + '}';
  }
}

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xall.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xall.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XAll = /*#__PURE__*/function () {
  function XAll(f, xf) {
    this.xf = xf;
    this.f = f;
    this.all = true;
  }
  XAll.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XAll.prototype['@@transducer/result'] = function (result) {
    if (this.all) {
      result = this.xf['@@transducer/step'](result, true);
    }
    return this.xf['@@transducer/result'](result);
  };
  XAll.prototype['@@transducer/step'] = function (result, input) {
    if (!this.f(input)) {
      this.all = false;
      result = Object(_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"])(this.xf['@@transducer/step'](result, false));
    }
    return result;
  };

  return XAll;
}();

var _xall = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xall(f, xf) {
  return new XAll(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xall);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xany.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xany.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XAny = /*#__PURE__*/function () {
  function XAny(f, xf) {
    this.xf = xf;
    this.f = f;
    this.any = false;
  }
  XAny.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XAny.prototype['@@transducer/result'] = function (result) {
    if (!this.any) {
      result = this.xf['@@transducer/step'](result, false);
    }
    return this.xf['@@transducer/result'](result);
  };
  XAny.prototype['@@transducer/step'] = function (result, input) {
    if (this.f(input)) {
      this.any = true;
      result = Object(_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"])(this.xf['@@transducer/step'](result, true));
    }
    return result;
  };

  return XAny;
}();

var _xany = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xany(f, xf) {
  return new XAny(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xany);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xaperture.js":
/*!******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xaperture.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XAperture = /*#__PURE__*/function () {
  function XAperture(n, xf) {
    this.xf = xf;
    this.pos = 0;
    this.full = false;
    this.acc = new Array(n);
  }
  XAperture.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XAperture.prototype['@@transducer/result'] = function (result) {
    this.acc = null;
    return this.xf['@@transducer/result'](result);
  };
  XAperture.prototype['@@transducer/step'] = function (result, input) {
    this.store(input);
    return this.full ? this.xf['@@transducer/step'](result, this.getCopy()) : result;
  };
  XAperture.prototype.store = function (input) {
    this.acc[this.pos] = input;
    this.pos += 1;
    if (this.pos === this.acc.length) {
      this.pos = 0;
      this.full = true;
    }
  };
  XAperture.prototype.getCopy = function () {
    return Object(_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])(Array.prototype.slice.call(this.acc, this.pos), Array.prototype.slice.call(this.acc, 0, this.pos));
  };

  return XAperture;
}();

var _xaperture = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function _xaperture(n, xf) {
  return new XAperture(n, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xaperture);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xchain.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xchain.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _flatCat_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_flatCat.js */ "./node_modules/ramda/es/internal/_flatCat.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ../map.js */ "./node_modules/ramda/es/map.js");




var _xchain = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xchain(f, xf) {
  return Object(_map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(f, Object(_flatCat_js__WEBPACK_IMPORTED_MODULE_1__["default"])(xf));
});
/* harmony default export */ __webpack_exports__["default"] = (_xchain);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xdrop.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xdrop.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XDrop = /*#__PURE__*/function () {
  function XDrop(n, xf) {
    this.xf = xf;
    this.n = n;
  }
  XDrop.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XDrop.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].result;
  XDrop.prototype['@@transducer/step'] = function (result, input) {
    if (this.n > 0) {
      this.n -= 1;
      return result;
    }
    return this.xf['@@transducer/step'](result, input);
  };

  return XDrop;
}();

var _xdrop = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xdrop(n, xf) {
  return new XDrop(n, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xdrop);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xdropLast.js":
/*!******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xdropLast.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XDropLast = /*#__PURE__*/function () {
  function XDropLast(n, xf) {
    this.xf = xf;
    this.pos = 0;
    this.full = false;
    this.acc = new Array(n);
  }
  XDropLast.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XDropLast.prototype['@@transducer/result'] = function (result) {
    this.acc = null;
    return this.xf['@@transducer/result'](result);
  };
  XDropLast.prototype['@@transducer/step'] = function (result, input) {
    if (this.full) {
      result = this.xf['@@transducer/step'](result, this.acc[this.pos]);
    }
    this.store(input);
    return result;
  };
  XDropLast.prototype.store = function (input) {
    this.acc[this.pos] = input;
    this.pos += 1;
    if (this.pos === this.acc.length) {
      this.pos = 0;
      this.full = true;
    }
  };

  return XDropLast;
}();

var _xdropLast = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xdropLast(n, xf) {
  return new XDropLast(n, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xdropLast);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xdropLastWhile.js":
/*!***********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xdropLastWhile.js ***!
  \***********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XDropLastWhile = /*#__PURE__*/function () {
  function XDropLastWhile(fn, xf) {
    this.f = fn;
    this.retained = [];
    this.xf = xf;
  }
  XDropLastWhile.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XDropLastWhile.prototype['@@transducer/result'] = function (result) {
    this.retained = null;
    return this.xf['@@transducer/result'](result);
  };
  XDropLastWhile.prototype['@@transducer/step'] = function (result, input) {
    return this.f(input) ? this.retain(result, input) : this.flush(result, input);
  };
  XDropLastWhile.prototype.flush = function (result, input) {
    result = Object(_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"])(this.xf['@@transducer/step'], result, this.retained);
    this.retained = [];
    return this.xf['@@transducer/step'](result, input);
  };
  XDropLastWhile.prototype.retain = function (result, input) {
    this.retained.push(input);
    return result;
  };

  return XDropLastWhile;
}();

var _xdropLastWhile = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xdropLastWhile(fn, xf) {
  return new XDropLastWhile(fn, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xdropLastWhile);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xdropRepeatsWith.js":
/*!*************************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xdropRepeatsWith.js ***!
  \*************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XDropRepeatsWith = /*#__PURE__*/function () {
  function XDropRepeatsWith(pred, xf) {
    this.xf = xf;
    this.pred = pred;
    this.lastValue = undefined;
    this.seenFirstValue = false;
  }

  XDropRepeatsWith.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XDropRepeatsWith.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].result;
  XDropRepeatsWith.prototype['@@transducer/step'] = function (result, input) {
    var sameAsLast = false;
    if (!this.seenFirstValue) {
      this.seenFirstValue = true;
    } else if (this.pred(this.lastValue, input)) {
      sameAsLast = true;
    }
    this.lastValue = input;
    return sameAsLast ? result : this.xf['@@transducer/step'](result, input);
  };

  return XDropRepeatsWith;
}();

var _xdropRepeatsWith = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xdropRepeatsWith(pred, xf) {
  return new XDropRepeatsWith(pred, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xdropRepeatsWith);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xdropWhile.js":
/*!*******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xdropWhile.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XDropWhile = /*#__PURE__*/function () {
  function XDropWhile(f, xf) {
    this.xf = xf;
    this.f = f;
  }
  XDropWhile.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XDropWhile.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].result;
  XDropWhile.prototype['@@transducer/step'] = function (result, input) {
    if (this.f) {
      if (this.f(input)) {
        return result;
      }
      this.f = null;
    }
    return this.xf['@@transducer/step'](result, input);
  };

  return XDropWhile;
}();

var _xdropWhile = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xdropWhile(f, xf) {
  return new XDropWhile(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xdropWhile);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xfBase.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xfBase.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony default export */ __webpack_exports__["default"] = ({
  init: function () {
    return this.xf['@@transducer/init']();
  },
  result: function (result) {
    return this.xf['@@transducer/result'](result);
  }
});

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xfilter.js":
/*!****************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xfilter.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XFilter = /*#__PURE__*/function () {
  function XFilter(f, xf) {
    this.xf = xf;
    this.f = f;
  }
  XFilter.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XFilter.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].result;
  XFilter.prototype['@@transducer/step'] = function (result, input) {
    return this.f(input) ? this.xf['@@transducer/step'](result, input) : result;
  };

  return XFilter;
}();

var _xfilter = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xfilter(f, xf) {
  return new XFilter(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xfilter);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xfind.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xfind.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XFind = /*#__PURE__*/function () {
  function XFind(f, xf) {
    this.xf = xf;
    this.f = f;
    this.found = false;
  }
  XFind.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XFind.prototype['@@transducer/result'] = function (result) {
    if (!this.found) {
      result = this.xf['@@transducer/step'](result, void 0);
    }
    return this.xf['@@transducer/result'](result);
  };
  XFind.prototype['@@transducer/step'] = function (result, input) {
    if (this.f(input)) {
      this.found = true;
      result = Object(_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"])(this.xf['@@transducer/step'](result, input));
    }
    return result;
  };

  return XFind;
}();

var _xfind = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xfind(f, xf) {
  return new XFind(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xfind);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xfindIndex.js":
/*!*******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xfindIndex.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XFindIndex = /*#__PURE__*/function () {
  function XFindIndex(f, xf) {
    this.xf = xf;
    this.f = f;
    this.idx = -1;
    this.found = false;
  }
  XFindIndex.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XFindIndex.prototype['@@transducer/result'] = function (result) {
    if (!this.found) {
      result = this.xf['@@transducer/step'](result, -1);
    }
    return this.xf['@@transducer/result'](result);
  };
  XFindIndex.prototype['@@transducer/step'] = function (result, input) {
    this.idx += 1;
    if (this.f(input)) {
      this.found = true;
      result = Object(_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"])(this.xf['@@transducer/step'](result, this.idx));
    }
    return result;
  };

  return XFindIndex;
}();

var _xfindIndex = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xfindIndex(f, xf) {
  return new XFindIndex(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xfindIndex);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xfindLast.js":
/*!******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xfindLast.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XFindLast = /*#__PURE__*/function () {
  function XFindLast(f, xf) {
    this.xf = xf;
    this.f = f;
  }
  XFindLast.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XFindLast.prototype['@@transducer/result'] = function (result) {
    return this.xf['@@transducer/result'](this.xf['@@transducer/step'](result, this.last));
  };
  XFindLast.prototype['@@transducer/step'] = function (result, input) {
    if (this.f(input)) {
      this.last = input;
    }
    return result;
  };

  return XFindLast;
}();

var _xfindLast = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xfindLast(f, xf) {
  return new XFindLast(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xfindLast);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xfindLastIndex.js":
/*!***********************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xfindLastIndex.js ***!
  \***********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XFindLastIndex = /*#__PURE__*/function () {
  function XFindLastIndex(f, xf) {
    this.xf = xf;
    this.f = f;
    this.idx = -1;
    this.lastIdx = -1;
  }
  XFindLastIndex.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XFindLastIndex.prototype['@@transducer/result'] = function (result) {
    return this.xf['@@transducer/result'](this.xf['@@transducer/step'](result, this.lastIdx));
  };
  XFindLastIndex.prototype['@@transducer/step'] = function (result, input) {
    this.idx += 1;
    if (this.f(input)) {
      this.lastIdx = this.idx;
    }
    return result;
  };

  return XFindLastIndex;
}();

var _xfindLastIndex = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xfindLastIndex(f, xf) {
  return new XFindLastIndex(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xfindLastIndex);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xmap.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xmap.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XMap = /*#__PURE__*/function () {
  function XMap(f, xf) {
    this.xf = xf;
    this.f = f;
  }
  XMap.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XMap.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].result;
  XMap.prototype['@@transducer/step'] = function (result, input) {
    return this.xf['@@transducer/step'](result, this.f(input));
  };

  return XMap;
}();

var _xmap = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xmap(f, xf) {
  return new XMap(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xmap);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xreduceBy.js":
/*!******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xreduceBy.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curryN.js */ "./node_modules/ramda/es/internal/_curryN.js");
/* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_has.js */ "./node_modules/ramda/es/internal/_has.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XReduceBy = /*#__PURE__*/function () {
  function XReduceBy(valueFn, valueAcc, keyFn, xf) {
    this.valueFn = valueFn;
    this.valueAcc = valueAcc;
    this.keyFn = keyFn;
    this.xf = xf;
    this.inputs = {};
  }
  XReduceBy.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XReduceBy.prototype['@@transducer/result'] = function (result) {
    var key;
    for (key in this.inputs) {
      if (Object(_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(key, this.inputs)) {
        result = this.xf['@@transducer/step'](result, this.inputs[key]);
        if (result['@@transducer/reduced']) {
          result = result['@@transducer/value'];
          break;
        }
      }
    }
    this.inputs = null;
    return this.xf['@@transducer/result'](result);
  };
  XReduceBy.prototype['@@transducer/step'] = function (result, input) {
    var key = this.keyFn(input);
    this.inputs[key] = this.inputs[key] || [key, this.valueAcc];
    this.inputs[key][1] = this.valueFn(this.inputs[key][1], input);
    return result;
  };

  return XReduceBy;
}();

var _xreduceBy = /*#__PURE__*/Object(_curryN_js__WEBPACK_IMPORTED_MODULE_0__["default"])(4, [], function _xreduceBy(valueFn, valueAcc, keyFn, xf) {
  return new XReduceBy(valueFn, valueAcc, keyFn, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xreduceBy);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xtake.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xtake.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XTake = /*#__PURE__*/function () {
  function XTake(n, xf) {
    this.xf = xf;
    this.n = n;
    this.i = 0;
  }
  XTake.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XTake.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].result;
  XTake.prototype['@@transducer/step'] = function (result, input) {
    this.i += 1;
    var ret = this.n === 0 ? result : this.xf['@@transducer/step'](result, input);
    return this.n >= 0 && this.i >= this.n ? Object(_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"])(ret) : ret;
  };

  return XTake;
}();

var _xtake = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xtake(n, xf) {
  return new XTake(n, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xtake);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xtakeWhile.js":
/*!*******************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xtakeWhile.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");




var XTakeWhile = /*#__PURE__*/function () {
  function XTakeWhile(f, xf) {
    this.xf = xf;
    this.f = f;
  }
  XTakeWhile.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].init;
  XTakeWhile.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_2__["default"].result;
  XTakeWhile.prototype['@@transducer/step'] = function (result, input) {
    return this.f(input) ? this.xf['@@transducer/step'](result, input) : Object(_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"])(result);
  };

  return XTakeWhile;
}();

var _xtakeWhile = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xtakeWhile(f, xf) {
  return new XTakeWhile(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xtakeWhile);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xtap.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xtap.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _xfBase_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./_xfBase.js */ "./node_modules/ramda/es/internal/_xfBase.js");



var XTap = /*#__PURE__*/function () {
  function XTap(f, xf) {
    this.xf = xf;
    this.f = f;
  }
  XTap.prototype['@@transducer/init'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].init;
  XTap.prototype['@@transducer/result'] = _xfBase_js__WEBPACK_IMPORTED_MODULE_1__["default"].result;
  XTap.prototype['@@transducer/step'] = function (result, input) {
    this.f(input);
    return this.xf['@@transducer/step'](result, input);
  };

  return XTap;
}();

var _xtap = /*#__PURE__*/Object(_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function _xtap(f, xf) {
  return new XTap(f, xf);
});
/* harmony default export */ __webpack_exports__["default"] = (_xtap);

/***/ }),

/***/ "./node_modules/ramda/es/internal/_xwrap.js":
/*!**************************************************!*\
  !*** ./node_modules/ramda/es/internal/_xwrap.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return _xwrap; });
var XWrap = /*#__PURE__*/function () {
  function XWrap(fn) {
    this.f = fn;
  }
  XWrap.prototype['@@transducer/init'] = function () {
    throw new Error('init not implemented on XWrap');
  };
  XWrap.prototype['@@transducer/result'] = function (acc) {
    return acc;
  };
  XWrap.prototype['@@transducer/step'] = function (acc, x) {
    return this.f(acc, x);
  };

  return XWrap;
}();

function _xwrap(fn) {
  return new XWrap(fn);
}

/***/ }),

/***/ "./node_modules/ramda/es/intersection.js":
/*!***********************************************!*\
  !*** ./node_modules/ramda/es/intersection.js ***!
  \***********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includes_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includes.js */ "./node_modules/ramda/es/internal/_includes.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_filter_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_filter.js */ "./node_modules/ramda/es/internal/_filter.js");
/* harmony import */ var _flip_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./flip.js */ "./node_modules/ramda/es/flip.js");
/* harmony import */ var _uniq_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./uniq.js */ "./node_modules/ramda/es/uniq.js");






/**
 * Combines two lists into a set (i.e. no duplicates) composed of those
 * elements common to both lists.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig [*] -> [*] -> [*]
 * @param {Array} list1 The first list.
 * @param {Array} list2 The second list.
 * @return {Array} The list of elements found in both `list1` and `list2`.
 * @see R.innerJoin
 * @example
 *
 *      R.intersection([1,2,3,4], [7,6,5,4,3]); //=> [4, 3]
 */
var intersection = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function intersection(list1, list2) {
  var lookupList, filteredList;
  if (list1.length > list2.length) {
    lookupList = list1;
    filteredList = list2;
  } else {
    lookupList = list2;
    filteredList = list1;
  }
  return Object(_uniq_js__WEBPACK_IMPORTED_MODULE_4__["default"])(Object(_internal_filter_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_flip_js__WEBPACK_IMPORTED_MODULE_3__["default"])(_internal_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"])(lookupList), filteredList));
});
/* harmony default export */ __webpack_exports__["default"] = (intersection);

/***/ }),

/***/ "./node_modules/ramda/es/intersperse.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/intersperse.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_checkForMethod.js */ "./node_modules/ramda/es/internal/_checkForMethod.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Creates a new list with the separator interposed between elements.
 *
 * Dispatches to the `intersperse` method of the second argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category List
 * @sig a -> [a] -> [a]
 * @param {*} separator The element to add to the list.
 * @param {Array} list The list to be interposed.
 * @return {Array} The new list.
 * @example
 *
 *      R.intersperse('a', ['b', 'n', 'n', 's']); //=> ['b', 'a', 'n', 'a', 'n', 'a', 's']
 */
var intersperse = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__["default"])('intersperse', function intersperse(separator, list) {
  var out = [];
  var idx = 0;
  var length = list.length;
  while (idx < length) {
    if (idx === length - 1) {
      out.push(list[idx]);
    } else {
      out.push(list[idx], separator);
    }
    idx += 1;
  }
  return out;
}));
/* harmony default export */ __webpack_exports__["default"] = (intersperse);

/***/ }),

/***/ "./node_modules/ramda/es/into.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/into.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_clone_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_clone.js */ "./node_modules/ramda/es/internal/_clone.js");
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _internal_isTransformer_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isTransformer.js */ "./node_modules/ramda/es/internal/_isTransformer.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _internal_stepCat_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./internal/_stepCat.js */ "./node_modules/ramda/es/internal/_stepCat.js");






/**
 * Transforms the items of the list with the transducer and appends the
 * transformed items to the accumulator using an appropriate iterator function
 * based on the accumulator type.
 *
 * The accumulator can be an array, string, object or a transformer. Iterated
 * items will be appended to arrays and concatenated to strings. Objects will
 * be merged directly or 2-item arrays will be merged as key, value pairs.
 *
 * The accumulator can also be a transformer object that provides a 2-arity
 * reducing iterator function, step, 0-arity initial value function, init, and
 * 1-arity result extraction function result. The step function is used as the
 * iterator function in reduce. The result function is used to convert the
 * final accumulator into the return type and in most cases is R.identity. The
 * init function is used to provide the initial accumulator.
 *
 * The iteration is performed with [`R.reduce`](#reduce) after initializing the
 * transducer.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category List
 * @sig a -> (b -> b) -> [c] -> a
 * @param {*} acc The initial accumulator value.
 * @param {Function} xf The transducer function. Receives a transformer and returns a transformer.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.transduce
 * @example
 *
 *      const numbers = [1, 2, 3, 4];
 *      const transducer = R.compose(R.map(R.add(1)), R.take(2));
 *
 *      R.into([], transducer, numbers); //=> [2, 3]
 *
 *      const intoArray = R.into([]);
 *      intoArray(transducer, numbers); //=> [2, 3]
 */
var into = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function into(acc, xf, list) {
  return Object(_internal_isTransformer_js__WEBPACK_IMPORTED_MODULE_2__["default"])(acc) ? Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__["default"])(xf(acc), acc['@@transducer/init'](), list) : Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__["default"])(xf(Object(_internal_stepCat_js__WEBPACK_IMPORTED_MODULE_4__["default"])(acc)), Object(_internal_clone_js__WEBPACK_IMPORTED_MODULE_0__["default"])(acc, [], [], false), list);
});
/* harmony default export */ __webpack_exports__["default"] = (into);

/***/ }),

/***/ "./node_modules/ramda/es/invert.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/invert.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");




/**
 * Same as [`R.invertObj`](#invertObj), however this accounts for objects with
 * duplicate values by putting the values into an array.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Object
 * @sig {s: x} -> {x: [ s, ... ]}
 * @param {Object} obj The object or array to invert
 * @return {Object} out A new object with keys in an array.
 * @see R.invertObj
 * @example
 *
 *      const raceResultsByFirstName = {
 *        first: 'alice',
 *        second: 'jake',
 *        third: 'alice',
 *      };
 *      R.invert(raceResultsByFirstName);
 *      //=> { 'alice': ['first', 'third'], 'jake':['second'] }
 */
var invert = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function invert(obj) {
  var props = Object(_keys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj);
  var len = props.length;
  var idx = 0;
  var out = {};

  while (idx < len) {
    var key = props[idx];
    var val = obj[key];
    var list = Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(val, out) ? out[val] : out[val] = [];
    list[list.length] = key;
    idx += 1;
  }
  return out;
});
/* harmony default export */ __webpack_exports__["default"] = (invert);

/***/ }),

/***/ "./node_modules/ramda/es/invertObj.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/invertObj.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");



/**
 * Returns a new object with the keys of the given object as values, and the
 * values of the given object, which are coerced to strings, as keys. Note
 * that the last key found is preferred when handling the same value.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Object
 * @sig {s: x} -> {x: s}
 * @param {Object} obj The object or array to invert
 * @return {Object} out A new object
 * @see R.invert
 * @example
 *
 *      const raceResults = {
 *        first: 'alice',
 *        second: 'jake'
 *      };
 *      R.invertObj(raceResults);
 *      //=> { 'alice': 'first', 'jake':'second' }
 *
 *      // Alternatively:
 *      const raceResults = ['alice', 'jake'];
 *      R.invertObj(raceResults);
 *      //=> { 'alice': '0', 'jake':'1' }
 */
var invertObj = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function invertObj(obj) {
  var props = Object(_keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj);
  var len = props.length;
  var idx = 0;
  var out = {};

  while (idx < len) {
    var key = props[idx];
    out[obj[key]] = key;
    idx += 1;
  }
  return out;
});
/* harmony default export */ __webpack_exports__["default"] = (invertObj);

/***/ }),

/***/ "./node_modules/ramda/es/invoker.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/invoker.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isFunction_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isFunction.js */ "./node_modules/ramda/es/internal/_isFunction.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _toString_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./toString.js */ "./node_modules/ramda/es/toString.js");





/**
 * Turns a named method with a specified arity into a function that can be
 * called directly supplied with arguments and a target object.
 *
 * The returned function is curried and accepts `arity + 1` parameters where
 * the final parameter is the target object.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig Number -> String -> (a -> b -> ... -> n -> Object -> *)
 * @param {Number} arity Number of arguments the returned function should take
 *        before the target object.
 * @param {String} method Name of the method to call.
 * @return {Function} A new curried function.
 * @see R.construct
 * @example
 *
 *      const sliceFrom = R.invoker(1, 'slice');
 *      sliceFrom(6, 'abcdefghijklm'); //=> 'ghijklm'
 *      const sliceFrom6 = R.invoker(2, 'slice')(6);
 *      sliceFrom6(8, 'abcdefghijklm'); //=> 'gh'
 * @symb R.invoker(0, 'method')(o) = o['method']()
 * @symb R.invoker(1, 'method')(a, o) = o['method'](a)
 * @symb R.invoker(2, 'method')(a, b, o) = o['method'](a, b)
 */
var invoker = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function invoker(arity, method) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_2__["default"])(arity + 1, function () {
    var target = arguments[arity];
    if (target != null && Object(_internal_isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(target[method])) {
      return target[method].apply(target, Array.prototype.slice.call(arguments, 0, arity));
    }
    throw new TypeError(Object(_toString_js__WEBPACK_IMPORTED_MODULE_3__["default"])(target) + ' does not have a method named "' + method + '"');
  });
});
/* harmony default export */ __webpack_exports__["default"] = (invoker);

/***/ }),

/***/ "./node_modules/ramda/es/is.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/is.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * See if an object (`val`) is an instance of the supplied constructor. This
 * function will check up the inheritance chain, if any.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category Type
 * @sig (* -> {*}) -> a -> Boolean
 * @param {Object} ctor A constructor
 * @param {*} val The value to test
 * @return {Boolean}
 * @example
 *
 *      R.is(Object, {}); //=> true
 *      R.is(Number, 1); //=> true
 *      R.is(Object, 1); //=> false
 *      R.is(String, 's'); //=> true
 *      R.is(String, new String('')); //=> true
 *      R.is(Object, new String('')); //=> true
 *      R.is(Object, 's'); //=> false
 *      R.is(Number, {}); //=> false
 */
var is = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function is(Ctor, val) {
  return val != null && val.constructor === Ctor || val instanceof Ctor;
});
/* harmony default export */ __webpack_exports__["default"] = (is);

/***/ }),

/***/ "./node_modules/ramda/es/isEmpty.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/isEmpty.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _empty_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./empty.js */ "./node_modules/ramda/es/empty.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");




/**
 * Returns `true` if the given value is its type's empty value; `false`
 * otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Logic
 * @sig a -> Boolean
 * @param {*} x
 * @return {Boolean}
 * @see R.empty
 * @example
 *
 *      R.isEmpty([1, 2, 3]);   //=> false
 *      R.isEmpty([]);          //=> true
 *      R.isEmpty('');          //=> true
 *      R.isEmpty(null);        //=> false
 *      R.isEmpty({});          //=> true
 *      R.isEmpty({length: 0}); //=> false
 */
var isEmpty = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function isEmpty(x) {
  return x != null && Object(_equals_js__WEBPACK_IMPORTED_MODULE_2__["default"])(x, Object(_empty_js__WEBPACK_IMPORTED_MODULE_1__["default"])(x));
});
/* harmony default export */ __webpack_exports__["default"] = (isEmpty);

/***/ }),

/***/ "./node_modules/ramda/es/isNil.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/isNil.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Checks if the input value is `null` or `undefined`.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Type
 * @sig * -> Boolean
 * @param {*} x The value to test.
 * @return {Boolean} `true` if `x` is `undefined` or `null`, otherwise `false`.
 * @example
 *
 *      R.isNil(null); //=> true
 *      R.isNil(undefined); //=> true
 *      R.isNil(0); //=> false
 *      R.isNil([]); //=> false
 */
var isNil = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function isNil(x) {
  return x == null;
});
/* harmony default export */ __webpack_exports__["default"] = (isNil);

/***/ }),

/***/ "./node_modules/ramda/es/join.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/join.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _invoker_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./invoker.js */ "./node_modules/ramda/es/invoker.js");


/**
 * Returns a string made by inserting the `separator` between each element and
 * concatenating all the elements into a single string.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig String -> [a] -> String
 * @param {Number|String} separator The string used to separate the elements.
 * @param {Array} xs The elements to join into a string.
 * @return {String} str The string made by concatenating `xs` with `separator`.
 * @see R.split
 * @example
 *
 *      const spacer = R.join(' ');
 *      spacer(['a', 2, 3.4]);   //=> 'a 2 3.4'
 *      R.join('|', [1, 2, 3]);    //=> '1|2|3'
 */
var join = /*#__PURE__*/Object(_invoker_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, 'join');
/* harmony default export */ __webpack_exports__["default"] = (join);

/***/ }),

/***/ "./node_modules/ramda/es/juxt.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/juxt.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _converge_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./converge.js */ "./node_modules/ramda/es/converge.js");



/**
 * juxt applies a list of functions to a list of values.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Function
 * @sig [(a, b, ..., m) -> n] -> ((a, b, ..., m) -> [n])
 * @param {Array} fns An array of functions
 * @return {Function} A function that returns a list of values after applying each of the original `fns` to its parameters.
 * @see R.applySpec
 * @example
 *
 *      const getRange = R.juxt([Math.min, Math.max]);
 *      getRange(3, 4, 9, -3); //=> [-3, 9]
 * @symb R.juxt([f, g, h])(a, b) = [f(a, b), g(a, b), h(a, b)]
 */
var juxt = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function juxt(fns) {
  return Object(_converge_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function () {
    return Array.prototype.slice.call(arguments, 0);
  }, fns);
});
/* harmony default export */ __webpack_exports__["default"] = (juxt);

/***/ }),

/***/ "./node_modules/ramda/es/keys.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/keys.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");
/* harmony import */ var _internal_isArguments_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isArguments.js */ "./node_modules/ramda/es/internal/_isArguments.js");




// cover IE < 9 keys issues
var hasEnumBug = ! /*#__PURE__*/{ toString: null }.propertyIsEnumerable('toString');
var nonEnumerableProps = ['constructor', 'valueOf', 'isPrototypeOf', 'toString', 'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];
// Safari bug
var hasArgsEnumBug = /*#__PURE__*/function () {
  'use strict';

  return arguments.propertyIsEnumerable('length');
}();

var contains = function contains(list, item) {
  var idx = 0;
  while (idx < list.length) {
    if (list[idx] === item) {
      return true;
    }
    idx += 1;
  }
  return false;
};

/**
 * Returns a list containing the names of all the enumerable own properties of
 * the supplied object.
 * Note that the order of the output array is not guaranteed to be consistent
 * across different JS platforms.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig {k: v} -> [k]
 * @param {Object} obj The object to extract properties from
 * @return {Array} An array of the object's own properties.
 * @see R.keysIn, R.values
 * @example
 *
 *      R.keys({a: 1, b: 2, c: 3}); //=> ['a', 'b', 'c']
 */
var keys = typeof Object.keys === 'function' && !hasArgsEnumBug ? /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function keys(obj) {
  return Object(obj) !== obj ? [] : Object.keys(obj);
}) : /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function keys(obj) {
  if (Object(obj) !== obj) {
    return [];
  }
  var prop, nIdx;
  var ks = [];
  var checkArgsLength = hasArgsEnumBug && Object(_internal_isArguments_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj);
  for (prop in obj) {
    if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(prop, obj) && (!checkArgsLength || prop !== 'length')) {
      ks[ks.length] = prop;
    }
  }
  if (hasEnumBug) {
    nIdx = nonEnumerableProps.length - 1;
    while (nIdx >= 0) {
      prop = nonEnumerableProps[nIdx];
      if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(prop, obj) && !contains(ks, prop)) {
        ks[ks.length] = prop;
      }
      nIdx -= 1;
    }
  }
  return ks;
});
/* harmony default export */ __webpack_exports__["default"] = (keys);

/***/ }),

/***/ "./node_modules/ramda/es/keysIn.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/keysIn.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Returns a list containing the names of all the properties of the supplied
 * object, including prototype properties.
 * Note that the order of the output array is not guaranteed to be consistent
 * across different JS platforms.
 *
 * @func
 * @memberOf R
 * @since v0.2.0
 * @category Object
 * @sig {k: v} -> [k]
 * @param {Object} obj The object to extract properties from
 * @return {Array} An array of the object's own and prototype properties.
 * @see R.keys, R.valuesIn
 * @example
 *
 *      const F = function() { this.x = 'X'; };
 *      F.prototype.y = 'Y';
 *      const f = new F();
 *      R.keysIn(f); //=> ['x', 'y']
 */
var keysIn = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function keysIn(obj) {
  var prop;
  var ks = [];
  for (prop in obj) {
    ks[ks.length] = prop;
  }
  return ks;
});
/* harmony default export */ __webpack_exports__["default"] = (keysIn);

/***/ }),

/***/ "./node_modules/ramda/es/last.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/last.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _nth_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./nth.js */ "./node_modules/ramda/es/nth.js");


/**
 * Returns the last element of the given list or string.
 *
 * @func
 * @memberOf R
 * @since v0.1.4
 * @category List
 * @sig [a] -> a | Undefined
 * @sig String -> String
 * @param {*} list
 * @return {*}
 * @see R.init, R.head, R.tail
 * @example
 *
 *      R.last(['fi', 'fo', 'fum']); //=> 'fum'
 *      R.last([]); //=> undefined
 *
 *      R.last('abc'); //=> 'c'
 *      R.last(''); //=> ''
 */
var last = /*#__PURE__*/Object(_nth_js__WEBPACK_IMPORTED_MODULE_0__["default"])(-1);
/* harmony default export */ __webpack_exports__["default"] = (last);

/***/ }),

/***/ "./node_modules/ramda/es/lastIndexOf.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/lastIndexOf.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isArray_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isArray.js */ "./node_modules/ramda/es/internal/_isArray.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");




/**
 * Returns the position of the last occurrence of an item in an array, or -1 if
 * the item is not included in the array. [`R.equals`](#equals) is used to
 * determine equality.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig a -> [a] -> Number
 * @param {*} target The item to find.
 * @param {Array} xs The array to search in.
 * @return {Number} the index of the target, or -1 if the target is not found.
 * @see R.indexOf
 * @example
 *
 *      R.lastIndexOf(3, [-1,3,3,0,1,2,3,4]); //=> 6
 *      R.lastIndexOf(10, [1,2,3,4]); //=> -1
 */
var lastIndexOf = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lastIndexOf(target, xs) {
  if (typeof xs.lastIndexOf === 'function' && !Object(_internal_isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(xs)) {
    return xs.lastIndexOf(target);
  } else {
    var idx = xs.length - 1;
    while (idx >= 0) {
      if (Object(_equals_js__WEBPACK_IMPORTED_MODULE_2__["default"])(xs[idx], target)) {
        return idx;
      }
      idx -= 1;
    }
    return -1;
  }
});
/* harmony default export */ __webpack_exports__["default"] = (lastIndexOf);

/***/ }),

/***/ "./node_modules/ramda/es/length.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/length.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_isNumber_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isNumber.js */ "./node_modules/ramda/es/internal/_isNumber.js");



/**
 * Returns the number of elements in the array by returning `list.length`.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category List
 * @sig [a] -> Number
 * @param {Array} list The array to inspect.
 * @return {Number} The length of the array.
 * @example
 *
 *      R.length([]); //=> 0
 *      R.length([1, 2, 3]); //=> 3
 */
var length = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function length(list) {
  return list != null && Object(_internal_isNumber_js__WEBPACK_IMPORTED_MODULE_1__["default"])(list.length) ? list.length : NaN;
});
/* harmony default export */ __webpack_exports__["default"] = (length);

/***/ }),

/***/ "./node_modules/ramda/es/lens.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/lens.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");



/**
 * Returns a lens for the given getter and setter functions. The getter "gets"
 * the value of the focus; the setter "sets" the value of the focus. The setter
 * should not mutate the data structure.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Object
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig (s -> a) -> ((a, s) -> s) -> Lens s a
 * @param {Function} getter
 * @param {Function} setter
 * @return {Lens}
 * @see R.view, R.set, R.over, R.lensIndex, R.lensProp
 * @example
 *
 *      const xLens = R.lens(R.prop('x'), R.assoc('x'));
 *
 *      R.view(xLens, {x: 1, y: 2});            //=> 1
 *      R.set(xLens, 4, {x: 1, y: 2});          //=> {x: 4, y: 2}
 *      R.over(xLens, R.negate, {x: 1, y: 2});  //=> {x: -1, y: 2}
 */
var lens = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lens(getter, setter) {
  return function (toFunctorFn) {
    return function (target) {
      return Object(_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (focus) {
        return setter(focus, target);
      }, toFunctorFn(getter(target)));
    };
  };
});
/* harmony default export */ __webpack_exports__["default"] = (lens);

/***/ }),

/***/ "./node_modules/ramda/es/lensIndex.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/lensIndex.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _lens_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./lens.js */ "./node_modules/ramda/es/lens.js");
/* harmony import */ var _nth_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./nth.js */ "./node_modules/ramda/es/nth.js");
/* harmony import */ var _update_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./update.js */ "./node_modules/ramda/es/update.js");





/**
 * Returns a lens whose focus is the specified index.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category Object
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig Number -> Lens s a
 * @param {Number} n
 * @return {Lens}
 * @see R.view, R.set, R.over
 * @example
 *
 *      const headLens = R.lensIndex(0);
 *
 *      R.view(headLens, ['a', 'b', 'c']);            //=> 'a'
 *      R.set(headLens, 'x', ['a', 'b', 'c']);        //=> ['x', 'b', 'c']
 *      R.over(headLens, R.toUpper, ['a', 'b', 'c']); //=> ['A', 'b', 'c']
 */
var lensIndex = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lensIndex(n) {
  return Object(_lens_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_nth_js__WEBPACK_IMPORTED_MODULE_2__["default"])(n), Object(_update_js__WEBPACK_IMPORTED_MODULE_3__["default"])(n));
});
/* harmony default export */ __webpack_exports__["default"] = (lensIndex);

/***/ }),

/***/ "./node_modules/ramda/es/lensPath.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/lensPath.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _assocPath_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./assocPath.js */ "./node_modules/ramda/es/assocPath.js");
/* harmony import */ var _lens_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lens.js */ "./node_modules/ramda/es/lens.js");
/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./path.js */ "./node_modules/ramda/es/path.js");





/**
 * Returns a lens whose focus is the specified path.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Object
 * @typedefn Idx = String | Int
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig [Idx] -> Lens s a
 * @param {Array} path The path to use.
 * @return {Lens}
 * @see R.view, R.set, R.over
 * @example
 *
 *      const xHeadYLens = R.lensPath(['x', 0, 'y']);
 *
 *      R.view(xHeadYLens, {x: [{y: 2, z: 3}, {y: 4, z: 5}]});
 *      //=> 2
 *      R.set(xHeadYLens, 1, {x: [{y: 2, z: 3}, {y: 4, z: 5}]});
 *      //=> {x: [{y: 1, z: 3}, {y: 4, z: 5}]}
 *      R.over(xHeadYLens, R.negate, {x: [{y: 2, z: 3}, {y: 4, z: 5}]});
 *      //=> {x: [{y: -2, z: 3}, {y: 4, z: 5}]}
 */
var lensPath = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lensPath(p) {
  return Object(_lens_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_path_js__WEBPACK_IMPORTED_MODULE_3__["default"])(p), Object(_assocPath_js__WEBPACK_IMPORTED_MODULE_1__["default"])(p));
});
/* harmony default export */ __webpack_exports__["default"] = (lensPath);

/***/ }),

/***/ "./node_modules/ramda/es/lensProp.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/lensProp.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _assoc_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./assoc.js */ "./node_modules/ramda/es/assoc.js");
/* harmony import */ var _lens_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./lens.js */ "./node_modules/ramda/es/lens.js");
/* harmony import */ var _prop_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./prop.js */ "./node_modules/ramda/es/prop.js");





/**
 * Returns a lens whose focus is the specified property.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category Object
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig String -> Lens s a
 * @param {String} k
 * @return {Lens}
 * @see R.view, R.set, R.over
 * @example
 *
 *      const xLens = R.lensProp('x');
 *
 *      R.view(xLens, {x: 1, y: 2});            //=> 1
 *      R.set(xLens, 4, {x: 1, y: 2});          //=> {x: 4, y: 2}
 *      R.over(xLens, R.negate, {x: 1, y: 2});  //=> {x: -1, y: 2}
 */
var lensProp = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lensProp(k) {
  return Object(_lens_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_prop_js__WEBPACK_IMPORTED_MODULE_3__["default"])(k), Object(_assoc_js__WEBPACK_IMPORTED_MODULE_1__["default"])(k));
});
/* harmony default export */ __webpack_exports__["default"] = (lensProp);

/***/ }),

/***/ "./node_modules/ramda/es/lift.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/lift.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _liftN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./liftN.js */ "./node_modules/ramda/es/liftN.js");



/**
 * "lifts" a function of arity > 1 so that it may "map over" a list, Function or other
 * object that satisfies the [FantasyLand Apply spec](https://github.com/fantasyland/fantasy-land#apply).
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category Function
 * @sig (*... -> *) -> ([*]... -> [*])
 * @param {Function} fn The function to lift into higher context
 * @return {Function} The lifted function.
 * @see R.liftN
 * @example
 *
 *      const madd3 = R.lift((a, b, c) => a + b + c);
 *
 *      madd3([1,2,3], [1,2,3], [1]); //=> [3, 4, 5, 4, 5, 6, 5, 6, 7]
 *
 *      const madd5 = R.lift((a, b, c, d, e) => a + b + c + d + e);
 *
 *      madd5([1,2], [3], [4, 5], [6], [7, 8]); //=> [21, 22, 22, 23, 22, 23, 23, 24]
 */
var lift = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lift(fn) {
  return Object(_liftN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(fn.length, fn);
});
/* harmony default export */ __webpack_exports__["default"] = (lift);

/***/ }),

/***/ "./node_modules/ramda/es/liftN.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/liftN.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _ap_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./ap.js */ "./node_modules/ramda/es/ap.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");






/**
 * "lifts" a function to be the specified arity, so that it may "map over" that
 * many lists, Functions or other objects that satisfy the [FantasyLand Apply spec](https://github.com/fantasyland/fantasy-land#apply).
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category Function
 * @sig Number -> (*... -> *) -> ([*]... -> [*])
 * @param {Function} fn The function to lift into higher context
 * @return {Function} The lifted function.
 * @see R.lift, R.ap
 * @example
 *
 *      const madd3 = R.liftN(3, (...args) => R.sum(args));
 *      madd3([1,2,3], [1,2,3], [1]); //=> [3, 4, 5, 4, 5, 6, 5, 6, 7]
 */
var liftN = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function liftN(arity, fn) {
  var lifted = Object(_curryN_js__WEBPACK_IMPORTED_MODULE_3__["default"])(arity, fn);
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_3__["default"])(arity, function () {
    return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_ap_js__WEBPACK_IMPORTED_MODULE_2__["default"], Object(_map_js__WEBPACK_IMPORTED_MODULE_4__["default"])(lifted, arguments[0]), Array.prototype.slice.call(arguments, 1));
  });
});
/* harmony default export */ __webpack_exports__["default"] = (liftN);

/***/ }),

/***/ "./node_modules/ramda/es/lt.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/lt.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns `true` if the first argument is less than the second; `false`
 * otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord a => a -> a -> Boolean
 * @param {*} a
 * @param {*} b
 * @return {Boolean}
 * @see R.gt
 * @example
 *
 *      R.lt(2, 1); //=> false
 *      R.lt(2, 2); //=> false
 *      R.lt(2, 3); //=> true
 *      R.lt('a', 'z'); //=> true
 *      R.lt('z', 'a'); //=> false
 */
var lt = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lt(a, b) {
  return a < b;
});
/* harmony default export */ __webpack_exports__["default"] = (lt);

/***/ }),

/***/ "./node_modules/ramda/es/lte.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/lte.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns `true` if the first argument is less than or equal to the second;
 * `false` otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord a => a -> a -> Boolean
 * @param {Number} a
 * @param {Number} b
 * @return {Boolean}
 * @see R.gte
 * @example
 *
 *      R.lte(2, 1); //=> false
 *      R.lte(2, 2); //=> true
 *      R.lte(2, 3); //=> true
 *      R.lte('a', 'z'); //=> true
 *      R.lte('z', 'a'); //=> false
 */
var lte = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function lte(a, b) {
  return a <= b;
});
/* harmony default export */ __webpack_exports__["default"] = (lte);

/***/ }),

/***/ "./node_modules/ramda/es/map.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/map.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_map.js */ "./node_modules/ramda/es/internal/_map.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _internal_xmap_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./internal/_xmap.js */ "./node_modules/ramda/es/internal/_xmap.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");








/**
 * Takes a function and
 * a [functor](https://github.com/fantasyland/fantasy-land#functor),
 * applies the function to each of the functor's values, and returns
 * a functor of the same shape.
 *
 * Ramda provides suitable `map` implementations for `Array` and `Object`,
 * so this function may be applied to `[1, 2, 3]` or `{x: 1, y: 2, z: 3}`.
 *
 * Dispatches to the `map` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * Also treats functions as functors and will compose them together.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Functor f => (a -> b) -> f a -> f b
 * @param {Function} fn The function to be called on every element of the input `list`.
 * @param {Array} list The list to be iterated over.
 * @return {Array} The new list.
 * @see R.transduce, R.addIndex
 * @example
 *
 *      const double = x => x * 2;
 *
 *      R.map(double, [1, 2, 3]); //=> [2, 4, 6]
 *
 *      R.map(double, {x: 1, y: 2, z: 3}); //=> {x: 2, y: 4, z: 6}
 * @symb R.map(f, [a, b]) = [f(a), f(b)]
 * @symb R.map(f, { x: a, y: b }) = { x: f(a), y: f(b) }
 * @symb R.map(f, functor_o) = functor_o.map(f)
 */
var map = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['fantasy-land/map', 'map'], _internal_xmap_js__WEBPACK_IMPORTED_MODULE_4__["default"], function map(fn, functor) {
  switch (Object.prototype.toString.call(functor)) {
    case '[object Function]':
      return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_5__["default"])(functor.length, function () {
        return fn.call(this, functor.apply(this, arguments));
      });
    case '[object Object]':
      return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__["default"])(function (acc, key) {
        acc[key] = fn(functor[key]);
        return acc;
      }, {}, Object(_keys_js__WEBPACK_IMPORTED_MODULE_6__["default"])(functor));
    default:
      return Object(_internal_map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(fn, functor);
  }
}));
/* harmony default export */ __webpack_exports__["default"] = (map);

/***/ }),

/***/ "./node_modules/ramda/es/mapAccum.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/mapAccum.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * The `mapAccum` function behaves like a combination of map and reduce; it
 * applies a function to each element of a list, passing an accumulating
 * parameter from left to right, and returning a final value of this
 * accumulator together with the new list.
 *
 * The iterator function receives two arguments, *acc* and *value*, and should
 * return a tuple *[acc, value]*.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category List
 * @sig ((acc, x) -> (acc, y)) -> acc -> [x] -> (acc, [y])
 * @param {Function} fn The function to be called on every element of the input `list`.
 * @param {*} acc The accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.scan, R.addIndex, R.mapAccumRight
 * @example
 *
 *      const digits = ['1', '2', '3', '4'];
 *      const appender = (a, b) => [a + b, a + b];
 *
 *      R.mapAccum(appender, 0, digits); //=> ['01234', ['01', '012', '0123', '01234']]
 * @symb R.mapAccum(f, a, [b, c, d]) = [
 *   f(f(f(a, b)[0], c)[0], d)[0],
 *   [
 *     f(a, b)[1],
 *     f(f(a, b)[0], c)[1],
 *     f(f(f(a, b)[0], c)[0], d)[1]
 *   ]
 * ]
 */
var mapAccum = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mapAccum(fn, acc, list) {
  var idx = 0;
  var len = list.length;
  var result = [];
  var tuple = [acc];
  while (idx < len) {
    tuple = fn(tuple[0], list[idx]);
    result[idx] = tuple[1];
    idx += 1;
  }
  return [tuple[0], result];
});
/* harmony default export */ __webpack_exports__["default"] = (mapAccum);

/***/ }),

/***/ "./node_modules/ramda/es/mapAccumRight.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/mapAccumRight.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * The `mapAccumRight` function behaves like a combination of map and reduce; it
 * applies a function to each element of a list, passing an accumulating
 * parameter from right to left, and returning a final value of this
 * accumulator together with the new list.
 *
 * Similar to [`mapAccum`](#mapAccum), except moves through the input list from
 * the right to the left.
 *
 * The iterator function receives two arguments, *acc* and *value*, and should
 * return a tuple *[acc, value]*.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category List
 * @sig ((acc, x) -> (acc, y)) -> acc -> [x] -> (acc, [y])
 * @param {Function} fn The function to be called on every element of the input `list`.
 * @param {*} acc The accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.addIndex, R.mapAccum
 * @example
 *
 *      const digits = ['1', '2', '3', '4'];
 *      const appender = (a, b) => [b + a, b + a];
 *
 *      R.mapAccumRight(appender, 5, digits); //=> ['12345', ['12345', '2345', '345', '45']]
 * @symb R.mapAccumRight(f, a, [b, c, d]) = [
 *   f(f(f(a, d)[0], c)[0], b)[0],
 *   [
 *     f(a, d)[1],
 *     f(f(a, d)[0], c)[1],
 *     f(f(f(a, d)[0], c)[0], b)[1]
 *   ]
 * ]
 */
var mapAccumRight = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mapAccumRight(fn, acc, list) {
  var idx = list.length - 1;
  var result = [];
  var tuple = [acc];
  while (idx >= 0) {
    tuple = fn(tuple[0], list[idx]);
    result[idx] = tuple[1];
    idx -= 1;
  }
  return [tuple[0], result];
});
/* harmony default export */ __webpack_exports__["default"] = (mapAccumRight);

/***/ }),

/***/ "./node_modules/ramda/es/mapObjIndexed.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/mapObjIndexed.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");




/**
 * An Object-specific version of [`map`](#map). The function is applied to three
 * arguments: *(value, key, obj)*. If only the value is significant, use
 * [`map`](#map) instead.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Object
 * @sig ((*, String, Object) -> *) -> Object -> Object
 * @param {Function} fn
 * @param {Object} obj
 * @return {Object}
 * @see R.map
 * @example
 *
 *      const xyz = { x: 1, y: 2, z: 3 };
 *      const prependKeyAndDouble = (num, key, obj) => key + (num * 2);
 *
 *      R.mapObjIndexed(prependKeyAndDouble, xyz); //=> { x: 'x2', y: 'y4', z: 'z6' }
 */
var mapObjIndexed = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mapObjIndexed(fn, obj) {
  return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (acc, key) {
    acc[key] = fn(obj[key], key, obj);
    return acc;
  }, {}, Object(_keys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj));
});
/* harmony default export */ __webpack_exports__["default"] = (mapObjIndexed);

/***/ }),

/***/ "./node_modules/ramda/es/match.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/match.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Tests a regular expression against a String. Note that this function will
 * return an empty array when there are no matches. This differs from
 * [`String.prototype.match`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/match)
 * which returns `null` when there are no matches.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category String
 * @sig RegExp -> String -> [String | Undefined]
 * @param {RegExp} rx A regular expression.
 * @param {String} str The string to match against
 * @return {Array} The list of matches or empty array.
 * @see R.test
 * @example
 *
 *      R.match(/([a-z]a)/g, 'bananas'); //=> ['ba', 'na', 'na']
 *      R.match(/a/, 'b'); //=> []
 *      R.match(/a/, null); //=> TypeError: null does not have a method named "match"
 */
var match = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function match(rx, str) {
  return str.match(rx) || [];
});
/* harmony default export */ __webpack_exports__["default"] = (match);

/***/ }),

/***/ "./node_modules/ramda/es/mathMod.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/mathMod.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isInteger_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isInteger.js */ "./node_modules/ramda/es/internal/_isInteger.js");



/**
 * `mathMod` behaves like the modulo operator should mathematically, unlike the
 * `%` operator (and by extension, [`R.modulo`](#modulo)). So while
 * `-17 % 5` is `-2`, `mathMod(-17, 5)` is `3`. `mathMod` requires Integer
 * arguments, and returns NaN when the modulus is zero or negative.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category Math
 * @sig Number -> Number -> Number
 * @param {Number} m The dividend.
 * @param {Number} p the modulus.
 * @return {Number} The result of `b mod a`.
 * @see R.modulo
 * @example
 *
 *      R.mathMod(-17, 5);  //=> 3
 *      R.mathMod(17, 5);   //=> 2
 *      R.mathMod(17, -5);  //=> NaN
 *      R.mathMod(17, 0);   //=> NaN
 *      R.mathMod(17.2, 5); //=> NaN
 *      R.mathMod(17, 5.3); //=> NaN
 *
 *      const clock = R.mathMod(R.__, 12);
 *      clock(15); //=> 3
 *      clock(24); //=> 0
 *
 *      const seventeenMod = R.mathMod(17);
 *      seventeenMod(3);  //=> 2
 *      seventeenMod(4);  //=> 1
 *      seventeenMod(10); //=> 7
 */
var mathMod = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mathMod(m, p) {
  if (!Object(_internal_isInteger_js__WEBPACK_IMPORTED_MODULE_1__["default"])(m)) {
    return NaN;
  }
  if (!Object(_internal_isInteger_js__WEBPACK_IMPORTED_MODULE_1__["default"])(p) || p < 1) {
    return NaN;
  }
  return (m % p + p) % p;
});
/* harmony default export */ __webpack_exports__["default"] = (mathMod);

/***/ }),

/***/ "./node_modules/ramda/es/max.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/max.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns the larger of its two arguments.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord a => a -> a -> a
 * @param {*} a
 * @param {*} b
 * @return {*}
 * @see R.maxBy, R.min
 * @example
 *
 *      R.max(789, 123); //=> 789
 *      R.max('a', 'b'); //=> 'b'
 */
var max = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function max(a, b) {
  return b > a ? b : a;
});
/* harmony default export */ __webpack_exports__["default"] = (max);

/***/ }),

/***/ "./node_modules/ramda/es/maxBy.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/maxBy.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Takes a function and two values, and returns whichever value produces the
 * larger result when passed to the provided function.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Relation
 * @sig Ord b => (a -> b) -> a -> a -> a
 * @param {Function} f
 * @param {*} a
 * @param {*} b
 * @return {*}
 * @see R.max, R.minBy
 * @example
 *
 *      //  square :: Number -> Number
 *      const square = n => n * n;
 *
 *      R.maxBy(square, -3, 2); //=> -3
 *
 *      R.reduce(R.maxBy(square), 0, [3, -5, 4, 1, -2]); //=> -5
 *      R.reduce(R.maxBy(square), 0, []); //=> 0
 */
var maxBy = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function maxBy(f, a, b) {
  return f(b) > f(a) ? b : a;
});
/* harmony default export */ __webpack_exports__["default"] = (maxBy);

/***/ }),

/***/ "./node_modules/ramda/es/mean.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/mean.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _sum_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./sum.js */ "./node_modules/ramda/es/sum.js");



/**
 * Returns the mean of the given list of numbers.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category Math
 * @sig [Number] -> Number
 * @param {Array} list
 * @return {Number}
 * @see R.median
 * @example
 *
 *      R.mean([2, 7, 9]); //=> 6
 *      R.mean([]); //=> NaN
 */
var mean = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mean(list) {
  return Object(_sum_js__WEBPACK_IMPORTED_MODULE_1__["default"])(list) / list.length;
});
/* harmony default export */ __webpack_exports__["default"] = (mean);

/***/ }),

/***/ "./node_modules/ramda/es/median.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/median.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _mean_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mean.js */ "./node_modules/ramda/es/mean.js");



/**
 * Returns the median of the given list of numbers.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category Math
 * @sig [Number] -> Number
 * @param {Array} list
 * @return {Number}
 * @see R.mean
 * @example
 *
 *      R.median([2, 9, 7]); //=> 7
 *      R.median([7, 2, 10, 9]); //=> 8
 *      R.median([]); //=> NaN
 */
var median = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function median(list) {
  var len = list.length;
  if (len === 0) {
    return NaN;
  }
  var width = 2 - len % 2;
  var idx = (len - width) / 2;
  return Object(_mean_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Array.prototype.slice.call(list, 0).sort(function (a, b) {
    return a < b ? -1 : a > b ? 1 : 0;
  }).slice(idx, idx + width));
});
/* harmony default export */ __webpack_exports__["default"] = (median);

/***/ }),

/***/ "./node_modules/ramda/es/memoizeWith.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/memoizeWith.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");




/**
 * Creates a new function that, when invoked, caches the result of calling `fn`
 * for a given argument set and returns the result. Subsequent calls to the
 * memoized `fn` with the same argument set will not result in an additional
 * call to `fn`; instead, the cached result for that set of arguments will be
 * returned.
 *
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Function
 * @sig (*... -> String) -> (*... -> a) -> (*... -> a)
 * @param {Function} fn The function to generate the cache key.
 * @param {Function} fn The function to memoize.
 * @return {Function} Memoized version of `fn`.
 * @example
 *
 *      let count = 0;
 *      const factorial = R.memoizeWith(R.identity, n => {
 *        count += 1;
 *        return R.product(R.range(1, n + 1));
 *      });
 *      factorial(5); //=> 120
 *      factorial(5); //=> 120
 *      factorial(5); //=> 120
 *      count; //=> 1
 */
var memoizeWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function memoizeWith(mFn, fn) {
  var cache = {};
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(fn.length, function () {
    var key = mFn.apply(this, arguments);
    if (!Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_2__["default"])(key, cache)) {
      cache[key] = fn.apply(this, arguments);
    }
    return cache[key];
  });
});
/* harmony default export */ __webpack_exports__["default"] = (memoizeWith);

/***/ }),

/***/ "./node_modules/ramda/es/merge.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/merge.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_objectAssign.js */ "./node_modules/ramda/es/internal/_objectAssign.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Create a new object with the own properties of the first object merged with
 * the own properties of the second object. If a key exists in both objects,
 * the value from the second object will be used.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig {k: v} -> {k: v} -> {k: v}
 * @param {Object} l
 * @param {Object} r
 * @return {Object}
 * @see R.mergeRight, R.mergeDeepRight, R.mergeWith, R.mergeWithKey
 * @deprecated
 * @example
 *
 *      R.merge({ 'name': 'fred', 'age': 10 }, { 'age': 40 });
 *      //=> { 'name': 'fred', 'age': 40 }
 *
 *      const withDefaults = R.merge({x: 0, y: 0});
 *      withDefaults({y: 2}); //=> {x: 0, y: 2}
 * @symb R.merge(a, b) = {...a, ...b}
 */
var merge = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function merge(l, r) {
  return Object(_internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__["default"])({}, l, r);
});
/* harmony default export */ __webpack_exports__["default"] = (merge);

/***/ }),

/***/ "./node_modules/ramda/es/mergeAll.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/mergeAll.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_objectAssign.js */ "./node_modules/ramda/es/internal/_objectAssign.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");



/**
 * Merges a list of objects together into one object.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category List
 * @sig [{k: v}] -> {k: v}
 * @param {Array} list An array of objects
 * @return {Object} A merged object.
 * @see R.reduce
 * @example
 *
 *      R.mergeAll([{foo:1},{bar:2},{baz:3}]); //=> {foo:1,bar:2,baz:3}
 *      R.mergeAll([{foo:1},{foo:2},{bar:2}]); //=> {foo:2,bar:2}
 * @symb R.mergeAll([{ x: 1 }, { y: 2 }, { z: 3 }]) = { x: 1, y: 2, z: 3 }
 */
var mergeAll = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function mergeAll(list) {
  return _internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__["default"].apply(null, [{}].concat(list));
});
/* harmony default export */ __webpack_exports__["default"] = (mergeAll);

/***/ }),

/***/ "./node_modules/ramda/es/mergeDeepLeft.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/mergeDeepLeft.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mergeDeepWithKey.js */ "./node_modules/ramda/es/mergeDeepWithKey.js");



/**
 * Creates a new object with the own properties of the first object merged with
 * the own properties of the second object. If a key exists in both objects:
 * - and both values are objects, the two values will be recursively merged
 * - otherwise the value from the first object will be used.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Object
 * @sig {a} -> {a} -> {a}
 * @param {Object} lObj
 * @param {Object} rObj
 * @return {Object}
 * @see R.merge, R.mergeDeepRight, R.mergeDeepWith, R.mergeDeepWithKey
 * @example
 *
 *      R.mergeDeepLeft({ name: 'fred', age: 10, contact: { email: 'moo@example.com' }},
 *                      { age: 40, contact: { email: 'baa@example.com' }});
 *      //=> { name: 'fred', age: 10, contact: { email: 'moo@example.com' }}
 */
var mergeDeepLeft = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mergeDeepLeft(lObj, rObj) {
  return Object(_mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (k, lVal, rVal) {
    return lVal;
  }, lObj, rObj);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeDeepLeft);

/***/ }),

/***/ "./node_modules/ramda/es/mergeDeepRight.js":
/*!*************************************************!*\
  !*** ./node_modules/ramda/es/mergeDeepRight.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mergeDeepWithKey.js */ "./node_modules/ramda/es/mergeDeepWithKey.js");



/**
 * Creates a new object with the own properties of the first object merged with
 * the own properties of the second object. If a key exists in both objects:
 * - and both values are objects, the two values will be recursively merged
 * - otherwise the value from the second object will be used.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Object
 * @sig {a} -> {a} -> {a}
 * @param {Object} lObj
 * @param {Object} rObj
 * @return {Object}
 * @see R.merge, R.mergeDeepLeft, R.mergeDeepWith, R.mergeDeepWithKey
 * @example
 *
 *      R.mergeDeepRight({ name: 'fred', age: 10, contact: { email: 'moo@example.com' }},
 *                       { age: 40, contact: { email: 'baa@example.com' }});
 *      //=> { name: 'fred', age: 40, contact: { email: 'baa@example.com' }}
 */
var mergeDeepRight = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mergeDeepRight(lObj, rObj) {
  return Object(_mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (k, lVal, rVal) {
    return rVal;
  }, lObj, rObj);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeDeepRight);

/***/ }),

/***/ "./node_modules/ramda/es/mergeDeepWith.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/mergeDeepWith.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mergeDeepWithKey.js */ "./node_modules/ramda/es/mergeDeepWithKey.js");



/**
 * Creates a new object with the own properties of the two provided objects.
 * If a key exists in both objects:
 * - and both associated values are also objects then the values will be
 *   recursively merged.
 * - otherwise the provided function is applied to associated values using the
 *   resulting value as the new value associated with the key.
 * If a key only exists in one object, the value will be associated with the key
 * of the resulting object.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Object
 * @sig ((a, a) -> a) -> {a} -> {a} -> {a}
 * @param {Function} fn
 * @param {Object} lObj
 * @param {Object} rObj
 * @return {Object}
 * @see R.mergeWith, R.mergeDeepWithKey
 * @example
 *
 *      R.mergeDeepWith(R.concat,
 *                      { a: true, c: { values: [10, 20] }},
 *                      { b: true, c: { values: [15, 35] }});
 *      //=> { a: true, b: true, c: { values: [10, 20, 15, 35] }}
 */
var mergeDeepWith = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mergeDeepWith(fn, lObj, rObj) {
  return Object(_mergeDeepWithKey_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (k, lVal, rVal) {
    return fn(lVal, rVal);
  }, lObj, rObj);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeDeepWith);

/***/ }),

/***/ "./node_modules/ramda/es/mergeDeepWithKey.js":
/*!***************************************************!*\
  !*** ./node_modules/ramda/es/mergeDeepWithKey.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _internal_isObject_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isObject.js */ "./node_modules/ramda/es/internal/_isObject.js");
/* harmony import */ var _mergeWithKey_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./mergeWithKey.js */ "./node_modules/ramda/es/mergeWithKey.js");




/**
 * Creates a new object with the own properties of the two provided objects.
 * If a key exists in both objects:
 * - and both associated values are also objects then the values will be
 *   recursively merged.
 * - otherwise the provided function is applied to the key and associated values
 *   using the resulting value as the new value associated with the key.
 * If a key only exists in one object, the value will be associated with the key
 * of the resulting object.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Object
 * @sig ((String, a, a) -> a) -> {a} -> {a} -> {a}
 * @param {Function} fn
 * @param {Object} lObj
 * @param {Object} rObj
 * @return {Object}
 * @see R.mergeWithKey, R.mergeDeepWith
 * @example
 *
 *      let concatValues = (k, l, r) => k == 'values' ? R.concat(l, r) : r
 *      R.mergeDeepWithKey(concatValues,
 *                         { a: true, c: { thing: 'foo', values: [10, 20] }},
 *                         { b: true, c: { thing: 'bar', values: [15, 35] }});
 *      //=> { a: true, b: true, c: { thing: 'bar', values: [10, 20, 15, 35] }}
 */
var mergeDeepWithKey = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mergeDeepWithKey(fn, lObj, rObj) {
  return Object(_mergeWithKey_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function (k, lVal, rVal) {
    if (Object(_internal_isObject_js__WEBPACK_IMPORTED_MODULE_1__["default"])(lVal) && Object(_internal_isObject_js__WEBPACK_IMPORTED_MODULE_1__["default"])(rVal)) {
      return mergeDeepWithKey(fn, lVal, rVal);
    } else {
      return fn(k, lVal, rVal);
    }
  }, lObj, rObj);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeDeepWithKey);

/***/ }),

/***/ "./node_modules/ramda/es/mergeLeft.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/mergeLeft.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_objectAssign.js */ "./node_modules/ramda/es/internal/_objectAssign.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Create a new object with the own properties of the first object merged with
 * the own properties of the second object. If a key exists in both objects,
 * the value from the first object will be used.
 *
 * @func
 * @memberOf R
 * @category Object
 * @sig {k: v} -> {k: v} -> {k: v}
 * @param {Object} l
 * @param {Object} r
 * @return {Object}
 * @see R.mergeRight, R.mergeDeepLeft, R.mergeWith, R.mergeWithKey
 * @example
 *
 *      R.mergeLeft({ 'age': 40 }, { 'name': 'fred', 'age': 10 });
 *      //=> { 'name': 'fred', 'age': 40 }
 *
 *      const resetToDefault = R.mergeLeft({x: 0});
 *      resetToDefault({x: 5, y: 2}); //=> {x: 0, y: 2}
 * @symb R.mergeLeft(a, b) = {...b, ...a}
 */
var mergeLeft = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function mergeLeft(l, r) {
  return Object(_internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__["default"])({}, r, l);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeLeft);

/***/ }),

/***/ "./node_modules/ramda/es/mergeRight.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/mergeRight.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_objectAssign.js */ "./node_modules/ramda/es/internal/_objectAssign.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Create a new object with the own properties of the first object merged with
 * the own properties of the second object. If a key exists in both objects,
 * the value from the second object will be used.
 *
 * @func
 * @memberOf R
 * @category Object
 * @sig {k: v} -> {k: v} -> {k: v}
 * @param {Object} l
 * @param {Object} r
 * @return {Object}
 * @see R.mergeLeft, R.mergeDeepRight, R.mergeWith, R.mergeWithKey
 * @example
 *
 *      R.mergeRight({ 'name': 'fred', 'age': 10 }, { 'age': 40 });
 *      //=> { 'name': 'fred', 'age': 40 }
 *
 *      const withDefaults = R.mergeRight({x: 0, y: 0});
 *      withDefaults({y: 2}); //=> {x: 0, y: 2}
 * @symb R.mergeRight(a, b) = {...a, ...b}
 */
var mergeRight = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function mergeRight(l, r) {
  return Object(_internal_objectAssign_js__WEBPACK_IMPORTED_MODULE_0__["default"])({}, l, r);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeRight);

/***/ }),

/***/ "./node_modules/ramda/es/mergeWith.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/mergeWith.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _mergeWithKey_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./mergeWithKey.js */ "./node_modules/ramda/es/mergeWithKey.js");



/**
 * Creates a new object with the own properties of the two provided objects. If
 * a key exists in both objects, the provided function is applied to the values
 * associated with the key in each object, with the result being used as the
 * value associated with the key in the returned object.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Object
 * @sig ((a, a) -> a) -> {a} -> {a} -> {a}
 * @param {Function} fn
 * @param {Object} l
 * @param {Object} r
 * @return {Object}
 * @see R.mergeDeepWith, R.merge, R.mergeWithKey
 * @example
 *
 *      R.mergeWith(R.concat,
 *                  { a: true, values: [10, 20] },
 *                  { b: true, values: [15, 35] });
 *      //=> { a: true, b: true, values: [10, 20, 15, 35] }
 */
var mergeWith = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mergeWith(fn, l, r) {
  return Object(_mergeWithKey_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (_, _l, _r) {
    return fn(_l, _r);
  }, l, r);
});
/* harmony default export */ __webpack_exports__["default"] = (mergeWith);

/***/ }),

/***/ "./node_modules/ramda/es/mergeWithKey.js":
/*!***********************************************!*\
  !*** ./node_modules/ramda/es/mergeWithKey.js ***!
  \***********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");



/**
 * Creates a new object with the own properties of the two provided objects. If
 * a key exists in both objects, the provided function is applied to the key
 * and the values associated with the key in each object, with the result being
 * used as the value associated with the key in the returned object.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Object
 * @sig ((String, a, a) -> a) -> {a} -> {a} -> {a}
 * @param {Function} fn
 * @param {Object} l
 * @param {Object} r
 * @return {Object}
 * @see R.mergeDeepWithKey, R.merge, R.mergeWith
 * @example
 *
 *      let concatValues = (k, l, r) => k == 'values' ? R.concat(l, r) : r
 *      R.mergeWithKey(concatValues,
 *                     { a: true, thing: 'foo', values: [10, 20] },
 *                     { b: true, thing: 'bar', values: [15, 35] });
 *      //=> { a: true, b: true, thing: 'bar', values: [10, 20, 15, 35] }
 * @symb R.mergeWithKey(f, { x: 1, y: 2 }, { y: 5, z: 3 }) = { x: 1, y: f('y', 2, 5), z: 3 }
 */
var mergeWithKey = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function mergeWithKey(fn, l, r) {
  var result = {};
  var k;

  for (k in l) {
    if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(k, l)) {
      result[k] = Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(k, r) ? fn(k, l[k], r[k]) : l[k];
    }
  }

  for (k in r) {
    if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(k, r) && !Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(k, result)) {
      result[k] = r[k];
    }
  }

  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (mergeWithKey);

/***/ }),

/***/ "./node_modules/ramda/es/min.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/min.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns the smaller of its two arguments.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord a => a -> a -> a
 * @param {*} a
 * @param {*} b
 * @return {*}
 * @see R.minBy, R.max
 * @example
 *
 *      R.min(789, 123); //=> 123
 *      R.min('a', 'b'); //=> 'a'
 */
var min = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function min(a, b) {
  return b < a ? b : a;
});
/* harmony default export */ __webpack_exports__["default"] = (min);

/***/ }),

/***/ "./node_modules/ramda/es/minBy.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/minBy.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Takes a function and two values, and returns whichever value produces the
 * smaller result when passed to the provided function.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Relation
 * @sig Ord b => (a -> b) -> a -> a -> a
 * @param {Function} f
 * @param {*} a
 * @param {*} b
 * @return {*}
 * @see R.min, R.maxBy
 * @example
 *
 *      //  square :: Number -> Number
 *      const square = n => n * n;
 *
 *      R.minBy(square, -3, 2); //=> 2
 *
 *      R.reduce(R.minBy(square), Infinity, [3, -5, 4, 1, -2]); //=> 1
 *      R.reduce(R.minBy(square), Infinity, []); //=> Infinity
 */
var minBy = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function minBy(f, a, b) {
  return f(b) < f(a) ? b : a;
});
/* harmony default export */ __webpack_exports__["default"] = (minBy);

/***/ }),

/***/ "./node_modules/ramda/es/modulo.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/modulo.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Divides the first parameter by the second and returns the remainder. Note
 * that this function preserves the JavaScript-style behavior for modulo. For
 * mathematical modulo see [`mathMod`](#mathMod).
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category Math
 * @sig Number -> Number -> Number
 * @param {Number} a The value to the divide.
 * @param {Number} b The pseudo-modulus
 * @return {Number} The result of `b % a`.
 * @see R.mathMod
 * @example
 *
 *      R.modulo(17, 3); //=> 2
 *      // JS behavior:
 *      R.modulo(-17, 3); //=> -2
 *      R.modulo(17, -3); //=> 2
 *
 *      const isOdd = R.modulo(R.__, 2);
 *      isOdd(42); //=> 0
 *      isOdd(21); //=> 1
 */
var modulo = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function modulo(a, b) {
  return a % b;
});
/* harmony default export */ __webpack_exports__["default"] = (modulo);

/***/ }),

/***/ "./node_modules/ramda/es/move.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/move.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Move an item, at index `from`, to index `to`, in a list of elements.
 * A new list will be created containing the new elements order.
 *
 * @func
 * @memberOf R
 * @category List
 * @sig Number -> Number -> [a] -> [a]
 * @param {Number} from The source index
 * @param {Number} to The destination index
 * @param {Array} list The list which will serve to realise the move
 * @return {Array} The new list reordered
 * @example
 *
 *      R.move(0, 2, ['a', 'b', 'c', 'd', 'e', 'f']); //=> ['b', 'c', 'a', 'd', 'e', 'f']
 *      R.move(-1, 0, ['a', 'b', 'c', 'd', 'e', 'f']); //=> ['f', 'a', 'b', 'c', 'd', 'e'] list rotation
 */
var move = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (from, to, list) {
  var length = list.length;
  var result = list.slice();
  var positiveFrom = from < 0 ? length + from : from;
  var positiveTo = to < 0 ? length + to : to;
  var item = result.splice(positiveFrom, 1);

  return positiveFrom < 0 || positiveFrom >= list.length || positiveTo < 0 || positiveTo >= list.length ? list : [].concat(result.slice(0, positiveTo)).concat(item).concat(result.slice(positiveTo, list.length));
});

/* harmony default export */ __webpack_exports__["default"] = (move);

/***/ }),

/***/ "./node_modules/ramda/es/multiply.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/multiply.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Multiplies two numbers. Equivalent to `a * b` but curried.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Math
 * @sig Number -> Number -> Number
 * @param {Number} a The first value.
 * @param {Number} b The second value.
 * @return {Number} The result of `a * b`.
 * @see R.divide
 * @example
 *
 *      const double = R.multiply(2);
 *      const triple = R.multiply(3);
 *      double(3);       //=>  6
 *      triple(4);       //=> 12
 *      R.multiply(2, 5);  //=> 10
 */
var multiply = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function multiply(a, b) {
  return a * b;
});
/* harmony default export */ __webpack_exports__["default"] = (multiply);

/***/ }),

/***/ "./node_modules/ramda/es/nAry.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/nAry.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Wraps a function of any arity (including nullary) in a function that accepts
 * exactly `n` parameters. Any extraneous parameters will not be passed to the
 * supplied function.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig Number -> (* -> a) -> (* -> a)
 * @param {Number} n The desired arity of the new function.
 * @param {Function} fn The function to wrap.
 * @return {Function} A new function wrapping `fn`. The new function is guaranteed to be of
 *         arity `n`.
 * @see R.binary, R.unary
 * @example
 *
 *      const takesTwoArgs = (a, b) => [a, b];
 *
 *      takesTwoArgs.length; //=> 2
 *      takesTwoArgs(1, 2); //=> [1, 2]
 *
 *      const takesOneArg = R.nAry(1, takesTwoArgs);
 *      takesOneArg.length; //=> 1
 *      // Only `n` arguments are passed to the wrapped function
 *      takesOneArg(1, 2); //=> [1, undefined]
 * @symb R.nAry(0, f)(a, b) = f()
 * @symb R.nAry(1, f)(a, b) = f(a)
 * @symb R.nAry(2, f)(a, b) = f(a, b)
 */
var nAry = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function nAry(n, fn) {
  switch (n) {
    case 0:
      return function () {
        return fn.call(this);
      };
    case 1:
      return function (a0) {
        return fn.call(this, a0);
      };
    case 2:
      return function (a0, a1) {
        return fn.call(this, a0, a1);
      };
    case 3:
      return function (a0, a1, a2) {
        return fn.call(this, a0, a1, a2);
      };
    case 4:
      return function (a0, a1, a2, a3) {
        return fn.call(this, a0, a1, a2, a3);
      };
    case 5:
      return function (a0, a1, a2, a3, a4) {
        return fn.call(this, a0, a1, a2, a3, a4);
      };
    case 6:
      return function (a0, a1, a2, a3, a4, a5) {
        return fn.call(this, a0, a1, a2, a3, a4, a5);
      };
    case 7:
      return function (a0, a1, a2, a3, a4, a5, a6) {
        return fn.call(this, a0, a1, a2, a3, a4, a5, a6);
      };
    case 8:
      return function (a0, a1, a2, a3, a4, a5, a6, a7) {
        return fn.call(this, a0, a1, a2, a3, a4, a5, a6, a7);
      };
    case 9:
      return function (a0, a1, a2, a3, a4, a5, a6, a7, a8) {
        return fn.call(this, a0, a1, a2, a3, a4, a5, a6, a7, a8);
      };
    case 10:
      return function (a0, a1, a2, a3, a4, a5, a6, a7, a8, a9) {
        return fn.call(this, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
      };
    default:
      throw new Error('First argument to nAry must be a non-negative integer no greater than ten');
  }
});
/* harmony default export */ __webpack_exports__["default"] = (nAry);

/***/ }),

/***/ "./node_modules/ramda/es/negate.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/negate.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Negates its argument.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Math
 * @sig Number -> Number
 * @param {Number} n
 * @return {Number}
 * @example
 *
 *      R.negate(42); //=> -42
 */
var negate = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function negate(n) {
  return -n;
});
/* harmony default export */ __webpack_exports__["default"] = (negate);

/***/ }),

/***/ "./node_modules/ramda/es/none.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/none.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_complement_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_complement.js */ "./node_modules/ramda/es/internal/_complement.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _all_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./all.js */ "./node_modules/ramda/es/all.js");




/**
 * Returns `true` if no elements of the list match the predicate, `false`
 * otherwise.
 *
 * Dispatches to the `all` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> Boolean
 * @param {Function} fn The predicate function.
 * @param {Array} list The array to consider.
 * @return {Boolean} `true` if the predicate is not satisfied by every element, `false` otherwise.
 * @see R.all, R.any
 * @example
 *
 *      const isEven = n => n % 2 === 0;
 *      const isOdd = n => n % 2 === 1;
 *
 *      R.none(isEven, [1, 3, 5, 7, 9, 11]); //=> true
 *      R.none(isOdd, [1, 3, 5, 7, 8, 11]); //=> false
 */
var none = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function none(fn, input) {
  return Object(_all_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_internal_complement_js__WEBPACK_IMPORTED_MODULE_0__["default"])(fn), input);
});
/* harmony default export */ __webpack_exports__["default"] = (none);

/***/ }),

/***/ "./node_modules/ramda/es/not.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/not.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * A function that returns the `!` of its argument. It will return `true` when
 * passed false-y value, and `false` when passed a truth-y one.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Logic
 * @sig * -> Boolean
 * @param {*} a any value
 * @return {Boolean} the logical inverse of passed argument.
 * @see R.complement
 * @example
 *
 *      R.not(true); //=> false
 *      R.not(false); //=> true
 *      R.not(0); //=> true
 *      R.not(1); //=> false
 */
var not = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function not(a) {
  return !a;
});
/* harmony default export */ __webpack_exports__["default"] = (not);

/***/ }),

/***/ "./node_modules/ramda/es/nth.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/nth.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isString_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isString.js */ "./node_modules/ramda/es/internal/_isString.js");



/**
 * Returns the nth element of the given list or string. If n is negative the
 * element at index length + n is returned.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Number -> [a] -> a | Undefined
 * @sig Number -> String -> String
 * @param {Number} offset
 * @param {*} list
 * @return {*}
 * @example
 *
 *      const list = ['foo', 'bar', 'baz', 'quux'];
 *      R.nth(1, list); //=> 'bar'
 *      R.nth(-1, list); //=> 'quux'
 *      R.nth(-99, list); //=> undefined
 *
 *      R.nth(2, 'abc'); //=> 'c'
 *      R.nth(3, 'abc'); //=> ''
 * @symb R.nth(-1, [a, b, c]) = c
 * @symb R.nth(0, [a, b, c]) = a
 * @symb R.nth(1, [a, b, c]) = b
 */
var nth = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function nth(offset, list) {
  var idx = offset < 0 ? list.length + offset : offset;
  return Object(_internal_isString_js__WEBPACK_IMPORTED_MODULE_1__["default"])(list) ? list.charAt(idx) : list[idx];
});
/* harmony default export */ __webpack_exports__["default"] = (nth);

/***/ }),

/***/ "./node_modules/ramda/es/nthArg.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/nthArg.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _nth_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./nth.js */ "./node_modules/ramda/es/nth.js");




/**
 * Returns a function which returns its nth argument.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category Function
 * @sig Number -> *... -> *
 * @param {Number} n
 * @return {Function}
 * @example
 *
 *      R.nthArg(1)('a', 'b', 'c'); //=> 'b'
 *      R.nthArg(-1)('a', 'b', 'c'); //=> 'c'
 * @symb R.nthArg(-1)(a, b, c) = c
 * @symb R.nthArg(0)(a, b, c) = a
 * @symb R.nthArg(1)(a, b, c) = b
 */
var nthArg = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function nthArg(n) {
  var arity = n < 0 ? 1 : n + 1;
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(arity, function () {
    return Object(_nth_js__WEBPACK_IMPORTED_MODULE_2__["default"])(n, arguments);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (nthArg);

/***/ }),

/***/ "./node_modules/ramda/es/o.js":
/*!************************************!*\
  !*** ./node_modules/ramda/es/o.js ***!
  \************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * `o` is a curried composition function that returns a unary function.
 * Like [`compose`](#compose), `o` performs right-to-left function composition.
 * Unlike [`compose`](#compose), the rightmost function passed to `o` will be
 * invoked with only one argument. Also, unlike [`compose`](#compose), `o` is
 * limited to accepting only 2 unary functions. The name o was chosen because
 * of its similarity to the mathematical composition operator ∘.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category Function
 * @sig (b -> c) -> (a -> b) -> a -> c
 * @param {Function} f
 * @param {Function} g
 * @return {Function}
 * @see R.compose, R.pipe
 * @example
 *
 *      const classyGreeting = name => "The name's " + name.last + ", " + name.first + " " + name.last
 *      const yellGreeting = R.o(R.toUpper, classyGreeting);
 *      yellGreeting({first: 'James', last: 'Bond'}); //=> "THE NAME'S BOND, JAMES BOND"
 *
 *      R.o(R.multiply(10), R.add(10))(-4) //=> 60
 *
 * @symb R.o(f, g, x) = f(g(x))
 */
var o = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function o(f, g, x) {
  return f(g(x));
});
/* harmony default export */ __webpack_exports__["default"] = (o);

/***/ }),

/***/ "./node_modules/ramda/es/objOf.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/objOf.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Creates an object containing a single key:value pair.
 *
 * @func
 * @memberOf R
 * @since v0.18.0
 * @category Object
 * @sig String -> a -> {String:a}
 * @param {String} key
 * @param {*} val
 * @return {Object}
 * @see R.pair
 * @example
 *
 *      const matchPhrases = R.compose(
 *        R.objOf('must'),
 *        R.map(R.objOf('match_phrase'))
 *      );
 *      matchPhrases(['foo', 'bar', 'baz']); //=> {must: [{match_phrase: 'foo'}, {match_phrase: 'bar'}, {match_phrase: 'baz'}]}
 */
var objOf = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function objOf(key, val) {
  var obj = {};
  obj[key] = val;
  return obj;
});
/* harmony default export */ __webpack_exports__["default"] = (objOf);

/***/ }),

/***/ "./node_modules/ramda/es/of.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/of.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_of_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_of.js */ "./node_modules/ramda/es/internal/_of.js");



/**
 * Returns a singleton array containing the value provided.
 *
 * Note this `of` is different from the ES6 `of`; See
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/of
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category Function
 * @sig a -> [a]
 * @param {*} x any value
 * @return {Array} An array wrapping `x`.
 * @example
 *
 *      R.of(null); //=> [null]
 *      R.of([42]); //=> [[42]]
 */
var of = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(_internal_of_js__WEBPACK_IMPORTED_MODULE_1__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (of);

/***/ }),

/***/ "./node_modules/ramda/es/omit.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/omit.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns a partial copy of an object omitting the keys specified.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig [String] -> {String: *} -> {String: *}
 * @param {Array} names an array of String property names to omit from the new object
 * @param {Object} obj The object to copy from
 * @return {Object} A new object with properties from `names` not on it.
 * @see R.pick
 * @example
 *
 *      R.omit(['a', 'd'], {a: 1, b: 2, c: 3, d: 4}); //=> {b: 2, c: 3}
 */
var omit = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function omit(names, obj) {
  var result = {};
  var index = {};
  var idx = 0;
  var len = names.length;

  while (idx < len) {
    index[names[idx]] = 1;
    idx += 1;
  }

  for (var prop in obj) {
    if (!index.hasOwnProperty(prop)) {
      result[prop] = obj[prop];
    }
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (omit);

/***/ }),

/***/ "./node_modules/ramda/es/once.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/once.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");



/**
 * Accepts a function `fn` and returns a function that guards invocation of
 * `fn` such that `fn` can only ever be called once, no matter how many times
 * the returned function is invoked. The first value calculated is returned in
 * subsequent invocations.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig (a... -> b) -> (a... -> b)
 * @param {Function} fn The function to wrap in a call-only-once wrapper.
 * @return {Function} The wrapped function.
 * @example
 *
 *      const addOneOnce = R.once(x => x + 1);
 *      addOneOnce(10); //=> 11
 *      addOneOnce(addOneOnce(50)); //=> 11
 */
var once = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function once(fn) {
  var called = false;
  var result;
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(fn.length, function () {
    if (called) {
      return result;
    }
    called = true;
    result = fn.apply(this, arguments);
    return result;
  });
});
/* harmony default export */ __webpack_exports__["default"] = (once);

/***/ }),

/***/ "./node_modules/ramda/es/or.js":
/*!*************************************!*\
  !*** ./node_modules/ramda/es/or.js ***!
  \*************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns `true` if one or both of its arguments are `true`. Returns `false`
 * if both arguments are `false`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Logic
 * @sig a -> b -> a | b
 * @param {Any} a
 * @param {Any} b
 * @return {Any} the first argument if truthy, otherwise the second argument.
 * @see R.either
 * @example
 *
 *      R.or(true, true); //=> true
 *      R.or(true, false); //=> true
 *      R.or(false, true); //=> true
 *      R.or(false, false); //=> false
 */
var or = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function or(a, b) {
  return a || b;
});
/* harmony default export */ __webpack_exports__["default"] = (or);

/***/ }),

/***/ "./node_modules/ramda/es/otherwise.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/otherwise.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_assertPromise_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_assertPromise.js */ "./node_modules/ramda/es/internal/_assertPromise.js");



/**
 * Returns the result of applying the onFailure function to the value inside
 * a failed promise. This is useful for handling rejected promises
 * inside function compositions.
 *
 * @func
 * @memberOf R
 * @category Function
 * @sig (e -> b) -> (Promise e a) -> (Promise e b)
 * @sig (e -> (Promise f b)) -> (Promise e a) -> (Promise f b)
 * @param {Function} onFailure The function to apply. Can return a value or a promise of a value.
 * @param {Promise} p
 * @return {Promise} The result of calling `p.then(null, onFailure)`
 * @see R.then
 * @example
 *
 *      var failedFetch = (id) => Promise.reject('bad ID');
 *      var useDefault = () => ({ firstName: 'Bob', lastName: 'Loblaw' })
 *
 *      //recoverFromFailure :: String -> Promise ({firstName, lastName})
 *      var recoverFromFailure = R.pipe(
 *        failedFetch,
 *        R.otherwise(useDefault),
 *        R.then(R.pick(['firstName', 'lastName'])),
 *      );
 *      recoverFromFailure(12345).then(console.log)
 */
var otherwise = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function otherwise(f, p) {
  Object(_internal_assertPromise_js__WEBPACK_IMPORTED_MODULE_1__["default"])('otherwise', p);

  return p.then(null, f);
});
/* harmony default export */ __webpack_exports__["default"] = (otherwise);

/***/ }),

/***/ "./node_modules/ramda/es/over.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/over.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


// `Identity` is a functor that holds a single value, where `map` simply
// transforms the held value with the provided function.
var Identity = function (x) {
  return { value: x, map: function (f) {
      return Identity(f(x));
    } };
};

/**
 * Returns the result of "setting" the portion of the given data structure
 * focused by the given lens to the result of applying the given function to
 * the focused value.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Object
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig Lens s a -> (a -> a) -> s -> s
 * @param {Lens} lens
 * @param {*} v
 * @param {*} x
 * @return {*}
 * @see R.prop, R.lensIndex, R.lensProp
 * @example
 *
 *      const headLens = R.lensIndex(0);
 *
 *      R.over(headLens, R.toUpper, ['foo', 'bar', 'baz']); //=> ['FOO', 'bar', 'baz']
 */
var over = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function over(lens, f, x) {
  // The value returned by the getter function is first transformed with `f`,
  // then set as the value of an `Identity`. This is then mapped over with the
  // setter function of the lens.
  return lens(function (y) {
    return Identity(f(y));
  })(x).value;
});
/* harmony default export */ __webpack_exports__["default"] = (over);

/***/ }),

/***/ "./node_modules/ramda/es/pair.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/pair.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Takes two arguments, `fst` and `snd`, and returns `[fst, snd]`.
 *
 * @func
 * @memberOf R
 * @since v0.18.0
 * @category List
 * @sig a -> b -> (a,b)
 * @param {*} fst
 * @param {*} snd
 * @return {Array}
 * @see R.objOf, R.of
 * @example
 *
 *      R.pair('foo', 'bar'); //=> ['foo', 'bar']
 */
var pair = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pair(fst, snd) {
  return [fst, snd];
});
/* harmony default export */ __webpack_exports__["default"] = (pair);

/***/ }),

/***/ "./node_modules/ramda/es/partial.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/partial.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_createPartialApplicator_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_createPartialApplicator.js */ "./node_modules/ramda/es/internal/_createPartialApplicator.js");



/**
 * Takes a function `f` and a list of arguments, and returns a function `g`.
 * When applied, `g` returns the result of applying `f` to the arguments
 * provided initially followed by the arguments provided to `g`.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category Function
 * @sig ((a, b, c, ..., n) -> x) -> [a, b, c, ...] -> ((d, e, f, ..., n) -> x)
 * @param {Function} f
 * @param {Array} args
 * @return {Function}
 * @see R.partialRight, R.curry
 * @example
 *
 *      const multiply2 = (a, b) => a * b;
 *      const double = R.partial(multiply2, [2]);
 *      double(2); //=> 4
 *
 *      const greet = (salutation, title, firstName, lastName) =>
 *        salutation + ', ' + title + ' ' + firstName + ' ' + lastName + '!';
 *
 *      const sayHello = R.partial(greet, ['Hello']);
 *      const sayHelloToMs = R.partial(sayHello, ['Ms.']);
 *      sayHelloToMs('Jane', 'Jones'); //=> 'Hello, Ms. Jane Jones!'
 * @symb R.partial(f, [a, b])(c, d) = f(a, b, c, d)
 */
var partial = /*#__PURE__*/Object(_internal_createPartialApplicator_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (partial);

/***/ }),

/***/ "./node_modules/ramda/es/partialRight.js":
/*!***********************************************!*\
  !*** ./node_modules/ramda/es/partialRight.js ***!
  \***********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_createPartialApplicator_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_createPartialApplicator.js */ "./node_modules/ramda/es/internal/_createPartialApplicator.js");
/* harmony import */ var _flip_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./flip.js */ "./node_modules/ramda/es/flip.js");




/**
 * Takes a function `f` and a list of arguments, and returns a function `g`.
 * When applied, `g` returns the result of applying `f` to the arguments
 * provided to `g` followed by the arguments provided initially.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category Function
 * @sig ((a, b, c, ..., n) -> x) -> [d, e, f, ..., n] -> ((a, b, c, ...) -> x)
 * @param {Function} f
 * @param {Array} args
 * @return {Function}
 * @see R.partial
 * @example
 *
 *      const greet = (salutation, title, firstName, lastName) =>
 *        salutation + ', ' + title + ' ' + firstName + ' ' + lastName + '!';
 *
 *      const greetMsJaneJones = R.partialRight(greet, ['Ms.', 'Jane', 'Jones']);
 *
 *      greetMsJaneJones('Hello'); //=> 'Hello, Ms. Jane Jones!'
 * @symb R.partialRight(f, [a, b])(c, d) = f(c, d, a, b)
 */
var partialRight = /*#__PURE__*/Object(_internal_createPartialApplicator_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_flip_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"]));
/* harmony default export */ __webpack_exports__["default"] = (partialRight);

/***/ }),

/***/ "./node_modules/ramda/es/partition.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/partition.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./filter.js */ "./node_modules/ramda/es/filter.js");
/* harmony import */ var _juxt_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./juxt.js */ "./node_modules/ramda/es/juxt.js");
/* harmony import */ var _reject_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./reject.js */ "./node_modules/ramda/es/reject.js");




/**
 * Takes a predicate and a list or other `Filterable` object and returns the
 * pair of filterable objects of the same type of elements which do and do not
 * satisfy, the predicate, respectively. Filterable objects include plain objects or any object
 * that has a filter method such as `Array`.
 *
 * @func
 * @memberOf R
 * @since v0.1.4
 * @category List
 * @sig Filterable f => (a -> Boolean) -> f a -> [f a, f a]
 * @param {Function} pred A predicate to determine which side the element belongs to.
 * @param {Array} filterable the list (or other filterable) to partition.
 * @return {Array} An array, containing first the subset of elements that satisfy the
 *         predicate, and second the subset of elements that do not satisfy.
 * @see R.filter, R.reject
 * @example
 *
 *      R.partition(R.includes('s'), ['sss', 'ttt', 'foo', 'bars']);
 *      // => [ [ 'sss', 'bars' ],  [ 'ttt', 'foo' ] ]
 *
 *      R.partition(R.includes('s'), { a: 'sss', b: 'ttt', foo: 'bars' });
 *      // => [ { a: 'sss', foo: 'bars' }, { b: 'ttt' }  ]
 */
var partition = /*#__PURE__*/Object(_juxt_js__WEBPACK_IMPORTED_MODULE_1__["default"])([_filter_js__WEBPACK_IMPORTED_MODULE_0__["default"], _reject_js__WEBPACK_IMPORTED_MODULE_2__["default"]]);
/* harmony default export */ __webpack_exports__["default"] = (partition);

/***/ }),

/***/ "./node_modules/ramda/es/path.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/path.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Retrieve the value at a given path.
 *
 * @func
 * @memberOf R
 * @since v0.2.0
 * @category Object
 * @typedefn Idx = String | Int
 * @sig [Idx] -> {a} -> a | Undefined
 * @param {Array} path The path to use.
 * @param {Object} obj The object to retrieve the nested property from.
 * @return {*} The data at `path`.
 * @see R.prop
 * @example
 *
 *      R.path(['a', 'b'], {a: {b: 2}}); //=> 2
 *      R.path(['a', 'b'], {c: {b: 2}}); //=> undefined
 */
var path = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function path(paths, obj) {
  var val = obj;
  var idx = 0;
  while (idx < paths.length) {
    if (val == null) {
      return;
    }
    val = val[paths[idx]];
    idx += 1;
  }
  return val;
});
/* harmony default export */ __webpack_exports__["default"] = (path);

/***/ }),

/***/ "./node_modules/ramda/es/pathEq.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/pathEq.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");
/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./path.js */ "./node_modules/ramda/es/path.js");




/**
 * Determines whether a nested path on an object has a specific value, in
 * [`R.equals`](#equals) terms. Most likely used to filter a list.
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category Relation
 * @typedefn Idx = String | Int
 * @sig [Idx] -> a -> {a} -> Boolean
 * @param {Array} path The path of the nested property to use
 * @param {*} val The value to compare the nested property with
 * @param {Object} obj The object to check the nested property in
 * @return {Boolean} `true` if the value equals the nested object property,
 *         `false` otherwise.
 * @example
 *
 *      const user1 = { address: { zipCode: 90210 } };
 *      const user2 = { address: { zipCode: 55555 } };
 *      const user3 = { name: 'Bob' };
 *      const users = [ user1, user2, user3 ];
 *      const isFamous = R.pathEq(['address', 'zipCode'], 90210);
 *      R.filter(isFamous, users); //=> [ user1 ]
 */
var pathEq = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pathEq(_path, val, obj) {
  return Object(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_path_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_path, obj), val);
});
/* harmony default export */ __webpack_exports__["default"] = (pathEq);

/***/ }),

/***/ "./node_modules/ramda/es/pathOr.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/pathOr.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _defaultTo_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./defaultTo.js */ "./node_modules/ramda/es/defaultTo.js");
/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./path.js */ "./node_modules/ramda/es/path.js");




/**
 * If the given, non-null object has a value at the given path, returns the
 * value at that path. Otherwise returns the provided default value.
 *
 * @func
 * @memberOf R
 * @since v0.18.0
 * @category Object
 * @typedefn Idx = String | Int
 * @sig a -> [Idx] -> {a} -> a
 * @param {*} d The default value.
 * @param {Array} p The path to use.
 * @param {Object} obj The object to retrieve the nested property from.
 * @return {*} The data at `path` of the supplied object or the default value.
 * @example
 *
 *      R.pathOr('N/A', ['a', 'b'], {a: {b: 2}}); //=> 2
 *      R.pathOr('N/A', ['a', 'b'], {c: {b: 2}}); //=> "N/A"
 */
var pathOr = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pathOr(d, p, obj) {
  return Object(_defaultTo_js__WEBPACK_IMPORTED_MODULE_1__["default"])(d, Object(_path_js__WEBPACK_IMPORTED_MODULE_2__["default"])(p, obj));
});
/* harmony default export */ __webpack_exports__["default"] = (pathOr);

/***/ }),

/***/ "./node_modules/ramda/es/pathSatisfies.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/pathSatisfies.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./path.js */ "./node_modules/ramda/es/path.js");



/**
 * Returns `true` if the specified object property at given path satisfies the
 * given predicate; `false` otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Logic
 * @typedefn Idx = String | Int
 * @sig (a -> Boolean) -> [Idx] -> {a} -> Boolean
 * @param {Function} pred
 * @param {Array} propPath
 * @param {*} obj
 * @return {Boolean}
 * @see R.propSatisfies, R.path
 * @example
 *
 *      R.pathSatisfies(y => y > 0, ['x', 'y'], {x: {y: 2}}); //=> true
 */
var pathSatisfies = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pathSatisfies(pred, propPath, obj) {
  return propPath.length > 0 && pred(Object(_path_js__WEBPACK_IMPORTED_MODULE_1__["default"])(propPath, obj));
});
/* harmony default export */ __webpack_exports__["default"] = (pathSatisfies);

/***/ }),

/***/ "./node_modules/ramda/es/pick.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/pick.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns a partial copy of an object containing only the keys specified. If
 * the key does not exist, the property is ignored.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig [k] -> {k: v} -> {k: v}
 * @param {Array} names an array of String property names to copy onto a new object
 * @param {Object} obj The object to copy from
 * @return {Object} A new object with only properties from `names` on it.
 * @see R.omit, R.props
 * @example
 *
 *      R.pick(['a', 'd'], {a: 1, b: 2, c: 3, d: 4}); //=> {a: 1, d: 4}
 *      R.pick(['a', 'e', 'f'], {a: 1, b: 2, c: 3, d: 4}); //=> {a: 1}
 */
var pick = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pick(names, obj) {
  var result = {};
  var idx = 0;
  while (idx < names.length) {
    if (names[idx] in obj) {
      result[names[idx]] = obj[names[idx]];
    }
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (pick);

/***/ }),

/***/ "./node_modules/ramda/es/pickAll.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/pickAll.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Similar to `pick` except that this one includes a `key: undefined` pair for
 * properties that don't exist.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig [k] -> {k: v} -> {k: v}
 * @param {Array} names an array of String property names to copy onto a new object
 * @param {Object} obj The object to copy from
 * @return {Object} A new object with only properties from `names` on it.
 * @see R.pick
 * @example
 *
 *      R.pickAll(['a', 'd'], {a: 1, b: 2, c: 3, d: 4}); //=> {a: 1, d: 4}
 *      R.pickAll(['a', 'e', 'f'], {a: 1, b: 2, c: 3, d: 4}); //=> {a: 1, e: undefined, f: undefined}
 */
var pickAll = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pickAll(names, obj) {
  var result = {};
  var idx = 0;
  var len = names.length;
  while (idx < len) {
    var name = names[idx];
    result[name] = obj[name];
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (pickAll);

/***/ }),

/***/ "./node_modules/ramda/es/pickBy.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/pickBy.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns a partial copy of an object containing only the keys that satisfy
 * the supplied predicate.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Object
 * @sig ((v, k) -> Boolean) -> {k: v} -> {k: v}
 * @param {Function} pred A predicate to determine whether or not a key
 *        should be included on the output object.
 * @param {Object} obj The object to copy from
 * @return {Object} A new object with only properties that satisfy `pred`
 *         on it.
 * @see R.pick, R.filter
 * @example
 *
 *      const isUpperCase = (val, key) => key.toUpperCase() === key;
 *      R.pickBy(isUpperCase, {a: 1, b: 2, A: 3, B: 4}); //=> {A: 3, B: 4}
 */
var pickBy = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pickBy(test, obj) {
  var result = {};
  for (var prop in obj) {
    if (test(obj[prop], prop, obj)) {
      result[prop] = obj[prop];
    }
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (pickBy);

/***/ }),

/***/ "./node_modules/ramda/es/pipe.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/pipe.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return pipe; });
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_pipe_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_pipe.js */ "./node_modules/ramda/es/internal/_pipe.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");
/* harmony import */ var _tail_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./tail.js */ "./node_modules/ramda/es/tail.js");





/**
 * Performs left-to-right function composition. The leftmost function may have
 * any arity; the remaining functions must be unary.
 *
 * In some libraries this function is named `sequence`.
 *
 * **Note:** The result of pipe is not automatically curried.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig (((a, b, ..., n) -> o), (o -> p), ..., (x -> y), (y -> z)) -> ((a, b, ..., n) -> z)
 * @param {...Function} functions
 * @return {Function}
 * @see R.compose
 * @example
 *
 *      const f = R.pipe(Math.pow, R.negate, R.inc);
 *
 *      f(3, 4); // -(3^4) + 1
 * @symb R.pipe(f, g, h)(a, b) = h(g(f(a, b)))
 */
function pipe() {
  if (arguments.length === 0) {
    throw new Error('pipe requires at least one argument');
  }
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(arguments[0].length, Object(_reduce_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_internal_pipe_js__WEBPACK_IMPORTED_MODULE_1__["default"], arguments[0], Object(_tail_js__WEBPACK_IMPORTED_MODULE_3__["default"])(arguments)));
}

/***/ }),

/***/ "./node_modules/ramda/es/pipeK.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/pipeK.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return pipeK; });
/* harmony import */ var _composeK_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./composeK.js */ "./node_modules/ramda/es/composeK.js");
/* harmony import */ var _reverse_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reverse.js */ "./node_modules/ramda/es/reverse.js");



/**
 * Returns the left-to-right Kleisli composition of the provided functions,
 * each of which must return a value of a type supported by [`chain`](#chain).
 *
 * `R.pipeK(f, g, h)` is equivalent to `R.pipe(f, R.chain(g), R.chain(h))`.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Function
 * @sig Chain m => ((a -> m b), (b -> m c), ..., (y -> m z)) -> (a -> m z)
 * @param {...Function}
 * @return {Function}
 * @see R.composeK
 * @deprecated since v0.26.0
 * @example
 *
 *      //  parseJson :: String -> Maybe *
 *      //  get :: String -> Object -> Maybe *
 *
 *      //  getStateCode :: Maybe String -> Maybe String
 *      const getStateCode = R.pipeK(
 *        parseJson,
 *        get('user'),
 *        get('address'),
 *        get('state'),
 *        R.compose(Maybe.of, R.toUpper)
 *      );
 *
 *      getStateCode('{"user":{"address":{"state":"ny"}}}');
 *      //=> Just('NY')
 *      getStateCode('[Invalid JSON]');
 *      //=> Nothing()
 * @symb R.pipeK(f, g, h)(a) = R.chain(h, R.chain(g, f(a)))
 */
function pipeK() {
  if (arguments.length === 0) {
    throw new Error('pipeK requires at least one argument');
  }
  return _composeK_js__WEBPACK_IMPORTED_MODULE_0__["default"].apply(this, Object(_reverse_js__WEBPACK_IMPORTED_MODULE_1__["default"])(arguments));
}

/***/ }),

/***/ "./node_modules/ramda/es/pipeP.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/pipeP.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, "default", function() { return pipeP; });
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_pipeP_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_pipeP.js */ "./node_modules/ramda/es/internal/_pipeP.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");
/* harmony import */ var _tail_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./tail.js */ "./node_modules/ramda/es/tail.js");





/**
 * Performs left-to-right composition of one or more Promise-returning
 * functions. The leftmost function may have any arity; the remaining functions
 * must be unary.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category Function
 * @sig ((a -> Promise b), (b -> Promise c), ..., (y -> Promise z)) -> (a -> Promise z)
 * @param {...Function} functions
 * @return {Function}
 * @see R.composeP
 * @deprecated since v0.26.0
 * @example
 *
 *      //  followersForUser :: String -> Promise [User]
 *      const followersForUser = R.pipeP(db.getUserById, db.getFollowers);
 */
function pipeP() {
  if (arguments.length === 0) {
    throw new Error('pipeP requires at least one argument');
  }
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(arguments[0].length, Object(_reduce_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_internal_pipeP_js__WEBPACK_IMPORTED_MODULE_1__["default"], arguments[0], Object(_tail_js__WEBPACK_IMPORTED_MODULE_3__["default"])(arguments)));
}

/***/ }),

/***/ "./node_modules/ramda/es/pipeWith.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/pipeWith.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _head_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./head.js */ "./node_modules/ramda/es/head.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _tail_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./tail.js */ "./node_modules/ramda/es/tail.js");
/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./identity.js */ "./node_modules/ramda/es/identity.js");







/**
 * Performs left-to-right function composition using transforming function. The leftmost function may have
 * any arity; the remaining functions must be unary.
 *
 * **Note:** The result of pipeWith is not automatically curried.
 *
 * @func
 * @memberOf R
 * @category Function
 * @sig ((* -> *), [((a, b, ..., n) -> o), (o -> p), ..., (x -> y), (y -> z)]) -> ((a, b, ..., n) -> z)
 * @param {...Function} functions
 * @return {Function}
 * @see R.composeWith, R.pipe
 * @example
 *
 *      const pipeWhileNotNil = R.pipeWith((f, res) => R.isNil(res) ? res : f(res));
 *      const f = pipeWhileNotNil([Math.pow, R.negate, R.inc])
 *
 *      f(3, 4); // -(3^4) + 1
 * @symb R.pipeWith(f)([g, h, i])(...args) = f(i, f(h, f(g, ...args)))
 */
var pipeWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function pipeWith(xf, list) {
  if (list.length <= 0) {
    return _identity_js__WEBPACK_IMPORTED_MODULE_5__["default"];
  }

  var headList = Object(_head_js__WEBPACK_IMPORTED_MODULE_2__["default"])(list);
  var tailList = Object(_tail_js__WEBPACK_IMPORTED_MODULE_4__["default"])(list);

  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(headList.length, function () {
    return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__["default"])(function (result, f) {
      return xf.call(this, f, result);
    }, headList.apply(this, arguments), tailList);
  });
});
/* harmony default export */ __webpack_exports__["default"] = (pipeWith);

/***/ }),

/***/ "./node_modules/ramda/es/pluck.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/pluck.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");
/* harmony import */ var _prop_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./prop.js */ "./node_modules/ramda/es/prop.js");




/**
 * Returns a new list by plucking the same named property off all objects in
 * the list supplied.
 *
 * `pluck` will work on
 * any [functor](https://github.com/fantasyland/fantasy-land#functor) in
 * addition to arrays, as it is equivalent to `R.map(R.prop(k), f)`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Functor f => k -> f {k: v} -> f v
 * @param {Number|String} key The key name to pluck off of each object.
 * @param {Array} f The array or functor to consider.
 * @return {Array} The list of values for the given key.
 * @see R.props
 * @example
 *
 *      var getAges = R.pluck('age');
 *      getAges([{name: 'fred', age: 29}, {name: 'wilma', age: 27}]); //=> [29, 27]
 *
 *      R.pluck(0, [[1, 2], [3, 4]]);               //=> [1, 3]
 *      R.pluck('val', {a: {val: 3}, b: {val: 5}}); //=> {a: 3, b: 5}
 * @symb R.pluck('x', [{x: 1, y: 2}, {x: 3, y: 4}, {x: 5, y: 6}]) = [1, 3, 5]
 * @symb R.pluck(0, [[1, 2], [3, 4], [5, 6]]) = [1, 3, 5]
 */
var pluck = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function pluck(p, list) {
  return Object(_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_prop_js__WEBPACK_IMPORTED_MODULE_2__["default"])(p), list);
});
/* harmony default export */ __webpack_exports__["default"] = (pluck);

/***/ }),

/***/ "./node_modules/ramda/es/prepend.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/prepend.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns a new list with the given element at the front, followed by the
 * contents of the list.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig a -> [a] -> [a]
 * @param {*} el The item to add to the head of the output list.
 * @param {Array} list The array to add to the tail of the output list.
 * @return {Array} A new array.
 * @see R.append
 * @example
 *
 *      R.prepend('fee', ['fi', 'fo', 'fum']); //=> ['fee', 'fi', 'fo', 'fum']
 */
var prepend = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function prepend(el, list) {
  return Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])([el], list);
});
/* harmony default export */ __webpack_exports__["default"] = (prepend);

/***/ }),

/***/ "./node_modules/ramda/es/product.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/product.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _multiply_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./multiply.js */ "./node_modules/ramda/es/multiply.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");



/**
 * Multiplies together all the elements of a list.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Math
 * @sig [Number] -> Number
 * @param {Array} list An array of numbers
 * @return {Number} The product of all the numbers in the list.
 * @see R.reduce
 * @example
 *
 *      R.product([2,4,6,8,100,1]); //=> 38400
 */
var product = /*#__PURE__*/Object(_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_multiply_js__WEBPACK_IMPORTED_MODULE_0__["default"], 1);
/* harmony default export */ __webpack_exports__["default"] = (product);

/***/ }),

/***/ "./node_modules/ramda/es/project.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/project.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_map_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_map.js */ "./node_modules/ramda/es/internal/_map.js");
/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./identity.js */ "./node_modules/ramda/es/identity.js");
/* harmony import */ var _pickAll_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./pickAll.js */ "./node_modules/ramda/es/pickAll.js");
/* harmony import */ var _useWith_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./useWith.js */ "./node_modules/ramda/es/useWith.js");





/**
 * Reasonable analog to SQL `select` statement.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @category Relation
 * @sig [k] -> [{k: v}] -> [{k: v}]
 * @param {Array} props The property names to project
 * @param {Array} objs The objects to query
 * @return {Array} An array of objects with just the `props` properties.
 * @example
 *
 *      const abby = {name: 'Abby', age: 7, hair: 'blond', grade: 2};
 *      const fred = {name: 'Fred', age: 12, hair: 'brown', grade: 7};
 *      const kids = [abby, fred];
 *      R.project(['name', 'grade'], kids); //=> [{name: 'Abby', grade: 2}, {name: 'Fred', grade: 7}]
 */
var project = /*#__PURE__*/Object(_useWith_js__WEBPACK_IMPORTED_MODULE_3__["default"])(_internal_map_js__WEBPACK_IMPORTED_MODULE_0__["default"], [_pickAll_js__WEBPACK_IMPORTED_MODULE_2__["default"], _identity_js__WEBPACK_IMPORTED_MODULE_1__["default"]]); // passing `identity` gives correct arity
/* harmony default export */ __webpack_exports__["default"] = (project);

/***/ }),

/***/ "./node_modules/ramda/es/prop.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/prop.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _path_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./path.js */ "./node_modules/ramda/es/path.js");



/**
 * Returns a function that when supplied an object returns the indicated
 * property of that object, if it exists.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig s -> {s: a} -> a | Undefined
 * @param {String} p The property name
 * @param {Object} obj The object to query
 * @return {*} The value at `obj.p`.
 * @see R.path
 * @example
 *
 *      R.prop('x', {x: 100}); //=> 100
 *      R.prop('x', {}); //=> undefined
 *      R.compose(R.inc, R.prop('x'))({ x: 3 }) //=> 4
 */

var prop = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function prop(p, obj) {
  return Object(_path_js__WEBPACK_IMPORTED_MODULE_1__["default"])([p], obj);
});
/* harmony default export */ __webpack_exports__["default"] = (prop);

/***/ }),

/***/ "./node_modules/ramda/es/propEq.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/propEq.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");



/**
 * Returns `true` if the specified object property is equal, in
 * [`R.equals`](#equals) terms, to the given value; `false` otherwise.
 * You can test multiple properties with [`R.whereEq`](#whereEq).
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig String -> a -> Object -> Boolean
 * @param {String} name
 * @param {*} val
 * @param {*} obj
 * @return {Boolean}
 * @see R.whereEq, R.propSatisfies, R.equals
 * @example
 *
 *      const abby = {name: 'Abby', age: 7, hair: 'blond'};
 *      const fred = {name: 'Fred', age: 12, hair: 'brown'};
 *      const rusty = {name: 'Rusty', age: 10, hair: 'brown'};
 *      const alois = {name: 'Alois', age: 15, disposition: 'surly'};
 *      const kids = [abby, fred, rusty, alois];
 *      const hasBrownHair = R.propEq('hair', 'brown');
 *      R.filter(hasBrownHair, kids); //=> [fred, rusty]
 */
var propEq = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function propEq(name, val, obj) {
  return Object(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(val, obj[name]);
});
/* harmony default export */ __webpack_exports__["default"] = (propEq);

/***/ }),

/***/ "./node_modules/ramda/es/propIs.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/propIs.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _is_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./is.js */ "./node_modules/ramda/es/is.js");



/**
 * Returns `true` if the specified object property is of the given type;
 * `false` otherwise.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Type
 * @sig Type -> String -> Object -> Boolean
 * @param {Function} type
 * @param {String} name
 * @param {*} obj
 * @return {Boolean}
 * @see R.is, R.propSatisfies
 * @example
 *
 *      R.propIs(Number, 'x', {x: 1, y: 2});  //=> true
 *      R.propIs(Number, 'x', {x: 'foo'});    //=> false
 *      R.propIs(Number, 'x', {});            //=> false
 */
var propIs = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function propIs(type, name, obj) {
  return Object(_is_js__WEBPACK_IMPORTED_MODULE_1__["default"])(type, obj[name]);
});
/* harmony default export */ __webpack_exports__["default"] = (propIs);

/***/ }),

/***/ "./node_modules/ramda/es/propOr.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/propOr.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _pathOr_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./pathOr.js */ "./node_modules/ramda/es/pathOr.js");



/**
 * If the given, non-null object has an own property with the specified name,
 * returns the value of that property. Otherwise returns the provided default
 * value.
 *
 * @func
 * @memberOf R
 * @since v0.6.0
 * @category Object
 * @sig a -> String -> Object -> a
 * @param {*} val The default value.
 * @param {String} p The name of the property to return.
 * @param {Object} obj The object to query.
 * @return {*} The value of given property of the supplied object or the default value.
 * @example
 *
 *      const alice = {
 *        name: 'ALICE',
 *        age: 101
 *      };
 *      const favorite = R.prop('favoriteLibrary');
 *      const favoriteWithDefault = R.propOr('Ramda', 'favoriteLibrary');
 *
 *      favorite(alice);  //=> undefined
 *      favoriteWithDefault(alice);  //=> 'Ramda'
 */
var propOr = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function propOr(val, p, obj) {
  return Object(_pathOr_js__WEBPACK_IMPORTED_MODULE_1__["default"])(val, [p], obj);
});
/* harmony default export */ __webpack_exports__["default"] = (propOr);

/***/ }),

/***/ "./node_modules/ramda/es/propSatisfies.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/propSatisfies.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Returns `true` if the specified object property satisfies the given
 * predicate; `false` otherwise. You can test multiple properties with
 * [`R.where`](#where).
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Logic
 * @sig (a -> Boolean) -> String -> {String: a} -> Boolean
 * @param {Function} pred
 * @param {String} name
 * @param {*} obj
 * @return {Boolean}
 * @see R.where, R.propEq, R.propIs
 * @example
 *
 *      R.propSatisfies(x => x > 0, 'x', {x: 1, y: 2}); //=> true
 */
var propSatisfies = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function propSatisfies(pred, name, obj) {
  return pred(obj[name]);
});
/* harmony default export */ __webpack_exports__["default"] = (propSatisfies);

/***/ }),

/***/ "./node_modules/ramda/es/props.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/props.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Acts as multiple `prop`: array of keys in, array of values out. Preserves
 * order.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig [k] -> {k: v} -> [v]
 * @param {Array} ps The property names to fetch
 * @param {Object} obj The object to query
 * @return {Array} The corresponding values or partially applied function.
 * @example
 *
 *      R.props(['x', 'y'], {x: 1, y: 2}); //=> [1, 2]
 *      R.props(['c', 'a', 'b'], {b: 2, a: 1}); //=> [undefined, 1, 2]
 *
 *      const fullName = R.compose(R.join(' '), R.props(['first', 'last']));
 *      fullName({last: 'Bullet-Tooth', age: 33, first: 'Tony'}); //=> 'Tony Bullet-Tooth'
 */
var props = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function props(ps, obj) {
  var len = ps.length;
  var out = [];
  var idx = 0;

  while (idx < len) {
    out[idx] = obj[ps[idx]];
    idx += 1;
  }

  return out;
});
/* harmony default export */ __webpack_exports__["default"] = (props);

/***/ }),

/***/ "./node_modules/ramda/es/range.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/range.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isNumber_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isNumber.js */ "./node_modules/ramda/es/internal/_isNumber.js");



/**
 * Returns a list of numbers from `from` (inclusive) to `to` (exclusive).
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Number -> Number -> [Number]
 * @param {Number} from The first number in the list.
 * @param {Number} to One more than the last number in the list.
 * @return {Array} The list of numbers in the set `[a, b)`.
 * @example
 *
 *      R.range(1, 5);    //=> [1, 2, 3, 4]
 *      R.range(50, 53);  //=> [50, 51, 52]
 */
var range = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function range(from, to) {
  if (!(Object(_internal_isNumber_js__WEBPACK_IMPORTED_MODULE_1__["default"])(from) && Object(_internal_isNumber_js__WEBPACK_IMPORTED_MODULE_1__["default"])(to))) {
    throw new TypeError('Both arguments to range must be numbers');
  }
  var result = [];
  var n = from;
  while (n < to) {
    result.push(n);
    n += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (range);

/***/ }),

/***/ "./node_modules/ramda/es/reduce.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/reduce.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");



/**
 * Returns a single item by iterating through the list, successively calling
 * the iterator function and passing it an accumulator value and the current
 * value from the array, and then passing the result to the next call.
 *
 * The iterator function receives two values: *(acc, value)*. It may use
 * [`R.reduced`](#reduced) to shortcut the iteration.
 *
 * The arguments' order of [`reduceRight`](#reduceRight)'s iterator function
 * is *(value, acc)*.
 *
 * Note: `R.reduce` does not skip deleted or unassigned indices (sparse
 * arrays), unlike the native `Array.prototype.reduce` method. For more details
 * on this behavior, see:
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/reduce#Description
 *
 * Dispatches to the `reduce` method of the third argument, if present. When
 * doing so, it is up to the user to handle the [`R.reduced`](#reduced)
 * shortcuting, as this is not implemented by `reduce`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig ((a, b) -> a) -> a -> [b] -> a
 * @param {Function} fn The iterator function. Receives two values, the accumulator and the
 *        current element from the array.
 * @param {*} acc The accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.reduced, R.addIndex, R.reduceRight
 * @example
 *
 *      R.reduce(R.subtract, 0, [1, 2, 3, 4]) // => ((((0 - 1) - 2) - 3) - 4) = -10
 *      //          -               -10
 *      //         / \              / \
 *      //        -   4           -6   4
 *      //       / \              / \
 *      //      -   3   ==>     -3   3
 *      //     / \              / \
 *      //    -   2           -1   2
 *      //   / \              / \
 *      //  0   1            0   1
 *
 * @symb R.reduce(f, a, [b, c, d]) = f(f(f(a, b), c), d)
 */
var reduce = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (reduce);

/***/ }),

/***/ "./node_modules/ramda/es/reduceBy.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/reduceBy.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curryN_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curryN.js */ "./node_modules/ramda/es/internal/_curryN.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _internal_xreduceBy_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./internal/_xreduceBy.js */ "./node_modules/ramda/es/internal/_xreduceBy.js");






/**
 * Groups the elements of the list according to the result of calling
 * the String-returning function `keyFn` on each element and reduces the elements
 * of each group to a single value via the reducer function `valueFn`.
 *
 * This function is basically a more general [`groupBy`](#groupBy) function.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.20.0
 * @category List
 * @sig ((a, b) -> a) -> a -> (b -> String) -> [b] -> {String: a}
 * @param {Function} valueFn The function that reduces the elements of each group to a single
 *        value. Receives two values, accumulator for a particular group and the current element.
 * @param {*} acc The (initial) accumulator value for each group.
 * @param {Function} keyFn The function that maps the list's element into a key.
 * @param {Array} list The array to group.
 * @return {Object} An object with the output of `keyFn` for keys, mapped to the output of
 *         `valueFn` for elements which produced that key when passed to `keyFn`.
 * @see R.groupBy, R.reduce
 * @example
 *
 *      const groupNames = (acc, {name}) => acc.concat(name)
 *      const toGrade = ({score}) =>
 *        score < 65 ? 'F' :
 *        score < 70 ? 'D' :
 *        score < 80 ? 'C' :
 *        score < 90 ? 'B' : 'A'
 *
 *      var students = [
 *        {name: 'Abby', score: 83},
 *        {name: 'Bart', score: 62},
 *        {name: 'Curt', score: 88},
 *        {name: 'Dora', score: 92},
 *      ]
 *
 *      reduceBy(groupNames, [], toGrade, students)
 *      //=> {"A": ["Dora"], "B": ["Abby", "Curt"], "F": ["Bart"]}
 */
var reduceBy = /*#__PURE__*/Object(_internal_curryN_js__WEBPACK_IMPORTED_MODULE_0__["default"])(4, [], /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xreduceBy_js__WEBPACK_IMPORTED_MODULE_4__["default"], function reduceBy(valueFn, valueAcc, keyFn, list) {
  return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_3__["default"])(function (acc, elt) {
    var key = keyFn(elt);
    acc[key] = valueFn(Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_2__["default"])(key, acc) ? acc[key] : valueAcc, elt);
    return acc;
  }, {}, list);
}));
/* harmony default export */ __webpack_exports__["default"] = (reduceBy);

/***/ }),

/***/ "./node_modules/ramda/es/reduceRight.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/reduceRight.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Returns a single item by iterating through the list, successively calling
 * the iterator function and passing it an accumulator value and the current
 * value from the array, and then passing the result to the next call.
 *
 * Similar to [`reduce`](#reduce), except moves through the input list from the
 * right to the left.
 *
 * The iterator function receives two values: *(value, acc)*, while the arguments'
 * order of `reduce`'s iterator function is *(acc, value)*.
 *
 * Note: `R.reduceRight` does not skip deleted or unassigned indices (sparse
 * arrays), unlike the native `Array.prototype.reduceRight` method. For more details
 * on this behavior, see:
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/reduceRight#Description
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig ((a, b) -> b) -> b -> [a] -> b
 * @param {Function} fn The iterator function. Receives two values, the current element from the array
 *        and the accumulator.
 * @param {*} acc The accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.reduce, R.addIndex
 * @example
 *
 *      R.reduceRight(R.subtract, 0, [1, 2, 3, 4]) // => (1 - (2 - (3 - (4 - 0)))) = -2
 *      //    -               -2
 *      //   / \              / \
 *      //  1   -            1   3
 *      //     / \              / \
 *      //    2   -     ==>    2  -1
 *      //       / \              / \
 *      //      3   -            3   4
 *      //         / \              / \
 *      //        4   0            4   0
 *
 * @symb R.reduceRight(f, a, [b, c, d]) = f(b, f(c, f(d, a)))
 */
var reduceRight = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function reduceRight(fn, acc, list) {
  var idx = list.length - 1;
  while (idx >= 0) {
    acc = fn(list[idx], acc);
    idx -= 1;
  }
  return acc;
});
/* harmony default export */ __webpack_exports__["default"] = (reduceRight);

/***/ }),

/***/ "./node_modules/ramda/es/reduceWhile.js":
/*!**********************************************!*\
  !*** ./node_modules/ramda/es/reduceWhile.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curryN_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curryN.js */ "./node_modules/ramda/es/internal/_curryN.js");
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _internal_reduced_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");




/**
 * Like [`reduce`](#reduce), `reduceWhile` returns a single item by iterating
 * through the list, successively calling the iterator function. `reduceWhile`
 * also takes a predicate that is evaluated before each step. If the predicate
 * returns `false`, it "short-circuits" the iteration and returns the current
 * value of the accumulator.
 *
 * @func
 * @memberOf R
 * @since v0.22.0
 * @category List
 * @sig ((a, b) -> Boolean) -> ((a, b) -> a) -> a -> [b] -> a
 * @param {Function} pred The predicate. It is passed the accumulator and the
 *        current element.
 * @param {Function} fn The iterator function. Receives two values, the
 *        accumulator and the current element.
 * @param {*} a The accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.reduce, R.reduced
 * @example
 *
 *      const isOdd = (acc, x) => x % 2 === 1;
 *      const xs = [1, 3, 5, 60, 777, 800];
 *      R.reduceWhile(isOdd, R.add, 0, xs); //=> 9
 *
 *      const ys = [2, 4, 6]
 *      R.reduceWhile(isOdd, R.add, 111, ys); //=> 111
 */
var reduceWhile = /*#__PURE__*/Object(_internal_curryN_js__WEBPACK_IMPORTED_MODULE_0__["default"])(4, [], function _reduceWhile(pred, fn, a, list) {
  return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (acc, x) {
    return pred(acc, x) ? fn(acc, x) : Object(_internal_reduced_js__WEBPACK_IMPORTED_MODULE_2__["default"])(acc);
  }, a, list);
});
/* harmony default export */ __webpack_exports__["default"] = (reduceWhile);

/***/ }),

/***/ "./node_modules/ramda/es/reduced.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/reduced.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_reduced_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_reduced.js */ "./node_modules/ramda/es/internal/_reduced.js");



/**
 * Returns a value wrapped to indicate that it is the final value of the reduce
 * and transduce functions. The returned value should be considered a black
 * box: the internal structure is not guaranteed to be stable.
 *
 * Note: this optimization is only available to the below functions:
 * - [`reduce`](#reduce)
 * - [`reduceWhile`](#reduceWhile)
 * - [`transduce`](#transduce)
 *
 * @func
 * @memberOf R
 * @since v0.15.0
 * @category List
 * @sig a -> *
 * @param {*} x The final value of the reduce.
 * @return {*} The wrapped value.
 * @see R.reduce, R.reduceWhile, R.transduce
 * @example
 *
 *     R.reduce(
 *       (acc, item) => item > 3 ? R.reduced(acc) : acc.concat(item),
 *       [],
 *       [1, 2, 3, 4, 5]) // [1, 2, 3]
 */
var reduced = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(_internal_reduced_js__WEBPACK_IMPORTED_MODULE_1__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (reduced);

/***/ }),

/***/ "./node_modules/ramda/es/reject.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/reject.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_complement_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_complement.js */ "./node_modules/ramda/es/internal/_complement.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./filter.js */ "./node_modules/ramda/es/filter.js");




/**
 * The complement of [`filter`](#filter).
 *
 * Acts as a transducer if a transformer is given in list position. Filterable
 * objects include plain objects or any object that has a filter method such
 * as `Array`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Filterable f => (a -> Boolean) -> f a -> f a
 * @param {Function} pred
 * @param {Array} filterable
 * @return {Array}
 * @see R.filter, R.transduce, R.addIndex
 * @example
 *
 *      const isOdd = (n) => n % 2 === 1;
 *
 *      R.reject(isOdd, [1, 2, 3, 4]); //=> [2, 4]
 *
 *      R.reject(isOdd, {a: 1, b: 2, c: 3, d: 4}); //=> {b: 2, d: 4}
 */
var reject = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function reject(pred, filterable) {
  return Object(_filter_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_internal_complement_js__WEBPACK_IMPORTED_MODULE_0__["default"])(pred), filterable);
});
/* harmony default export */ __webpack_exports__["default"] = (reject);

/***/ }),

/***/ "./node_modules/ramda/es/remove.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/remove.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Removes the sub-list of `list` starting at index `start` and containing
 * `count` elements. _Note that this is not destructive_: it returns a copy of
 * the list with the changes.
 * <small>No lists have been harmed in the application of this function.</small>
 *
 * @func
 * @memberOf R
 * @since v0.2.2
 * @category List
 * @sig Number -> Number -> [a] -> [a]
 * @param {Number} start The position to start removing elements
 * @param {Number} count The number of elements to remove
 * @param {Array} list The list to remove from
 * @return {Array} A new Array with `count` elements from `start` removed.
 * @see R.without
 * @example
 *
 *      R.remove(2, 3, [1,2,3,4,5,6,7,8]); //=> [1,2,6,7,8]
 */
var remove = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function remove(start, count, list) {
  var result = Array.prototype.slice.call(list, 0);
  result.splice(start, count);
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (remove);

/***/ }),

/***/ "./node_modules/ramda/es/repeat.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/repeat.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _always_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./always.js */ "./node_modules/ramda/es/always.js");
/* harmony import */ var _times_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./times.js */ "./node_modules/ramda/es/times.js");




/**
 * Returns a fixed list of size `n` containing a specified identical value.
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category List
 * @sig a -> n -> [a]
 * @param {*} value The value to repeat.
 * @param {Number} n The desired size of the output list.
 * @return {Array} A new array containing `n` `value`s.
 * @see R.times
 * @example
 *
 *      R.repeat('hi', 5); //=> ['hi', 'hi', 'hi', 'hi', 'hi']
 *
 *      const obj = {};
 *      const repeatedObjs = R.repeat(obj, 5); //=> [{}, {}, {}, {}, {}]
 *      repeatedObjs[0] === repeatedObjs[1]; //=> true
 * @symb R.repeat(a, 0) = []
 * @symb R.repeat(a, 1) = [a]
 * @symb R.repeat(a, 2) = [a, a]
 */
var repeat = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function repeat(value, n) {
  return Object(_times_js__WEBPACK_IMPORTED_MODULE_2__["default"])(Object(_always_js__WEBPACK_IMPORTED_MODULE_1__["default"])(value), n);
});
/* harmony default export */ __webpack_exports__["default"] = (repeat);

/***/ }),

/***/ "./node_modules/ramda/es/replace.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/replace.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Replace a substring or regex match in a string with a replacement.
 *
 * The first two parameters correspond to the parameters of the
 * `String.prototype.replace()` function, so the second parameter can also be a
 * function.
 *
 * @func
 * @memberOf R
 * @since v0.7.0
 * @category String
 * @sig RegExp|String -> String -> String -> String
 * @param {RegExp|String} pattern A regular expression or a substring to match.
 * @param {String} replacement The string to replace the matches with.
 * @param {String} str The String to do the search and replacement in.
 * @return {String} The result.
 * @example
 *
 *      R.replace('foo', 'bar', 'foo foo foo'); //=> 'bar foo foo'
 *      R.replace(/foo/, 'bar', 'foo foo foo'); //=> 'bar foo foo'
 *
 *      // Use the "g" (global) flag to replace all occurrences:
 *      R.replace(/foo/g, 'bar', 'foo foo foo'); //=> 'bar bar bar'
 */
var replace = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function replace(regex, replacement, str) {
  return str.replace(regex, replacement);
});
/* harmony default export */ __webpack_exports__["default"] = (replace);

/***/ }),

/***/ "./node_modules/ramda/es/reverse.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/reverse.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_isString_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_isString.js */ "./node_modules/ramda/es/internal/_isString.js");



/**
 * Returns a new list or string with the elements or characters in reverse
 * order.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [a]
 * @sig String -> String
 * @param {Array|String} list
 * @return {Array|String}
 * @example
 *
 *      R.reverse([1, 2, 3]);  //=> [3, 2, 1]
 *      R.reverse([1, 2]);     //=> [2, 1]
 *      R.reverse([1]);        //=> [1]
 *      R.reverse([]);         //=> []
 *
 *      R.reverse('abc');      //=> 'cba'
 *      R.reverse('ab');       //=> 'ba'
 *      R.reverse('a');        //=> 'a'
 *      R.reverse('');         //=> ''
 */
var reverse = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function reverse(list) {
  return Object(_internal_isString_js__WEBPACK_IMPORTED_MODULE_1__["default"])(list) ? list.split('').reverse().join('') : Array.prototype.slice.call(list, 0).reverse();
});
/* harmony default export */ __webpack_exports__["default"] = (reverse);

/***/ }),

/***/ "./node_modules/ramda/es/scan.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/scan.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Scan is similar to [`reduce`](#reduce), but returns a list of successively
 * reduced values from the left
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category List
 * @sig ((a, b) -> a) -> a -> [b] -> [a]
 * @param {Function} fn The iterator function. Receives two values, the accumulator and the
 *        current element from the array
 * @param {*} acc The accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {Array} A list of all intermediately reduced values.
 * @see R.reduce, R.mapAccum
 * @example
 *
 *      const numbers = [1, 2, 3, 4];
 *      const factorials = R.scan(R.multiply, 1, numbers); //=> [1, 1, 2, 6, 24]
 * @symb R.scan(f, a, [b, c]) = [a, f(a, b), f(f(a, b), c)]
 */
var scan = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function scan(fn, acc, list) {
  var idx = 0;
  var len = list.length;
  var result = [acc];
  while (idx < len) {
    acc = fn(acc, list[idx]);
    result[idx + 1] = acc;
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (scan);

/***/ }),

/***/ "./node_modules/ramda/es/sequence.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/sequence.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _ap_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./ap.js */ "./node_modules/ramda/es/ap.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");
/* harmony import */ var _prepend_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./prepend.js */ "./node_modules/ramda/es/prepend.js");
/* harmony import */ var _reduceRight_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./reduceRight.js */ "./node_modules/ramda/es/reduceRight.js");






/**
 * Transforms a [Traversable](https://github.com/fantasyland/fantasy-land#traversable)
 * of [Applicative](https://github.com/fantasyland/fantasy-land#applicative) into an
 * Applicative of Traversable.
 *
 * Dispatches to the `sequence` method of the second argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig (Applicative f, Traversable t) => (a -> f a) -> t (f a) -> f (t a)
 * @param {Function} of
 * @param {*} traversable
 * @return {*}
 * @see R.traverse
 * @example
 *
 *      R.sequence(Maybe.of, [Just(1), Just(2), Just(3)]);   //=> Just([1, 2, 3])
 *      R.sequence(Maybe.of, [Just(1), Just(2), Nothing()]); //=> Nothing()
 *
 *      R.sequence(R.of, Just([1, 2, 3])); //=> [Just(1), Just(2), Just(3)]
 *      R.sequence(R.of, Nothing());       //=> [Nothing()]
 */
var sequence = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function sequence(of, traversable) {
  return typeof traversable.sequence === 'function' ? traversable.sequence(of) : Object(_reduceRight_js__WEBPACK_IMPORTED_MODULE_4__["default"])(function (x, acc) {
    return Object(_ap_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_prepend_js__WEBPACK_IMPORTED_MODULE_3__["default"], x), acc);
  }, of([]), traversable);
});
/* harmony default export */ __webpack_exports__["default"] = (sequence);

/***/ }),

/***/ "./node_modules/ramda/es/set.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/set.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _always_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./always.js */ "./node_modules/ramda/es/always.js");
/* harmony import */ var _over_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./over.js */ "./node_modules/ramda/es/over.js");




/**
 * Returns the result of "setting" the portion of the given data structure
 * focused by the given lens to the given value.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Object
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig Lens s a -> a -> s -> s
 * @param {Lens} lens
 * @param {*} v
 * @param {*} x
 * @return {*}
 * @see R.prop, R.lensIndex, R.lensProp
 * @example
 *
 *      const xLens = R.lensProp('x');
 *
 *      R.set(xLens, 4, {x: 1, y: 2});  //=> {x: 4, y: 2}
 *      R.set(xLens, 8, {x: 1, y: 2});  //=> {x: 8, y: 2}
 */
var set = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function set(lens, v, x) {
  return Object(_over_js__WEBPACK_IMPORTED_MODULE_2__["default"])(lens, Object(_always_js__WEBPACK_IMPORTED_MODULE_1__["default"])(v), x);
});
/* harmony default export */ __webpack_exports__["default"] = (set);

/***/ }),

/***/ "./node_modules/ramda/es/slice.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/slice.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_checkForMethod.js */ "./node_modules/ramda/es/internal/_checkForMethod.js");
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");



/**
 * Returns the elements of the given list or string (or object with a `slice`
 * method) from `fromIndex` (inclusive) to `toIndex` (exclusive).
 *
 * Dispatches to the `slice` method of the third argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.1.4
 * @category List
 * @sig Number -> Number -> [a] -> [a]
 * @sig Number -> Number -> String -> String
 * @param {Number} fromIndex The start index (inclusive).
 * @param {Number} toIndex The end index (exclusive).
 * @param {*} list
 * @return {*}
 * @example
 *
 *      R.slice(1, 3, ['a', 'b', 'c', 'd']);        //=> ['b', 'c']
 *      R.slice(1, Infinity, ['a', 'b', 'c', 'd']); //=> ['b', 'c', 'd']
 *      R.slice(0, -1, ['a', 'b', 'c', 'd']);       //=> ['a', 'b', 'c']
 *      R.slice(-3, -1, ['a', 'b', 'c', 'd']);      //=> ['b', 'c']
 *      R.slice(0, 3, 'ramda');                     //=> 'ram'
 */
var slice = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__["default"])('slice', function slice(fromIndex, toIndex, list) {
  return Array.prototype.slice.call(list, fromIndex, toIndex);
}));
/* harmony default export */ __webpack_exports__["default"] = (slice);

/***/ }),

/***/ "./node_modules/ramda/es/sort.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/sort.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Returns a copy of the list, sorted according to the comparator function,
 * which should accept two values at a time and return a negative number if the
 * first value is smaller, a positive number if it's larger, and zero if they
 * are equal. Please note that this is a **copy** of the list. It does not
 * modify the original.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig ((a, a) -> Number) -> [a] -> [a]
 * @param {Function} comparator A sorting function :: a -> b -> Int
 * @param {Array} list The list to sort
 * @return {Array} a new array with its elements sorted by the comparator function.
 * @example
 *
 *      const diff = function(a, b) { return a - b; };
 *      R.sort(diff, [4,2,7,5]); //=> [2, 4, 5, 7]
 */
var sort = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function sort(comparator, list) {
  return Array.prototype.slice.call(list, 0).sort(comparator);
});
/* harmony default export */ __webpack_exports__["default"] = (sort);

/***/ }),

/***/ "./node_modules/ramda/es/sortBy.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/sortBy.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Sorts the list according to the supplied function.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig Ord b => (a -> b) -> [a] -> [a]
 * @param {Function} fn
 * @param {Array} list The list to sort.
 * @return {Array} A new list sorted by the keys generated by `fn`.
 * @example
 *
 *      const sortByFirstItem = R.sortBy(R.prop(0));
 *      const pairs = [[-1, 1], [-2, 2], [-3, 3]];
 *      sortByFirstItem(pairs); //=> [[-3, 3], [-2, 2], [-1, 1]]
 *
 *      const sortByNameCaseInsensitive = R.sortBy(R.compose(R.toLower, R.prop('name')));
 *      const alice = {
 *        name: 'ALICE',
 *        age: 101
 *      };
 *      const bob = {
 *        name: 'Bob',
 *        age: -10
 *      };
 *      const clara = {
 *        name: 'clara',
 *        age: 314.159
 *      };
 *      const people = [clara, bob, alice];
 *      sortByNameCaseInsensitive(people); //=> [alice, bob, clara]
 */
var sortBy = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function sortBy(fn, list) {
  return Array.prototype.slice.call(list, 0).sort(function (a, b) {
    var aa = fn(a);
    var bb = fn(b);
    return aa < bb ? -1 : aa > bb ? 1 : 0;
  });
});
/* harmony default export */ __webpack_exports__["default"] = (sortBy);

/***/ }),

/***/ "./node_modules/ramda/es/sortWith.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/sortWith.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Sorts a list according to a list of comparators.
 *
 * @func
 * @memberOf R
 * @since v0.23.0
 * @category Relation
 * @sig [(a, a) -> Number] -> [a] -> [a]
 * @param {Array} functions A list of comparator functions.
 * @param {Array} list The list to sort.
 * @return {Array} A new list sorted according to the comarator functions.
 * @example
 *
 *      const alice = {
 *        name: 'alice',
 *        age: 40
 *      };
 *      const bob = {
 *        name: 'bob',
 *        age: 30
 *      };
 *      const clara = {
 *        name: 'clara',
 *        age: 40
 *      };
 *      const people = [clara, bob, alice];
 *      const ageNameSort = R.sortWith([
 *        R.descend(R.prop('age')),
 *        R.ascend(R.prop('name'))
 *      ]);
 *      ageNameSort(people); //=> [alice, clara, bob]
 */
var sortWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function sortWith(fns, list) {
  return Array.prototype.slice.call(list, 0).sort(function (a, b) {
    var result = 0;
    var i = 0;
    while (result === 0 && i < fns.length) {
      result = fns[i](a, b);
      i += 1;
    }
    return result;
  });
});
/* harmony default export */ __webpack_exports__["default"] = (sortWith);

/***/ }),

/***/ "./node_modules/ramda/es/split.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/split.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _invoker_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./invoker.js */ "./node_modules/ramda/es/invoker.js");


/**
 * Splits a string into an array of strings based on the given
 * separator.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category String
 * @sig (String | RegExp) -> String -> [String]
 * @param {String|RegExp} sep The pattern.
 * @param {String} str The string to separate into an array.
 * @return {Array} The array of strings from `str` separated by `str`.
 * @see R.join
 * @example
 *
 *      const pathComponents = R.split('/');
 *      R.tail(pathComponents('/usr/local/bin/node')); //=> ['usr', 'local', 'bin', 'node']
 *
 *      R.split('.', 'a.b.c.xyz.d'); //=> ['a', 'b', 'c', 'xyz', 'd']
 */
var split = /*#__PURE__*/Object(_invoker_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1, 'split');
/* harmony default export */ __webpack_exports__["default"] = (split);

/***/ }),

/***/ "./node_modules/ramda/es/splitAt.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/splitAt.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _length_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./length.js */ "./node_modules/ramda/es/length.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");




/**
 * Splits a given list or string at a given index.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig Number -> [a] -> [[a], [a]]
 * @sig Number -> String -> [String, String]
 * @param {Number} index The index where the array/string is split.
 * @param {Array|String} array The array/string to be split.
 * @return {Array}
 * @example
 *
 *      R.splitAt(1, [1, 2, 3]);          //=> [[1], [2, 3]]
 *      R.splitAt(5, 'hello world');      //=> ['hello', ' world']
 *      R.splitAt(-1, 'foobar');          //=> ['fooba', 'r']
 */
var splitAt = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function splitAt(index, array) {
  return [Object(_slice_js__WEBPACK_IMPORTED_MODULE_2__["default"])(0, index, array), Object(_slice_js__WEBPACK_IMPORTED_MODULE_2__["default"])(index, Object(_length_js__WEBPACK_IMPORTED_MODULE_1__["default"])(array), array)];
});
/* harmony default export */ __webpack_exports__["default"] = (splitAt);

/***/ }),

/***/ "./node_modules/ramda/es/splitEvery.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/splitEvery.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");



/**
 * Splits a collection into slices of the specified length.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category List
 * @sig Number -> [a] -> [[a]]
 * @sig Number -> String -> [String]
 * @param {Number} n
 * @param {Array} list
 * @return {Array}
 * @example
 *
 *      R.splitEvery(3, [1, 2, 3, 4, 5, 6, 7]); //=> [[1, 2, 3], [4, 5, 6], [7]]
 *      R.splitEvery(3, 'foobarbaz'); //=> ['foo', 'bar', 'baz']
 */
var splitEvery = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function splitEvery(n, list) {
  if (n <= 0) {
    throw new Error('First argument to splitEvery must be a positive integer');
  }
  var result = [];
  var idx = 0;
  while (idx < list.length) {
    result.push(Object(_slice_js__WEBPACK_IMPORTED_MODULE_1__["default"])(idx, idx += n, list));
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (splitEvery);

/***/ }),

/***/ "./node_modules/ramda/es/splitWhen.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/splitWhen.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Takes a list and a predicate and returns a pair of lists with the following properties:
 *
 *  - the result of concatenating the two output lists is equivalent to the input list;
 *  - none of the elements of the first output list satisfies the predicate; and
 *  - if the second output list is non-empty, its first element satisfies the predicate.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> [[a], [a]]
 * @param {Function} pred The predicate that determines where the array is split.
 * @param {Array} list The array to be split.
 * @return {Array}
 * @example
 *
 *      R.splitWhen(R.equals(2), [1, 2, 3, 1, 2, 3]);   //=> [[1], [2, 3, 1, 2, 3]]
 */
var splitWhen = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function splitWhen(pred, list) {
  var idx = 0;
  var len = list.length;
  var prefix = [];

  while (idx < len && !pred(list[idx])) {
    prefix.push(list[idx]);
    idx += 1;
  }

  return [prefix, Array.prototype.slice.call(list, idx)];
});
/* harmony default export */ __webpack_exports__["default"] = (splitWhen);

/***/ }),

/***/ "./node_modules/ramda/es/startsWith.js":
/*!*********************************************!*\
  !*** ./node_modules/ramda/es/startsWith.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");
/* harmony import */ var _take_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./take.js */ "./node_modules/ramda/es/take.js");




/**
 * Checks if a list starts with the provided sublist.
 *
 * Similarly, checks if a string starts with the provided substring.
 *
 * @func
 * @memberOf R
 * @since v0.24.0
 * @category List
 * @sig [a] -> [a] -> Boolean
 * @sig String -> String -> Boolean
 * @param {*} prefix
 * @param {*} list
 * @return {Boolean}
 * @see R.endsWith
 * @example
 *
 *      R.startsWith('a', 'abc')                //=> true
 *      R.startsWith('b', 'abc')                //=> false
 *      R.startsWith(['a'], ['a', 'b', 'c'])    //=> true
 *      R.startsWith(['b'], ['a', 'b', 'c'])    //=> false
 */
var startsWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (prefix, list) {
  return Object(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_take_js__WEBPACK_IMPORTED_MODULE_2__["default"])(prefix.length, list), prefix);
});
/* harmony default export */ __webpack_exports__["default"] = (startsWith);

/***/ }),

/***/ "./node_modules/ramda/es/subtract.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/subtract.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Subtracts its second argument from its first argument.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Math
 * @sig Number -> Number -> Number
 * @param {Number} a The first value.
 * @param {Number} b The second value.
 * @return {Number} The result of `a - b`.
 * @see R.add
 * @example
 *
 *      R.subtract(10, 8); //=> 2
 *
 *      const minus5 = R.subtract(R.__, 5);
 *      minus5(17); //=> 12
 *
 *      const complementaryAngle = R.subtract(90);
 *      complementaryAngle(30); //=> 60
 *      complementaryAngle(72); //=> 18
 */
var subtract = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function subtract(a, b) {
  return Number(a) - Number(b);
});
/* harmony default export */ __webpack_exports__["default"] = (subtract);

/***/ }),

/***/ "./node_modules/ramda/es/sum.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/sum.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _add_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./add.js */ "./node_modules/ramda/es/add.js");
/* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./reduce.js */ "./node_modules/ramda/es/reduce.js");



/**
 * Adds together all the elements of a list.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Math
 * @sig [Number] -> Number
 * @param {Array} list An array of numbers
 * @return {Number} The sum of all the numbers in the list.
 * @see R.reduce
 * @example
 *
 *      R.sum([2,4,6,8,100,1]); //=> 121
 */
var sum = /*#__PURE__*/Object(_reduce_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_add_js__WEBPACK_IMPORTED_MODULE_0__["default"], 0);
/* harmony default export */ __webpack_exports__["default"] = (sum);

/***/ }),

/***/ "./node_modules/ramda/es/symmetricDifference.js":
/*!******************************************************!*\
  !*** ./node_modules/ramda/es/symmetricDifference.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _concat_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./concat.js */ "./node_modules/ramda/es/concat.js");
/* harmony import */ var _difference_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./difference.js */ "./node_modules/ramda/es/difference.js");




/**
 * Finds the set (i.e. no duplicates) of all elements contained in the first or
 * second list, but not both.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Relation
 * @sig [*] -> [*] -> [*]
 * @param {Array} list1 The first list.
 * @param {Array} list2 The second list.
 * @return {Array} The elements in `list1` or `list2`, but not both.
 * @see R.symmetricDifferenceWith, R.difference, R.differenceWith
 * @example
 *
 *      R.symmetricDifference([1,2,3,4], [7,6,5,4,3]); //=> [1,2,7,6,5]
 *      R.symmetricDifference([7,6,5,4,3], [1,2,3,4]); //=> [7,6,5,1,2]
 */
var symmetricDifference = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function symmetricDifference(list1, list2) {
  return Object(_concat_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_difference_js__WEBPACK_IMPORTED_MODULE_2__["default"])(list1, list2), Object(_difference_js__WEBPACK_IMPORTED_MODULE_2__["default"])(list2, list1));
});
/* harmony default export */ __webpack_exports__["default"] = (symmetricDifference);

/***/ }),

/***/ "./node_modules/ramda/es/symmetricDifferenceWith.js":
/*!**********************************************************!*\
  !*** ./node_modules/ramda/es/symmetricDifferenceWith.js ***!
  \**********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _concat_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./concat.js */ "./node_modules/ramda/es/concat.js");
/* harmony import */ var _differenceWith_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./differenceWith.js */ "./node_modules/ramda/es/differenceWith.js");




/**
 * Finds the set (i.e. no duplicates) of all elements contained in the first or
 * second list, but not both. Duplication is determined according to the value
 * returned by applying the supplied predicate to two list elements.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category Relation
 * @sig ((a, a) -> Boolean) -> [a] -> [a] -> [a]
 * @param {Function} pred A predicate used to test whether two items are equal.
 * @param {Array} list1 The first list.
 * @param {Array} list2 The second list.
 * @return {Array} The elements in `list1` or `list2`, but not both.
 * @see R.symmetricDifference, R.difference, R.differenceWith
 * @example
 *
 *      const eqA = R.eqBy(R.prop('a'));
 *      const l1 = [{a: 1}, {a: 2}, {a: 3}, {a: 4}];
 *      const l2 = [{a: 3}, {a: 4}, {a: 5}, {a: 6}];
 *      R.symmetricDifferenceWith(eqA, l1, l2); //=> [{a: 1}, {a: 2}, {a: 5}, {a: 6}]
 */
var symmetricDifferenceWith = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function symmetricDifferenceWith(pred, list1, list2) {
  return Object(_concat_js__WEBPACK_IMPORTED_MODULE_1__["default"])(Object(_differenceWith_js__WEBPACK_IMPORTED_MODULE_2__["default"])(pred, list1, list2), Object(_differenceWith_js__WEBPACK_IMPORTED_MODULE_2__["default"])(pred, list2, list1));
});
/* harmony default export */ __webpack_exports__["default"] = (symmetricDifferenceWith);

/***/ }),

/***/ "./node_modules/ramda/es/tail.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/tail.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_checkForMethod.js */ "./node_modules/ramda/es/internal/_checkForMethod.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");




/**
 * Returns all but the first element of the given list or string (or object
 * with a `tail` method).
 *
 * Dispatches to the `slice` method of the first argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [a]
 * @sig String -> String
 * @param {*} list
 * @return {*}
 * @see R.head, R.init, R.last
 * @example
 *
 *      R.tail([1, 2, 3]);  //=> [2, 3]
 *      R.tail([1, 2]);     //=> [2]
 *      R.tail([1]);        //=> []
 *      R.tail([]);         //=> []
 *
 *      R.tail('abc');  //=> 'bc'
 *      R.tail('ab');   //=> 'b'
 *      R.tail('a');    //=> ''
 *      R.tail('');     //=> ''
 */
var tail = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_internal_checkForMethod_js__WEBPACK_IMPORTED_MODULE_0__["default"])('tail', /*#__PURE__*/Object(_slice_js__WEBPACK_IMPORTED_MODULE_2__["default"])(1, Infinity)));
/* harmony default export */ __webpack_exports__["default"] = (tail);

/***/ }),

/***/ "./node_modules/ramda/es/take.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/take.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xtake_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xtake.js */ "./node_modules/ramda/es/internal/_xtake.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");





/**
 * Returns the first `n` elements of the given list, string, or
 * transducer/transformer (or object with a `take` method).
 *
 * Dispatches to the `take` method of the second argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig Number -> [a] -> [a]
 * @sig Number -> String -> String
 * @param {Number} n
 * @param {*} list
 * @return {*}
 * @see R.drop
 * @example
 *
 *      R.take(1, ['foo', 'bar', 'baz']); //=> ['foo']
 *      R.take(2, ['foo', 'bar', 'baz']); //=> ['foo', 'bar']
 *      R.take(3, ['foo', 'bar', 'baz']); //=> ['foo', 'bar', 'baz']
 *      R.take(4, ['foo', 'bar', 'baz']); //=> ['foo', 'bar', 'baz']
 *      R.take(3, 'ramda');               //=> 'ram'
 *
 *      const personnel = [
 *        'Dave Brubeck',
 *        'Paul Desmond',
 *        'Eugene Wright',
 *        'Joe Morello',
 *        'Gerry Mulligan',
 *        'Bob Bates',
 *        'Joe Dodge',
 *        'Ron Crotty'
 *      ];
 *
 *      const takeFive = R.take(5);
 *      takeFive(personnel);
 *      //=> ['Dave Brubeck', 'Paul Desmond', 'Eugene Wright', 'Joe Morello', 'Gerry Mulligan']
 * @symb R.take(-1, [a, b]) = [a, b]
 * @symb R.take(0, [a, b]) = []
 * @symb R.take(1, [a, b]) = [a]
 * @symb R.take(2, [a, b]) = [a, b]
 */
var take = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['take'], _internal_xtake_js__WEBPACK_IMPORTED_MODULE_2__["default"], function take(n, xs) {
  return Object(_slice_js__WEBPACK_IMPORTED_MODULE_3__["default"])(0, n < 0 ? Infinity : n, xs);
}));
/* harmony default export */ __webpack_exports__["default"] = (take);

/***/ }),

/***/ "./node_modules/ramda/es/takeLast.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/takeLast.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _drop_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./drop.js */ "./node_modules/ramda/es/drop.js");



/**
 * Returns a new list containing the last `n` elements of the given list.
 * If `n > list.length`, returns a list of `list.length` elements.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category List
 * @sig Number -> [a] -> [a]
 * @sig Number -> String -> String
 * @param {Number} n The number of elements to return.
 * @param {Array} xs The collection to consider.
 * @return {Array}
 * @see R.dropLast
 * @example
 *
 *      R.takeLast(1, ['foo', 'bar', 'baz']); //=> ['baz']
 *      R.takeLast(2, ['foo', 'bar', 'baz']); //=> ['bar', 'baz']
 *      R.takeLast(3, ['foo', 'bar', 'baz']); //=> ['foo', 'bar', 'baz']
 *      R.takeLast(4, ['foo', 'bar', 'baz']); //=> ['foo', 'bar', 'baz']
 *      R.takeLast(3, 'ramda');               //=> 'mda'
 */
var takeLast = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function takeLast(n, xs) {
  return Object(_drop_js__WEBPACK_IMPORTED_MODULE_1__["default"])(n >= 0 ? xs.length - n : 0, xs);
});
/* harmony default export */ __webpack_exports__["default"] = (takeLast);

/***/ }),

/***/ "./node_modules/ramda/es/takeLastWhile.js":
/*!************************************************!*\
  !*** ./node_modules/ramda/es/takeLastWhile.js ***!
  \************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");



/**
 * Returns a new list containing the last `n` elements of a given list, passing
 * each value to the supplied predicate function, and terminating when the
 * predicate function returns `false`. Excludes the element that caused the
 * predicate function to fail. The predicate function is passed one argument:
 * *(value)*.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> [a]
 * @sig (a -> Boolean) -> String -> String
 * @param {Function} fn The function called per iteration.
 * @param {Array} xs The collection to iterate over.
 * @return {Array} A new array.
 * @see R.dropLastWhile, R.addIndex
 * @example
 *
 *      const isNotOne = x => x !== 1;
 *
 *      R.takeLastWhile(isNotOne, [1, 2, 3, 4]); //=> [2, 3, 4]
 *
 *      R.takeLastWhile(x => x !== 'R' , 'Ramda'); //=> 'amda'
 */
var takeLastWhile = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function takeLastWhile(fn, xs) {
  var idx = xs.length - 1;
  while (idx >= 0 && fn(xs[idx])) {
    idx -= 1;
  }
  return Object(_slice_js__WEBPACK_IMPORTED_MODULE_1__["default"])(idx + 1, Infinity, xs);
});
/* harmony default export */ __webpack_exports__["default"] = (takeLastWhile);

/***/ }),

/***/ "./node_modules/ramda/es/takeWhile.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/takeWhile.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xtakeWhile_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xtakeWhile.js */ "./node_modules/ramda/es/internal/_xtakeWhile.js");
/* harmony import */ var _slice_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./slice.js */ "./node_modules/ramda/es/slice.js");





/**
 * Returns a new list containing the first `n` elements of a given list,
 * passing each value to the supplied predicate function, and terminating when
 * the predicate function returns `false`. Excludes the element that caused the
 * predicate function to fail. The predicate function is passed one argument:
 * *(value)*.
 *
 * Dispatches to the `takeWhile` method of the second argument, if present.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig (a -> Boolean) -> [a] -> [a]
 * @sig (a -> Boolean) -> String -> String
 * @param {Function} fn The function called per iteration.
 * @param {Array} xs The collection to iterate over.
 * @return {Array} A new array.
 * @see R.dropWhile, R.transduce, R.addIndex
 * @example
 *
 *      const isNotFour = x => x !== 4;
 *
 *      R.takeWhile(isNotFour, [1, 2, 3, 4, 3, 2, 1]); //=> [1, 2, 3]
 *
 *      R.takeWhile(x => x !== 'd' , 'Ramda'); //=> 'Ram'
 */
var takeWhile = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])(['takeWhile'], _internal_xtakeWhile_js__WEBPACK_IMPORTED_MODULE_2__["default"], function takeWhile(fn, xs) {
  var idx = 0;
  var len = xs.length;
  while (idx < len && fn(xs[idx])) {
    idx += 1;
  }
  return Object(_slice_js__WEBPACK_IMPORTED_MODULE_3__["default"])(0, idx, xs);
}));
/* harmony default export */ __webpack_exports__["default"] = (takeWhile);

/***/ }),

/***/ "./node_modules/ramda/es/tap.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/tap.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_dispatchable.js */ "./node_modules/ramda/es/internal/_dispatchable.js");
/* harmony import */ var _internal_xtap_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_xtap.js */ "./node_modules/ramda/es/internal/_xtap.js");




/**
 * Runs the given function with the supplied object, then returns the object.
 *
 * Acts as a transducer if a transformer is given as second parameter.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig (a -> *) -> a -> a
 * @param {Function} fn The function to call with `x`. The return value of `fn` will be thrown away.
 * @param {*} x
 * @return {*} `x`.
 * @example
 *
 *      const sayX = x => console.log('x is ' + x);
 *      R.tap(sayX, 100); //=> 100
 *      // logs 'x is 100'
 * @symb R.tap(f, a) = a
 */
var tap = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])( /*#__PURE__*/Object(_internal_dispatchable_js__WEBPACK_IMPORTED_MODULE_1__["default"])([], _internal_xtap_js__WEBPACK_IMPORTED_MODULE_2__["default"], function tap(fn, x) {
  fn(x);
  return x;
}));
/* harmony default export */ __webpack_exports__["default"] = (tap);

/***/ }),

/***/ "./node_modules/ramda/es/test.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/test.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_cloneRegExp_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_cloneRegExp.js */ "./node_modules/ramda/es/internal/_cloneRegExp.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_isRegExp_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_isRegExp.js */ "./node_modules/ramda/es/internal/_isRegExp.js");
/* harmony import */ var _toString_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./toString.js */ "./node_modules/ramda/es/toString.js");





/**
 * Determines whether a given string matches a given regular expression.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category String
 * @sig RegExp -> String -> Boolean
 * @param {RegExp} pattern
 * @param {String} str
 * @return {Boolean}
 * @see R.match
 * @example
 *
 *      R.test(/^x/, 'xyz'); //=> true
 *      R.test(/^y/, 'xyz'); //=> false
 */
var test = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function test(pattern, str) {
  if (!Object(_internal_isRegExp_js__WEBPACK_IMPORTED_MODULE_2__["default"])(pattern)) {
    throw new TypeError('‘test’ requires a value of type RegExp as its first argument; received ' + Object(_toString_js__WEBPACK_IMPORTED_MODULE_3__["default"])(pattern));
  }
  return Object(_internal_cloneRegExp_js__WEBPACK_IMPORTED_MODULE_0__["default"])(pattern).test(str);
});
/* harmony default export */ __webpack_exports__["default"] = (test);

/***/ }),

/***/ "./node_modules/ramda/es/then.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/then.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_assertPromise_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_assertPromise.js */ "./node_modules/ramda/es/internal/_assertPromise.js");



/**
 * Returns the result of applying the onSuccess function to the value inside
 * a successfully resolved promise. This is useful for working with promises
 * inside function compositions.
 *
 * @func
 * @memberOf R
 * @category Function
 * @sig (a -> b) -> (Promise e a) -> (Promise e b)
 * @sig (a -> (Promise e b)) -> (Promise e a) -> (Promise e b)
 * @param {Function} onSuccess The function to apply. Can return a value or a promise of a value.
 * @param {Promise} p
 * @return {Promise} The result of calling `p.then(onSuccess)`
 * @see R.otherwise
 * @example
 *
 *      var makeQuery = (email) => ({ query: { email }});
 *
 *      //getMemberName :: String -> Promise ({firstName, lastName})
 *      var getMemberName = R.pipe(
 *        makeQuery,
 *        fetchMember,
 *        R.then(R.pick(['firstName', 'lastName']))
 *      );
 */
var then = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function then(f, p) {
  Object(_internal_assertPromise_js__WEBPACK_IMPORTED_MODULE_1__["default"])('then', p);

  return p.then(f);
});
/* harmony default export */ __webpack_exports__["default"] = (then);

/***/ }),

/***/ "./node_modules/ramda/es/thunkify.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/thunkify.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");



/**
 * Creates a thunk out of a function. A thunk delays a calculation until
 * its result is needed, providing lazy evaluation of arguments.
 *
 * @func
 * @memberOf R
 * @category Function
 * @sig ((a, b, ..., j) -> k) -> (a, b, ..., j) -> (() -> k)
 * @param {Function} fn A function to wrap in a thunk
 * @return {Function} Expects arguments for `fn` and returns a new function
 *  that, when called, applies those arguments to `fn`.
 * @see R.partial, R.partialRight
 * @example
 *
 *      R.thunkify(R.identity)(42)(); //=> 42
 *      R.thunkify((a, b) => a + b)(25, 17)(); //=> 42
 */
var thunkify = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function thunkify(fn) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_0__["default"])(fn.length, function createThunk() {
    var fnArgs = arguments;
    return function invokeThunk() {
      return fn.apply(this, fnArgs);
    };
  });
});

/* harmony default export */ __webpack_exports__["default"] = (thunkify);

/***/ }),

/***/ "./node_modules/ramda/es/times.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/times.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Calls an input function `n` times, returning an array containing the results
 * of those function calls.
 *
 * `fn` is passed one argument: The current value of `n`, which begins at `0`
 * and is gradually incremented to `n - 1`.
 *
 * @func
 * @memberOf R
 * @since v0.2.3
 * @category List
 * @sig (Number -> a) -> Number -> [a]
 * @param {Function} fn The function to invoke. Passed one argument, the current value of `n`.
 * @param {Number} n A value between `0` and `n - 1`. Increments after each function call.
 * @return {Array} An array containing the return values of all calls to `fn`.
 * @see R.repeat
 * @example
 *
 *      R.times(R.identity, 5); //=> [0, 1, 2, 3, 4]
 * @symb R.times(f, 0) = []
 * @symb R.times(f, 1) = [f(0)]
 * @symb R.times(f, 2) = [f(0), f(1)]
 */
var times = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function times(fn, n) {
  var len = Number(n);
  var idx = 0;
  var list;

  if (len < 0 || isNaN(len)) {
    throw new RangeError('n must be a non-negative number');
  }
  list = new Array(len);
  while (idx < len) {
    list[idx] = fn(idx);
    idx += 1;
  }
  return list;
});
/* harmony default export */ __webpack_exports__["default"] = (times);

/***/ }),

/***/ "./node_modules/ramda/es/toLower.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/toLower.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _invoker_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./invoker.js */ "./node_modules/ramda/es/invoker.js");


/**
 * The lower case version of a string.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category String
 * @sig String -> String
 * @param {String} str The string to lower case.
 * @return {String} The lower case version of `str`.
 * @see R.toUpper
 * @example
 *
 *      R.toLower('XYZ'); //=> 'xyz'
 */
var toLower = /*#__PURE__*/Object(_invoker_js__WEBPACK_IMPORTED_MODULE_0__["default"])(0, 'toLowerCase');
/* harmony default export */ __webpack_exports__["default"] = (toLower);

/***/ }),

/***/ "./node_modules/ramda/es/toPairs.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/toPairs.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");



/**
 * Converts an object into an array of key, value arrays. Only the object's
 * own properties are used.
 * Note that the order of the output array is not guaranteed to be consistent
 * across different JS platforms.
 *
 * @func
 * @memberOf R
 * @since v0.4.0
 * @category Object
 * @sig {String: *} -> [[String,*]]
 * @param {Object} obj The object to extract from
 * @return {Array} An array of key, value arrays from the object's own properties.
 * @see R.fromPairs
 * @example
 *
 *      R.toPairs({a: 1, b: 2, c: 3}); //=> [['a', 1], ['b', 2], ['c', 3]]
 */
var toPairs = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function toPairs(obj) {
  var pairs = [];
  for (var prop in obj) {
    if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(prop, obj)) {
      pairs[pairs.length] = [prop, obj[prop]];
    }
  }
  return pairs;
});
/* harmony default export */ __webpack_exports__["default"] = (toPairs);

/***/ }),

/***/ "./node_modules/ramda/es/toPairsIn.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/toPairsIn.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Converts an object into an array of key, value arrays. The object's own
 * properties and prototype properties are used. Note that the order of the
 * output array is not guaranteed to be consistent across different JS
 * platforms.
 *
 * @func
 * @memberOf R
 * @since v0.4.0
 * @category Object
 * @sig {String: *} -> [[String,*]]
 * @param {Object} obj The object to extract from
 * @return {Array} An array of key, value arrays from the object's own
 *         and prototype properties.
 * @example
 *
 *      const F = function() { this.x = 'X'; };
 *      F.prototype.y = 'Y';
 *      const f = new F();
 *      R.toPairsIn(f); //=> [['x','X'], ['y','Y']]
 */
var toPairsIn = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function toPairsIn(obj) {
  var pairs = [];
  for (var prop in obj) {
    pairs[pairs.length] = [prop, obj[prop]];
  }
  return pairs;
});
/* harmony default export */ __webpack_exports__["default"] = (toPairsIn);

/***/ }),

/***/ "./node_modules/ramda/es/toString.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/toString.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _internal_toString_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_toString.js */ "./node_modules/ramda/es/internal/_toString.js");



/**
 * Returns the string representation of the given value. `eval`'ing the output
 * should result in a value equivalent to the input value. Many of the built-in
 * `toString` methods do not satisfy this requirement.
 *
 * If the given value is an `[object Object]` with a `toString` method other
 * than `Object.prototype.toString`, this method is invoked with no arguments
 * to produce the return value. This means user-defined constructor functions
 * can provide a suitable `toString` method. For example:
 *
 *     function Point(x, y) {
 *       this.x = x;
 *       this.y = y;
 *     }
 *
 *     Point.prototype.toString = function() {
 *       return 'new Point(' + this.x + ', ' + this.y + ')';
 *     };
 *
 *     R.toString(new Point(1, 2)); //=> 'new Point(1, 2)'
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category String
 * @sig * -> String
 * @param {*} val
 * @return {String}
 * @example
 *
 *      R.toString(42); //=> '42'
 *      R.toString('abc'); //=> '"abc"'
 *      R.toString([1, 2, 3]); //=> '[1, 2, 3]'
 *      R.toString({foo: 1, bar: 2, baz: 3}); //=> '{"bar": 2, "baz": 3, "foo": 1}'
 *      R.toString(new Date('2001-02-03T04:05:06Z')); //=> 'new Date("2001-02-03T04:05:06.000Z")'
 */
var toString = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function toString(val) {
  return Object(_internal_toString_js__WEBPACK_IMPORTED_MODULE_1__["default"])(val, []);
});
/* harmony default export */ __webpack_exports__["default"] = (toString);

/***/ }),

/***/ "./node_modules/ramda/es/toUpper.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/toUpper.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _invoker_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./invoker.js */ "./node_modules/ramda/es/invoker.js");


/**
 * The upper case version of a string.
 *
 * @func
 * @memberOf R
 * @since v0.9.0
 * @category String
 * @sig String -> String
 * @param {String} str The string to upper case.
 * @return {String} The upper case version of `str`.
 * @see R.toLower
 * @example
 *
 *      R.toUpper('abc'); //=> 'ABC'
 */
var toUpper = /*#__PURE__*/Object(_invoker_js__WEBPACK_IMPORTED_MODULE_0__["default"])(0, 'toUpperCase');
/* harmony default export */ __webpack_exports__["default"] = (toUpper);

/***/ }),

/***/ "./node_modules/ramda/es/transduce.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/transduce.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_reduce_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_reduce.js */ "./node_modules/ramda/es/internal/_reduce.js");
/* harmony import */ var _internal_xwrap_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_xwrap.js */ "./node_modules/ramda/es/internal/_xwrap.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");




/**
 * Initializes a transducer using supplied iterator function. Returns a single
 * item by iterating through the list, successively calling the transformed
 * iterator function and passing it an accumulator value and the current value
 * from the array, and then passing the result to the next call.
 *
 * The iterator function receives two values: *(acc, value)*. It will be
 * wrapped as a transformer to initialize the transducer. A transformer can be
 * passed directly in place of an iterator function. In both cases, iteration
 * may be stopped early with the [`R.reduced`](#reduced) function.
 *
 * A transducer is a function that accepts a transformer and returns a
 * transformer and can be composed directly.
 *
 * A transformer is an an object that provides a 2-arity reducing iterator
 * function, step, 0-arity initial value function, init, and 1-arity result
 * extraction function, result. The step function is used as the iterator
 * function in reduce. The result function is used to convert the final
 * accumulator into the return type and in most cases is
 * [`R.identity`](#identity). The init function can be used to provide an
 * initial accumulator, but is ignored by transduce.
 *
 * The iteration is performed with [`R.reduce`](#reduce) after initializing the transducer.
 *
 * @func
 * @memberOf R
 * @since v0.12.0
 * @category List
 * @sig (c -> c) -> ((a, b) -> a) -> a -> [b] -> a
 * @param {Function} xf The transducer function. Receives a transformer and returns a transformer.
 * @param {Function} fn The iterator function. Receives two values, the accumulator and the
 *        current element from the array. Wrapped as transformer, if necessary, and used to
 *        initialize the transducer
 * @param {*} acc The initial accumulator value.
 * @param {Array} list The list to iterate over.
 * @return {*} The final, accumulated value.
 * @see R.reduce, R.reduced, R.into
 * @example
 *
 *      const numbers = [1, 2, 3, 4];
 *      const transducer = R.compose(R.map(R.add(1)), R.take(2));
 *      R.transduce(transducer, R.flip(R.append), [], numbers); //=> [2, 3]
 *
 *      const isOdd = (x) => x % 2 === 1;
 *      const firstOddTransducer = R.compose(R.filter(isOdd), R.take(1));
 *      R.transduce(firstOddTransducer, R.flip(R.append), [], R.range(0, 100)); //=> [1]
 */
var transduce = /*#__PURE__*/Object(_curryN_js__WEBPACK_IMPORTED_MODULE_2__["default"])(4, function transduce(xf, fn, acc, list) {
  return Object(_internal_reduce_js__WEBPACK_IMPORTED_MODULE_0__["default"])(xf(typeof fn === 'function' ? Object(_internal_xwrap_js__WEBPACK_IMPORTED_MODULE_1__["default"])(fn) : fn), acc, list);
});
/* harmony default export */ __webpack_exports__["default"] = (transduce);

/***/ }),

/***/ "./node_modules/ramda/es/transpose.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/transpose.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Transposes the rows and columns of a 2D list.
 * When passed a list of `n` lists of length `x`,
 * returns a list of `x` lists of length `n`.
 *
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig [[a]] -> [[a]]
 * @param {Array} list A 2D list
 * @return {Array} A 2D list
 * @example
 *
 *      R.transpose([[1, 'a'], [2, 'b'], [3, 'c']]) //=> [[1, 2, 3], ['a', 'b', 'c']]
 *      R.transpose([[1, 2, 3], ['a', 'b', 'c']]) //=> [[1, 'a'], [2, 'b'], [3, 'c']]
 *
 *      // If some of the rows are shorter than the following rows, their elements are skipped:
 *      R.transpose([[10, 11], [20], [], [30, 31, 32]]) //=> [[10, 20, 30], [11, 31], [32]]
 * @symb R.transpose([[a], [b], [c]]) = [a, b, c]
 * @symb R.transpose([[a, b], [c, d]]) = [[a, c], [b, d]]
 * @symb R.transpose([[a, b], [c]]) = [[a, c], [b]]
 */
var transpose = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function transpose(outerlist) {
  var i = 0;
  var result = [];
  while (i < outerlist.length) {
    var innerlist = outerlist[i];
    var j = 0;
    while (j < innerlist.length) {
      if (typeof result[j] === 'undefined') {
        result[j] = [];
      }
      result[j].push(innerlist[j]);
      j += 1;
    }
    i += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (transpose);

/***/ }),

/***/ "./node_modules/ramda/es/traverse.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/traverse.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");
/* harmony import */ var _sequence_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./sequence.js */ "./node_modules/ramda/es/sequence.js");




/**
 * Maps an [Applicative](https://github.com/fantasyland/fantasy-land#applicative)-returning
 * function over a [Traversable](https://github.com/fantasyland/fantasy-land#traversable),
 * then uses [`sequence`](#sequence) to transform the resulting Traversable of Applicative
 * into an Applicative of Traversable.
 *
 * Dispatches to the `traverse` method of the third argument, if present.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig (Applicative f, Traversable t) => (a -> f a) -> (a -> f b) -> t a -> f (t b)
 * @param {Function} of
 * @param {Function} f
 * @param {*} traversable
 * @return {*}
 * @see R.sequence
 * @example
 *
 *      // Returns `Maybe.Nothing` if the given divisor is `0`
 *      const safeDiv = n => d => d === 0 ? Maybe.Nothing() : Maybe.Just(n / d)
 *
 *      R.traverse(Maybe.of, safeDiv(10), [2, 4, 5]); //=> Maybe.Just([5, 2.5, 2])
 *      R.traverse(Maybe.of, safeDiv(10), [2, 0, 5]); //=> Maybe.Nothing
 */
var traverse = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function traverse(of, f, traversable) {
  return typeof traversable['fantasy-land/traverse'] === 'function' ? traversable['fantasy-land/traverse'](f, of) : Object(_sequence_js__WEBPACK_IMPORTED_MODULE_2__["default"])(of, Object(_map_js__WEBPACK_IMPORTED_MODULE_1__["default"])(f, traversable));
});
/* harmony default export */ __webpack_exports__["default"] = (traverse);

/***/ }),

/***/ "./node_modules/ramda/es/trim.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/trim.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


var ws = '\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003' + '\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028' + '\u2029\uFEFF';
var zeroWidth = '\u200b';
var hasProtoTrim = typeof String.prototype.trim === 'function';
/**
 * Removes (strips) whitespace from both ends of the string.
 *
 * @func
 * @memberOf R
 * @since v0.6.0
 * @category String
 * @sig String -> String
 * @param {String} str The string to trim.
 * @return {String} Trimmed version of `str`.
 * @example
 *
 *      R.trim('   xyz  '); //=> 'xyz'
 *      R.map(R.trim, R.split(',', 'x, y, z')); //=> ['x', 'y', 'z']
 */
var trim = !hasProtoTrim || /*#__PURE__*/ws.trim() || ! /*#__PURE__*/zeroWidth.trim() ? /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function trim(str) {
  var beginRx = new RegExp('^[' + ws + '][' + ws + ']*');
  var endRx = new RegExp('[' + ws + '][' + ws + ']*$');
  return str.replace(beginRx, '').replace(endRx, '');
}) : /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function trim(str) {
  return str.trim();
});
/* harmony default export */ __webpack_exports__["default"] = (trim);

/***/ }),

/***/ "./node_modules/ramda/es/tryCatch.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/tryCatch.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_arity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_arity.js */ "./node_modules/ramda/es/internal/_arity.js");
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");




/**
 * `tryCatch` takes two functions, a `tryer` and a `catcher`. The returned
 * function evaluates the `tryer`; if it does not throw, it simply returns the
 * result. If the `tryer` *does* throw, the returned function evaluates the
 * `catcher` function and returns its result. Note that for effective
 * composition with this function, both the `tryer` and `catcher` functions
 * must return the same type of results.
 *
 * @func
 * @memberOf R
 * @since v0.20.0
 * @category Function
 * @sig (...x -> a) -> ((e, ...x) -> a) -> (...x -> a)
 * @param {Function} tryer The function that may throw.
 * @param {Function} catcher The function that will be evaluated if `tryer` throws.
 * @return {Function} A new function that will catch exceptions and send then to the catcher.
 * @example
 *
 *      R.tryCatch(R.prop('x'), R.F)({x: true}); //=> true
 *      R.tryCatch(() => { throw 'foo'}, R.always('catched'))('bar') // => 'catched'
 *      R.tryCatch(R.times(R.identity), R.always([]))('s') // => []
 `` */
var tryCatch = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_2__["default"])(function _tryCatch(tryer, catcher) {
  return Object(_internal_arity_js__WEBPACK_IMPORTED_MODULE_0__["default"])(tryer.length, function () {
    try {
      return tryer.apply(this, arguments);
    } catch (e) {
      return catcher.apply(this, Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_1__["default"])([e], arguments));
    }
  });
});
/* harmony default export */ __webpack_exports__["default"] = (tryCatch);

/***/ }),

/***/ "./node_modules/ramda/es/type.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/type.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Gives a single-word string description of the (native) type of a value,
 * returning such answers as 'Object', 'Number', 'Array', or 'Null'. Does not
 * attempt to distinguish user Object types any further, reporting them all as
 * 'Object'.
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Type
 * @sig (* -> {*}) -> String
 * @param {*} val The value to test
 * @return {String}
 * @example
 *
 *      R.type({}); //=> "Object"
 *      R.type(1); //=> "Number"
 *      R.type(false); //=> "Boolean"
 *      R.type('s'); //=> "String"
 *      R.type(null); //=> "Null"
 *      R.type([]); //=> "Array"
 *      R.type(/[A-z]/); //=> "RegExp"
 *      R.type(() => {}); //=> "Function"
 *      R.type(undefined); //=> "Undefined"
 */
var type = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function type(val) {
  return val === null ? 'Null' : val === undefined ? 'Undefined' : Object.prototype.toString.call(val).slice(8, -1);
});
/* harmony default export */ __webpack_exports__["default"] = (type);

/***/ }),

/***/ "./node_modules/ramda/es/unapply.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/unapply.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Takes a function `fn`, which takes a single array argument, and returns a
 * function which:
 *
 *   - takes any number of positional arguments;
 *   - passes these arguments to `fn` as an array; and
 *   - returns the result.
 *
 * In other words, `R.unapply` derives a variadic function from a function which
 * takes an array. `R.unapply` is the inverse of [`R.apply`](#apply).
 *
 * @func
 * @memberOf R
 * @since v0.8.0
 * @category Function
 * @sig ([*...] -> a) -> (*... -> a)
 * @param {Function} fn
 * @return {Function}
 * @see R.apply
 * @example
 *
 *      R.unapply(JSON.stringify)(1, 2, 3); //=> '[1,2,3]'
 * @symb R.unapply(f)(a, b) = f([a, b])
 */
var unapply = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function unapply(fn) {
  return function () {
    return fn(Array.prototype.slice.call(arguments, 0));
  };
});
/* harmony default export */ __webpack_exports__["default"] = (unapply);

/***/ }),

/***/ "./node_modules/ramda/es/unary.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/unary.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _nAry_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./nAry.js */ "./node_modules/ramda/es/nAry.js");



/**
 * Wraps a function of any arity (including nullary) in a function that accepts
 * exactly 1 parameter. Any extraneous parameters will not be passed to the
 * supplied function.
 *
 * @func
 * @memberOf R
 * @since v0.2.0
 * @category Function
 * @sig (* -> b) -> (a -> b)
 * @param {Function} fn The function to wrap.
 * @return {Function} A new function wrapping `fn`. The new function is guaranteed to be of
 *         arity 1.
 * @see R.binary, R.nAry
 * @example
 *
 *      const takesTwoArgs = function(a, b) {
 *        return [a, b];
 *      };
 *      takesTwoArgs.length; //=> 2
 *      takesTwoArgs(1, 2); //=> [1, 2]
 *
 *      const takesOneArg = R.unary(takesTwoArgs);
 *      takesOneArg.length; //=> 1
 *      // Only 1 argument is passed to the wrapped function
 *      takesOneArg(1, 2); //=> [1, undefined]
 * @symb R.unary(f)(a, b, c) = f(a)
 */
var unary = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function unary(fn) {
  return Object(_nAry_js__WEBPACK_IMPORTED_MODULE_1__["default"])(1, fn);
});
/* harmony default export */ __webpack_exports__["default"] = (unary);

/***/ }),

/***/ "./node_modules/ramda/es/uncurryN.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/uncurryN.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");



/**
 * Returns a function of arity `n` from a (manually) curried function.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category Function
 * @sig Number -> (a -> b) -> (a -> c)
 * @param {Number} length The arity for the returned function.
 * @param {Function} fn The function to uncurry.
 * @return {Function} A new function.
 * @see R.curry
 * @example
 *
 *      const addFour = a => b => c => d => a + b + c + d;
 *
 *      const uncurriedAddFour = R.uncurryN(4, addFour);
 *      uncurriedAddFour(1, 2, 3, 4); //=> 10
 */
var uncurryN = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function uncurryN(depth, fn) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(depth, function () {
    var currentDepth = 1;
    var value = fn;
    var idx = 0;
    var endIdx;
    while (currentDepth <= depth && typeof value === 'function') {
      endIdx = currentDepth === depth ? arguments.length : idx + value.length;
      value = value.apply(this, Array.prototype.slice.call(arguments, idx, endIdx));
      currentDepth += 1;
      idx = endIdx;
    }
    return value;
  });
});
/* harmony default export */ __webpack_exports__["default"] = (uncurryN);

/***/ }),

/***/ "./node_modules/ramda/es/unfold.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/unfold.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Builds a list from a seed value. Accepts an iterator function, which returns
 * either false to stop iteration or an array of length 2 containing the value
 * to add to the resulting list and the seed to be used in the next call to the
 * iterator function.
 *
 * The iterator function receives one argument: *(seed)*.
 *
 * @func
 * @memberOf R
 * @since v0.10.0
 * @category List
 * @sig (a -> [b]) -> * -> [b]
 * @param {Function} fn The iterator function. receives one argument, `seed`, and returns
 *        either false to quit iteration or an array of length two to proceed. The element
 *        at index 0 of this array will be added to the resulting array, and the element
 *        at index 1 will be passed to the next call to `fn`.
 * @param {*} seed The seed value.
 * @return {Array} The final list.
 * @example
 *
 *      const f = n => n > 50 ? false : [-n, n + 10];
 *      R.unfold(f, 10); //=> [-10, -20, -30, -40, -50]
 * @symb R.unfold(f, x) = [f(x)[0], f(f(x)[1])[0], f(f(f(x)[1])[1])[0], ...]
 */
var unfold = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function unfold(fn, seed) {
  var pair = fn(seed);
  var result = [];
  while (pair && pair.length) {
    result[result.length] = pair[0];
    pair = fn(pair[1]);
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (unfold);

/***/ }),

/***/ "./node_modules/ramda/es/union.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/union.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _compose_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./compose.js */ "./node_modules/ramda/es/compose.js");
/* harmony import */ var _uniq_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./uniq.js */ "./node_modules/ramda/es/uniq.js");





/**
 * Combines two lists into a set (i.e. no duplicates) composed of the elements
 * of each list.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig [*] -> [*] -> [*]
 * @param {Array} as The first list.
 * @param {Array} bs The second list.
 * @return {Array} The first and second lists concatenated, with
 *         duplicates removed.
 * @example
 *
 *      R.union([1, 2, 3], [2, 3, 4]); //=> [1, 2, 3, 4]
 */
var union = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])( /*#__PURE__*/Object(_compose_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_uniq_js__WEBPACK_IMPORTED_MODULE_3__["default"], _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"]));
/* harmony default export */ __webpack_exports__["default"] = (union);

/***/ }),

/***/ "./node_modules/ramda/es/unionWith.js":
/*!********************************************!*\
  !*** ./node_modules/ramda/es/unionWith.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_concat_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_concat.js */ "./node_modules/ramda/es/internal/_concat.js");
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _uniqWith_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./uniqWith.js */ "./node_modules/ramda/es/uniqWith.js");




/**
 * Combines two lists into a set (i.e. no duplicates) composed of the elements
 * of each list. Duplication is determined according to the value returned by
 * applying the supplied predicate to two list elements.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Relation
 * @sig ((a, a) -> Boolean) -> [*] -> [*] -> [*]
 * @param {Function} pred A predicate used to test whether two items are equal.
 * @param {Array} list1 The first list.
 * @param {Array} list2 The second list.
 * @return {Array} The first and second lists concatenated, with
 *         duplicates removed.
 * @see R.union
 * @example
 *
 *      const l1 = [{a: 1}, {a: 2}];
 *      const l2 = [{a: 1}, {a: 4}];
 *      R.unionWith(R.eqBy(R.prop('a')), l1, l2); //=> [{a: 1}, {a: 2}, {a: 4}]
 */
var unionWith = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function unionWith(pred, list1, list2) {
  return Object(_uniqWith_js__WEBPACK_IMPORTED_MODULE_2__["default"])(pred, Object(_internal_concat_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list1, list2));
});
/* harmony default export */ __webpack_exports__["default"] = (unionWith);

/***/ }),

/***/ "./node_modules/ramda/es/uniq.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/uniq.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./identity.js */ "./node_modules/ramda/es/identity.js");
/* harmony import */ var _uniqBy_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./uniqBy.js */ "./node_modules/ramda/es/uniqBy.js");



/**
 * Returns a new list containing only one copy of each element in the original
 * list. [`R.equals`](#equals) is used to determine equality.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [a]
 * @param {Array} list The array to consider.
 * @return {Array} The list of unique items.
 * @example
 *
 *      R.uniq([1, 1, 2, 1]); //=> [1, 2]
 *      R.uniq([1, '1']);     //=> [1, '1']
 *      R.uniq([[42], [42]]); //=> [[42]]
 */
var uniq = /*#__PURE__*/Object(_uniqBy_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_identity_js__WEBPACK_IMPORTED_MODULE_0__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (uniq);

/***/ }),

/***/ "./node_modules/ramda/es/uniqBy.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/uniqBy.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_Set_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_Set.js */ "./node_modules/ramda/es/internal/_Set.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns a new list containing only one copy of each element in the original
 * list, based upon the value returned by applying the supplied function to
 * each list element. Prefers the first item if the supplied function produces
 * the same value on two items. [`R.equals`](#equals) is used for comparison.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category List
 * @sig (a -> b) -> [a] -> [a]
 * @param {Function} fn A function used to produce a value to use during comparisons.
 * @param {Array} list The array to consider.
 * @return {Array} The list of unique items.
 * @example
 *
 *      R.uniqBy(Math.abs, [-1, -5, 2, 10, 1, 2]); //=> [-1, -5, 2, 10]
 */
var uniqBy = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function uniqBy(fn, list) {
  var set = new _internal_Set_js__WEBPACK_IMPORTED_MODULE_0__["default"]();
  var result = [];
  var idx = 0;
  var appliedItem, item;

  while (idx < list.length) {
    item = list[idx];
    appliedItem = fn(item);
    if (set.add(appliedItem)) {
      result.push(item);
    }
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (uniqBy);

/***/ }),

/***/ "./node_modules/ramda/es/uniqWith.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/uniqWith.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includesWith.js */ "./node_modules/ramda/es/internal/_includesWith.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");



/**
 * Returns a new list containing only one copy of each element in the original
 * list, based upon the value returned by applying the supplied predicate to
 * two list elements. Prefers the first item if two items compare equal based
 * on the predicate.
 *
 * @func
 * @memberOf R
 * @since v0.2.0
 * @category List
 * @sig ((a, a) -> Boolean) -> [a] -> [a]
 * @param {Function} pred A predicate used to test whether two items are equal.
 * @param {Array} list The array to consider.
 * @return {Array} The list of unique items.
 * @example
 *
 *      const strEq = R.eqBy(String);
 *      R.uniqWith(strEq)([1, '1', 2, 1]); //=> [1, 2]
 *      R.uniqWith(strEq)([{}, {}]);       //=> [{}]
 *      R.uniqWith(strEq)([1, '1', 1]);    //=> [1]
 *      R.uniqWith(strEq)(['1', 1, 1]);    //=> ['1']
 */
var uniqWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function uniqWith(pred, list) {
  var idx = 0;
  var len = list.length;
  var result = [];
  var item;
  while (idx < len) {
    item = list[idx];
    if (!Object(_internal_includesWith_js__WEBPACK_IMPORTED_MODULE_0__["default"])(pred, item, result)) {
      result[result.length] = item;
    }
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (uniqWith);

/***/ }),

/***/ "./node_modules/ramda/es/unless.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/unless.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Tests the final argument by passing it to the given predicate function. If
 * the predicate is not satisfied, the function will return the result of
 * calling the `whenFalseFn` function with the same argument. If the predicate
 * is satisfied, the argument is returned as is.
 *
 * @func
 * @memberOf R
 * @since v0.18.0
 * @category Logic
 * @sig (a -> Boolean) -> (a -> a) -> a -> a
 * @param {Function} pred        A predicate function
 * @param {Function} whenFalseFn A function to invoke when the `pred` evaluates
 *                               to a falsy value.
 * @param {*}        x           An object to test with the `pred` function and
 *                               pass to `whenFalseFn` if necessary.
 * @return {*} Either `x` or the result of applying `x` to `whenFalseFn`.
 * @see R.ifElse, R.when, R.cond
 * @example
 *
 *      let safeInc = R.unless(R.isNil, R.inc);
 *      safeInc(null); //=> null
 *      safeInc(1); //=> 2
 */
var unless = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function unless(pred, whenFalseFn, x) {
  return pred(x) ? x : whenFalseFn(x);
});
/* harmony default export */ __webpack_exports__["default"] = (unless);

/***/ }),

/***/ "./node_modules/ramda/es/unnest.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/unnest.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_identity_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_identity.js */ "./node_modules/ramda/es/internal/_identity.js");
/* harmony import */ var _chain_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./chain.js */ "./node_modules/ramda/es/chain.js");



/**
 * Shorthand for `R.chain(R.identity)`, which removes one level of nesting from
 * any [Chain](https://github.com/fantasyland/fantasy-land#chain).
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category List
 * @sig Chain c => c (c a) -> c a
 * @param {*} list
 * @return {*}
 * @see R.flatten, R.chain
 * @example
 *
 *      R.unnest([1, [2], [[3]]]); //=> [1, 2, [3]]
 *      R.unnest([[1, 2], [3, 4], [5, 6]]); //=> [1, 2, 3, 4, 5, 6]
 */
var unnest = /*#__PURE__*/Object(_chain_js__WEBPACK_IMPORTED_MODULE_1__["default"])(_internal_identity_js__WEBPACK_IMPORTED_MODULE_0__["default"]);
/* harmony default export */ __webpack_exports__["default"] = (unnest);

/***/ }),

/***/ "./node_modules/ramda/es/until.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/until.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Takes a predicate, a transformation function, and an initial value,
 * and returns a value of the same type as the initial value.
 * It does so by applying the transformation until the predicate is satisfied,
 * at which point it returns the satisfactory value.
 *
 * @func
 * @memberOf R
 * @since v0.20.0
 * @category Logic
 * @sig (a -> Boolean) -> (a -> a) -> a -> a
 * @param {Function} pred A predicate function
 * @param {Function} fn The iterator function
 * @param {*} init Initial value
 * @return {*} Final value that satisfies predicate
 * @example
 *
 *      R.until(R.gt(R.__, 100), R.multiply(2))(1) // => 128
 */
var until = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function until(pred, fn, init) {
  var val = init;
  while (!pred(val)) {
    val = fn(val);
  }
  return val;
});
/* harmony default export */ __webpack_exports__["default"] = (until);

/***/ }),

/***/ "./node_modules/ramda/es/update.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/update.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");
/* harmony import */ var _adjust_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./adjust.js */ "./node_modules/ramda/es/adjust.js");
/* harmony import */ var _always_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./always.js */ "./node_modules/ramda/es/always.js");




/**
 * Returns a new copy of the array with the element at the provided index
 * replaced with the given value.
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category List
 * @sig Number -> a -> [a] -> [a]
 * @param {Number} idx The index to update.
 * @param {*} x The value to exist at the given index of the returned array.
 * @param {Array|Arguments} list The source array-like object to be updated.
 * @return {Array} A copy of `list` with the value at index `idx` replaced with `x`.
 * @see R.adjust
 * @example
 *
 *      R.update(1, '_', ['a', 'b', 'c']);      //=> ['a', '_', 'c']
 *      R.update(-1, '_', ['a', 'b', 'c']);     //=> ['a', 'b', '_']
 * @symb R.update(-1, a, [b, c]) = [b, a]
 * @symb R.update(0, a, [b, c]) = [a, c]
 * @symb R.update(1, a, [b, c]) = [b, a]
 */
var update = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function update(idx, x, list) {
  return Object(_adjust_js__WEBPACK_IMPORTED_MODULE_1__["default"])(idx, Object(_always_js__WEBPACK_IMPORTED_MODULE_2__["default"])(x), list);
});
/* harmony default export */ __webpack_exports__["default"] = (update);

/***/ }),

/***/ "./node_modules/ramda/es/useWith.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/useWith.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _curryN_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./curryN.js */ "./node_modules/ramda/es/curryN.js");



/**
 * Accepts a function `fn` and a list of transformer functions and returns a
 * new curried function. When the new function is invoked, it calls the
 * function `fn` with parameters consisting of the result of calling each
 * supplied handler on successive arguments to the new function.
 *
 * If more arguments are passed to the returned function than transformer
 * functions, those arguments are passed directly to `fn` as additional
 * parameters. If you expect additional arguments that don't need to be
 * transformed, although you can ignore them, it's best to pass an identity
 * function so that the new function reports the correct arity.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Function
 * @sig ((x1, x2, ...) -> z) -> [(a -> x1), (b -> x2), ...] -> (a -> b -> ... -> z)
 * @param {Function} fn The function to wrap.
 * @param {Array} transformers A list of transformer functions
 * @return {Function} The wrapped function.
 * @see R.converge
 * @example
 *
 *      R.useWith(Math.pow, [R.identity, R.identity])(3, 4); //=> 81
 *      R.useWith(Math.pow, [R.identity, R.identity])(3)(4); //=> 81
 *      R.useWith(Math.pow, [R.dec, R.inc])(3, 4); //=> 32
 *      R.useWith(Math.pow, [R.dec, R.inc])(3)(4); //=> 32
 * @symb R.useWith(f, [g, h])(a, b) = f(g(a), h(b))
 */
var useWith = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function useWith(fn, transformers) {
  return Object(_curryN_js__WEBPACK_IMPORTED_MODULE_1__["default"])(transformers.length, function () {
    var args = [];
    var idx = 0;
    while (idx < transformers.length) {
      args.push(transformers[idx].call(this, arguments[idx]));
      idx += 1;
    }
    return fn.apply(this, args.concat(Array.prototype.slice.call(arguments, transformers.length)));
  });
});
/* harmony default export */ __webpack_exports__["default"] = (useWith);

/***/ }),

/***/ "./node_modules/ramda/es/values.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/values.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");
/* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./keys.js */ "./node_modules/ramda/es/keys.js");



/**
 * Returns a list of all the enumerable own properties of the supplied object.
 * Note that the order of the output array is not guaranteed across different
 * JS platforms.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category Object
 * @sig {k: v} -> [v]
 * @param {Object} obj The object to extract values from
 * @return {Array} An array of the values of the object's own properties.
 * @see R.valuesIn, R.keys
 * @example
 *
 *      R.values({a: 1, b: 2, c: 3}); //=> [1, 2, 3]
 */
var values = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function values(obj) {
  var props = Object(_keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj);
  var len = props.length;
  var vals = [];
  var idx = 0;
  while (idx < len) {
    vals[idx] = obj[props[idx]];
    idx += 1;
  }
  return vals;
});
/* harmony default export */ __webpack_exports__["default"] = (values);

/***/ }),

/***/ "./node_modules/ramda/es/valuesIn.js":
/*!*******************************************!*\
  !*** ./node_modules/ramda/es/valuesIn.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry1.js */ "./node_modules/ramda/es/internal/_curry1.js");


/**
 * Returns a list of all the properties, including prototype properties, of the
 * supplied object.
 * Note that the order of the output array is not guaranteed to be consistent
 * across different JS platforms.
 *
 * @func
 * @memberOf R
 * @since v0.2.0
 * @category Object
 * @sig {k: v} -> [v]
 * @param {Object} obj The object to extract values from
 * @return {Array} An array of the values of the object's own and prototype properties.
 * @see R.values, R.keysIn
 * @example
 *
 *      const F = function() { this.x = 'X'; };
 *      F.prototype.y = 'Y';
 *      const f = new F();
 *      R.valuesIn(f); //=> ['X', 'Y']
 */
var valuesIn = /*#__PURE__*/Object(_internal_curry1_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function valuesIn(obj) {
  var prop;
  var vs = [];
  for (prop in obj) {
    vs[vs.length] = obj[prop];
  }
  return vs;
});
/* harmony default export */ __webpack_exports__["default"] = (valuesIn);

/***/ }),

/***/ "./node_modules/ramda/es/view.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/view.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


// `Const` is a functor that effectively ignores the function given to `map`.
var Const = function (x) {
  return { value: x, 'fantasy-land/map': function () {
      return this;
    } };
};

/**
 * Returns a "view" of the given data structure, determined by the given lens.
 * The lens's focus determines which portion of the data structure is visible.
 *
 * @func
 * @memberOf R
 * @since v0.16.0
 * @category Object
 * @typedefn Lens s a = Functor f => (a -> f a) -> s -> f s
 * @sig Lens s a -> s -> a
 * @param {Lens} lens
 * @param {*} x
 * @return {*}
 * @see R.prop, R.lensIndex, R.lensProp
 * @example
 *
 *      const xLens = R.lensProp('x');
 *
 *      R.view(xLens, {x: 1, y: 2});  //=> 1
 *      R.view(xLens, {x: 4, y: 2});  //=> 4
 */
var view = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function view(lens, x) {
  // Using `Const` effectively ignores the setter function of the `lens`,
  // leaving the value returned by the getter function unmodified.
  return lens(Const)(x).value;
});
/* harmony default export */ __webpack_exports__["default"] = (view);

/***/ }),

/***/ "./node_modules/ramda/es/when.js":
/*!***************************************!*\
  !*** ./node_modules/ramda/es/when.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Tests the final argument by passing it to the given predicate function. If
 * the predicate is satisfied, the function will return the result of calling
 * the `whenTrueFn` function with the same argument. If the predicate is not
 * satisfied, the argument is returned as is.
 *
 * @func
 * @memberOf R
 * @since v0.18.0
 * @category Logic
 * @sig (a -> Boolean) -> (a -> a) -> a -> a
 * @param {Function} pred       A predicate function
 * @param {Function} whenTrueFn A function to invoke when the `condition`
 *                              evaluates to a truthy value.
 * @param {*}        x          An object to test with the `pred` function and
 *                              pass to `whenTrueFn` if necessary.
 * @return {*} Either `x` or the result of applying `x` to `whenTrueFn`.
 * @see R.ifElse, R.unless, R.cond
 * @example
 *
 *      // truncate :: String -> String
 *      const truncate = R.when(
 *        R.propSatisfies(R.gt(R.__, 10), 'length'),
 *        R.pipe(R.take(10), R.append('…'), R.join(''))
 *      );
 *      truncate('12345');         //=> '12345'
 *      truncate('0123456789ABC'); //=> '0123456789…'
 */
var when = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function when(pred, whenTrueFn, x) {
  return pred(x) ? whenTrueFn(x) : x;
});
/* harmony default export */ __webpack_exports__["default"] = (when);

/***/ }),

/***/ "./node_modules/ramda/es/where.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/where.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _internal_has_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_has.js */ "./node_modules/ramda/es/internal/_has.js");



/**
 * Takes a spec object and a test object; returns true if the test satisfies
 * the spec. Each of the spec's own properties must be a predicate function.
 * Each predicate is applied to the value of the corresponding property of the
 * test object. `where` returns true if all the predicates return true, false
 * otherwise.
 *
 * `where` is well suited to declaratively expressing constraints for other
 * functions such as [`filter`](#filter) and [`find`](#find).
 *
 * @func
 * @memberOf R
 * @since v0.1.1
 * @category Object
 * @sig {String: (* -> Boolean)} -> {String: *} -> Boolean
 * @param {Object} spec
 * @param {Object} testObj
 * @return {Boolean}
 * @see R.propSatisfies, R.whereEq
 * @example
 *
 *      // pred :: Object -> Boolean
 *      const pred = R.where({
 *        a: R.equals('foo'),
 *        b: R.complement(R.equals('bar')),
 *        x: R.gt(R.__, 10),
 *        y: R.lt(R.__, 20)
 *      });
 *
 *      pred({a: 'foo', b: 'xxx', x: 11, y: 19}); //=> true
 *      pred({a: 'xxx', b: 'xxx', x: 11, y: 19}); //=> false
 *      pred({a: 'foo', b: 'bar', x: 11, y: 19}); //=> false
 *      pred({a: 'foo', b: 'xxx', x: 10, y: 19}); //=> false
 *      pred({a: 'foo', b: 'xxx', x: 11, y: 20}); //=> false
 */
var where = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function where(spec, testObj) {
  for (var prop in spec) {
    if (Object(_internal_has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(prop, spec) && !spec[prop](testObj[prop])) {
      return false;
    }
  }
  return true;
});
/* harmony default export */ __webpack_exports__["default"] = (where);

/***/ }),

/***/ "./node_modules/ramda/es/whereEq.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/whereEq.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _equals_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./equals.js */ "./node_modules/ramda/es/equals.js");
/* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./map.js */ "./node_modules/ramda/es/map.js");
/* harmony import */ var _where_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./where.js */ "./node_modules/ramda/es/where.js");





/**
 * Takes a spec object and a test object; returns true if the test satisfies
 * the spec, false otherwise. An object satisfies the spec if, for each of the
 * spec's own properties, accessing that property of the object gives the same
 * value (in [`R.equals`](#equals) terms) as accessing that property of the
 * spec.
 *
 * `whereEq` is a specialization of [`where`](#where).
 *
 * @func
 * @memberOf R
 * @since v0.14.0
 * @category Object
 * @sig {String: *} -> {String: *} -> Boolean
 * @param {Object} spec
 * @param {Object} testObj
 * @return {Boolean}
 * @see R.propEq, R.where
 * @example
 *
 *      // pred :: Object -> Boolean
 *      const pred = R.whereEq({a: 1, b: 2});
 *
 *      pred({a: 1});              //=> false
 *      pred({a: 1, b: 2});        //=> true
 *      pred({a: 1, b: 2, c: 3});  //=> true
 *      pred({a: 1, b: 1});        //=> false
 */
var whereEq = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function whereEq(spec, testObj) {
  return Object(_where_js__WEBPACK_IMPORTED_MODULE_3__["default"])(Object(_map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_equals_js__WEBPACK_IMPORTED_MODULE_1__["default"], spec), testObj);
});
/* harmony default export */ __webpack_exports__["default"] = (whereEq);

/***/ }),

/***/ "./node_modules/ramda/es/without.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/without.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_includes_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_includes.js */ "./node_modules/ramda/es/internal/_includes.js");
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");
/* harmony import */ var _flip_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./flip.js */ "./node_modules/ramda/es/flip.js");
/* harmony import */ var _reject_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./reject.js */ "./node_modules/ramda/es/reject.js");





/**
 * Returns a new list without values in the first argument.
 * [`R.equals`](#equals) is used to determine equality.
 *
 * Acts as a transducer if a transformer is given in list position.
 *
 * @func
 * @memberOf R
 * @since v0.19.0
 * @category List
 * @sig [a] -> [a] -> [a]
 * @param {Array} list1 The values to be removed from `list2`.
 * @param {Array} list2 The array to remove values from.
 * @return {Array} The new array without values in `list1`.
 * @see R.transduce, R.difference, R.remove
 * @example
 *
 *      R.without([1, 2], [1, 2, 1, 3, 4]); //=> [3, 4]
 */
var without = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_1__["default"])(function (xs, list) {
  return Object(_reject_js__WEBPACK_IMPORTED_MODULE_3__["default"])(Object(_flip_js__WEBPACK_IMPORTED_MODULE_2__["default"])(_internal_includes_js__WEBPACK_IMPORTED_MODULE_0__["default"])(xs), list);
});
/* harmony default export */ __webpack_exports__["default"] = (without);

/***/ }),

/***/ "./node_modules/ramda/es/xprod.js":
/*!****************************************!*\
  !*** ./node_modules/ramda/es/xprod.js ***!
  \****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Creates a new list out of the two supplied by creating each possible pair
 * from the lists.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [b] -> [[a,b]]
 * @param {Array} as The first list.
 * @param {Array} bs The second list.
 * @return {Array} The list made by combining each possible pair from
 *         `as` and `bs` into pairs (`[a, b]`).
 * @example
 *
 *      R.xprod([1, 2], ['a', 'b']); //=> [[1, 'a'], [1, 'b'], [2, 'a'], [2, 'b']]
 * @symb R.xprod([a, b], [c, d]) = [[a, c], [a, d], [b, c], [b, d]]
 */
var xprod = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function xprod(a, b) {
  // = xprodWith(prepend); (takes about 3 times as long...)
  var idx = 0;
  var ilen = a.length;
  var j;
  var jlen = b.length;
  var result = [];
  while (idx < ilen) {
    j = 0;
    while (j < jlen) {
      result[result.length] = [a[idx], b[j]];
      j += 1;
    }
    idx += 1;
  }
  return result;
});
/* harmony default export */ __webpack_exports__["default"] = (xprod);

/***/ }),

/***/ "./node_modules/ramda/es/zip.js":
/*!**************************************!*\
  !*** ./node_modules/ramda/es/zip.js ***!
  \**************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Creates a new list out of the two supplied by pairing up equally-positioned
 * items from both lists. The returned list is truncated to the length of the
 * shorter of the two input lists.
 * Note: `zip` is equivalent to `zipWith(function(a, b) { return [a, b] })`.
 *
 * @func
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig [a] -> [b] -> [[a,b]]
 * @param {Array} list1 The first array to consider.
 * @param {Array} list2 The second array to consider.
 * @return {Array} The list made by pairing up same-indexed elements of `list1` and `list2`.
 * @example
 *
 *      R.zip([1, 2, 3], ['a', 'b', 'c']); //=> [[1, 'a'], [2, 'b'], [3, 'c']]
 * @symb R.zip([a, b, c], [d, e, f]) = [[a, d], [b, e], [c, f]]
 */
var zip = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function zip(a, b) {
  var rv = [];
  var idx = 0;
  var len = Math.min(a.length, b.length);
  while (idx < len) {
    rv[idx] = [a[idx], b[idx]];
    idx += 1;
  }
  return rv;
});
/* harmony default export */ __webpack_exports__["default"] = (zip);

/***/ }),

/***/ "./node_modules/ramda/es/zipObj.js":
/*!*****************************************!*\
  !*** ./node_modules/ramda/es/zipObj.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry2.js */ "./node_modules/ramda/es/internal/_curry2.js");


/**
 * Creates a new object out of a list of keys and a list of values.
 * Key/value pairing is truncated to the length of the shorter of the two lists.
 * Note: `zipObj` is equivalent to `pipe(zip, fromPairs)`.
 *
 * @func
 * @memberOf R
 * @since v0.3.0
 * @category List
 * @sig [String] -> [*] -> {String: *}
 * @param {Array} keys The array that will be properties on the output object.
 * @param {Array} values The list of values on the output object.
 * @return {Object} The object made by pairing up same-indexed elements of `keys` and `values`.
 * @example
 *
 *      R.zipObj(['a', 'b', 'c'], [1, 2, 3]); //=> {a: 1, b: 2, c: 3}
 */
var zipObj = /*#__PURE__*/Object(_internal_curry2_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function zipObj(keys, values) {
  var idx = 0;
  var len = Math.min(keys.length, values.length);
  var out = {};
  while (idx < len) {
    out[keys[idx]] = values[idx];
    idx += 1;
  }
  return out;
});
/* harmony default export */ __webpack_exports__["default"] = (zipObj);

/***/ }),

/***/ "./node_modules/ramda/es/zipWith.js":
/*!******************************************!*\
  !*** ./node_modules/ramda/es/zipWith.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./internal/_curry3.js */ "./node_modules/ramda/es/internal/_curry3.js");


/**
 * Creates a new list out of the two supplied by applying the function to each
 * equally-positioned pair in the lists. The returned list is truncated to the
 * length of the shorter of the two input lists.
 *
 * @function
 * @memberOf R
 * @since v0.1.0
 * @category List
 * @sig ((a, b) -> c) -> [a] -> [b] -> [c]
 * @param {Function} fn The function used to combine the two elements into one value.
 * @param {Array} list1 The first array to consider.
 * @param {Array} list2 The second array to consider.
 * @return {Array} The list made by combining same-indexed elements of `list1` and `list2`
 *         using `fn`.
 * @example
 *
 *      const f = (x, y) => {
 *        // ...
 *      };
 *      R.zipWith(f, [1, 2, 3], ['a', 'b', 'c']);
 *      //=> [f(1, 'a'), f(2, 'b'), f(3, 'c')]
 * @symb R.zipWith(fn, [a, b, c], [d, e, f]) = [fn(a, d), fn(b, e), fn(c, f)]
 */
var zipWith = /*#__PURE__*/Object(_internal_curry3_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function zipWith(fn, a, b) {
  var rv = [];
  var idx = 0;
  var len = Math.min(a.length, b.length);
  while (idx < len) {
    rv[idx] = fn(a[idx], b[idx]);
    idx += 1;
  }
  return rv;
});
/* harmony default export */ __webpack_exports__["default"] = (zipWith);

/***/ }),

/***/ "./src/lib/components/Animate.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/Animate.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Animate is a wrapper for the <animate> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/animate
 */

var Animate = function Animate(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("animate", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Animate.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Animate.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The accumulate attribute controls whether or not an animation
   *  is cumulative.It is frequently useful for repeated animations
   *  to build upon the previous results, accumulating with
   *  each iteration. This attribute said to the animation if
   *  the value is added to the previous animated attribute's
   *  value on each iteration.You can use this attribute with
   *  the following SVG elements:Specifies that each repeat
   *  iteration after the first builds upon the last value of
   *  the previous iteration.Specifies that repeat iterations
   *  are not cumulative.This attribute is ignored if the target
   *  attribute value does not support addition, or if the animation
   *  element does not repeat.This attribute will be ignored
   *  if the animation function is specified with only the to
   *  attribute.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  accumulate: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["none", "sum"]),

  /**
   *  The additive attribute controls whether or not an animation is
   *  additive.It is frequently useful to define animation as
   *  an offset or delta to an attribute's value, rather than
   *  as absolute values.You can use this attribute with the
   *  following SVG elements:Specifies that the animation will
   *  add to the underlying value of the attribute and other
   *  lower priority animations.Specifies that the animation
   *  will override the underlying value of the attribute and
   *  other lower priority animations. This is the default,
   *  however the behavior is also affected by the animation
   *  value attributes by and to, as described in SMIL Animation:
   *  How from, to and by attributes affect additive behavior.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  additive: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["replace", "sum"]),

  /**
   *  The attributeName attribute indicates the name of the CSS property
   *  or attribute of the target element that is going to be
   *  changed during an animation.You can use this attribute
   *  with the following SVG elements:This value indicates the
   *  name of the CSS property or attribute of the target element
   *  to be animated.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  attributeName: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The attributeType attribute
   *  specifies the namespace in which the target attribute
   *  and its associated values are defined.You can use this
   *  attribute with the following SVG elements:This value specifies
   *  that the value of attributeName is the name of a CSS property
   *  defined as animatable.This value specifies that the value
   *  of attributeName is the name of an XML attribute defined
   *  as animatable in the default XML namespace for the target
   *  element.This value specifies that the implementation should
   *  match the attributeName to an attribute for the target
   *  element. User agents first search through the list of
   *  CSS properties for a matching property name, and if none
   *  is found, search the default XML namespace for the element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  attributeType: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The begin attribute defines when an animation should begin or
   *  when an element should be discarded.The attribute value
   *  is a semicolon separated list of values. The interpretation
   *  of a list of start times is detailed in the SMIL specification
   *  in "Evaluation of begin and end time lists". Each individual
   *  value can be one of the following : <offset-value>, <syncbase-value>,
   *  <event-value>, <repeat-value>, <accessKey-value>, <wallclock-sync-value>
   *  or the keyword indefinite.You can use this attribute with
   *  the following SVG elements:For <animate>, <animateColor>,
   *  <animateMotion>, <animateTransform>, and <set>, begin
   *  defines when the element should begin, i.e. become active.The
   *  <begin-value-list> is a semicolon-separated list of values.
   *  Each value can be one of the following:This value defines
   *  a clock-value that represents a point in time relative
   *  to the beginning of the SVG document (usually the load
   *  or DOMContentLoaded event). Negative values are valid.This
   *  value defines a syncbase and an optional offset from that
   *  syncbase. The element's animation start time is defined
   *  relative to the begin or active end of another animation.A
   *  valid syncbase-value consists of an ID reference to another
   *  animation element followed by a dot and either begin or
   *  end to identify whether to synchronize with the beginning
   *  or active end of the referenced animation element. An
   *  optional offset value as defined in <offset-value> can
   *  be appended.This value defines an event and an optional
   *  offset that determines the time at which the element's
   *  animation should begin. The animation start time is defined
   *  relative to the time that the specified event is fired.A
   *  valid event-value consists of an element ID followed by
   *  a dot and one of the supported events for that element.
   *  All valid events (not necessarily supported by all elements)
   *  are defined by the DOM and HTML specifications. Those
   *  are: focus, blur, focusin, focusout, DOMActivate, auxclick,
   *  click, dblclick, mousedown, mouseenter, mouseleave, mousemove,
   *  mouseout, mouseover, mouseup, wheel, beforeinput, input,
   *  keydown, keyup, compositionstart, compositionupdate, compositionend,
   *  load, unload, abort, error, select, resize, scroll, beginEvent,
   *  endEvent, and repeatEvent. An optional offset value as
   *  defined in <offset-value> can be appended.This value defines
   *  a qualified repeat event. The element animation start
   *  time is defined relative to the time that the repeat event
   *  is raised with the specified iteration value.A valid repeat
   *  value consists of an element ID followed by a dot and
   *  the function repeat() with an integer value specifying
   *  the number of repetitions as parameter. An optional offset
   *  value as defined in <offset-value> can be appended.This
   *  value defines an access key that should trigger the animation.
   *  The element animation will begin when the user presses
   *  the specified key.A valid accessKey-value consists of
   *  the function accessKey() with the character to be input
   *  as parameter. An optional offset value as defined in <offset-value>
   *  can be appended.This value defines the animation start
   *  time as a real-world clock time.A valid wallclock-sync-value
   *  consists of the function wallclock() with a time value
   *  as parameter. The time syntax is based upon the syntax
   *  defined in ISO 8601.The begin of the animation will be
   *  determined by a beginElement() method call or a hyperlink
   *  targeted to the element.For <discard>, begin defines when
   *  the target element will be discarded.The <discard> element
   *  has an implicit simple duration of indefinite. As soon
   *  as the element's active duration starts, the element identified
   *  by the href attribute is discarded. The behavior is the
   *  same as if Node.removeChild() were called on the parent
   *  of the target element with the target element as parameter.After
   *  removal of the target element, the <discard> element is
   *  no longer useful, therefore it is also discarded after
   *  the target element's removal. If the href attribute has
   *  an invalid URL reference (e.g. the target element did
   *  not exist), the <discard> element itself is still removed
   *  after the activation.Seeking backwards in the timeline
   *  doesn't re-insert the discarded elements. So, authors
   *  are encouraged to set the playbackorder attribute to forwardonly
   *  when using the <discard> element.The <discard> element
   *  itself can be discarded prior to its activation, in which
   *  case it will never trigger the removal of its own target
   *  element.The definition of <begin-value-list> is the same
   *  as for the other animation elements.begin-1-offset.svgbegin-2-syncbase.svgbegin-3-event.svgbegin-4-repeat.svgThis
   *  example is embed in an iFrame. If you want to activate
   *  the key events, you have to click on it first.begin-5-accesskey.svgLast
   *  modified: Jul 12, 2022, by MDN contributors
   */
  begin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The by attribute specifies a relative offset value for an attribute
   *  that will be modified during an animation.The starting
   *  value for the attribute is either indicated by specifying
   *  it as value for the attribute given in the attributeName
   *  or the from attribute.You can use this attribute with
   *  the following SVG elements:The exact value type for this
   *  attribute depends on the value of the attribute that will
   *  be animated.When a list of values is defined via the values
   *  attribute, the by attribute is ignored.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  by: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The calcMode attribute specifies the interpolation mode for the
   *  animation.The default mode is linear, however if the attribute
   *  does not support linear interpolation (e.g. for strings),
   *  the calcMode attribute is ignored and discrete interpolation
   *  is used.You can use this attribute with the following
   *  SVG elements:This specifies that the animation function
   *  will jump from one value to the next without any interpolation.Simple
   *  linear interpolation between values is used to calculate
   *  the animation function. Except for <animateMotion>, this
   *  is the default value.Defines interpolation to produce
   *  an even pace of change across the animation. This is only
   *  supported for values that define a linear numeric range,
   *  and for which some notion of "distance" between points
   *  can be calculated (e.g. position, width, height, etc.).
   *  If paced is specified, any keyTimes or keySplines will
   *  be ignored. For <animateMotion>, this is the default value.Interpolates
   *  from one value in the values list to the next according
   *  to a time function defined by a cubic Bézier spline. The
   *  points of the spline are defined in the keyTimes attribute,
   *  and the control points for each interval are defined in
   *  the keySplines attribute.Last modified: May 13, 2022,
   *  by MDN contributors
   */
  calcMode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dur attribute indicates the simple duration of an animation.You
   *  can use this attribute with the following SVG elements:This
   *  value specifies the length of the simple duration. The
   *  value must be greater than 0 and can be expressed with
   *  hours (h), minutes (m), seconds (s) or milliseconds (ms).
   *  It's possible to combine those time representations to
   *  create some complex durations like hh:mm:ss.iii or mm:ss.iii.
    *       This value specifies the simple duration as the intrinsic
   *  media duration. This is only valid for elements that define
   *  media.
    (For animation elements the attribute will
   *  be ignored if media is specified.)
  This value specifies
   *  the simple duration as indefinite.Note: the interpolation
   *  will not work if the simple duration is indefinite (although
   *  this may still be useful for <set> elements).BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 17, 2022, by
   *  MDN contributors
   */
  dur: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The end attribute defines an end value for the animation that
   *  can constrain the active duration.You can use this attribute
   *  with the following SVG elements:The <end-value-list> is
   *  a semicolon-separated list of values. Each value can be
   *  one of the following:This value defines a clock-value
   *  that represents a point in time relative to the beginning
   *  of the SVG document (usually the load or DOMContentLoaded
   *  event). Negative values are valid.This value defines a
   *  syncbase and an optional offset from that syncbase. The
   *  element's animation end time is defined relative to the
   *  begin or active end of another animation.A valid syncbase-value
   *  consists of an ID reference to another animation element
   *  followed by a dot and either begin or end to identify
   *  whether to synchronize with the beginning or active end
   *  of the referenced animation element. An optional offset
   *  value as defined in <offset-value> can be appended.This
   *  value defines an event and an optional offset that determines
   *  the time at which the element's animation should end.
   *  The animation end time is defined relative to the time
   *  that the specified event is fired.A valid event-value
   *  consists of an element ID followed by a dot and one of
   *  the supported events for that element. All valid events
   *  (not necessarily supported by all elements) are defined
   *  by the DOM and HTML specifications. Those are: focus,
   *  blur, focusin, focusout, activate, auxclick, click, dblclick,
   *  mousedown, mouseenter, mouseleave, mousemove, mouseout,
   *  mouseover, mouseup, wheel, beforeinput, input, keydown,
   *  keyup, compositionstart, compositionupdate, compositionend,
   *  load, unload, abort, error, select, resize, scroll, beginEvent,
   *  endEvent, and repeatEvent . An optional offset value as
   *  defined in <offset-value> can be appended.This value defines
   *  a qualified repeat event. The element animation end time
   *  is defined relative to the time that the repeat event
   *  is raised with the specified iteration value.A valid repeat
   *  value consists of an element ID followed by a dot and
   *  the function repeat() with an integer value specifying
   *  the number of repetitions as parameter. An optional offset
   *  value as defined in <offset-value> can be appended.This
   *  value defines an access key that should trigger the end
   *  of the animation. The element animation will end when
   *  the user presses the specified key.A valid accessKey-value
   *  consists of the function accessKey() with the character
   *  to be input as parameter. An optional offset value as
   *  defined in <offset-value> can be appended.This value defines
   *  the animation end time as a real-world clock time.A valid
   *  wallclock-sync-value consists of the function wallclock()
   *  with a time value as parameter. The time syntax is based
   *  upon the syntax defined in ISO 8601.The end of the animation
   *  will be determined by an SVGAnimationElement.endElement()
   *  method call.This example is embed in an iFrame. If you
   *  want to activate the key events, you have to click on
   *  it first.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  end: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The from attribute indicates the initial value of the attribute
   *  that will be modified during the animation.When used with
   *  the to attribute, the animation will change the modified
   *  attribute from the from value to the to value. When used
   *  with the by attribute, the animation will change the attribute
   *  relatively from the from value by the value specified
   *  in by.You can use this attribute with the following SVG
   *  elements:The exact value type for this attribute depends
   *  on the value of the attribute that will be animated.When
   *  a list of values is defined via the values attribute,
   *  the from attribute is ignored.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  from: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The keyPoints attribute indicates the simple duration of an animation.You
   *  can use this attribute with the following SVG elements:This
   *  value defines a semicolon-separated list of floating point
   *  values between 0 and 1 and indicates how far along the
   *  motion path the object shall move at the moment in time
   *  specified by corresponding keyTimes value. The distance
   *  is calculated along the path specified by the path attribute.
   *  Each progress value in the list corresponds to a value
   *  in the keyTimes attribute list.If a list of key points
   *  is specified, there must be exactly as many values in
   *  the keyPoints list as in the keyTimes list.If there's
   *  a semicolon at the end of the value, optionally followed
   *  by white space, both the semicolon and the trailing white
   *  space are ignored.If there are any errors in the value
   *  specification (i.e. bad values, too many or too few values),
   *  then that's an error.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  keyPoints: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The keySplines attribute defines a set of Bézier curve control
   *  points associated with the keyTimes list, defining a cubic
   *  Bézier function that controls interval pacing.This attribute
   *  is ignored unless the calcMode attribute is set to spline.If
   *  there are any errors in the keySplines specification (bad
   *  values, too many or too few values), the animation will
   *  not occur.You can use this attribute with the following
   *  SVG elements:The attribute value is a semicolon-separated
   *  list of control point descriptions.Last modified: May
   *  17, 2022, by MDN contributors
   */
  keySplines: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The keyTimes attribute represents a list of time values used
   *  to control the pacing of the animation.Each time in the
   *  list corresponds to a value in the values attribute list,
   *  and defines when the value is used in the animation. Each
   *  time value in the keyTimes list is specified as a floating
   *  point value between 0 and 1 (inclusive), representing
   *  a proportional offset into the duration of the animation
   *  element.You can use this attribute with the following
   *  SVG elements:The value of the keyTimes attribute is a
   *  semicolon-separated list of values.There must be exactly
   *  as many values in the keyTimes list as in the values list.Each
   *  successive time value must be greater than or equal to
   *  the preceding time value.The keyTimes list semantics depends
   *  upon the interpolation mode:If the calcMode attribute
   *  is set to paced, the keyTimes attribute is ignored.If
   *  the duration of the animation is indefinite, any keyTimes
   *  specification will be ignored.Last modified: May 13, 2022,
   *  by MDN contributors
   */
  keyTimes: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The repeatCount attribute indicates the number of times an animation
   *  will take place.You can use this attribute with the following
   *  SVG elements:This value specifies the number of iterations.
   *  It can include partial iterations expressed as fraction
   *  values. A fractional value describes a portion of the
   *  simple duration. Values must be greater than 0.This value
   *  indicates that the animation will be repeated indefinitely
   *  (i.e. until the document ends).BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  repeatCount: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The repeatDur attribute specifies the total duration for repeating
   *  an animation.You can use this attribute with the following
   *  SVG elements:This value specifies the duration in presentation
   *  time to repeat the animation.This value indicates that
   *  the animation will be repeated indefinitely (i.e. until
   *  the document ends).Last modified: May 13, 2022, by MDN
   *  contributors
   */
  repeatDur: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The restart attribute specifies whether or not an animation can
   *  restart.You can use this attribute with the following
   *  SVG elements:This value indicates that the animation can
   *  be restarted at any time.This value indicates that the
   *  animation can only be restarted when it is not active
   *  (i.e. after the active end). Attempts to restart the animation
   *  during its active duration are ignored.This value indicates
   *  that the animation cannot be restarted for the time the
   *  document is loaded.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  restart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The to attribute indicates the final value of the attribute that
   *  will be modified during the animation.The value of the
   *  attribute will change between the from attribute value
   *  and this value.You can use this attribute with the following
   *  SVG elements:For <animate>, <animateColor>, <animateMotion>,
   *  and <animateTransform>, to specifies the ending value
   *  of the animation.The exact value type for this attribute
   *  depend on the value of the attribute that will be animated.If
   *  a list of values is defined via the values attribute,
   *  the to attribute is ignored.For the <set> element, to
   *  specifies the value for the attribute during the duration
   *  of the element.The exact value type for this attribute
   *  depend on the value of the attribute that will be animated.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  to: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The values attribute has different meanings, depending upon the
   *  context where it's used, either it defines a sequence
   *  of values used over the course of an animation, or it's
   *  a list of numbers for a color matrix, which is interpreted
   *  differently depending on the type of color change to be
   *  performed.You can use this attribute with the following
   *  SVG elements:For <animate>, <animateColor>, <animateMotion>,
   *  and <animateTransform>, values is a list of values defining
   *  the sequence of values over the course of the animation.
   *  If this attribute is specified, any from, to, and by attribute
   *  values set on the element are ignored.The value holds
   *  a semicolon-separated list of one or more values. The
   *  type of the values is defined by the href and attributeName
   *  attributes.For the <feColorMatrix> element, values is
   *  a list of numbers interpreted differently depending on
   *  the value of the type attribute.The value is a list of
   *  numbers, which is interpreted differently depending on
   *  the value of the type attribute:Last modified: Jul 10,
   *  2022, by MDN contributors
   */
  values: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Animate);

/***/ }),

/***/ "./src/lib/components/Circle.react.js":
/*!********************************************!*\
  !*** ./src/lib/components/Circle.react.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Circle$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Circle is a wrapper for the <circle> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/circle
 */

var Circle = function Circle(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("circle", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Circle.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Circle.propTypes = (_Circle$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The cx attribute define the x-axis coordinate of a center point.You
   *  can use this attribute with the following SVG elements:For
   *  <circle>, cx defines the x-axis coordinate of the center
   *  of the shape.Note: Starting with SVG2 cx, is a Geometry
   *  Property, meaning this attribute can also be used as CSS
   *  property for circles.For <ellipse>, cx defines the x-axis
   *  coordinate of the center of the shape.Note: Starting with
   *  SVG2 cx, is a Geometry Property, meaning this attribute
   *  can also be used as CSS property for ellipses.For <radialGradient>,
   *  cx defines the x-axis coordinate of the end circle for
   *  the radial gradient.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  cx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The cy attribute define the y-axis coordinate of a center point.You
   *  can use this attribute with the following SVG elements:For
   *  <circle>, cy defines the y-axis coordinate of the center
   *  of the shape.Note: Starting with SVG2, cy is a Geometry
   *  Property meaning this attribute can also be used as a
   *  CSS property for circles.For <ellipse>, cy defines the
   *  y-axis coordinate of the center of the shape.Note: Starting
   *  with SVG2, cy is a Geometry Property meaning this attribute
   *  can also be used as a CSS property for ellipses.For <radialGradient>,
   *  cy defines the y-axis coordinate of the end circle for
   *  the radial gradient.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  cy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The r attribute defines the radius of a circle.You can use this
   *  attribute with the following SVG elements:For <circle>,
   *  r defines the radius of the circle and therefor its size.
   *  With a value lower or equal to zero the circle won't be
   *  drawn at all.Note: Starting with SVG2, r is a Geometry
   *  Property meaning this attribute can also be used as a
   *  CSS property for circles.For <radialGradient>, r defines
   *  the radius of the end circle for the radial gradient.The
   *  gradient will be drawn such that the 100% gradient stop
   *  is mapped to the perimeter of this end circle. A value
   *  of lower or equal to zero will cause the area to be painted
   *  as a single color using the color and opacity of the last
   *  gradient <stop>.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  r: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])
}, _defineProperty(_Circle$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Circle$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Circle$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Circle$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Circle);

/***/ }),

/***/ "./src/lib/components/ClipPath.react.js":
/*!**********************************************!*\
  !*** ./src/lib/components/ClipPath.react.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * ClipPath is a wrapper for the <clipPath> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/clipPath
 */

var ClipPath = function ClipPath(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("clipPath", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

ClipPath.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
ClipPath.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clipPathUnits attribute indicates which coordinate system
   *  to use for the contents of the <clipPath> element.You
   *  can use this attribute with the following SVG elements:For
   *  <clipPath>, clipPathUnits define the coordinate system
   *  in use for the content of the element.This value indicates
   *  that all coordinates inside the <clipPath> element refer
   *  to the user coordinate system as defined when the clipping
   *  path was created.This value indicates that all coordinates
   *  inside the <clipPath> element are relative to the bounding
   *  box of the element the clipping path is applied to. It
   *  means that the origin of the coordinate system is the
   *  top left corner of the object bounding box and the width
   *  and height of the object bounding box are considered to
   *  have a length of 1 unit value.Last modified: May 13, 2022,
   *  by MDN contributors
   */
  clipPathUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (ClipPath);

/***/ }),

/***/ "./src/lib/components/Defs.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Defs.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Defs is a wrapper for the <defs> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/defs
 */

var Defs = function Defs(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("defs", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Defs.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Defs.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Defs);

/***/ }),

/***/ "./src/lib/components/Desc.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Desc.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Desc is a wrapper for the <desc> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/desc
 */

var Desc = function Desc(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("desc", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Desc.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Desc.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Desc);

/***/ }),

/***/ "./src/lib/components/Ellipse.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/Ellipse.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Ellipse$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Ellipse is a wrapper for the <ellipse> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/ellipse
 */

var Ellipse = function Ellipse(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("ellipse", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Ellipse.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Ellipse.propTypes = (_Ellipse$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The cx attribute define the x-axis coordinate of a center point.You
   *  can use this attribute with the following SVG elements:For
   *  <circle>, cx defines the x-axis coordinate of the center
   *  of the shape.Note: Starting with SVG2 cx, is a Geometry
   *  Property, meaning this attribute can also be used as CSS
   *  property for circles.For <ellipse>, cx defines the x-axis
   *  coordinate of the center of the shape.Note: Starting with
   *  SVG2 cx, is a Geometry Property, meaning this attribute
   *  can also be used as CSS property for ellipses.For <radialGradient>,
   *  cx defines the x-axis coordinate of the end circle for
   *  the radial gradient.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  cx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The cy attribute define the y-axis coordinate of a center point.You
   *  can use this attribute with the following SVG elements:For
   *  <circle>, cy defines the y-axis coordinate of the center
   *  of the shape.Note: Starting with SVG2, cy is a Geometry
   *  Property meaning this attribute can also be used as a
   *  CSS property for circles.For <ellipse>, cy defines the
   *  y-axis coordinate of the center of the shape.Note: Starting
   *  with SVG2, cy is a Geometry Property meaning this attribute
   *  can also be used as a CSS property for ellipses.For <radialGradient>,
   *  cy defines the y-axis coordinate of the end circle for
   *  the radial gradient.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  cy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x border radius
   */
  rx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y border radius
   */
  ry: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])
}, _defineProperty(_Ellipse$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Ellipse$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Ellipse$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Ellipse$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Ellipse);

/***/ }),

/***/ "./src/lib/components/FeBlend.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeBlend.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeBlend$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeBlend is a wrapper for the <feBlend> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feBlend
 */

var FeBlend = function FeBlend(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feBlend", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeBlend.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeBlend.propTypes = (_FeBlend$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in2 attribute identifies the second input for the given filter
   *  primitive. It works exactly like the in attribute.You
   *  can use this attribute with the following SVG elements:For
   *  <feBlend>, in2 defines the second input image to the blending
   *  operation.For <feComposite>, in2 defines the second input
   *  image to the compositing operation.For <feDisplacementMap>,
   *  in2 defines the second input image, which is used to displace
   *  the pixels in the image defined in the in attribute.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  in2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mode attribute defines the blending mode on the <feBlend>
   *  filter primitive.You can use this attribute with the following
   *  SVG elements:For a description of the values, see <blend-mode>.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  mode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeBlend$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeBlend$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeBlend$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeBlend$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeBlend$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeBlend$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeBlend);

/***/ }),

/***/ "./src/lib/components/FeColorMatrix.react.js":
/*!***************************************************!*\
  !*** ./src/lib/components/FeColorMatrix.react.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeColorMatrix$propTy;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeColorMatrix is a wrapper for the <feColorMatrix> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feColorMatrix
 */

var FeColorMatrix = function FeColorMatrix(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feColorMatrix", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeColorMatrix.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeColorMatrix.propTypes = (_FeColorMatrix$propTy = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The values attribute has different meanings, depending upon the
   *  context where it's used, either it defines a sequence
   *  of values used over the course of an animation, or it's
   *  a list of numbers for a color matrix, which is interpreted
   *  differently depending on the type of color change to be
   *  performed.You can use this attribute with the following
   *  SVG elements:For <animate>, <animateColor>, <animateMotion>,
   *  and <animateTransform>, values is a list of values defining
   *  the sequence of values over the course of the animation.
   *  If this attribute is specified, any from, to, and by attribute
   *  values set on the element are ignored.The value holds
   *  a semicolon-separated list of one or more values. The
   *  type of the values is defined by the href and attributeName
   *  attributes.For the <feColorMatrix> element, values is
   *  a list of numbers interpreted differently depending on
   *  the value of the type attribute.The value is a list of
   *  numbers, which is interpreted differently depending on
   *  the value of the type attribute:Last modified: Jul 10,
   *  2022, by MDN contributors
   */
  values: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeColorMatrix$propTy, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeColorMatrix$propTy, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeColorMatrix$propTy, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeColorMatrix$propTy, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeColorMatrix$propTy, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeColorMatrix$propTy);
/* harmony default export */ __webpack_exports__["default"] = (FeColorMatrix);

/***/ }),

/***/ "./src/lib/components/FeComponentTransfer.react.js":
/*!*********************************************************!*\
  !*** ./src/lib/components/FeComponentTransfer.react.js ***!
  \*********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeComponentTransfer$;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeComponentTransfer is a wrapper for the <feComponentTransfer> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComponentTransfer
 */

var FeComponentTransfer = function FeComponentTransfer(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feComponentTransfer", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeComponentTransfer.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeComponentTransfer.propTypes = (_FeComponentTransfer$ = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeComponentTransfer$, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeComponentTransfer$, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeComponentTransfer$, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeComponentTransfer$, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeComponentTransfer$, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeComponentTransfer$);
/* harmony default export */ __webpack_exports__["default"] = (FeComponentTransfer);

/***/ }),

/***/ "./src/lib/components/FeComposite.react.js":
/*!*************************************************!*\
  !*** ./src/lib/components/FeComposite.react.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeComposite$propType;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeComposite is a wrapper for the <feComposite> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feComposite
 */

var FeComposite = function FeComposite(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feComposite", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeComposite.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeComposite.propTypes = (_FeComposite$propType = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in2 attribute identifies the second input for the given filter
   *  primitive. It works exactly like the in attribute.You
   *  can use this attribute with the following SVG elements:For
   *  <feBlend>, in2 defines the second input image to the blending
   *  operation.For <feComposite>, in2 defines the second input
   *  image to the compositing operation.For <feDisplacementMap>,
   *  in2 defines the second input image, which is used to displace
   *  the pixels in the image defined in the in attribute.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  in2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The k1 attribute defines one of the values to be used within
   *  the arithmetic operation of the <feComposite> filter primitive.The
   *  pixel composition is computed using the following formula:You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  k1: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The k2 attribute defines one of the values to be used within
   *  the arithmetic operation of the <feComposite> filter primitive.The
   *  pixel composition is computed using the following formula:You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  k2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The k3 attribute defines one of the values to be used within
   *  the arithmetic operation of the <feComposite> filter primitive.The
   *  pixel composition is computed using the following formula:You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  k3: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The k4 attribute defines one of the values to be used within
   *  the arithmetic operation of the <feComposite> filter primitive.The
   *  pixel composition is computed using the following formula:You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  k4: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The operator attribute has two meanings based on the context
   *  it's used in. Either it defines the compositing or morphing
   *  operation to be performed.You can use this attribute with
   *  the following SVG elements:For <feComposite>, operator
   *  defines the compositing operation that is to be performed.This
   *  value indicates that the source graphic defined in the
   *  in attribute is placed over the destination graphic defined
   *  in the in2 attribute.This value indicates that the parts
   *  of the source graphic defined in the in attribute that
   *  overlap the destination graphic defined in the in2 attribute,
   *  replace the destination graphic.This value indicates that
   *  the parts of the source graphic defined in the in attribute
   *  that fall outside the destination graphic defined in the
   *  in2 attribute, are displayed.This value indicates that
   *  the parts of the source graphic defined in the in attribute,
   *  which overlap the destination graphic defined in the in2
   *  attribute, replace the destination graphic. The parts
   *  of the destination graphic that do not overlap with the
   *  source graphic stay untouched.This value indicates that
   *  the non-overlapping regions of the source graphic defined
   *  in the in attribute and the destination graphic defined
   *  in the in2 attribute are combined.This value indicates
   *  that the sum of the source graphic defined in the in attribute
   *  and the destination graphic defined in the in2 attribute
   *  is displayed.This value indicates that the source graphic
   *  defined in the in attribute and the destination graphic
   *  defined in the in2 attribute are combined using the following
   *  formula:result = k1*i1*i2 + k2*i1 + k3*i2 + k4
    where:
    *       i1 and i2 indicate the corresponding pixel channel
   *  values of the input image, which map to in and in2 respectively,
   *  and k1, k2, k3, and k4 indicate the values of the attributes
   *  with the same name.
  For <feMorphology>, operator defines
   *  whether to erode (i.e., thin) or dilate (fatten) the source
   *  graphic.This value thins the source graphic defined in
   *  the in attribute.This value fattens the source graphic
   *  defined in the in attribute.Last modified: Jul 12, 2022,
   *  by MDN contributors
   */
  operator: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeComposite$propType, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeComposite$propType, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeComposite$propType, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeComposite$propType, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeComposite$propType, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeComposite$propType);
/* harmony default export */ __webpack_exports__["default"] = (FeComposite);

/***/ }),

/***/ "./src/lib/components/FeConvolveMatrix.react.js":
/*!******************************************************!*\
  !*** ./src/lib/components/FeConvolveMatrix.react.js ***!
  \******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeConvolveMatrix$pro;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeConvolveMatrix is a wrapper for the <feConvolveMatrix> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feConvolveMatrix
 */

var FeConvolveMatrix = function FeConvolveMatrix(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feConvolveMatrix", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeConvolveMatrix.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeConvolveMatrix.propTypes = (_FeConvolveMatrix$pro = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The bias attribute shifts the range of the filter. After applying
   *  the kernelMatrix of the <feConvolveMatrix> element to
   *  the input image to yield a number and applied the divisor
   *  attribute, the bias attribute is added to each component.
   *  This allows representation of values that would otherwise
   *  be clamped to 0 or 1.You can use this attribute with the
   *  following SVG elements:One application of bias is when
   *  it is desirable to have 0.5 gray value be the zero response
   *  of the filter.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  bias: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The divisor attribute specifies the value by which the resulting
   *  number of applying the kernelMatrix of a <feConvolveMatrix>
   *  element to the input image color value is divided to yield
   *  the destination color value.A divisor that is the sum
   *  of all the matrix values tends to have an evening effect
   *  on the overall color intensity of the result.You can use
   *  this attribute with the following SVG elements:This value
   *  defines the divisor. If the specified divisor is 0 then
   *  the default value will be used instead.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  divisor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The edgeMode attribute determines how to extend the input image
   *  as necessary with color values so that the matrix operations
   *  can be applied when the kernel is positioned at or near
   *  the edge of the input image.You can use this attribute
   *  with the following SVG elements:For <feConvolveMatrix>,
   *  edgeMode determines how to extend the input image as necessary
   *  with color values so that the matrix operations can be
   *  applied when the kernel is positioned at or near the edge
   *  of the input image.This value indicates that the input
   *  image is extended along each of its borders as necessary
   *  by duplicating the color values at the given edge of the
   *  input image.This value indicates that the input image
   *  is extended by taking the color values from the opposite
   *  edge of the image.This value indicates that the input
   *  image is extended with pixel values of zero for R, G,
   *  B and A.For <feGaussianBlur>, edgeMode determines how
   *  to extend the input image as necessary with color values
   *  so that the matrix operations can be applied when the
   *  kernel is positioned at or near the edge of the input
   *  image.This value indicates that the input image is extended
   *  along each of its borders as necessary by duplicating
   *  the color values at the given edge of the input image.This
   *  value indicates that the input image is extended by taking
   *  the color values from the opposite edge of the image.This
   *  value indicates that the input image is extended with
   *  pixel values of zero for R, G, B and A.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  edgeMode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The kernelMatrix attribute defines the list of numbers that make
   *  up the kernel matrix for the <feConvolveMatrix> element.Values
   *  are separated by space characters and/or a comma. The
   *  number of entries in the list must equal to <orderX> by
   *  <orderY> as defined in the order attribute.You can use
   *  this attribute with the following SVG elements:The list
   *  of <number>s that make up the kernel matrix for the convolution.
   *  Values are separated by space characters and/or a comma.
   *  The number of entries in the list must equal <orderX>
   *  times <orderY>.If the result of orderX * orderY is not
   *  equal to the number of entries in the value list, the
   *  filter primitive acts as a pass through filter.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  kernelMatrix: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The kernelUnitLength attribute
   *  has two meanings based on the context it's used in. For
   *  lighting filter primitives, it indicates the intended
   *  distance for the x and y coordinates, for <feConvolveMatrix>,
   *  it indicates the intended distance between successive
   *  columns and rows in the kernel matrix.You can use this
   *  attribute with the following SVG elements:For the <feConvolveMatrix>,
   *  kernelUnitLength indicates the intended distance in current
   *  filter units (i.e., units as determined by the value of
   *  primitiveUnits attribute) between successive columns and
   *  rows, respectively, in the kernelMatrix. By specifying
   *  value(s) for kernelUnitLength, the kernel becomes defined
   *  in a scalable, abstract coordinate system. If the attribute
   *  is not specified, the default value is one pixel in the
   *  offscreen bitmap, which is a pixel-based coordinate system,
   *  and thus potentially not scalable.If a negative or zero
   *  value is specified the default value will be used instead.The
   *  first number is the x value. The second number is the
   *  y value. If the x value is not specified, it defaults
   *  to the same value as x.For the <feDiffuseLighting>, kernelUnitLength
   *  indicates the intended distance in current filter units
   *  (i.e., units as determined by the value of attribute primitiveUnits)
   *  for the x and y coordinate, respectively, in the surface
   *  normal calculation formulas.The first number is the x
   *  value. The second number is the y value. If the y value
   *  is not specified, it defaults to the same value as x.
   *  By specifying value(s) for kernelUnitLength, the kernel
   *  becomes defined in a scalable, abstract coordinate system.
   *  If the attribute is not specified, the x and y values
   *  represent very small deltas relative to a given position,
   *  which might be implemented in some cases as one pixel
   *  in the intermediate image offscreen bitmap, which is a
   *  pixel-based coordinate system, and thus potentially not
   *  scalable.If a negative or zero value is specified the
   *  default value will be used instead.For the <feSpecularLighting>,
   *  kernelUnitLength indicates the intended distance in current
   *  filter units (i.e., units as determined by the value of
   *  attribute primitiveUnits) for the x and y coordinate,
   *  respectively, in the surface normal calculation formulas.The
   *  first number is the x value. The second number is the
   *  y value. If the y value is not specified, it defaults
   *  to the same value as x. By specifying value(s) for kernelUnitLength,
   *  the kernel becomes defined in a scalable, abstract coordinate
   *  system. If the attribute is not specified, the x and y
   *  values represent very small deltas relative to a given
   *  position, which might be implemented in some cases as
   *  one pixel in the intermediate image offscreen bitmap,
   *  which is a pixel-based coordinate system, and thus potentially
   *  not scalable.If a negative or zero value is specified
   *  the default value will be used instead.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  kernelUnitLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The order attribute indicates the size of the matrix to be used
   *  by a <feConvolveMatrix> element.You can use this attribute
   *  with the following SVG elements:This value indicates the
   *  number of cells in each dimension for the kernel matrix.
   *  The values provided must be <integer>s greater than zero.
   *  Values that are not integers will be truncated, i.e. rounded
   *  to the closest integer value towards zero. The first number,
   *  indicates the number of columns in the matrix. The second
   *  number, indicates the number of rows in the matrix. If
   *  no second number is not provided, it defaults to the first
   *  number.It is recommended that only small values (e.g.,
   *  3) be used; higher values may result in very high CPU
   *  overhead and usually do not produce results that justify
   *  the impact on performance.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: Jun 12, 2022, by MDN contributors
   * 
   */
  order: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["no", "yes"]),

  /**
   *  the preserveAlpha attribute indicates how a <feConvolveMatrix>
   *  element handled alpha transparency.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the convolution will only apply to the color channels.
   *  In this case, the filter will temporarily unpremultiply
   *  the color component values and apply the kernel.This value
   *  indicates that the convolution will apply to all channels,
   *  including the alpha channel.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAlpha: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(['true', 'false']),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The targetX attribute determines the positioning in horizontal
   *  direction of the convolution matrix relative to a given
   *  target pixel in the input image. The leftmost column of
   *  the matrix is column number zero. The value must be such
   *  that: 0 <= targetX < orderX.You can use this attribute
   *  with the following SVG elements:This value indicates the
   *  positioning in horizontal direction of the convolution
   *  matrix relative to a given target pixel in the input image.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  targetX: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The targetY attribute determines the positioning in vertical
   *  direction of the convolution matrix relative to a given
   *  target pixel in the input image. The topmost row of the
   *  matrix is row number zero. The value must be such that:
   *  0 <= targetY < orderY.You can use this attribute with
   *  the following SVG elements:This value indicates the positioning
   *  in vertical direction of the convolution matrix relative
   *  to a given target pixel in the input image.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  targetY: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeConvolveMatrix$pro, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeConvolveMatrix$pro, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeConvolveMatrix$pro, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeConvolveMatrix$pro, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeConvolveMatrix$pro, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeConvolveMatrix$pro);
/* harmony default export */ __webpack_exports__["default"] = (FeConvolveMatrix);

/***/ }),

/***/ "./src/lib/components/FeDiffuseLighting.react.js":
/*!*******************************************************!*\
  !*** ./src/lib/components/FeDiffuseLighting.react.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeDiffuseLighting$pr;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeDiffuseLighting is a wrapper for the <feDiffuseLighting> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDiffuseLighting
 */

var FeDiffuseLighting = function FeDiffuseLighting(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feDiffuseLighting", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeDiffuseLighting.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeDiffuseLighting.propTypes = (_FeDiffuseLighting$pr = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The diffuseConstant attribute represents the kd value in the
   *  Phong lighting model. In SVG, this can be any non-negative
   *  number.It's used to determine the final RGB value of a
   *  given pixel. The brighter the lighting-color, the smaller
   *  this number should be.You can use this attribute with
   *  the following SVG elements:BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  diffuseConstant: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The kernelUnitLength attribute
   *  has two meanings based on the context it's used in. For
   *  lighting filter primitives, it indicates the intended
   *  distance for the x and y coordinates, for <feConvolveMatrix>,
   *  it indicates the intended distance between successive
   *  columns and rows in the kernel matrix.You can use this
   *  attribute with the following SVG elements:For the <feConvolveMatrix>,
   *  kernelUnitLength indicates the intended distance in current
   *  filter units (i.e., units as determined by the value of
   *  primitiveUnits attribute) between successive columns and
   *  rows, respectively, in the kernelMatrix. By specifying
   *  value(s) for kernelUnitLength, the kernel becomes defined
   *  in a scalable, abstract coordinate system. If the attribute
   *  is not specified, the default value is one pixel in the
   *  offscreen bitmap, which is a pixel-based coordinate system,
   *  and thus potentially not scalable.If a negative or zero
   *  value is specified the default value will be used instead.The
   *  first number is the x value. The second number is the
   *  y value. If the x value is not specified, it defaults
   *  to the same value as x.For the <feDiffuseLighting>, kernelUnitLength
   *  indicates the intended distance in current filter units
   *  (i.e., units as determined by the value of attribute primitiveUnits)
   *  for the x and y coordinate, respectively, in the surface
   *  normal calculation formulas.The first number is the x
   *  value. The second number is the y value. If the y value
   *  is not specified, it defaults to the same value as x.
   *  By specifying value(s) for kernelUnitLength, the kernel
   *  becomes defined in a scalable, abstract coordinate system.
   *  If the attribute is not specified, the x and y values
   *  represent very small deltas relative to a given position,
   *  which might be implemented in some cases as one pixel
   *  in the intermediate image offscreen bitmap, which is a
   *  pixel-based coordinate system, and thus potentially not
   *  scalable.If a negative or zero value is specified the
   *  default value will be used instead.For the <feSpecularLighting>,
   *  kernelUnitLength indicates the intended distance in current
   *  filter units (i.e., units as determined by the value of
   *  attribute primitiveUnits) for the x and y coordinate,
   *  respectively, in the surface normal calculation formulas.The
   *  first number is the x value. The second number is the
   *  y value. If the y value is not specified, it defaults
   *  to the same value as x. By specifying value(s) for kernelUnitLength,
   *  the kernel becomes defined in a scalable, abstract coordinate
   *  system. If the attribute is not specified, the x and y
   *  values represent very small deltas relative to a given
   *  position, which might be implemented in some cases as
   *  one pixel in the intermediate image offscreen bitmap,
   *  which is a pixel-based coordinate system, and thus potentially
   *  not scalable.If a negative or zero value is specified
   *  the default value will be used instead.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  kernelUnitLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The lighting-color attribute defines the color of the light source
   *  for lighting filter primitives.You can use this attribute
   *  with the following SVG elements:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  lightingColor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The surfaceScale attribute represents the height of the surface
   *  for a light filter primitive.You can use this attribute
   *  with the following SVG elements:For <feSpecularLighting>,
   *  surfaceScale defines the height of the surface.For <feDiffuseLighting>,
   *  surfaceScale defines the height of the surface.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  surfaceScale: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeDiffuseLighting$pr, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeDiffuseLighting$pr, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeDiffuseLighting$pr, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeDiffuseLighting$pr, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeDiffuseLighting$pr, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeDiffuseLighting$pr);
/* harmony default export */ __webpack_exports__["default"] = (FeDiffuseLighting);

/***/ }),

/***/ "./src/lib/components/FeDisplacementMap.react.js":
/*!*******************************************************!*\
  !*** ./src/lib/components/FeDisplacementMap.react.js ***!
  \*******************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeDisplacementMap$pr;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeDisplacementMap is a wrapper for the <feDisplacementMap> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDisplacementMap
 */

var FeDisplacementMap = function FeDisplacementMap(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feDisplacementMap", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeDisplacementMap.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeDisplacementMap.propTypes = (_FeDisplacementMap$pr = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in2 attribute identifies the second input for the given filter
   *  primitive. It works exactly like the in attribute.You
   *  can use this attribute with the following SVG elements:For
   *  <feBlend>, in2 defines the second input image to the blending
   *  operation.For <feComposite>, in2 defines the second input
   *  image to the compositing operation.For <feDisplacementMap>,
   *  in2 defines the second input image, which is used to displace
   *  the pixels in the image defined in the in attribute.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  in2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The scale attribute defines the displacement scale factor to
   *  be used on a <feDisplacementMap> filter primitive. The
   *  amount is expressed in the coordinate system established
   *  by the primitiveUnits attribute on the <filter> element.You
   *  can use this attribute with the following SVG elements:This
   *  value defines the scale factor for the displacement.When
   *  the value of this attribute is 0, this operation has no
   *  effect on the source image.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  scale: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The xChannelSelector attribute indicates which color channel
   *  from in2 to use to displace the pixels in in along the
   *  x-axis.You can use this attribute with the following SVG
   *  elements:This keyword specifies that the red color channel
   *  of the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  x-axis.This keyword specifies that the green color channel
   *  of the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  x-axis.This keyword specifies that the blue color channel
   *  of the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  x-axis.This keyword specifies that the alpha channel of
   *  the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  x-axis.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  xChannelSelector: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The yChannelSelector attribute indicates which color channel
   *  from in2 to use to displace the pixels in in along the
   *  y-axis.You can use this attribute with the following SVG
   *  elements:This keyword specifies that the red color channel
   *  of the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  y-axis.This keyword specifies that the green color channel
   *  of the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  y-axis.This keyword specifies that the blue color channel
   *  of the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  y-axis.This keyword specifies that the alpha channel of
   *  the input image defined in in2 will be used to displace
   *  the pixels of the input image defined in in along the
   *  y-axis.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  yChannelSelector: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeDisplacementMap$pr, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeDisplacementMap$pr, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeDisplacementMap$pr, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeDisplacementMap$pr, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeDisplacementMap$pr, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeDisplacementMap$pr);
/* harmony default export */ __webpack_exports__["default"] = (FeDisplacementMap);

/***/ }),

/***/ "./src/lib/components/FeDistantLight.react.js":
/*!****************************************************!*\
  !*** ./src/lib/components/FeDistantLight.react.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeDistantLight is a wrapper for the <feDistantLight> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDistantLight
 */

var FeDistantLight = function FeDistantLight(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feDistantLight", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeDistantLight.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeDistantLight.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The azimuth attribute specifies the direction angle for the light
   *  source on the XY plane (clockwise), in degrees from the
   *  x axis.You can use this attribute with the following SVG
   *  elements:BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  azimuth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The elevation attribute specifies the direction angle for the
   *  light source from the XY plane towards the Z-axis, in
   *  degrees. Note that the positive Z-axis points towards
   *  the viewer of the content.You can use this attribute with
   *  the following SVG elements:BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  elevation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (FeDistantLight);

/***/ }),

/***/ "./src/lib/components/FeDropShadow.react.js":
/*!**************************************************!*\
  !*** ./src/lib/components/FeDropShadow.react.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeDropShadow$propTyp;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeDropShadow is a wrapper for the <feDropShadow> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feDropShadow
 */

var FeDropShadow = function FeDropShadow(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feDropShadow", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeDropShadow.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeDropShadow.propTypes = (_FeDropShadow$propTyp = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The dx attribute indicates a shift along the x-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dx defines a shift along the
   *  x-axis for all alternate glyph.If there are multiple values,
   *  dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dx defines the x offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dx defines the
   *  x offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dx defines the x offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dx defines
   *  a shift along the x-axis for all glyphs.If there are multiple
   *  values, dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dx defines a shift along the x-axis for all glyphs.If
   *  there are multiple values, dx defines a shift along the
   *  x-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dx defines a shift along the x-axis for
   *  all alternate glyph.If there are multiple values, dx defines
   *  a shift along the x-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dy attribute indicates a shift along the y-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dy defines a shift along the
   *  y-axis for all alternate glyph.If there are multiple values,
   *  dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dy defines the y offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dy defines the
   *  y offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dy defines the y offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dy defines
   *  a shift along the y-axis for all glyphs.If there are multiple
   *  values, dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dy defines a shift along the y-axis for all glyphs.If
   *  there are multiple values, dy defines a shift along the
   *  y-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dy defines a shift along the y-axis for
   *  all alternate glyph.If there are multiple values, dy defines
   *  a shift along the y-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The flood-color attribute indicates what color to use to flood
   *  the current filter primitive subregion.Note: As a presentation
   *  attribute, flood-color can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  floodColor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The flood-opacity attribute indicates the opacity value to use
   *  across the current filter primitive subregion.Note: As
   *  a presentation attribute, flood-opacity can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:
    A number or percentage indicating
   *  the opacity value to use across the current filter primitive
   *  subregion.
    A number of 0 or a percentage of 0% represents
   *  a fully transparent color, 1 or 100% represents a fully
   *  opaque color.
  BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  floodOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeDropShadow$propTyp, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeDropShadow$propTyp, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeDropShadow$propTyp, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeDropShadow$propTyp, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeDropShadow$propTyp, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeDropShadow$propTyp);
/* harmony default export */ __webpack_exports__["default"] = (FeDropShadow);

/***/ }),

/***/ "./src/lib/components/FeFlood.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeFlood.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeFlood$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeFlood is a wrapper for the <feFlood> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFlood
 */

var FeFlood = function FeFlood(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feFlood", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeFlood.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeFlood.propTypes = (_FeFlood$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The flood-color attribute indicates what color to use to flood
   *  the current filter primitive subregion.Note: As a presentation
   *  attribute, flood-color can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  floodColor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The flood-opacity attribute indicates the opacity value to use
   *  across the current filter primitive subregion.Note: As
   *  a presentation attribute, flood-opacity can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:
    A number or percentage indicating
   *  the opacity value to use across the current filter primitive
   *  subregion.
    A number of 0 or a percentage of 0% represents
   *  a fully transparent color, 1 or 100% represents a fully
   *  opaque color.
  BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  floodOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeFlood$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFlood$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFlood$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeFlood$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeFlood$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeFlood$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeFlood);

/***/ }),

/***/ "./src/lib/components/FeFuncA.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeFuncA.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeFuncA$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeFuncA is a wrapper for the <feFuncA> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncA
 */

var FeFuncA = function FeFuncA(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feFuncA", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeFuncA.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeFuncA.propTypes = (_FeFuncA$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The amplitude attribute controls the amplitude of the gamma function
   *  of a component transfer element when its type attribute
   *  is gamma.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  amplitude: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The exponent attribute defines the exponent of the gamma function.You
   *  can use this attribute with the following SVG elements:If
   *  the type attribute of the component element is set to
   *  gamma, this value specifies the exponent of the gamma
   *  functionLast modified: May 13, 2022, by MDN contributors
   * 
   */
  exponent: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The intercept attribute defines the intercept of the linear function
   *  of color component transfers when the type attribute is
   *  set to linear.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  intercept: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The tableValues attribute defines a list of numbers defining
   *  a lookup table of values for a color component transfer
   *  function.You can use this attribute with the following
   *  SVG elements:This value holds a comma- and/or space-separated
   *  list of <number>s, which define a lookup table for the
   *  color component transfer function. Each number can be
   *  between 0 and 1.An empty list results in an identity transfer
   *  function.Last modified: Jul 1, 2022, by MDN contributors
   * 
   */
  tableValues: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeFuncA$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncA$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncA$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeFuncA$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeFuncA$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeFuncA$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeFuncA);

/***/ }),

/***/ "./src/lib/components/FeFuncB.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeFuncB.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeFuncB$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeFuncB is a wrapper for the <feFuncB> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncB
 */

var FeFuncB = function FeFuncB(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feFuncB", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeFuncB.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeFuncB.propTypes = (_FeFuncB$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The amplitude attribute controls the amplitude of the gamma function
   *  of a component transfer element when its type attribute
   *  is gamma.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  amplitude: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The exponent attribute defines the exponent of the gamma function.You
   *  can use this attribute with the following SVG elements:If
   *  the type attribute of the component element is set to
   *  gamma, this value specifies the exponent of the gamma
   *  functionLast modified: May 13, 2022, by MDN contributors
   * 
   */
  exponent: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The intercept attribute defines the intercept of the linear function
   *  of color component transfers when the type attribute is
   *  set to linear.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  intercept: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The tableValues attribute defines a list of numbers defining
   *  a lookup table of values for a color component transfer
   *  function.You can use this attribute with the following
   *  SVG elements:This value holds a comma- and/or space-separated
   *  list of <number>s, which define a lookup table for the
   *  color component transfer function. Each number can be
   *  between 0 and 1.An empty list results in an identity transfer
   *  function.Last modified: Jul 1, 2022, by MDN contributors
   * 
   */
  tableValues: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeFuncB$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncB$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncB$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeFuncB$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeFuncB$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeFuncB$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeFuncB);

/***/ }),

/***/ "./src/lib/components/FeFuncG.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeFuncG.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeFuncG$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeFuncG is a wrapper for the <feFuncG> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncG
 */

var FeFuncG = function FeFuncG(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feFuncG", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeFuncG.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeFuncG.propTypes = (_FeFuncG$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The amplitude attribute controls the amplitude of the gamma function
   *  of a component transfer element when its type attribute
   *  is gamma.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  amplitude: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The exponent attribute defines the exponent of the gamma function.You
   *  can use this attribute with the following SVG elements:If
   *  the type attribute of the component element is set to
   *  gamma, this value specifies the exponent of the gamma
   *  functionLast modified: May 13, 2022, by MDN contributors
   * 
   */
  exponent: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The intercept attribute defines the intercept of the linear function
   *  of color component transfers when the type attribute is
   *  set to linear.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  intercept: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The tableValues attribute defines a list of numbers defining
   *  a lookup table of values for a color component transfer
   *  function.You can use this attribute with the following
   *  SVG elements:This value holds a comma- and/or space-separated
   *  list of <number>s, which define a lookup table for the
   *  color component transfer function. Each number can be
   *  between 0 and 1.An empty list results in an identity transfer
   *  function.Last modified: Jul 1, 2022, by MDN contributors
   * 
   */
  tableValues: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeFuncG$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncG$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncG$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeFuncG$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeFuncG$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeFuncG$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeFuncG);

/***/ }),

/***/ "./src/lib/components/FeFuncR.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeFuncR.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeFuncR$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeFuncR is a wrapper for the <feFuncR> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feFuncR
 */

var FeFuncR = function FeFuncR(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feFuncR", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeFuncR.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeFuncR.propTypes = (_FeFuncR$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The amplitude attribute controls the amplitude of the gamma function
   *  of a component transfer element when its type attribute
   *  is gamma.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  amplitude: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The exponent attribute defines the exponent of the gamma function.You
   *  can use this attribute with the following SVG elements:If
   *  the type attribute of the component element is set to
   *  gamma, this value specifies the exponent of the gamma
   *  functionLast modified: May 13, 2022, by MDN contributors
   * 
   */
  exponent: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The intercept attribute defines the intercept of the linear function
   *  of color component transfers when the type attribute is
   *  set to linear.You can use this attribute with the following
   *  SVG elements:Last modified: May 13, 2022, by MDN contributors
   * 
   */
  intercept: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The tableValues attribute defines a list of numbers defining
   *  a lookup table of values for a color component transfer
   *  function.You can use this attribute with the following
   *  SVG elements:This value holds a comma- and/or space-separated
   *  list of <number>s, which define a lookup table for the
   *  color component transfer function. Each number can be
   *  between 0 and 1.An empty list results in an identity transfer
   *  function.Last modified: Jul 1, 2022, by MDN contributors
   * 
   */
  tableValues: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeFuncR$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncR$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeFuncR$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeFuncR$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeFuncR$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeFuncR$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeFuncR);

/***/ }),

/***/ "./src/lib/components/FeGaussianBlur.react.js":
/*!****************************************************!*\
  !*** ./src/lib/components/FeGaussianBlur.react.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeGaussianBlur$propT;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeGaussianBlur is a wrapper for the <feGaussianBlur> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feGaussianBlur
 */

var FeGaussianBlur = function FeGaussianBlur(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feGaussianBlur", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeGaussianBlur.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeGaussianBlur.propTypes = (_FeGaussianBlur$propT = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The edgeMode attribute determines how to extend the input image
   *  as necessary with color values so that the matrix operations
   *  can be applied when the kernel is positioned at or near
   *  the edge of the input image.You can use this attribute
   *  with the following SVG elements:For <feConvolveMatrix>,
   *  edgeMode determines how to extend the input image as necessary
   *  with color values so that the matrix operations can be
   *  applied when the kernel is positioned at or near the edge
   *  of the input image.This value indicates that the input
   *  image is extended along each of its borders as necessary
   *  by duplicating the color values at the given edge of the
   *  input image.This value indicates that the input image
   *  is extended by taking the color values from the opposite
   *  edge of the image.This value indicates that the input
   *  image is extended with pixel values of zero for R, G,
   *  B and A.For <feGaussianBlur>, edgeMode determines how
   *  to extend the input image as necessary with color values
   *  so that the matrix operations can be applied when the
   *  kernel is positioned at or near the edge of the input
   *  image.This value indicates that the input image is extended
   *  along each of its borders as necessary by duplicating
   *  the color values at the given edge of the input image.This
   *  value indicates that the input image is extended by taking
   *  the color values from the opposite edge of the image.This
   *  value indicates that the input image is extended with
   *  pixel values of zero for R, G, B and A.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  edgeMode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stdDeviation attribute defines the standard deviation for
   *  the blur operation.You can use this attribute with the
   *  following SVG elements:If two numbers are provided, the
   *  first number represents a standard deviation value along
   *  the x-axis. The second value represents a standard deviation
   *  along the y-axis. If one number is provided, then that
   *  value is used for both X and Y.A negative value is forbidden.
   *  A value of zero disables the effect of the given filter
   *  primitive (i.e., the result is the filter input image).
   *  If stdDeviation is 0 in only one of X or Y, then the effect
   *  is that the blur is only applied in the direction that
   *  has a non-zero value.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  stdDeviation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeGaussianBlur$propT, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeGaussianBlur$propT, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeGaussianBlur$propT, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeGaussianBlur$propT, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeGaussianBlur$propT, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeGaussianBlur$propT);
/* harmony default export */ __webpack_exports__["default"] = (FeGaussianBlur);

/***/ }),

/***/ "./src/lib/components/FeImage.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeImage.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeImage$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeImage is a wrapper for the <feImage> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feImage
 */

var FeImage = function FeImage(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feImage", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeImage.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeImage.propTypes = (_FeImage$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeImage$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeImage$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeImage$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeImage$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeImage$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeImage$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeImage);

/***/ }),

/***/ "./src/lib/components/FeMerge.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/FeMerge.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeMerge$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeMerge is a wrapper for the <feMerge> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMerge
 */

var FeMerge = function FeMerge(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feMerge", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeMerge.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeMerge.propTypes = (_FeMerge$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeMerge$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeMerge$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeMerge$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeMerge$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeMerge$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeMerge$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeMerge);

/***/ }),

/***/ "./src/lib/components/FeMergeNode.react.js":
/*!*************************************************!*\
  !*** ./src/lib/components/FeMergeNode.react.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeMergeNode$propType;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeMergeNode is a wrapper for the <feMergeNode> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMergeNode
 */

var FeMergeNode = function FeMergeNode(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feMergeNode", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeMergeNode.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeMergeNode.propTypes = (_FeMergeNode$propType = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeMergeNode$propType, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeMergeNode$propType, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeMergeNode$propType, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeMergeNode$propType, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeMergeNode$propType, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeMergeNode$propType);
/* harmony default export */ __webpack_exports__["default"] = (FeMergeNode);

/***/ }),

/***/ "./src/lib/components/FeMorphology.react.js":
/*!**************************************************!*\
  !*** ./src/lib/components/FeMorphology.react.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeMorphology$propTyp;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeMorphology is a wrapper for the <feMorphology> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feMorphology
 */

var FeMorphology = function FeMorphology(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feMorphology", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeMorphology.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeMorphology.propTypes = (_FeMorphology$propTyp = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The operator attribute has two meanings based on the context
   *  it's used in. Either it defines the compositing or morphing
   *  operation to be performed.You can use this attribute with
   *  the following SVG elements:For <feComposite>, operator
   *  defines the compositing operation that is to be performed.This
   *  value indicates that the source graphic defined in the
   *  in attribute is placed over the destination graphic defined
   *  in the in2 attribute.This value indicates that the parts
   *  of the source graphic defined in the in attribute that
   *  overlap the destination graphic defined in the in2 attribute,
   *  replace the destination graphic.This value indicates that
   *  the parts of the source graphic defined in the in attribute
   *  that fall outside the destination graphic defined in the
   *  in2 attribute, are displayed.This value indicates that
   *  the parts of the source graphic defined in the in attribute,
   *  which overlap the destination graphic defined in the in2
   *  attribute, replace the destination graphic. The parts
   *  of the destination graphic that do not overlap with the
   *  source graphic stay untouched.This value indicates that
   *  the non-overlapping regions of the source graphic defined
   *  in the in attribute and the destination graphic defined
   *  in the in2 attribute are combined.This value indicates
   *  that the sum of the source graphic defined in the in attribute
   *  and the destination graphic defined in the in2 attribute
   *  is displayed.This value indicates that the source graphic
   *  defined in the in attribute and the destination graphic
   *  defined in the in2 attribute are combined using the following
   *  formula:result = k1*i1*i2 + k2*i1 + k3*i2 + k4
    where:
    *       i1 and i2 indicate the corresponding pixel channel
   *  values of the input image, which map to in and in2 respectively,
   *  and k1, k2, k3, and k4 indicate the values of the attributes
   *  with the same name.
  For <feMorphology>, operator defines
   *  whether to erode (i.e., thin) or dilate (fatten) the source
   *  graphic.This value thins the source graphic defined in
   *  the in attribute.This value fattens the source graphic
   *  defined in the in attribute.Last modified: Jul 12, 2022,
   *  by MDN contributors
   */
  operator: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The radius attribute represents the radius (or radii) for the
   *  operation on a given <feMorphology> filter primitive.If
   *  two numbers are provided, the first number represents
   *  the x-radius and the second one the y-radius. If one number
   *  is provided, then that value is used for both x and y.
   *  The values are in the coordinate system established by
   *  the primitiveUnits attribute on the <filter> element.A
   *  negative or zero value disables the effect of the given
   *  filter primitive (i.e., the result is the filter input
   *  image).You can use this attribute with the following SVG
   *  elements:BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  radius: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeMorphology$propTyp, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeMorphology$propTyp, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeMorphology$propTyp, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeMorphology$propTyp, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeMorphology$propTyp, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeMorphology$propTyp);
/* harmony default export */ __webpack_exports__["default"] = (FeMorphology);

/***/ }),

/***/ "./src/lib/components/FeOffset.react.js":
/*!**********************************************!*\
  !*** ./src/lib/components/FeOffset.react.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeOffset$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeOffset is a wrapper for the <feOffset> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feOffset
 */

var FeOffset = function FeOffset(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feOffset", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeOffset.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeOffset.propTypes = (_FeOffset$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The dx attribute indicates a shift along the x-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dx defines a shift along the
   *  x-axis for all alternate glyph.If there are multiple values,
   *  dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dx defines the x offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dx defines the
   *  x offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dx defines the x offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dx defines
   *  a shift along the x-axis for all glyphs.If there are multiple
   *  values, dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dx defines a shift along the x-axis for all glyphs.If
   *  there are multiple values, dx defines a shift along the
   *  x-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dx defines a shift along the x-axis for
   *  all alternate glyph.If there are multiple values, dx defines
   *  a shift along the x-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dy attribute indicates a shift along the y-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dy defines a shift along the
   *  y-axis for all alternate glyph.If there are multiple values,
   *  dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dy defines the y offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dy defines the
   *  y offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dy defines the y offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dy defines
   *  a shift along the y-axis for all glyphs.If there are multiple
   *  values, dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dy defines a shift along the y-axis for all glyphs.If
   *  there are multiple values, dy defines a shift along the
   *  y-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dy defines a shift along the y-axis for
   *  all alternate glyph.If there are multiple values, dy defines
   *  a shift along the y-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeOffset$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeOffset$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeOffset$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeOffset$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeOffset$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeOffset$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeOffset);

/***/ }),

/***/ "./src/lib/components/FePointLight.react.js":
/*!**************************************************!*\
  !*** ./src/lib/components/FePointLight.react.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FePointLight$propTyp;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FePointLight is a wrapper for the <fePointLight> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/fePointLight
 */

var FePointLight = function FePointLight(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("fePointLight", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FePointLight.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FePointLight.propTypes = (_FePointLight$propTyp = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The z attribute defines the location along the z-axis for a light
   *  source in the coordinate system established by the primitiveUnits
   *  attribute on the <filter> element, assuming that, in the
   *  initial coordinate system, the positive z-axis comes out
   *  towards the person viewing the content and assuming that
   *  one unit along the z-axis equals one unit in x and y.You
   *  can use this attribute with the following SVG elements:For
   *  <fePointLight>, z defines the location along the z-axis
   *  for the light source in the coordinate system established
   *  by the primitiveUnits attribute on the <filter> element.For
   *  <feSpotLight>, z defines the location along the z-axis
   *  for the light source in the coordinate system established
   *  by the primitiveUnits attribute on the <filter> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  z: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FePointLight$propTyp, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FePointLight$propTyp, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FePointLight$propTyp, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FePointLight$propTyp, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FePointLight$propTyp, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FePointLight$propTyp);
/* harmony default export */ __webpack_exports__["default"] = (FePointLight);

/***/ }),

/***/ "./src/lib/components/FeSpecularLighting.react.js":
/*!********************************************************!*\
  !*** ./src/lib/components/FeSpecularLighting.react.js ***!
  \********************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeSpecularLighting$p;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeSpecularLighting is a wrapper for the <feSpecularLighting> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpecularLighting
 */

var FeSpecularLighting = function FeSpecularLighting(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feSpecularLighting", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeSpecularLighting.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeSpecularLighting.propTypes = (_FeSpecularLighting$p = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The kernelUnitLength attribute
   *  has two meanings based on the context it's used in. For
   *  lighting filter primitives, it indicates the intended
   *  distance for the x and y coordinates, for <feConvolveMatrix>,
   *  it indicates the intended distance between successive
   *  columns and rows in the kernel matrix.You can use this
   *  attribute with the following SVG elements:For the <feConvolveMatrix>,
   *  kernelUnitLength indicates the intended distance in current
   *  filter units (i.e., units as determined by the value of
   *  primitiveUnits attribute) between successive columns and
   *  rows, respectively, in the kernelMatrix. By specifying
   *  value(s) for kernelUnitLength, the kernel becomes defined
   *  in a scalable, abstract coordinate system. If the attribute
   *  is not specified, the default value is one pixel in the
   *  offscreen bitmap, which is a pixel-based coordinate system,
   *  and thus potentially not scalable.If a negative or zero
   *  value is specified the default value will be used instead.The
   *  first number is the x value. The second number is the
   *  y value. If the x value is not specified, it defaults
   *  to the same value as x.For the <feDiffuseLighting>, kernelUnitLength
   *  indicates the intended distance in current filter units
   *  (i.e., units as determined by the value of attribute primitiveUnits)
   *  for the x and y coordinate, respectively, in the surface
   *  normal calculation formulas.The first number is the x
   *  value. The second number is the y value. If the y value
   *  is not specified, it defaults to the same value as x.
   *  By specifying value(s) for kernelUnitLength, the kernel
   *  becomes defined in a scalable, abstract coordinate system.
   *  If the attribute is not specified, the x and y values
   *  represent very small deltas relative to a given position,
   *  which might be implemented in some cases as one pixel
   *  in the intermediate image offscreen bitmap, which is a
   *  pixel-based coordinate system, and thus potentially not
   *  scalable.If a negative or zero value is specified the
   *  default value will be used instead.For the <feSpecularLighting>,
   *  kernelUnitLength indicates the intended distance in current
   *  filter units (i.e., units as determined by the value of
   *  attribute primitiveUnits) for the x and y coordinate,
   *  respectively, in the surface normal calculation formulas.The
   *  first number is the x value. The second number is the
   *  y value. If the y value is not specified, it defaults
   *  to the same value as x. By specifying value(s) for kernelUnitLength,
   *  the kernel becomes defined in a scalable, abstract coordinate
   *  system. If the attribute is not specified, the x and y
   *  values represent very small deltas relative to a given
   *  position, which might be implemented in some cases as
   *  one pixel in the intermediate image offscreen bitmap,
   *  which is a pixel-based coordinate system, and thus potentially
   *  not scalable.If a negative or zero value is specified
   *  the default value will be used instead.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  kernelUnitLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The lighting-color attribute defines the color of the light source
   *  for lighting filter primitives.You can use this attribute
   *  with the following SVG elements:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  lightingColor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The specularConstant attribute controls the ratio of reflection
   *  of the specular lighting. It represents the ks value in
   *  the Phong lighting model. The bigger the value the stronger
   *  the reflection.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  specularConstant: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The specularExponent attribute controls the focus for the light
   *  source. The bigger the value the brighter the light.You
   *  can use this attribute with the following SVG elements:For
   *  <feSpecularLighting>, specularExponent defines the exponent
   *  value for the specular term.For <feSpotLight>, specularExponent
   *  defines the exponent value controlling the focus for the
   *  light source.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  specularExponent: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The surfaceScale attribute represents the height of the surface
   *  for a light filter primitive.You can use this attribute
   *  with the following SVG elements:For <feSpecularLighting>,
   *  surfaceScale defines the height of the surface.For <feDiffuseLighting>,
   *  surfaceScale defines the height of the surface.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  surfaceScale: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeSpecularLighting$p, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeSpecularLighting$p, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeSpecularLighting$p, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeSpecularLighting$p, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeSpecularLighting$p, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeSpecularLighting$p);
/* harmony default export */ __webpack_exports__["default"] = (FeSpecularLighting);

/***/ }),

/***/ "./src/lib/components/FeSpotLight.react.js":
/*!*************************************************!*\
  !*** ./src/lib/components/FeSpotLight.react.js ***!
  \*************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeSpotLight$propType;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeSpotLight is a wrapper for the <feSpotLight> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feSpotLight
 */

var FeSpotLight = function FeSpotLight(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feSpotLight", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeSpotLight.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeSpotLight.propTypes = (_FeSpotLight$propType = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  The limitingConeAngle attribute represents the angle in degrees
   *  between the spot light axis (i.e. the axis between the
   *  light source and the point to which it is pointing at)
   *  and the spot light cone. So it defines a limiting cone
   *  which restricts the region where the light is projected.
   *  No light is projected outside the cone.You can use this
   *  attribute with the following SVG elements:BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  limitingConeAngle: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointsAtX attribute represents the x location in the coordinate
   *  system established by attribute primitiveUnits on the
   *  <filter> element of the point at which the light source
   *  is pointing.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  pointsAtX: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointsAtY attribute represents the y location in the coordinate
   *  system established by attribute primitiveUnits on the
   *  <filter> element of the point at which the light source
   *  is pointing.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  pointsAtY: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointsAtZ attribute represents the y location in the coordinate
   *  system established by attribute primitiveUnits on the
   *  <filter> element of the point at which the light source
   *  is pointing, assuming that, in the initial local coordinate
   *  system, the positive z-axis comes out towards the person
   *  viewing the content and assuming that one unit along the
   *  z-axis equals one unit in x and y.You can use this attribute
   *  with the following SVG elements:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointsAtZ: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The specularExponent attribute controls the focus for the light
   *  source. The bigger the value the brighter the light.You
   *  can use this attribute with the following SVG elements:For
   *  <feSpecularLighting>, specularExponent defines the exponent
   *  value for the specular term.For <feSpotLight>, specularExponent
   *  defines the exponent value controlling the focus for the
   *  light source.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  specularExponent: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The z attribute defines the location along the z-axis for a light
   *  source in the coordinate system established by the primitiveUnits
   *  attribute on the <filter> element, assuming that, in the
   *  initial coordinate system, the positive z-axis comes out
   *  towards the person viewing the content and assuming that
   *  one unit along the z-axis equals one unit in x and y.You
   *  can use this attribute with the following SVG elements:For
   *  <fePointLight>, z defines the location along the z-axis
   *  for the light source in the coordinate system established
   *  by the primitiveUnits attribute on the <filter> element.For
   *  <feSpotLight>, z defines the location along the z-axis
   *  for the light source in the coordinate system established
   *  by the primitiveUnits attribute on the <filter> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  z: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeSpotLight$propType, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeSpotLight$propType, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeSpotLight$propType, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeSpotLight$propType, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeSpotLight$propType, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeSpotLight$propType);
/* harmony default export */ __webpack_exports__["default"] = (FeSpotLight);

/***/ }),

/***/ "./src/lib/components/FeTile.react.js":
/*!********************************************!*\
  !*** ./src/lib/components/FeTile.react.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeTile$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeTile is a wrapper for the <feTile> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTile
 */

var FeTile = function FeTile(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feTile", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeTile.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeTile.propTypes = (_FeTile$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The in attribute identifies input for the given filter primitive.The
   *  value can be either one of the six keywords defined below,
   *  or a string which matches a previous result attribute
   *  value within the same <filter> element. If no value is
   *  provided and this is the first filter primitive, then
   *  this filter primitive will use SourceGraphic as its input.
   *  If no value is provided and this is a subsequent filter
   *  primitive, then this filter primitive will use the result
   *  from the previous filter primitive as its input.If the
   *  value for result appears multiple times within a given
   *  <filter> element, then a reference to that result will
   *  use the closest preceding filter primitive with the given
   *  value for attribute result.You can use this attribute
   *  with the following SVG elements:This keyword represents
   *  the graphics elements that were the original input into
   *  the <filter> element.This keyword represents the graphics
   *  elements that were the original input into the <filter>
   *  element. SourceAlpha has all of the same rules as SourceGraphic
   *  except that only the alpha channel is used.This keyword
   *  represents an image snapshot of the SVG document under
   *  the filter region at the time that the <filter> element
   *  was invoked.Same as BackgroundImage except only the alpha
   *  channel is used.This keyword represents the value of the
   *  fill property on the target element for the filter effect.
   *  In many cases, the FillPaint is opaque everywhere, but
   *  that might not be the case if a shape is painted with
   *  a gradient or pattern which itself includes transparent
   *  or semi-transparent parts.This keyword represents the
   *  value of the stroke property on the target element for
   *  the filter effect. In many cases, the StrokePaint is opaque
   *  everywhere, but that might not be the case if a shape
   *  is painted with a gradient or pattern which itself includes
   *  transparent or semi-transparent parts.This value is an
   *  assigned name for the filter primitive in the form of
   *  a <custom-ident>. If supplied, then graphics that result
   *  from processing this filter primitive can be referenced
   *  by an in attribute on a subsequent filter primitive within
   *  the same filter element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.BackgroundImage
   *  is not supported as a filter source in modern browsers
   *  (see the feComposite compatibility table). We therefore
   *  need to import one of the images to blend inside the filter
   *  itself, using an <feImage> element.Note: Firefox Bug 455986
   *  means that feImage cannot load partial images, including
   *  circles, rectangles, paths or other fragments defined
   *  in the document. So that this example works on more browsers,
   *  a full external image of the logo is loaded.Last modified:
   *  Jul 1, 2022, by MDN contributors
   */
  "in": prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeTile$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeTile$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeTile$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeTile$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeTile$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeTile$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (FeTile);

/***/ }),

/***/ "./src/lib/components/FeTurbulence.react.js":
/*!**************************************************!*\
  !*** ./src/lib/components/FeTurbulence.react.js ***!
  \**************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _FeTurbulence$propTyp;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * FeTurbulence is a wrapper for the <feTurbulence> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/feTurbulence
 */

var FeTurbulence = function FeTurbulence(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("feTurbulence", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

FeTurbulence.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
FeTurbulence.propTypes = (_FeTurbulence$propTyp = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The baseFrequency attribute represents the base frequency parameter
   *  for the noise function of the <feTurbulence> filter primitive.You
   *  can use this attribute with the following SVG elements:If
   *  two numbers are provided, the first one represents the
   *  base frequency in the horizontal direction and the second
   *  one the base frequency in the vertical direction. If one
   *  number is provided, then that value is used for both x
   *  and y.Negative values are forbidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  baseFrequency: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The color-interpolation-filters attribute specifies the color
   *  space for imaging operations performed via filter effects.Note:
   *  This property just has an affect on filter operations.
   *  Therefore, it has no effect on filter primitives like
   *  <feOffset>, <feImage>, <feTile> or <feFlood>.color-interpolation-filters
   *  has a different initial value than color-interpolation.
   *  color-interpolation-filters has an initial value of linearRGB,
   *  whereas color-interpolation has an initial value of sRGB.
   *  Thus, in the default case, filter effects operations occur
   *  in the linearRGB color space, whereas all other color
   *  interpolations occur by default in the sRGB color space.It
   *  has no affect on filter functions, which operate in the
   *  sRGB color space.Note: As a presentation attribute, color-interpolation-filters
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Indicates that the user
   *  agent can choose either the sRGB or linearRGB spaces for
   *  color interpolation. This option indicates that the author
   *  doesn't require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolationFilters: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["auto", "inherit", "linearRGB", "sRGB"]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The numOctaves attribute defines the number of octaves for the
   *  noise function of the <feTurbulence> primitive.
  An octave
   *  is a noise function defined by its frequency and amplitude.
   *  A turbulence is built by accumulating several octaves
   *  with increasing frequencies and decreasing amplitudes.
    *   The higher the number of octaves, the more natural the
   *  noise looks. Though more octaves also require more calculations,
   *  resulting in a negative impact on performance.
  You can
   *  use this attribute with the following SVG elements:Defines
   *  the number of octaves. Negative values are forbidden.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  numOctaves: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The result attribute defines the assigned name for this filter
   *  primitive. If supplied, then graphics that result from
   *  processing this filter primitive can be referenced by
   *  an in attribute on a subsequent filter primitive within
   *  the same <filter> element. If no value is provided, the
   *  output will only be available for re-use as the implicit
   *  input into the next filter primitive if that filter primitive
   *  provides no value for its in attribute.You can use this
   *  attribute with the following SVG elements:This value is
   *  a <custom-ident> and defines the name for the filter primitive.
   *  It is only meaningful within a given <filter> element
   *  and thus has only local scope. It is legal for the same
   *  <filter-primitive-reference> to appear multiple times
   *  within the same <filter> element. When referenced, this
   *  value will use the closest preceding filter primitive
   *  with the given result.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  result: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The seed attribute represents the starting number for the pseudo
   *  random number generator of the <feTurbulence> filter primitive.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  seed: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stitchTiles attribute defines how the Perlin Noise tiles
   *  behave at the border.You can use this attribute with the
   *  following SVG elements:This value indicates that no attempt
   *  is made to achieve smooth transitions at the border of
   *  tiles which contain a turbulence function. Sometimes the
   *  result will show clear discontinuities at the tile borders.This
   *  value indicates that the user agent will automatically
   *  adjust the x and y values of the base frequency such that
   *  the <feTurbulence> node's width and height (i.e., the
   *  width and height of the current subregion) contain an
   *  integral number of the tile width and height for the first
   *  octave.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  stitchTiles: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_FeTurbulence$propTyp, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeTurbulence$propTyp, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_FeTurbulence$propTyp, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_FeTurbulence$propTyp, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_FeTurbulence$propTyp, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _FeTurbulence$propTyp);
/* harmony default export */ __webpack_exports__["default"] = (FeTurbulence);

/***/ }),

/***/ "./src/lib/components/Filter.react.js":
/*!********************************************!*\
  !*** ./src/lib/components/Filter.react.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Filter$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Filter is a wrapper for the <filter> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/filter
 */

var Filter = function Filter(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("filter", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Filter.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Filter.propTypes = (_Filter$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The filterRes attribute
   *  indicates the width and height of the intermediate images
   *  in pixels of a filter primitive.Take care when assigning
   *  a non-default value to this attribute. Too small of a
   *  value may result in unwanted pixelation in the result.
   *  Too large of a value may result in slow processing and
   *  large memory usage.Note that negative values or zero values
   *  disable the rendering of the element which referenced
   *  the filter.You can use this attribute with the following
   *  SVG elements:This value takes one or two values, the first
   *  one outlining the resolution in horizontal direction,
   *  the second one in vertical direction. If only one value
   *  is specified, it is used for both directions.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  filterRes: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The filterUnits attribute defines the coordinate system for the
   *  attributes x, y, width and height.You can use this attribute
   *  with the following SVG elements:x, y, width and height
   *  represent values in the current coordinate system that
   *  results from taking the current user coordinate system
   *  in place at the time when the <filter> element is referenced
   *  (i.e., the user coordinate system for the element referencing
   *  the <filter> element via a filter attribute).In that case,
   *  x, y, width and height represent fractions or percentages
   *  of the bounding box on the referencing element.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  filterUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The primitiveUnits attribute specifies the coordinate system
   *  for the various length values within the filter primitives
   *  and for the attributes that define the filter primitive
   *  subregion.You can use this attribute with the following
   *  SVG elements:This value indicates that any length values
   *  within the filter definitions represent values in the
   *  current user coordinate system in place at the time when
   *  the <filter> element is referenced (i.e., the user coordinate
   *  system for the element referencing the <filter> element
   *  via a filter attribute).This value indicates that any
   *  length values within the filter definitions represent
   *  fractions or percentages of the bounding box on the referencing
   *  element.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  primitiveUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Filter$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Filter$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Filter$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Filter$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Filter$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Filter$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Filter);

/***/ }),

/***/ "./src/lib/components/ForeignObject.react.js":
/*!***************************************************!*\
  !*** ./src/lib/components/ForeignObject.react.js ***!
  \***************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _ForeignObject$propTy;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * ForeignObject is a wrapper for the <foreignObject> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/foreignObject
 */

var ForeignObject = function ForeignObject(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("foreignObject", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

ForeignObject.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
ForeignObject.propTypes = (_ForeignObject$propTy = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The clip attribute is a
   *  presentation attribute defining the visible region of
   *  an element.This attribute has the same parameter values
   *  as defined for the css clip property. Unitless values,
   *  which indicate current user coordinates, are permitted
   *  on the coordinate values on the rect(). The value of auto
   *  defines a clipping path along the bounds of the viewport
   *  created by the given element.You can use this attribute
   *  with the following SVG elements:Warning: This property
   *  is deprecated. Use clip-path instead.The value auto defines
   *  a clipping path along the bounds of the viewport created
   *  by the given element. The value rect() defines a clipping
   *  rectangle following the following syntax: rect(<top>,
   *  <right>, <bottom>, <left>). The <top> and <bottom> values
   *  specify offsets from the top border edge of the element
   *  viewport, while <right> and <left> specify offsets from
   *  the left border edge of the element viewport.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jun 28, 2022, by
   *  MDN contributors
   */
  clip: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_ForeignObject$propTy, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_ForeignObject$propTy, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_ForeignObject$propTy, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_ForeignObject$propTy, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_ForeignObject$propTy, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _ForeignObject$propTy);
/* harmony default export */ __webpack_exports__["default"] = (ForeignObject);

/***/ }),

/***/ "./src/lib/components/G.react.js":
/*!***************************************!*\
  !*** ./src/lib/components/G.react.js ***!
  \***************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * G is a wrapper for the <g> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/g
 */

var G = function G(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("g", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

G.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
G.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (G);

/***/ }),

/***/ "./src/lib/components/Image.react.js":
/*!*******************************************!*\
  !*** ./src/lib/components/Image.react.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Image$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Image is a wrapper for the <image> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/image
 */

var Image = function Image(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("image", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Image.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Image.propTypes = (_Image$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The clip attribute is a
   *  presentation attribute defining the visible region of
   *  an element.This attribute has the same parameter values
   *  as defined for the css clip property. Unitless values,
   *  which indicate current user coordinates, are permitted
   *  on the coordinate values on the rect(). The value of auto
   *  defines a clipping path along the bounds of the viewport
   *  created by the given element.You can use this attribute
   *  with the following SVG elements:Warning: This property
   *  is deprecated. Use clip-path instead.The value auto defines
   *  a clipping path along the bounds of the viewport created
   *  by the given element. The value rect() defines a clipping
   *  rectangle following the following syntax: rect(<top>,
   *  <right>, <bottom>, <left>). The <top> and <bottom> values
   *  specify offsets from the top border edge of the element
   *  viewport, while <right> and <left> specify offsets from
   *  the left border edge of the element viewport.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jun 28, 2022, by
   *  MDN contributors
   */
  clip: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The color-profile attribute
   *  is used to define which color profile a raster image included
   *  through the <image> element should use.Note: As a presentation
   *  attribute, color-profile can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:All
   *  colors are presumed to be defined in the sRGB color space
   *  unless a more precise embedded profile is specified within
   *  content data. For images that do have a profile built
   *  into their data, that profile is used. For images that
   *  do not have a profile, the sRGB profile is used.The source
   *  profile is assumed to be sRGB. This differs from auto
   *  in that it overrides an embedded profile inside an image.A
   *  name corresponding to a defined color profile that is
   *  in the browser's color profile description database. The
   *  browser searches the color profile description database
   *  for a color profile description entry whose name descriptor
   *  matches <name> and uses the last matching entry that is
   *  found. If a match is found, the corresponding profile
   *  overrides an embedded profile inside an image. If no match
   *  is found, then the embedded profile inside the image is
   *  used.An IRI reference to the source color profile. The
   *  referenced color profile overrides an embedded profile
   *  inside the image.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  colorProfile: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The image-rendering attribute provides a hint to the browser
   *  about how to make speed vs. quality tradeoffs as it performs
   *  image processing.The resampling is always done in a truecolor
   *  (e.g., 24-bit) color space even if the original data and/or
   *  the target device is indexed color.Note: As a presentation
   *  attribute, image-rendering can be used as a CSS property.
   *  See the css image-rendering property for more information.You
   *  can use this attribute with the following SVG elements:Indicates
   *  that the user agent shall make appropriate tradeoffs to
   *  balance speed and quality, but quality shall be given
   *  more importance than speed.Indicates that the user agent
   *  shall emphasize rendering speed over quality.Indicates
   *  that the user agent shall emphasize quality over rendering
   *  speed.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  imageRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Image$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Image$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Image$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Image$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Image$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Image$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Image);

/***/ }),

/***/ "./src/lib/components/Line.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Line.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Line is a wrapper for the <line> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/line
 */

var Line = function Line(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("line", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Line.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Line.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linecap attribute is a presentation attribute defining
   *  the shape to be used at the end of open subpaths when
   *  they are stroked.Note: As a presentation attribute stroke-linecap
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:The butt value indicates
   *  that the stroke for each subpath does not extend beyond
   *  its two endpoints. On a zero length subpath, the path
   *  will not be rendered at all.The round value indicates
   *  that at the end of each subpath the stroke will be extended
   *  by a half circle with a diameter equal to the stroke width.
   *  On a zero length subpath, the stroke consists of a full
   *  circle centered at the subpath's point.The square value
   *  indicates that at the end of each subpath the stroke will
   *  be extended by a rectangle with a width equal to half
   *  the width of the stroke and a height equal to the width
   *  of the stroke. On a zero length subpath, the stroke consists
   *  of a square with its width equal to the stroke width,
   *  centered at the subpath's point.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeLinecap: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["butt", "inherit", "round", "square"]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The x1 attribute is used to specify the first x-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the x attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, x1 defines the x coordinate of
   *  the starting point of the line.For <linearGradient>, x1
   *  defines the x coordinate of the starting point of the
   *  gradient vector used to map the gradient stop values.
   *  The exact behavior of this attribute is influenced by
   *  the gradientUnits attributesLast modified: May 13, 2022,
   *  by MDN contributors
   */
  x1: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The x2 attribute is used to specify the second x-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the x attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, x2 defines the x coordinate of
   *  the ending point of the line.For <linearGradient>, x2
   *  defines the x coordinate of the ending point of the gradient
   *  vector used to map the gradient stop values. The exact
   *  behavior of this attribute is influenced by the gradientUnits
   *  attributesLast modified: May 13, 2022, by MDN contributors
   * 
   */
  x2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The y1 attribute is used to specify the first y-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the y attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, y1 defines the y coordinate of
   *  the starting point of the line.For <linearGradient>, y1
   *  defines the y coordinate of the starting point of the
   *  gradient vector used to map the gradient stop values.
   *  The exact behavior of this attribute is influenced by
   *  the gradientUnits attributesLast modified: May 13, 2022,
   *  by MDN contributors
   */
  y1: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The y2 attribute is used to specify the second y-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the y attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, y2 defines the y coordinate of
   *  the ending point of the line.For <linearGradient>, y2
   *  defines the y coordinate of the ending point of the gradient
   *  vector used to map the gradient stop values. The exact
   *  behavior of this attribute is influenced by the gradientUnits
   *  attributesLast modified: May 13, 2022, by MDN contributors
   * 
   */
  y2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Line);

/***/ }),

/***/ "./src/lib/components/LinearGradient.react.js":
/*!****************************************************!*\
  !*** ./src/lib/components/LinearGradient.react.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * LinearGradient is a wrapper for the <linearGradient> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/linearGradient
 */

var LinearGradient = function LinearGradient(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("linearGradient", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

LinearGradient.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
LinearGradient.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The gradientTransform attribute contains the definition of an
   *  optional additional transformation from the gradient coordinate
   *  system onto the target coordinate system (i.e., userSpaceOnUse
   *  or objectBoundingBox). This allows for things such as
   *  skewing the gradient. This additional transformation matrix
   *  is post-multiplied to (i.e., inserted to the right of)
   *  any previously defined transformations, including the
   *  implicit transformation necessary to convert from object
   *  bounding box units to user space.You can use this attribute
   *  with the following SVG elements:A list of transformation
   *  functions specifying some additional transformation from
   *  the gradient coordinate system onto the target coordinate
   *  system.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  gradientTransform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The gradientUnits attribute defines the coordinate system used
   *  for attributes specified on the gradient elements.You
   *  can use this attribute with the following SVG elements:For
   *  <linearGradient>, gradientUnits defines the coordinate
   *  system used for the attributes x1, y1, x2, and y2.
      *     This value indicates that the attributes represent
   *  values in the coordinate system that results from taking
   *  the current user coordinate system in place at the time
   *  when the gradient element is referenced (i.e., the user
   *  coordinate system for the element referencing the gradient
   *  element via a fill or stroke property) and then applying
   *  the transform specified by attribute gradientTransform.
    *       Percentages represent values relative to the current
   *  SVG viewport.
  This value indicates that the user coordinate
   *  system for the attributes is established using the bounding
   *  box of the element to which the gradient is applied and
   *  then applying the transform specified by attribute gradientTransform.Percentages
   *  represent values relative to the bounding box for the
   *  object.With this value and gradientTransform being the
   *  identity matrix, the normal of the linear gradient is
   *  perpendicular to the gradient vector in object bounding
   *  box space (i.e., the abstract coordinate system where
   *  (0,0) is at the top/left of the object bounding box and
   *  (1,1) is at the bottom/right of the object bounding box).
   *  When the object's bounding box is not square, the gradient
   *  normal which is initially perpendicular to the gradient
   *  vector within object bounding box space may render non-perpendicular
   *  relative to the gradient vector in user space. If the
   *  gradient vector is parallel to one of the axes of the
   *  bounding box, the gradient normal will remain perpendicular.
   *  This transformation is due to application of the non-uniform
   *  scaling transformation from bounding box space to user
   *  space.For <radialGradient>, gradientUnits defines the
   *  coordinate system used for the attributes cx, cy, r, fx,
   *  fy, and fr.cx, cy, r, fx, fy, and fr represent values
   *  in the coordinate system that results from taking the
   *  current user coordinate system in place at the time when
   *  the gradient element is referenced (i.e., the user coordinate
   *  system for the element referencing the gradient element
   *  via a fill or stroke property) and then applying the transform
   *  specified by attribute gradientTransform.
    for <radialGradient>:
   *  the user coordinate system for attributes cx, cy, r, fx,
   *  fy, and fr is established using the bounding box of the
   *  element to which the gradient is applied (see Object bounding
   *  box units) and then applying the transform specified by
   *  attribute gradientTransform.
    With this value and
   *  gradientTransform being the identity matrix, the rings
   *  of the radial gradient are circular with respect to the
   *  object bounding box space (i.e., the abstract coordinate
   *  system where (0,0) is at the top/left of the object bounding
   *  box and (1,1) is at the bottom/right of the object bounding
   *  box). When the object's bounding box is not square, the
   *  rings that are conceptually circular within object bounding
   *  box space will render as elliptical due to application
   *  of the non-uniform scaling transformation from bounding
   *  box space to user space.
  Last modified: May 13, 2022,
   *  by MDN contributors
   */
  gradientUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The spreadMethod attribute determines how a shape is filled beyond
   *  the defined edges of a gradient.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the final color of the gradient fills the shape beyond
   *  the gradient's edges.This value indicates that the gradient
   *  repeats in reverse beyond its edges.This value specifies
   *  that the gradient repeats in the original order beyond
   *  its edges.By default, a gradient reaches to the edges
   *  of the shape being filled. To see the effects of this
   *  attribute, you will need to set the size of the gradient
   *  smaller than the shape.In the case of a linear gradient,
   *  the edges may be defined as a rectangle by the x1, x2,
   *  y1 and y2 attributes. In the case of a radial gradient,
   *  the edges may be defined as outer and inner circles by
   *  the cx, cy and r (outer) and fx, fy and fr (inner) attributes.Notice
   *  that the middle third of each gradient is the same. The
   *  outer thirds show the difference between the three spread
   *  methods.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  spreadMethod: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The x1 attribute is used to specify the first x-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the x attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, x1 defines the x coordinate of
   *  the starting point of the line.For <linearGradient>, x1
   *  defines the x coordinate of the starting point of the
   *  gradient vector used to map the gradient stop values.
   *  The exact behavior of this attribute is influenced by
   *  the gradientUnits attributesLast modified: May 13, 2022,
   *  by MDN contributors
   */
  x1: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The x2 attribute is used to specify the second x-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the x attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, x2 defines the x coordinate of
   *  the ending point of the line.For <linearGradient>, x2
   *  defines the x coordinate of the ending point of the gradient
   *  vector used to map the gradient stop values. The exact
   *  behavior of this attribute is influenced by the gradientUnits
   *  attributesLast modified: May 13, 2022, by MDN contributors
   * 
   */
  x2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The y1 attribute is used to specify the first y-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the y attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, y1 defines the y coordinate of
   *  the starting point of the line.For <linearGradient>, y1
   *  defines the y coordinate of the starting point of the
   *  gradient vector used to map the gradient stop values.
   *  The exact behavior of this attribute is influenced by
   *  the gradientUnits attributesLast modified: May 13, 2022,
   *  by MDN contributors
   */
  y1: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The y2 attribute is used to specify the second y-coordinate for
   *  drawing an SVG element that requires more than one coordinate.
   *  Elements that only need one coordinate use the y attribute
   *  instead.You can use this attribute with the following
   *  SVG elements:For <line>, y2 defines the y coordinate of
   *  the ending point of the line.For <linearGradient>, y2
   *  defines the y coordinate of the ending point of the gradient
   *  vector used to map the gradient stop values. The exact
   *  behavior of this attribute is influenced by the gradientUnits
   *  attributesLast modified: May 13, 2022, by MDN contributors
   * 
   */
  y2: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (LinearGradient);

/***/ }),

/***/ "./src/lib/components/Marker.react.js":
/*!********************************************!*\
  !*** ./src/lib/components/Marker.react.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Marker is a wrapper for the <marker> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/marker
 */

var Marker = function Marker(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("marker", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Marker.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Marker.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The clip attribute is a
   *  presentation attribute defining the visible region of
   *  an element.This attribute has the same parameter values
   *  as defined for the css clip property. Unitless values,
   *  which indicate current user coordinates, are permitted
   *  on the coordinate values on the rect(). The value of auto
   *  defines a clipping path along the bounds of the viewport
   *  created by the given element.You can use this attribute
   *  with the following SVG elements:Warning: This property
   *  is deprecated. Use clip-path instead.The value auto defines
   *  a clipping path along the bounds of the viewport created
   *  by the given element. The value rect() defines a clipping
   *  rectangle following the following syntax: rect(<top>,
   *  <right>, <bottom>, <left>). The <top> and <bottom> values
   *  specify offsets from the top border edge of the element
   *  viewport, while <right> and <left> specify offsets from
   *  the left border edge of the element viewport.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jun 28, 2022, by
   *  MDN contributors
   */
  clip: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The markerHeight attribute represents the height of the viewport
   *  into which the <marker> is to be fitted when it is rendered
   *  according to the viewBox and preserveAspectRatio attributes.You
   *  can use this attribute with the following SVG elements:
    *       This value defines either an absolute or a relative
   *  height of the marker.
    Relative values refer to the
   *  height specified via the viewBox and preserveAspectRatio
   *  attributes.
  This value defines the height of the marker
   *  in the units defined by the markerUnits attribute.A value
   *  of zero disables rendering of the element and negative
   *  values are an error.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  markerHeight: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The markerUnits attribute defines the coordinate system for the
   *  markerWidth and markerHeight attributes and the contents
   *  of the <marker>.You can use this attribute with the following
   *  SVG elements:This value specifies that the markerWidth
   *  and markerHeight attributes and the contents of the <marker>
   *  element represent values in the current user coordinate
   *  system in place for the graphic object referencing the
   *  marker (i.e., the user coordinate system for the element
   *  referencing the <marker> element via a marker, marker-start,
   *  marker-mid, or marker-end property).This value specifies
   *  that the markerWidth and markerHeight attributes and the
   *  contents of the <marker> element represent values in a
   *  coordinate system which has a single unit equal the size
   *  in user units of the current stroke width (see the stroke-width
   *  attribute) in place for the graphic object referencing
   *  the marker.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  markerUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The markerWidth attribute represents the width of the viewport
   *  into which the <marker> is to be fitted when it is rendered
   *  according to the viewBox and preserveAspectRatio attributes.You
   *  can use this attribute with the following SVG elements:
    *       This value defines either an absolute or a relative
   *  width of the marker.
    Relative values refer to the
   *  width specified via the viewBox and preserveAspectRatio
   *  attributes.
  This value defines the width of the marker
   *  in the units defined by the markerUnits attribute.A value
   *  of zero disables rendering of the element and negative
   *  values are an error.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  markerWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The orient attribute indicates how a marker is rotated when it
   *  is placed at its position on the shape.You can use this
   *  attribute with the following SVG elements:This value indicates
   *  that the marker is oriented such that its positive x-axis
   *  is pointing in a direction relative to the path at the
   *  position the marker is placed.If placed by marker-start,
   *  the marker is oriented 180° different from the orientation
   *  that would be used if auto where specified. For all other
   *  markers, auto-start-reverse means the same as auto.Note:
   *  This allows a single arrowhead marker to be defined that
   *  can be used for both the start and end of a path, i.e.
   *  which points outwards from both ends.This value indicates
   *  that the marker is oriented such that the specified angle
   *  is that measured between the shape's positive x-axis and
   *  the marker's positive x-axis.Note: For example, if a value
   *  of 45 is given, then the marker's positive x-axis would
   *  be pointing down and right in the shape's coordinate system.This
   *  value indicates an angle in degrees. The marker is oriented
   *  such that the specified angle is that measured between
   *  the shape's positive x-axis and the marker's positive
   *  x-axis.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  orient: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The refX attribute defines the x coordinate of an element's reference
   *  point.You can use this attribute with the following SVG
   *  elements:For <marker>, refX defines the x coordinate of
   *  the marker's reference point, which is to be placed exactly
   *  at the marker's position on the shape.Lengths are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.Percentage values are interpreted as being
   *  a percentage of the viewBox width.Numbers are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the left edge of the shape.The reference point of the
   *  marker is placed at the horizontal center of the shape.The
   *  reference point of the marker is placed at the right edge
   *  of the shape.For <symbol>, refX defines the x coordinate
   *  of the symbol, which is defined by the cumulative effect
   *  of the x attribute and any transformations on the <symbol>
   *  and its host <use> element.Unlike other positioning attributes,
   *  refX is interpreted as being in the coordinate system
   *  of the symbol contents, after application of the viewBox
   *  and preserveAspectRatio attributes. If the attribute is
   *  not specified, no horizontal adjustment is made, and the
   *  left side of the symbol's rectangular viewport region
   *  (regardless of the viewBox coordinate) is positioned at
   *  the x coordinate.Note: For backwards compatibility, the
   *  behavior when refX is not specified on a <symbol> element
   *  is different from when it is specified with a value of
   *  0, and therefore different from the behavior when an equivalent
   *  attribute is not specified on a <marker> element.Lengths
   *  are interpreted as being in the coordinate system of the
   *  marker contents, after application of the viewBox and
   *  preserveAspectRatio attributes.Percentage values are interpreted
   *  as being a percentage of the viewBox width.Numbers are
   *  interpreted as being in the coordinate system of the marker
   *  contents, after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the left edge of the shape.The reference point of the
   *  marker is placed at the horizontal center of the shape.The
   *  reference point of the marker is placed at the right edge
   *  of the shape.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  refX: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The refY attribute defines the y coordinate of an element's reference
   *  point.You can use this attribute with the following SVG
   *  elements:For <marker>, refY defines the y coordinate of
   *  the marker's reference point, which is to be placed exactly
   *  at the marker's position on the shape.Lengths are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.Percentage values are interpreted as being
   *  a percentage of the viewBox height.Numbers are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the top edge of the shape.The reference point of the
   *  marker is placed at the vertical center of the shape.The
   *  reference point of the marker is placed at the bottom
   *  edge of the shape.For <symbol>, refY defines the y coordinate
   *  of the symbol, which is defined by the cumulative effect
   *  of the y attribute and any transformations on the <symbol>
   *  and its host <use> element.Unlike other positioning attributes,
   *  refY is interpreted as being in the coordinate system
   *  of the symbol contents, after application of the viewBox
   *  and preserveAspectRatio attributes. If the attribute is
   *  not specified, no vertical adjustment is made, and the
   *  top side of the symbol's rectangular viewport region (regardless
   *  of the viewBox coordinate) is positioned at the y coordinate.Note:
   *  For backwards compatibility, the behavior when refY is
   *  not specified on a <symbol> element is different from
   *  when it is specified with a value of 0, and therefore
   *  different from the behavior when an equivalent attribute
   *  is not specified on a <marker> element.Lengths are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.Percentage values are interpreted as being
   *  a percentage of the viewBox height.Numbers are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the top edge of the shape.The reference point of the
   *  marker is placed at the vertical center of the shape.The
   *  reference point of the marker is placed at the bottom
   *  edge of the shape.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  refY: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The viewBox attribute defines the position and dimension, in
   *  user space, of an SVG viewport.The value of the viewBox
   *  attribute is a list of four numbers: min-x, min-y, width
   *  and height. The numbers, which are separated by whitespace
   *  and/or a comma, specify a rectangle in user space which
   *  is mapped to the bounds of the viewport established for
   *  the associated SVG element (not the browser viewport).You
   *  can use this attribute with the following SVG elements:The
   *  exact effect of this attribute is influenced by the preserveAspectRatio
   *  attribute.Note: Values for width or height lower or equal
   *  to 0 disable rendering of the element.For <marker>, viewBox
   *  defines the position and dimension for the content of
   *  the <marker> element.For <pattern>, viewBox defines the
   *  position and dimension for the content of the pattern
   *  tile.For <svg>, viewBox defines the position and dimension
   *  for the content of the <svg> element.For <symbol>, viewBox
   *  defines the position and dimension for the content of
   *  the <symbol> element.For <view>, viewBox defines the position
   *  and dimension for the content of the <view> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  viewBox: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Marker);

/***/ }),

/***/ "./src/lib/components/Mask.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Mask.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Mask$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Mask is a wrapper for the <mask> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/mask
 */

var Mask = function Mask(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("mask", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Mask.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Mask.propTypes = (_Mask$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The maskContentUnits attribute indicates which coordinate system
   *  to use for the contents of the <mask> element.You can
   *  use this attribute with the following SVG elements:For
   *  <mask>, maskContentUnits defines the coordinate system
   *  in use for the content of the element.This value indicates
   *  that all coordinates inside the <mask> element refer to
   *  the user coordinate system as defined when the mask was
   *  created.This value indicates that all coordinates inside
   *  the <mask> element are relative to the bounding box of
   *  the element the mask is applied to. A bounding box could
   *  be considered the same as if the content of the <mask>
   *  were bound to a "0 0 1 1" viewbox.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  maskContentUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The maskUnits attribute indicates which coordinate system to
   *  use for the geometry properties of the <mask> element.You
   *  can use this attribute with the following SVG elements:For
   *  <mask>, maskUnits defines the coordinate system in use
   *  for the geometry attributes (x, y, width and height) of
   *  the element.This value indicates that all coordinates
   *  for the geometry attributes refer to the user coordinate
   *  system as defined when the mask was created.This value
   *  indicates that all coordinates for the geometry attributes
   *  represent fractions or percentages of the bounding box
   *  of the element to which the mask is applied. A bounding
   *  box could be considered the same as if the content of
   *  the <mask> were bound to a "0 0 1 1" viewbox.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  maskUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Mask$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Mask$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Mask$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Mask$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Mask$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Mask$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Mask);

/***/ }),

/***/ "./src/lib/components/Metadata.react.js":
/*!**********************************************!*\
  !*** ./src/lib/components/Metadata.react.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Metadata is a wrapper for the <metadata> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/metadata
 */

var Metadata = function Metadata(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("metadata", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Metadata.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Metadata.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Metadata);

/***/ }),

/***/ "./src/lib/components/Path.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Path.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Path$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Path is a wrapper for the <path> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/path
 */

var Path = function Path(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("path", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Path.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Path.propTypes = (_Path$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The d attribute defines a path to be drawn.
  A path definition
   *  is a list of path commands where each command is composed
   *  of a command letter and numbers that represent the command
   *  parameters.
  The commands are detailed below.
  You can
   *  use this attribute with the following SVG elements: <path>,
   *  <glyph>, <missing-glyph>.d is a presentation attribute,
   *  and hence can also be used as a CSS property.For <path>,
   *  d is a string containing a series of path commands that
   *  define the path to be drawn.Warning: As of SVG2 <glyph>
   *  is deprecated and shouldn't be used.For <glyph>, d is
   *  a string containing a series of path commands that define
   *  the outline shape of the glyph.Note: The point of origin
   *  (the coordinate 0,0) is usually the upper left corner
   *  of the context. However the <glyph> element has its origin
   *  in the bottom left corner of its letterbox.Warning: As
   *  of SVG2 <missing-glyph> is deprecated and shouldn't be
   *  used.For <missing-glyph>, d is a string containing a series
   *  of path commands that define the outline shape of the
   *  glyph.
  d is a presentation attribute, and hence can
   *  be also be modified using CSS.
  The property takes either
   *  path() or none.
  The example below shows how you might
   *  apply a new path on hover over an element.
  The new path
   *  is the same as the old one, but adds a line across the
   *  heart.
  Path commands are instructions that define a path
   *  to be drawn. Each command is composed of a command letter
   *  and numbers that represent the command parameters.SVG
   *  defines 6 types of path commands, for a total of 20 commands:Note:
   *  Commands are case-sensitive. An upper-case command specifies
   *  absolute coordinates, while a lower-case command specifies
   *  coordinates relative to the current position.It is always
   *  possible to specify a negative value as an argument to
   *  a command:MoveTo instructions can be thought of as picking
   *  up the drawing instrument, and setting it down somewhere
   *  else—in other words, moving the current point (Po; {xo,
   *  yo}). There is no line drawn between Po and the new current
   *  point (Pn; {xn, yn}).
        Move the current point
   *  to the coordinate
        x,y. Any subsequent coordinate
   *  pair(s) are interpreted as parameter(s)
        for
   *  implicit absolute LineTo (L) command(s) (see below).
    *         Formula: Pn = {x, y}
        Move the current
   *  point by shifting the last known position of
      
   *   the path by dx along the x-axis and by
        dy along
   *  the y-axis. Any subsequent coordinate
        pair(s)
   *  are interpreted as parameter(s) for implicit relative
   *  LineTo
        (l) command(s) (see below).
      
    *           Formula: Pn = {xo
        + dx, yo + dy}
     *        LineTo instructions draw a straight line from the
   *  current point (Po; {xo, yo}) to the end point (Pn; {xn,
   *  yn}), based on the parameters specified. The end point
   *  (Pn) then becomes the current point for the next command
   *  (Po′).
        Draw a line from the current point to
   *  the
        end point specified by x,y. Any subsequent
   *  coordinate pair(s) are interpreted as parameter(s)
      *         for implicit absolute LineTo (L) command(s).
     *        
        Formula: Po′ =
        Pn = {x, y}
    *         
        Draw a line from the current point to
   *  the
        end point, which is the current point shifted
   *  by
        dx along the x-axis and
        dy along
   *  the y-axis. Any subsequent coordinate
        pair(s)
   *  are interpreted as parameter(s) for implicit relative
   *  LineTo
        (l) command(s) (see below).
      
    *           Formula: Po′ =
        Pn = {xo +
      
   *   dx, yo + dy}
      
        Draw a horizontal line
   *  from the current point to the
        end point, which
   *  is specified by the
        x parameter and the current
   *  point's
        y coordinate. Any subsequent value(s)
   *  are interpreted as
        parameter(s) for implicit
   *  absolute horizontal LineTo (H)
        command(s).
    *         
        Formula: Po′ =
        Pn = {x, yo}
    *         
        Draw a horizontal line from the current
   *  point to the
        end point, which is specified by
   *  the
        current point shifted by dx along the
     *          x-axis and the current point's y coordinate. Any
    *           subsequent value(s) are interpreted as parameter(s)
   *  for implicit
        relative horizontal LineTo (h)
   *  command(s).
      
        Formula: Po′ =
     
   *    Pn = {xo +
        dx, yo}
      
        Draw
   *  a vertical line from the current point to the
     
   *    end point, which is specified by the
        y parameter
   *  and the current point's
        x coordinate. Any subsequent
   *  values are interpreted as
        parameters for implicit
   *  absolute vertical LineTo (V)
        command(s).
      *       
        Formula: Po′ =
        Pn = {xo, y}
    *         
        Draw a vertical line from the current
   *  point to the
        end point, which is specified by
   *  the
        current point shifted by dy along the
     *          y-axis and the current point's x coordinate. Any
    *           subsequent value(s) are interpreted as parameter(s)
   *  for implicit
        relative vertical LineTo (v) command(s).
    *         
        Formula: Po′ =
        Pn = {xo, yo
   *  + dy}
      Cubic Bézier curves are smooth curve definitions
   *  using four points:(Po = {xo, yo})(Pn = {xn, yn})
  
   *   (Pcs = {xcs, ycs})
    (controls curvature near the
   *  start of the curve)
  
    (Pce = {xce, yce})
       *    (controls curvature near the end of the curve)
  After
   *  drawing, the end point (Pn) becomes the current point
   *  for the next command (Po′).
        Draw a cubic Bézier
   *  curve from the current point to the
        end point
   *  specified by x,y. The start control point is specified
   *  by
        x1,y1 and the end control point is
   
   *      specified by x2,y2. Any subsequent triplet(s) of coordinate
   *  pairs are interpreted as
        parameter(s) for implicit
   *  absolute cubic Bézier curve (C)
        command(s).
    *         
        Draw a cubic Bézier curve from the current
   *  point to the
        end point, which is the current
   *  point shifted by
        dx along the x-axis and
      *         dy along the y-axis. The
        start control
   *  point is the current point (starting
        point of
   *  the curve) shifted by dx1 along the
        x-axis and
   *  dy1 along the y-axis. The
        end control point
   *  is the current point (starting
        point of the
   *  curve) shifted by dx2 along the
        x-axis and dy2
   *  along the y-axis. Any
        subsequent triplet(s)
   *  of coordinate pairs are interpreted as
        parameter(s)
   *  for implicit relative cubic Bézier curve (c)
      
   *   command(s).
      Quadratic Bézier curves are smooth
   *  curve definitions using three points:Po = {xo, yo}Pn =
   *  {xn, yn}
    Pc = {xc, yc}
    (controls curvature)
    *     After drawing, the end point (Pn) becomes the current
   *  point for the next command (Po′).
        Draw a quadratic
   *  Bézier curve from the current point to the
        end
   *  point specified by x,y. The control point is specified
   *  by
        x1,y1. Any subsequent pair(s) of coordinate
   *  pairs are interpreted as
        parameter(s) for implicit
   *  absolute quadratic Bézier curve
        (Q) command(s).
    *         
        Draw a quadratic Bézier curve from the
   *  current point to the
        end point, which is the
   *  current point shifted by
        dx along the x-axis
   *  and
        dy along the y-axis. The
        control
   *  point is the current point (starting point
        of
   *  the curve) shifted by dx1 along the x-axis
        and
   *  dy1 along the y-axis. Any subsequent
        pair(s)
   *  of coordinate pairs are interpreted as parameter(s) for
    *           implicit relative quadratic Bézier curve (q)
   *  command(s).
      
        Draw a smooth quadratic
   *  Bézier curve from the
        current point to the end
   *  point specified by
        x,y. The control point is
   *  a reflection of the
        control point of the previous
   *  curve command. If the previous
        command wasn't
   *  a quadratic Bézier curve, the control point is
    
   *     the same as the curve starting point (current point).
   *  Any
        subsequent coordinate pair(s) are interpreted
   *  as parameter(s) for
        implicit absolute smooth
   *  quadratic Bézier curve (T)
        command(s).
  
   *     
        Draw a smooth quadratic Bézier curve from
   *  the
        current point to the end point, which is
   *  the
        current point shifted by dx along the
     *          x-axis and dy along the y-axis. The
       
   *  control point is a reflection of the
        control
   *  point of the previous curve command. If the previous
    *           command wasn't a quadratic Bézier curve, the
   *  control point is
        the same as the curve starting
   *  point (current point). Any
        subsequent coordinate
   *  pair(s) are interpreted as parameter(s) for
       
   *  implicit relative smooth quadratic Bézier curve (t)
     *          command(s).
      Elliptical arc curves are
   *  curves defined as a portion of an ellipse. It is sometimes
   *  easier to draw highly regular curves with an elliptical
   *  arc than with a Bézier curve.
        Draw an Arc curve
   *  from the current point to the coordinate
        x,y.
   *  The center of the ellipse used to draw the arc is determined
    *           automatically based on the other parameters of
   *  the command:
      
        Draw an Arc curve from
   *  the current point to a point for which
        coordinates
   *  are those of the current point shifted by
        dx
   *  along the x-axis and
        dy along the y-axis. The
   *  center of the ellipse
        used to draw the arc is
   *  determined automatically based on the other
       
   *  parameters of the command:
      ClosePath instructions
   *  draw a straight line from the current position to the
   *  first point in the path.Note: The appearance of a shape
   *  closed with ClosePath may be different to that of one
   *  closed by drawing a line to the origin, using one of the
   *  other commands, because the line ends are joined together
   *  (according to the stroke-linejoin setting), rather than
   *  just being placed at the same coordinates.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 15, 2022, by MDN contributors
   * 
   */
  d: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fill-rule attribute is a presentation attribute defining
   *  the algorithm to use to determine the inside part of a
   *  shape.Note: As a presentation attribute, fill-rule can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:The fill-rule attribute provides
   *  two options for how the inside (that is, the area to be
   *  filled) of a shape is determined:The value nonzero determines
   *  the "insideness" of a point in the shape by drawing a
   *  ray from that point to infinity in any direction, and
   *  then examining the places where a segment of the shape
   *  crosses the ray. Starting with a count of zero, add one
   *  each time a path segment crosses the ray from left to
   *  right and subtract one each time a path segment crosses
   *  the ray from right to left. After counting the crossings,
   *  if the result is zero then the point is outside the path.
   *  Otherwise, it is inside.The value evenodd determines the
   *  "insideness" of a point in the shape by drawing a ray
   *  from that point to infinity in any direction and counting
   *  the number of path segments from the given shape that
   *  the ray crosses. If this number is odd, the point is inside;
   *  if even, the point is outside.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["evenodd", "inherit", "nonzero"]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linecap attribute is a presentation attribute defining
   *  the shape to be used at the end of open subpaths when
   *  they are stroked.Note: As a presentation attribute stroke-linecap
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:The butt value indicates
   *  that the stroke for each subpath does not extend beyond
   *  its two endpoints. On a zero length subpath, the path
   *  will not be rendered at all.The round value indicates
   *  that at the end of each subpath the stroke will be extended
   *  by a half circle with a diameter equal to the stroke width.
   *  On a zero length subpath, the stroke consists of a full
   *  circle centered at the subpath's point.The square value
   *  indicates that at the end of each subpath the stroke will
   *  be extended by a rectangle with a width equal to half
   *  the width of the stroke and a height equal to the width
   *  of the stroke. On a zero length subpath, the stroke consists
   *  of a square with its width equal to the stroke width,
   *  centered at the subpath's point.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeLinecap: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["butt", "inherit", "round", "square"]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  « SVG Attribute reference homeThe clip-rule attribute only applies
   *  to graphics elements that are contained within a <clipPath>
   *  element. The clip-rule attribute basically works as the
   *  fill-rule attribute, except that it applies to <clipPath>
   *  definitions.The following fragment of code will cause
   *  an evenodd clipping rule to be applied to the clipping
   *  path because clip-rule is specified on the <path> element
   *  that defines the clipping shape:whereas the following
   *  fragment of code will not cause an evenodd clipping rule
   *  to be applied because the clip-rule is specified on the
   *  referencing element, not on the object defining the clipping
   *  shape:As a presentation attribute, it also can be used
   *  as a property directly inside a CSS stylesheetSee description
   *  of fill-rule property.See description of fill-rule property.The
   *  following elements can use the clip-rule attribute, but
   *  only if they are inside a <clipPath> element.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 17, 2022, by
   *  MDN contributors
   */
  clipRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])
}, _defineProperty(_Path$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Path$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Path$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Path$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Path);

/***/ }),

/***/ "./src/lib/components/Pattern.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/Pattern.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Pattern$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Pattern is a wrapper for the <pattern> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/pattern
 */

var Pattern = function Pattern(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("pattern", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Pattern.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Pattern.propTypes = (_Pattern$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The clip attribute is a
   *  presentation attribute defining the visible region of
   *  an element.This attribute has the same parameter values
   *  as defined for the css clip property. Unitless values,
   *  which indicate current user coordinates, are permitted
   *  on the coordinate values on the rect(). The value of auto
   *  defines a clipping path along the bounds of the viewport
   *  created by the given element.You can use this attribute
   *  with the following SVG elements:Warning: This property
   *  is deprecated. Use clip-path instead.The value auto defines
   *  a clipping path along the bounds of the viewport created
   *  by the given element. The value rect() defines a clipping
   *  rectangle following the following syntax: rect(<top>,
   *  <right>, <bottom>, <left>). The <top> and <bottom> values
   *  specify offsets from the top border edge of the element
   *  viewport, while <right> and <left> specify offsets from
   *  the left border edge of the element viewport.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jun 28, 2022, by
   *  MDN contributors
   */
  clip: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The patternContentUnits attribute indicates which coordinate
   *  system to use for the contents of the <pattern> element.Note:
   *  That this attribute has no effect if attribute viewBox
   *  is specified on the <pattern> element.You can use this
   *  attribute with the following SVG elements:For <pattern>,
   *  patternContentUnits defines the coordinate system in use
   *  for the content of the element.This value indicates that
   *  all coordinates inside the <pattern> element refer to
   *  the user coordinate system as defined when the pattern
   *  tile was created.This value indicates that all coordinates
   *  inside the <pattern> element are relative to the bounding
   *  box of the element the pattern is applied to. A bounding
   *  box could be considered the same as if the content of
   *  the <pattern> were bound to a "0 0 1 1" viewbox for a
   *  pattern tile of width and height of 100%.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  patternContentUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The patternTransform attribute defines a list of transform definitions
   *  that are applied to a pattern tile.You can use this attribute
   *  with the following SVG elements:For <pattern>, patternTransform
   *  defines a list of transform definitions that are applied
   *  to a pattern tile.Note: As of SVG2, it is also allowed
   *  to use the CSS transform property. However, the current
   *  state of implementation isn't very good. For backward
   *  compatibility reason, it is highly suggested to keep using
   *  the patternTransform attribute.To know more about the
   *  definition of transform functions, see the transform attribute
   *  definition.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  patternTransform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The patternUnits attribute indicates which coordinate system
   *  to use for the geometry properties of the <pattern> element.You
   *  can use this attribute with the following SVG elements:For
   *  <pattern>, patternUnits defines the coordinate system
   *  in use for the geometry properties (x, y, width and height)
   *  of the element.This value indicates that all coordinates
   *  for the geometry properties refer to the user coordinate
   *  system as defined when the pattern was applied.This value
   *  indicates that all coordinates for the geometry properties
   *  represent fractions or percentages of the bounding box
   *  of the element to which the pattern is applied. A bounding
   *  box could be considered the same as if the content of
   *  the <pattern> were bound to a "0 0 1 1" viewbox.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  patternUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The viewBox attribute defines the position and dimension, in
   *  user space, of an SVG viewport.The value of the viewBox
   *  attribute is a list of four numbers: min-x, min-y, width
   *  and height. The numbers, which are separated by whitespace
   *  and/or a comma, specify a rectangle in user space which
   *  is mapped to the bounds of the viewport established for
   *  the associated SVG element (not the browser viewport).You
   *  can use this attribute with the following SVG elements:The
   *  exact effect of this attribute is influenced by the preserveAspectRatio
   *  attribute.Note: Values for width or height lower or equal
   *  to 0 disable rendering of the element.For <marker>, viewBox
   *  defines the position and dimension for the content of
   *  the <marker> element.For <pattern>, viewBox defines the
   *  position and dimension for the content of the pattern
   *  tile.For <svg>, viewBox defines the position and dimension
   *  for the content of the <svg> element.For <symbol>, viewBox
   *  defines the position and dimension for the content of
   *  the <symbol> element.For <view>, viewBox defines the position
   *  and dimension for the content of the <view> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  viewBox: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Pattern$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Pattern$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Pattern$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Pattern$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Pattern$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Pattern$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Pattern);

/***/ }),

/***/ "./src/lib/components/Polygon.react.js":
/*!*********************************************!*\
  !*** ./src/lib/components/Polygon.react.js ***!
  \*********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Polygon$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Polygon is a wrapper for the <polygon> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polygon
 */

var Polygon = function Polygon(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("polygon", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Polygon.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Polygon.propTypes = (_Polygon$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fill-rule attribute is a presentation attribute defining
   *  the algorithm to use to determine the inside part of a
   *  shape.Note: As a presentation attribute, fill-rule can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:The fill-rule attribute provides
   *  two options for how the inside (that is, the area to be
   *  filled) of a shape is determined:The value nonzero determines
   *  the "insideness" of a point in the shape by drawing a
   *  ray from that point to infinity in any direction, and
   *  then examining the places where a segment of the shape
   *  crosses the ray. Starting with a count of zero, add one
   *  each time a path segment crosses the ray from left to
   *  right and subtract one each time a path segment crosses
   *  the ray from right to left. After counting the crossings,
   *  if the result is zero then the point is outside the path.
   *  Otherwise, it is inside.The value evenodd determines the
   *  "insideness" of a point in the shape by drawing a ray
   *  from that point to infinity in any direction and counting
   *  the number of path segments from the given shape that
   *  the ray crosses. If this number is odd, the point is inside;
   *  if even, the point is outside.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["evenodd", "inherit", "nonzero"]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The points attribute defines a list of points. Each point is
   *  defined by a pair of number representing a X and a Y coordinate
   *  in the user coordinate system. If the attribute contains
   *  an odd number of coordinates, the last one will be ignored.You
   *  can use this attribute with the following SVG elements:For
   *  <polyline>, points defines a list of points, each representing
   *  a vertex of the line to be drawn. Each point is define
   *  by a X and Y coordinate in the user coordinate system.Note:
   *  A polyline is an open shape, meaning the last point is
   *  not connected to the first point.For <polygon>, points
   *  defines a list of points, each representing a vertex of
   *  the shape to be drawn. Each point is define by a X and
   *  Y coordinate in the user coordinate system.Note: A polygon
   *  is a closed shape, meaning the last point is connected
   *  to the first point.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  points: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])
}, _defineProperty(_Polygon$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Polygon$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Polygon$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Polygon$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Polygon);

/***/ }),

/***/ "./src/lib/components/Polyline.react.js":
/*!**********************************************!*\
  !*** ./src/lib/components/Polyline.react.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Polyline$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Polyline is a wrapper for the <polyline> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/polyline
 */

var Polyline = function Polyline(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("polyline", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Polyline.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Polyline.propTypes = (_Polyline$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fill-rule attribute is a presentation attribute defining
   *  the algorithm to use to determine the inside part of a
   *  shape.Note: As a presentation attribute, fill-rule can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:The fill-rule attribute provides
   *  two options for how the inside (that is, the area to be
   *  filled) of a shape is determined:The value nonzero determines
   *  the "insideness" of a point in the shape by drawing a
   *  ray from that point to infinity in any direction, and
   *  then examining the places where a segment of the shape
   *  crosses the ray. Starting with a count of zero, add one
   *  each time a path segment crosses the ray from left to
   *  right and subtract one each time a path segment crosses
   *  the ray from right to left. After counting the crossings,
   *  if the result is zero then the point is outside the path.
   *  Otherwise, it is inside.The value evenodd determines the
   *  "insideness" of a point in the shape by drawing a ray
   *  from that point to infinity in any direction and counting
   *  the number of path segments from the given shape that
   *  the ray crosses. If this number is odd, the point is inside;
   *  if even, the point is outside.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["evenodd", "inherit", "nonzero"]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The points attribute defines a list of points. Each point is
   *  defined by a pair of number representing a X and a Y coordinate
   *  in the user coordinate system. If the attribute contains
   *  an odd number of coordinates, the last one will be ignored.You
   *  can use this attribute with the following SVG elements:For
   *  <polyline>, points defines a list of points, each representing
   *  a vertex of the line to be drawn. Each point is define
   *  by a X and Y coordinate in the user coordinate system.Note:
   *  A polyline is an open shape, meaning the last point is
   *  not connected to the first point.For <polygon>, points
   *  defines a list of points, each representing a vertex of
   *  the shape to be drawn. Each point is define by a X and
   *  Y coordinate in the user coordinate system.Note: A polygon
   *  is a closed shape, meaning the last point is connected
   *  to the first point.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  points: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linecap attribute is a presentation attribute defining
   *  the shape to be used at the end of open subpaths when
   *  they are stroked.Note: As a presentation attribute stroke-linecap
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:The butt value indicates
   *  that the stroke for each subpath does not extend beyond
   *  its two endpoints. On a zero length subpath, the path
   *  will not be rendered at all.The round value indicates
   *  that at the end of each subpath the stroke will be extended
   *  by a half circle with a diameter equal to the stroke width.
   *  On a zero length subpath, the stroke consists of a full
   *  circle centered at the subpath's point.The square value
   *  indicates that at the end of each subpath the stroke will
   *  be extended by a rectangle with a width equal to half
   *  the width of the stroke and a height equal to the width
   *  of the stroke. On a zero length subpath, the stroke consists
   *  of a square with its width equal to the stroke width,
   *  centered at the subpath's point.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeLinecap: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["butt", "inherit", "round", "square"]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])
}, _defineProperty(_Polyline$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Polyline$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Polyline$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Polyline$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Polyline);

/***/ }),

/***/ "./src/lib/components/RadialGradient.react.js":
/*!****************************************************!*\
  !*** ./src/lib/components/RadialGradient.react.js ***!
  \****************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * RadialGradient is a wrapper for the <radialGradient> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/radialGradient
 */

var RadialGradient = function RadialGradient(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("radialGradient", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

RadialGradient.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
RadialGradient.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The cx attribute define the x-axis coordinate of a center point.You
   *  can use this attribute with the following SVG elements:For
   *  <circle>, cx defines the x-axis coordinate of the center
   *  of the shape.Note: Starting with SVG2 cx, is a Geometry
   *  Property, meaning this attribute can also be used as CSS
   *  property for circles.For <ellipse>, cx defines the x-axis
   *  coordinate of the center of the shape.Note: Starting with
   *  SVG2 cx, is a Geometry Property, meaning this attribute
   *  can also be used as CSS property for ellipses.For <radialGradient>,
   *  cx defines the x-axis coordinate of the end circle for
   *  the radial gradient.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  cx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The cy attribute define the y-axis coordinate of a center point.You
   *  can use this attribute with the following SVG elements:For
   *  <circle>, cy defines the y-axis coordinate of the center
   *  of the shape.Note: Starting with SVG2, cy is a Geometry
   *  Property meaning this attribute can also be used as a
   *  CSS property for circles.For <ellipse>, cy defines the
   *  y-axis coordinate of the center of the shape.Note: Starting
   *  with SVG2, cy is a Geometry Property meaning this attribute
   *  can also be used as a CSS property for ellipses.For <radialGradient>,
   *  cy defines the y-axis coordinate of the end circle for
   *  the radial gradient.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  cy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fx attribute defines the x-axis coordinate of the focal point
   *  for a radial gradient.You can use this attribute with
   *  the following SVG elements:BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fy attribute defines the y-axis coordinate of the focal point
   *  for a radial gradient.You can use this attribute with
   *  the following SVG elements:BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The gradientTransform attribute contains the definition of an
   *  optional additional transformation from the gradient coordinate
   *  system onto the target coordinate system (i.e., userSpaceOnUse
   *  or objectBoundingBox). This allows for things such as
   *  skewing the gradient. This additional transformation matrix
   *  is post-multiplied to (i.e., inserted to the right of)
   *  any previously defined transformations, including the
   *  implicit transformation necessary to convert from object
   *  bounding box units to user space.You can use this attribute
   *  with the following SVG elements:A list of transformation
   *  functions specifying some additional transformation from
   *  the gradient coordinate system onto the target coordinate
   *  system.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  gradientTransform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The gradientUnits attribute defines the coordinate system used
   *  for attributes specified on the gradient elements.You
   *  can use this attribute with the following SVG elements:For
   *  <linearGradient>, gradientUnits defines the coordinate
   *  system used for the attributes x1, y1, x2, and y2.
      *     This value indicates that the attributes represent
   *  values in the coordinate system that results from taking
   *  the current user coordinate system in place at the time
   *  when the gradient element is referenced (i.e., the user
   *  coordinate system for the element referencing the gradient
   *  element via a fill or stroke property) and then applying
   *  the transform specified by attribute gradientTransform.
    *       Percentages represent values relative to the current
   *  SVG viewport.
  This value indicates that the user coordinate
   *  system for the attributes is established using the bounding
   *  box of the element to which the gradient is applied and
   *  then applying the transform specified by attribute gradientTransform.Percentages
   *  represent values relative to the bounding box for the
   *  object.With this value and gradientTransform being the
   *  identity matrix, the normal of the linear gradient is
   *  perpendicular to the gradient vector in object bounding
   *  box space (i.e., the abstract coordinate system where
   *  (0,0) is at the top/left of the object bounding box and
   *  (1,1) is at the bottom/right of the object bounding box).
   *  When the object's bounding box is not square, the gradient
   *  normal which is initially perpendicular to the gradient
   *  vector within object bounding box space may render non-perpendicular
   *  relative to the gradient vector in user space. If the
   *  gradient vector is parallel to one of the axes of the
   *  bounding box, the gradient normal will remain perpendicular.
   *  This transformation is due to application of the non-uniform
   *  scaling transformation from bounding box space to user
   *  space.For <radialGradient>, gradientUnits defines the
   *  coordinate system used for the attributes cx, cy, r, fx,
   *  fy, and fr.cx, cy, r, fx, fy, and fr represent values
   *  in the coordinate system that results from taking the
   *  current user coordinate system in place at the time when
   *  the gradient element is referenced (i.e., the user coordinate
   *  system for the element referencing the gradient element
   *  via a fill or stroke property) and then applying the transform
   *  specified by attribute gradientTransform.
    for <radialGradient>:
   *  the user coordinate system for attributes cx, cy, r, fx,
   *  fy, and fr is established using the bounding box of the
   *  element to which the gradient is applied (see Object bounding
   *  box units) and then applying the transform specified by
   *  attribute gradientTransform.
    With this value and
   *  gradientTransform being the identity matrix, the rings
   *  of the radial gradient are circular with respect to the
   *  object bounding box space (i.e., the abstract coordinate
   *  system where (0,0) is at the top/left of the object bounding
   *  box and (1,1) is at the bottom/right of the object bounding
   *  box). When the object's bounding box is not square, the
   *  rings that are conceptually circular within object bounding
   *  box space will render as elliptical due to application
   *  of the non-uniform scaling transformation from bounding
   *  box space to user space.
  Last modified: May 13, 2022,
   *  by MDN contributors
   */
  gradientUnits: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The r attribute defines the radius of a circle.You can use this
   *  attribute with the following SVG elements:For <circle>,
   *  r defines the radius of the circle and therefor its size.
   *  With a value lower or equal to zero the circle won't be
   *  drawn at all.Note: Starting with SVG2, r is a Geometry
   *  Property meaning this attribute can also be used as a
   *  CSS property for circles.For <radialGradient>, r defines
   *  the radius of the end circle for the radial gradient.The
   *  gradient will be drawn such that the 100% gradient stop
   *  is mapped to the perimeter of this end circle. A value
   *  of lower or equal to zero will cause the area to be painted
   *  as a single color using the color and opacity of the last
   *  gradient <stop>.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  r: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The spreadMethod attribute determines how a shape is filled beyond
   *  the defined edges of a gradient.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the final color of the gradient fills the shape beyond
   *  the gradient's edges.This value indicates that the gradient
   *  repeats in reverse beyond its edges.This value specifies
   *  that the gradient repeats in the original order beyond
   *  its edges.By default, a gradient reaches to the edges
   *  of the shape being filled. To see the effects of this
   *  attribute, you will need to set the size of the gradient
   *  smaller than the shape.In the case of a linear gradient,
   *  the edges may be defined as a rectangle by the x1, x2,
   *  y1 and y2 attributes. In the case of a radial gradient,
   *  the edges may be defined as outer and inner circles by
   *  the cx, cy and r (outer) and fx, fy and fr (inner) attributes.Notice
   *  that the middle third of each gradient is the same. The
   *  outer thirds show the difference between the three spread
   *  methods.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  spreadMethod: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (RadialGradient);

/***/ }),

/***/ "./src/lib/components/Rect.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Rect.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Rect$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Rect is a wrapper for the <rect> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/rect
 */

var Rect = function Rect(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("rect", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Rect.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Rect.propTypes = (_Rect$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The marker-end attribute defines the arrowhead or polymarker
   *  that will be drawn at the final vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-end
   *  is only rendered on the final vertex of the path data.Note:
   *  As a presentation attribute, marker-end can be used as
   *  a CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the final vertex.This value is a reference to
   *  a <marker> element, which will be drawn at the final vertex.
   *  If the reference is not valid, then no marker will be
   *  drawn.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  markerEnd: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-mid attribute defines the arrowhead or polymarker
   *  that will be drawn at all interior vertices of the given
   *  shape.The marker is rendered on every vertex other than
   *  the first and last vertices of the path data.Note: As
   *  a presentation attribute, marker-mid can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Indicates that no marker symbol shall be
   *  drawn at the given vertices.This value is a reference
   *  to a <marker> element, which will be drawn at the given
   *  vertices. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerMid: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The marker-start attribute defines the arrowhead or polymarker
   *  that will be drawn at the first vertex of the given shape.For
   *  all shape elements, except <polyline> and <path>, the
   *  last vertex is the same as the first vertex. In this case,
   *  if the value of marker-start and marker-end are both not
   *  none, then two markers will be rendered on that final
   *  vertex. For <path> elements, for each closed subpath,
   *  the last vertex is the same as the first vertex. marker-start
   *  is only rendered on the first vertex of the path data.Note:
   *  As a presentation attribute, marker-start can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:Indicates that no marker symbol
   *  shall be drawn at the first vertex.This value is a reference
   *  to a <marker> element, which will be drawn at the first
   *  vertex. If the reference is not valid, then no marker
   *  will be drawn.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  markerStart: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pathLength attribute lets authors specify a total length
   *  for the path, in user units. This value is then used to
   *  calibrate the browser's distance calculations with those
   *  of the author, by scaling all distance computations using
   *  the ratio pathLength/(computed value of path length).This
   *  can affect the actual rendered lengths of paths; including
   *  text paths, animation paths, and various stroke operations.
   *  Basically, all computations that require the length of
   *  the path. stroke-dasharray, for example, will assume the
   *  start of the path being 0 and the end point the value
   *  defined in the pathLength attribute.You can use this attribute
   *  with the following SVG elements:For <circle>, pathLength
   *  lets authors specify a total length for the circle, in
   *  user units.For <ellipse>, pathLength lets authors specify
   *  a total length for the ellipse, in user units.For <line>,
   *  pathLength lets authors specify a total length for the
   *  line, in user units.For <path>, pathLength lets authors
   *  specify a total length for the path, in user units.For
   *  <polygon>, pathLength lets authors specify a total length
   *  for the shape, in user units.For <polyline>, pathLength
   *  lets authors specify a total length for the shape, in
   *  user units.For <rect>, pathLength lets authors specify
   *  a total length for the rectangle, in user units.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  pathLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x border radius
   */
  rx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y border radius
   */
  ry: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The shape-rendering attribute provides hints to the renderer
   *  about what tradeoffs to make when rendering shapes like
   *  paths, circles, or rectangles.Note: As a presentation
   *  attribute, shape-rendering can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value indicates that the user agent shall make appropriate
   *  tradeoffs to balance speed, crisp edges and geometric
   *  precision, but with geometric precision given more importance
   *  than speed and crisp edges.This value indicates that the
   *  user agent shall emphasize rendering speed over geometric
   *  precision and crisp edges. This option will sometimes
   *  cause the user agent to turn off shape anti-aliasing.This
   *  value indicates that the user agent shall attempt to emphasize
   *  the contrast between clean edges of artwork over rendering
   *  speed and geometric precision. To achieve crisp edges,
   *  the user agent might turn off anti-aliasing for all lines
   *  and curves or possibly just for straight lines which are
   *  close to vertical or horizontal. Also, the user agent
   *  might adjust line positions and line widths to align edges
   *  with device pixels.Indicates that the user agent shall
   *  emphasize geometric precision over speed and crisp edges.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  shapeRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Rect$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Rect$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Rect$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Rect$propTypes, "width", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Rect$propTypes, "height", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Rect$propTypes, "rx", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Rect$propTypes, "ry", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Rect$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Rect$propTypes, "stroke", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Rect$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Rect$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Rect$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Rect);

/***/ }),

/***/ "./src/lib/components/Stop.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Stop.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Stop is a wrapper for the <stop> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/stop
 */

var Stop = function Stop(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("stop", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Stop.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Stop.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stop-color attribute indicates what color to use at a gradient
   *  stop.Note: With respect to gradients, SVG treats the transparent
   *  keyword differently than CSS. SVG does not calculate gradients
   *  in pre-multiplied space, so transparent really means transparent
   *  black. So, specifying a stop-color with the value transparent
   *  is equivalent to specifying a stop-color with the value
   *  black and a stop-opacity with the value 0.Note: As a presentation
   *  attribute, stop-color can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  keyword denotes the current fill color and can be specified
   *  in the same manner as within a <paint> specification for
   *  the fill and stroke attributes.This value indicates a
   *  color value.This value refers to an ICC color profile.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  stopColor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stop-opacity attribute defines the opacity of a given color
   *  gradient stop.The opacity value used for the gradient
   *  calculation is the product of the value of stop-opacity
   *  and the opacity of the value of the stop-color attribute.
   *  For stop-color values that don't include explicit opacity
   *  information, the opacity is treated as 1.Note: As a presentation
   *  attribute, stop-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:This
   *  value is either a <number> between 0 and 1 or a <percentage>
   *  value specifying the opacity of the color gradient stop.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  stopOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Stop);

/***/ }),

/***/ "./src/lib/components/Svg.react.js":
/*!*****************************************!*\
  !*** ./src/lib/components/Svg.react.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Svg$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Svg is a wrapper for the <svg> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/svg
 */

var Svg = function Svg(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("svg", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Svg.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Svg.propTypes = (_Svg$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The baseProfile attribute
   *  describes the minimum SVG language profile that the author
   *  believes is necessary to correctly render the content.
   *  The attribute does not specify any processing restrictions;
   *  It can be considered metadata.For example, the value of
   *  the attribute could be used by an authoring tool to warn
   *  the user when they are modifying the document beyond the
   *  scope of the specified base profile.Each SVG profile should
   *  define the text that is appropriate for this attribute.You
   *  can use this attribute with the following SVG elements:Last
   *  modified: May 13, 2022, by MDN contributors
   */
  baseProfile: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The clip attribute is a
   *  presentation attribute defining the visible region of
   *  an element.This attribute has the same parameter values
   *  as defined for the css clip property. Unitless values,
   *  which indicate current user coordinates, are permitted
   *  on the coordinate values on the rect(). The value of auto
   *  defines a clipping path along the bounds of the viewport
   *  created by the given element.You can use this attribute
   *  with the following SVG elements:Warning: This property
   *  is deprecated. Use clip-path instead.The value auto defines
   *  a clipping path along the bounds of the viewport created
   *  by the given element. The value rect() defines a clipping
   *  rectangle following the following syntax: rect(<top>,
   *  <right>, <bottom>, <left>). The <top> and <bottom> values
   *  specify offsets from the top border edge of the element
   *  viewport, while <right> and <left> specify offsets from
   *  the left border edge of the element viewport.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jun 28, 2022, by
   *  MDN contributors
   */
  clip: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The version attribute is
   *  used to indicate what specification a SVG document conforms
   *  to. It is only allowed on the root <svg> element. It is
   *  purely advisory and has no influence on rendering or processing.While
   *  it is specified to accept any number, the only two valid
   *  choices are currently 1.0 and 1.1.You can use this attribute
   *  with the following SVG elements:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  version: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The viewBox attribute defines the position and dimension, in
   *  user space, of an SVG viewport.The value of the viewBox
   *  attribute is a list of four numbers: min-x, min-y, width
   *  and height. The numbers, which are separated by whitespace
   *  and/or a comma, specify a rectangle in user space which
   *  is mapped to the bounds of the viewport established for
   *  the associated SVG element (not the browser viewport).You
   *  can use this attribute with the following SVG elements:The
   *  exact effect of this attribute is influenced by the preserveAspectRatio
   *  attribute.Note: Values for width or height lower or equal
   *  to 0 disable rendering of the element.For <marker>, viewBox
   *  defines the position and dimension for the content of
   *  the <marker> element.For <pattern>, viewBox defines the
   *  position and dimension for the content of the pattern
   *  tile.For <svg>, viewBox defines the position and dimension
   *  for the content of the <svg> element.For <symbol>, viewBox
   *  defines the position and dimension for the content of
   *  the <symbol> element.For <view>, viewBox defines the position
   *  and dimension for the content of the <view> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  viewBox: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The zoomAndPan attribute
   *  specifies whether the SVG document can be magnified and
   *  panned.Magnification in this context means the effect
   *  of a supplemental scale and translate transformation on
   *  the outermost SVG document fragment.Panning represents
   *  a translation (i.e., a shift) transformation on an SVG
   *  document fragment in response to a user interface action.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  zoomAndPan: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
}, _defineProperty(_Svg$propTypes, "viewBox", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Svg$propTypes, "className", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Svg$propTypes, "transform", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Svg$propTypes, "style", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))), _defineProperty(_Svg$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Svg$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Svg$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Svg$propTypes, "alt", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Svg$propTypes, "xmlns", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Svg$propTypes, "width", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Svg$propTypes, "height", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Svg$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Svg$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Svg$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Svg);

/***/ }),

/***/ "./src/lib/components/Switch.react.js":
/*!********************************************!*\
  !*** ./src/lib/components/Switch.react.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Switch is a wrapper for the <switch> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/switch
 */

var Switch = function Switch(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("switch", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Switch.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Switch.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (Switch);

/***/ }),

/***/ "./src/lib/components/Symbol.react.js":
/*!********************************************!*\
  !*** ./src/lib/components/Symbol.react.js ***!
  \********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Symbol$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Symbol is a wrapper for the <symbol> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/symbol
 */

var _Symbol = function _Symbol(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("symbol", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

_Symbol.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
_Symbol.propTypes = (_Symbol$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The clip attribute is a
   *  presentation attribute defining the visible region of
   *  an element.This attribute has the same parameter values
   *  as defined for the css clip property. Unitless values,
   *  which indicate current user coordinates, are permitted
   *  on the coordinate values on the rect(). The value of auto
   *  defines a clipping path along the bounds of the viewport
   *  created by the given element.You can use this attribute
   *  with the following SVG elements:Warning: This property
   *  is deprecated. Use clip-path instead.The value auto defines
   *  a clipping path along the bounds of the viewport created
   *  by the given element. The value rect() defines a clipping
   *  rectangle following the following syntax: rect(<top>,
   *  <right>, <bottom>, <left>). The <top> and <bottom> values
   *  specify offsets from the top border edge of the element
   *  viewport, while <right> and <left> specify offsets from
   *  the left border edge of the element viewport.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jun 28, 2022, by
   *  MDN contributors
   */
  clip: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The enable-background attribute
   *  specifies how the accumulation of the background image
   *  is managed.Note: As a presentation attribute, enable-background
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:If an ancestor container
   *  element has a property value of enable-background: new,
   *  then all graphics elements within the current container
   *  element are rendered both onto the parent container element's
   *  background image canvas and onto the target device.Otherwise,
   *  there is no current background image canvas, so graphics
   *  elements are only rendered onto the target device.This
   *  value enables the ability of children of the current container
   *  element to access the background image.It also indicates
   *  that a new (i.e., initially transparent black) background
   *  image canvas is established and that in effect all children
   *  of the current container element shall be rendered into
   *  the new background image canvas in addition to being rendered
   *  onto the target device.
    The optional <x>, <y>, <width>,
   *  and <height> parameters are <number> values that indicate
   *  the subregion of the container element's user space where
   *  access to the background image is allowed to happen. Those
   *  values act as a clipping rectangle on the background image
   *  canvas.
    Negative values for <width> or <height>
   *  are forbidden. If one, two, or three values are specified
   *  or if neither <width> nor <height> are specified, the
   *  BackgroundImage and BackgroundAlpha of a filter primitive
   *  are processed as if background image processing were not
   *  enabled.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 17, 2022, by MDN contributors
   */
  enableBackground: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The refX attribute defines the x coordinate of an element's reference
   *  point.You can use this attribute with the following SVG
   *  elements:For <marker>, refX defines the x coordinate of
   *  the marker's reference point, which is to be placed exactly
   *  at the marker's position on the shape.Lengths are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.Percentage values are interpreted as being
   *  a percentage of the viewBox width.Numbers are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the left edge of the shape.The reference point of the
   *  marker is placed at the horizontal center of the shape.The
   *  reference point of the marker is placed at the right edge
   *  of the shape.For <symbol>, refX defines the x coordinate
   *  of the symbol, which is defined by the cumulative effect
   *  of the x attribute and any transformations on the <symbol>
   *  and its host <use> element.Unlike other positioning attributes,
   *  refX is interpreted as being in the coordinate system
   *  of the symbol contents, after application of the viewBox
   *  and preserveAspectRatio attributes. If the attribute is
   *  not specified, no horizontal adjustment is made, and the
   *  left side of the symbol's rectangular viewport region
   *  (regardless of the viewBox coordinate) is positioned at
   *  the x coordinate.Note: For backwards compatibility, the
   *  behavior when refX is not specified on a <symbol> element
   *  is different from when it is specified with a value of
   *  0, and therefore different from the behavior when an equivalent
   *  attribute is not specified on a <marker> element.Lengths
   *  are interpreted as being in the coordinate system of the
   *  marker contents, after application of the viewBox and
   *  preserveAspectRatio attributes.Percentage values are interpreted
   *  as being a percentage of the viewBox width.Numbers are
   *  interpreted as being in the coordinate system of the marker
   *  contents, after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the left edge of the shape.The reference point of the
   *  marker is placed at the horizontal center of the shape.The
   *  reference point of the marker is placed at the right edge
   *  of the shape.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  refX: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The refY attribute defines the y coordinate of an element's reference
   *  point.You can use this attribute with the following SVG
   *  elements:For <marker>, refY defines the y coordinate of
   *  the marker's reference point, which is to be placed exactly
   *  at the marker's position on the shape.Lengths are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.Percentage values are interpreted as being
   *  a percentage of the viewBox height.Numbers are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the top edge of the shape.The reference point of the
   *  marker is placed at the vertical center of the shape.The
   *  reference point of the marker is placed at the bottom
   *  edge of the shape.For <symbol>, refY defines the y coordinate
   *  of the symbol, which is defined by the cumulative effect
   *  of the y attribute and any transformations on the <symbol>
   *  and its host <use> element.Unlike other positioning attributes,
   *  refY is interpreted as being in the coordinate system
   *  of the symbol contents, after application of the viewBox
   *  and preserveAspectRatio attributes. If the attribute is
   *  not specified, no vertical adjustment is made, and the
   *  top side of the symbol's rectangular viewport region (regardless
   *  of the viewBox coordinate) is positioned at the y coordinate.Note:
   *  For backwards compatibility, the behavior when refY is
   *  not specified on a <symbol> element is different from
   *  when it is specified with a value of 0, and therefore
   *  different from the behavior when an equivalent attribute
   *  is not specified on a <marker> element.Lengths are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.Percentage values are interpreted as being
   *  a percentage of the viewBox height.Numbers are interpreted
   *  as being in the coordinate system of the marker contents,
   *  after application of the viewBox and preserveAspectRatio
   *  attributes.The reference point of the marker is placed
   *  at the top edge of the shape.The reference point of the
   *  marker is placed at the vertical center of the shape.The
   *  reference point of the marker is placed at the bottom
   *  edge of the shape.Last modified: May 13, 2022, by MDN
   *  contributors
   */
  refY: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The viewBox attribute defines the position and dimension, in
   *  user space, of an SVG viewport.The value of the viewBox
   *  attribute is a list of four numbers: min-x, min-y, width
   *  and height. The numbers, which are separated by whitespace
   *  and/or a comma, specify a rectangle in user space which
   *  is mapped to the bounds of the viewport established for
   *  the associated SVG element (not the browser viewport).You
   *  can use this attribute with the following SVG elements:The
   *  exact effect of this attribute is influenced by the preserveAspectRatio
   *  attribute.Note: Values for width or height lower or equal
   *  to 0 disable rendering of the element.For <marker>, viewBox
   *  defines the position and dimension for the content of
   *  the <marker> element.For <pattern>, viewBox defines the
   *  position and dimension for the content of the pattern
   *  tile.For <svg>, viewBox defines the position and dimension
   *  for the content of the <svg> element.For <symbol>, viewBox
   *  defines the position and dimension for the content of
   *  the <symbol> element.For <view>, viewBox defines the position
   *  and dimension for the content of the <view> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  viewBox: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Symbol$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Symbol$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Symbol$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Symbol$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Symbol$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Symbol$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (_Symbol);

/***/ }),

/***/ "./src/lib/components/Text.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/Text.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Text$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Text is a wrapper for the <text> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/text
 */

var Text = function Text(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("text", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Text.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Text.propTypes = (_Text$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The direction attribute specifies the inline-base direction of
   *  a <text> or <tspan> element. It defines the start and
   *  end points of a line of text as used by the text-anchor
   *  and inline-size properties. It also may affect the direction
   *  in which characters are positioned if the unicode-bidi
   *  property's value is either embed or bidi-override.It applies
   *  only to glyphs oriented perpendicular to the inline-base
   *  direction, which includes the usual case of horizontally-oriented
   *  Latin or Arabic text and the case of narrow-cell Latin
   *  or Arabic characters rotated 90 degrees clockwise relative
   *  to a top-to-bottom inline-base direction.In many cases,
   *  the bidirectional Unicode algorithm produces the desired
   *  result automatically, so this attribute doesn't need to
   *  be specified in those cases. For other cases, such as
   *  when using right-to-left languages, it may be sufficient
   *  to add the direction attribute to the outermost <svg>
   *  element, and allow that direction to inherit to all text
   *  elements:Note: As a presentation attribute, direction
   *  can be used as a CSS property. See css direction for further
   *  information.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dominant-baseline attribute specifies the dominant baseline,
   *  which is the baseline used to align the box's text and
   *  inline-level contents. It also indicates the default alignment
   *  baseline of any boxes participating in baseline alignment
   *  in the box's alignment context.It is used to determine
   *  or re-determine a scaled-baseline-table. A scaled-baseline-table
   *  is a compound value with three components:Some values
   *  of the property re-determine all three values. Others
   *  only re-establish the baseline-table font-size. When the
   *  initial value, auto, would give an undesired result, this
   *  property can be used to explicitly set the desired scaled-baseline-table.If
   *  there is no baseline table in the nominal font, or if
   *  the baseline table lacks an entry for the desired baseline,
   *  then the browser may use heuristics to determine the position
   *  of the desired baseline.Note: As a presentation attribute,
   *  dominant-baseline can be used as a CSS property.You can
   *  use this attribute with the following SVG elements:If
   *  this property occurs on a <text> element, then the computed
   *  value depends on the value of the writing-mode attribute.If
   *  the writing-mode is horizontal, then the value of the
   *  dominant-baseline component is alphabetic. Otherwise,
   *  if the writing-mode is vertical, then the value of the
   *  dominant-baseline component is central.If this property
   *  occurs on a <tspan>, <tref>, <altGlyph>, or <textPath>
   *  element, then the dominant-baseline and the baseline-table
   *  components remain the same as those of the parent text
   *  content element.If the computed baseline-shift value actually
   *  shifts the baseline, then the baseline-table font-size
   *  component is set to the value of the font-size attribute
   *  on the element on which the dominant-baseline attribute
   *  occurs, otherwise the baseline-table font-size remains
   *  the same as that of the element.If there is no parent
   *  text content element, the scaled-baseline-table value
   *  is constructed as above for <text> elements.The dominant-baseline
   *  and the baseline-table components are set by determining
   *  the predominant script of the character data content.
   *  The writing-mode, whether horizontal or vertical, is used
   *  to select the appropriate set of baseline-tables and the
   *  dominant baseline is used to select the baseline-table
   *  that corresponds to that baseline. The baseline-table
   *  font-size component is set to the value of the font-size
   *  attribute on the element on which the dominant-baseline
   *  attribute occurs.The dominant-baseline, the baseline-table,
   *  and the baseline-table font-size remain the same as that
   *  of the parent text content element.The dominant-baseline
   *  and the baseline-table remain the same, but the baseline-table
   *  font-size is changed to the value of the font-size attribute
   *  on this element. This re-scales the baseline-table for
   *  the current font-size.The baseline-identifier for the
   *  dominant-baseline is set to be ideographic, the derived
   *  baseline-table is constructed using the ideographic baseline-table
   *  in the font, and the baseline-table font-size is changed
   *  to the value of the font-size attribute on this element.The
   *  baseline-identifier for the dominant-baseline is set to
   *  be alphabetic, the derived baseline-table is constructed
   *  using the alphabetic baseline-table in the font, and the
   *  baseline-table font-size is changed to the value of the
   *  font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be hanging, the derived
   *  baseline-table is constructed using the hanging baseline-table
   *  in the font, and the baseline-table font-size is changed
   *  to the value of the font-size attribute on this element.The
   *  baseline-identifier for the dominant-baseline is set to
   *  be mathematical, the derived baseline-table is constructed
   *  using the mathematical baseline-table in the font, and
   *  the baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be central. The derived
   *  baseline-table is constructed from the defined baselines
   *  in a baseline-table in the font. That font baseline-table
   *  is chosen using the following priority order of baseline-table
   *  names: ideographic, alphabetic, hanging, mathematical.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be middle. The derived
   *  baseline-table is constructed from the defined baselines
   *  in a baseline-table in the font. That font baseline-table
   *  is chosen using the following priority order of baseline-table
   *  names: alphabetic, ideographic, hanging, mathematical.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be text-after-edge.
   *  The derived baseline-table is constructed from the defined
   *  baselines in a baseline-table in the font. The choice
   *  of which font baseline-table to use from the baseline-tables
   *  in the font is browser dependent. The baseline-table font-size
   *  is changed to the value of the font-size attribute on
   *  this element.The baseline-identifier for the dominant-baseline
   *  is set to be text-before-edge. The derived baseline-table
   *  is constructed from the defined baselines in a baseline-table
   *  in the font. The choice of which baseline-table to use
   *  from the baseline-tables in the font is browser dependent.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.This value uses
   *  the top of the em box as the baseline.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: Jul 8, 2022, by MDN contributors
   * 
   */
  dominantBaseline: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dx attribute indicates a shift along the x-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dx defines a shift along the
   *  x-axis for all alternate glyph.If there are multiple values,
   *  dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dx defines the x offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dx defines the
   *  x offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dx defines the x offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dx defines
   *  a shift along the x-axis for all glyphs.If there are multiple
   *  values, dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dx defines a shift along the x-axis for all glyphs.If
   *  there are multiple values, dx defines a shift along the
   *  x-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dx defines a shift along the x-axis for
   *  all alternate glyph.If there are multiple values, dx defines
   *  a shift along the x-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dy attribute indicates a shift along the y-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dy defines a shift along the
   *  y-axis for all alternate glyph.If there are multiple values,
   *  dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dy defines the y offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dy defines the
   *  y offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dy defines the y offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dy defines
   *  a shift along the y-axis for all glyphs.If there are multiple
   *  values, dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dy defines a shift along the y-axis for all glyphs.If
   *  there are multiple values, dy defines a shift along the
   *  y-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dy defines a shift along the y-axis for
   *  all alternate glyph.If there are multiple values, dy defines
   *  a shift along the y-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fill-rule attribute is a presentation attribute defining
   *  the algorithm to use to determine the inside part of a
   *  shape.Note: As a presentation attribute, fill-rule can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:The fill-rule attribute provides
   *  two options for how the inside (that is, the area to be
   *  filled) of a shape is determined:The value nonzero determines
   *  the "insideness" of a point in the shape by drawing a
   *  ray from that point to infinity in any direction, and
   *  then examining the places where a segment of the shape
   *  crosses the ray. Starting with a count of zero, add one
   *  each time a path segment crosses the ray from left to
   *  right and subtract one each time a path segment crosses
   *  the ray from right to left. After counting the crossings,
   *  if the result is zero then the point is outside the path.
   *  Otherwise, it is inside.The value evenodd determines the
   *  "insideness" of a point in the shape by drawing a ray
   *  from that point to infinity in any direction and counting
   *  the number of path segments from the given shape that
   *  the ray crosses. If this number is odd, the point is inside;
   *  if even, the point is outside.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["evenodd", "inherit", "nonzero"]),

  /**
   *  The font-family attribute indicates which font family will be
   *  used to render the text, specified as a prioritized list
   *  of font family names and/or generic family names.Note:
   *  As a presentation attribute, font-family can be used as
   *  a CSS property. See the css font-family property for more
   *  information.You can use this attribute with the following
   *  SVG elements:For a description of the values, please refer
   *  to the CSS font-family property.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontFamily: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The font-size attribute refers to the size of the font from baseline
   *  to baseline when multiple lines of text are set solid
   *  in a multiline layout environment.Note: As a presentation
   *  attribute, font-size can be used as a CSS property. See
   *  the css font-size property for more information.You can
   *  use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS font-size
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  fontSize: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-size-adjust attribute allows authors to specify an aspect
   *  value for an element that will preserve the x-height of
   *  the first choice font in a substitute font.Note: As a
   *  presentation attribute, font-size-adjust can be used as
   *  a CSS property. See the css font-size-adjust property
   *  for more information.You can use this attribute with the
   *  following SVG elements:Choose the size of the font based
   *  only on the font-size property.Choose the size of the
   *  font so that its lowercase letters (as determined by the
   *  x-height of the font) are the specified number times the
   *  font-size.The number specified should generally be the
   *  aspect ratio (ratio of x-height to font size) of the first
   *  choice font-family. This means that the first-choice font,
   *  when available, will appear the same size in browsers,
   *  whether or not they support font-size-adjust.0 yields
   *  text of zero height (hidden text).BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fontSizeAdjust: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-stretch attribute indicates the desired amount of condensing
   *  or expansion in the glyphs used to render the text.Note:
   *  As a presentation attribute, font-stretch can be used
   *  as a CSS property. See the css font-stretch property for
   *  more information.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  fontStretch: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-style attribute specifies whether the text is to be
   *  rendered using a normal, italic, or oblique face.Note:
   *  As a presentation attribute, font-style can be used as
   *  a CSS property. See the css font-style property for more
   *  information.You can use this attribute with the following
   *  SVG elements:For a description of the values, please refer
   *  to the CSS font-style property.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontStyle: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-variant attribute indicates whether the text is to be
   *  rendered using variations of the font's glyphs.Note: As
   *  a presentation attribute, font-variant can be used as
   *  a CSS property. See the css font-variant property for
   *  more information.You can use this attribute with the following
   *  SVG elements:
        normal | none | [
        <common-lig-values>
   *  ||
        <discretionary-lig-values> ||
        <historical-lig-values>
   *  ||
        <contextual-alt-values> ||
        stylistic(
   *  <feature-value-name> ) ||
        historical-forms ||
    *           styleset( <feature-value-name># ) ||
     
   *    character-variant( <feature-value-name># ) ||
   
   *      swash( <feature-value-name> ) ||
        ornaments(
   *  <feature-value-name> ) ||
        annotation( <feature-value-name>
   *  ) || [
        small-caps | all-small-caps |
    
   *     petite-caps | all-petite-caps |
        unicase |
   *  titling-caps ] ||
        <numeric-figure-values> ||
    *           <numeric-spacing-values> ||
        <numeric-fraction-values>
   *  || ordinal ||
        slashed-zero ||
        <east-asian-variant-values>
   *  ||
        <east-asian-width-values> || ruby ]
  
   *     For a description of the values, please refer to the
   *  CSS font-variant property.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontVariant: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-weight attribute refers to the boldness or lightness
   *  of the glyphs used to render the text, relative to other
   *  fonts in the same font family.Note: As a presentation
   *  attribute, font-weight can be used as a CSS property.
   *  See the css font-weight property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS font-weight
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  fontWeight: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The glyph-orientation-horizontal
   *  attribute affects the amount that the current text position
   *  advances as each glyph is rendered.When the reference
   *  orientation direction is horizontal and the glyph-orientation-horizontal
   *  results in an orientation angle that is a multiple of
   *  180 degrees, then the current text position is incremented
   *  according to the horizontal metrics of the glyph. Otherwise,
   *  if the value of this attribute is not a multiple of 180
   *  degrees, then the current text position is incremented
   *  according to the vertical metrics of the glyph.This attribute
   *  is applied only to text written in a horizontal writing-mode.Note:
   *  As a presentation attribute, glyph-orientation-horizontal
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:
    The value of the
   *  angle is restricted to 0, 90, 180, and 270 degrees. If
   *  another angle is specified, it is rounded to the closest
   *  of the permitted values.
    A value of 0deg indicates
   *  that all glyphs are set with the top of the glyphs oriented
   *  towards the reference orientation. A value of 90deg indicates
   *  an orientation of 90 degrees clockwise from the reference
   *  orientation.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  glyphOrientationHorizontal: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The glyph-orientation-vertical
   *  attribute affects the amount that hte current text position
   *  advances as each glyph is rendered.When the inline-progression-direction
   *  is vertical and the glyph-orientation-vertical results
   *  in an orientation angle that is a multiple of 180 degrees,
   *  then the current text position is incremented according
   *  to the vertical metrics of the glyph. Otherwise, if the
   *  angle is not a multiple of 180 degrees, then the current
   *  text position is incremented according to the horizontal
   *  metrics of the glyph.This attribute is applied only to
   *  text written in a vertical writing-mode.Note: As a presentation
   *  attribute, glyph-orientation-vertical can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Fullwidth ideographic and fullwidth Latin
   *  text will be set with a glyph orientation of 0 degrees.
   *  Ideographic punctuation and other ideographic characters
   *  having alternate horizontal and vertical forms will use
   *  the vertical form of the glyph. Text which is not fullwidth
   *  will be set with a glyph orientation of 90 degrees.This
   *  reorientation rule applies only to the first-level non-ideographic
   *  text. All further embedding of writing modes or bidirectional
   *  processing will be based on the first-level rotation.Note:
   *  Text set in this "rotated" manner may contain ligatures
   *  or other glyph combining and reordering common to the
   *  language and script. (This presentation form does not
   *  disable auto-ligature formation or similar context-driven
   *  variations.)The determination of which characters should
   *  be auto-rotated may vary across user agents. The determination
   *  is based on a complex interaction between country, language,
   *  script, character properties, font, and character context.
    *       The value of the angle is restricted to 0, 90, 180,
   *  and 270 degrees. If another angle is specified, it is
   *  rounded to the closest of the permitted values.
   
   *  A value of 0deg indicates that all glyphs are set with
   *  the top of the glyphs oriented towards the reference orientation.
   *  A value of 90deg indicates an orientation of 90 degrees
   *  clockwise from the reference orientation.
  BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  glyphOrientationVertical: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The kerning attribute indicates
   *  whether the spacing between glyphs should be adjusted
   *  based on kerning tables that are included in the relevant
   *  font (i.e., enable auto-kerning) or instead disable auto-kerning
   *  and set the spacing between them to a specific length
   *  (typically, zero).Note: As a presentation attribute kerning
   *  can be used as a CSS property. In CSS the property is
   *  called font-kerning, though.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the spacing between glyphs is adjusted based on kerning
   *  tables that are included in the font that will be used.If
   *  a length is provided, then auto-kerning is disabled. Instead,
   *  inter-character spacing is set to the given length.If
   *  a length is provided without a unit identifier (e.g.,
   *  an unqualified number such as 128), the length is processed
   *  as a width value in the current user coordinate system.
   *  If a unit identifier (e.g., 0.25em or 1%) is provided,
   *  then the length is converted into a corresponding value
   *  in the current user coordinate system.The most common
   *  scenario, other than auto, is to set kerning to a value
   *  of 0 so that auto-kerning is disabled.The given length
   *  is added to the inter-character spacing value specified
   *  by the letter-spacing attribute.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: Feb 4, 2022, by MDN contributors
   * 
   */
  kerning: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The lengthAdjust attribute controls how the text is stretched
   *  into the length defined by the textLength attribute.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  lengthAdjust: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The letter-spacing attribute controls spacing between text characters,
   *  in addition to any spacing from the kerning attribute.If
   *  the attribute value is a unitless number (like 128), the
   *  browser processes it as a <length> in the current user
   *  coordinate system.If the attribute value has a unit identifier,
   *  such as .25em or 1%, then the browser converts the <length>
   *  into its corresponding value in the current user coordinate
   *  system.Note: As a presentation attribute, letter-spacing
   *  can be used as a CSS property. See the css letter-spacing
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please refer to the CSS letter-spacing property.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  letterSpacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The overflow attribute sets what to do when an element's content
   *  is too big to fit in its block formatting context. This
   *  feature is not widely implemented yet.This attribute has
   *  the same parameter values and meaning as the css overflow
   *  property, however, the following additional points apply:Note:
   *  Although the initial value for overflow is auto, it is
   *  overwritten in the User Agent style sheet for the <svg>
   *  element when it is not the root element of a stand-alone
   *  document, the <pattern> element, and the <marker> element
   *  to be hidden by default.Note: As a presentation attribute,
   *  overflow can be used as a CSS property. See the CSS overflow
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please see the css overflow property.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  overflow: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linecap attribute is a presentation attribute defining
   *  the shape to be used at the end of open subpaths when
   *  they are stroked.Note: As a presentation attribute stroke-linecap
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:The butt value indicates
   *  that the stroke for each subpath does not extend beyond
   *  its two endpoints. On a zero length subpath, the path
   *  will not be rendered at all.The round value indicates
   *  that at the end of each subpath the stroke will be extended
   *  by a half circle with a diameter equal to the stroke width.
   *  On a zero length subpath, the stroke consists of a full
   *  circle centered at the subpath's point.The square value
   *  indicates that at the end of each subpath the stroke will
   *  be extended by a rectangle with a width equal to half
   *  the width of the stroke and a height equal to the width
   *  of the stroke. On a zero length subpath, the stroke consists
   *  of a square with its width equal to the stroke width,
   *  centered at the subpath's point.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeLinecap: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["butt", "inherit", "round", "square"]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The text-anchor attribute is used to align (start-, middle- or
   *  end-alignment) a string of pre-formatted text or auto-wrapped
   *  text where the wrapping area is determined from the inline-size
   *  property relative to a given point.This attribute is not
   *  applicable to other types of auto-wrapped text. For those
   *  cases you should use text-align. For multi-line text,
   *  the alignment takes place for each line.The text-anchor
   *  attribute is applied to each individual text chunk within
   *  a given <text> element. Each text chunk has an initial
   *  current text position, which represents the point in the
   *  user coordinate system resulting from (depending on context)
   *  application of the x and y attributes on the <text> element,
   *  any x or y attribute values on a <tspan>, <tref> or <altGlyph>
   *  element assigned explicitly to the first rendered character
   *  in a text chunk, or determination of the initial current
   *  text position for a <textPath> element.Note: As a presentation
   *  attribute, text-anchor can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:The
   *  rendered characters are aligned such that the start of
   *  the text string is at the initial current text position.
   *  For an element with a direction property value of ltr
   *  (typical for most European languages), the left side of
   *  the text is rendered at the initial text position. For
   *  an element with a direction property value of rtl (typical
   *  for Arabic and Hebrew), the right side of the text is
   *  rendered at the initial text position. For an element
   *  with a vertical primary text direction (often typical
   *  for Asian text), the top side of the text is rendered
   *  at the initial text position.The rendered characters are
   *  aligned such that the middle of the text string is at
   *  the current text position. (For text on a path, conceptually
   *  the text string is first laid out in a straight line.
   *  The midpoint between the start of the text string and
   *  the end of the text string is determined. Then, the text
   *  string is mapped onto the path with this midpoint placed
   *  at the current text position.)The rendered characters
   *  are shifted such that the end of the resulting rendered
   *  text (final current text position before applying the
   *  text-anchor property) is at the initial current text position.
   *  For an element with a direction property value of ltr
   *  (typical for most European languages), the right side
   *  of the text is rendered at the initial text position.
   *  For an element with a direction property value of rtl
   *  (typical for Arabic and Hebrew), the left side of the
   *  text is rendered at the initial text position. For an
   *  element with a vertical primary text direction (often
   *  typical for Asian text), the bottom of the text is rendered
   *  at the initial text position.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  textAnchor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The text-decoration attribute defines whether text is decorated
   *  with an underline, overline and/or strike-through. It
   *  is a shorthand for the text-decoration-line and text-decoration-style
   *  properties.The fill and stroke of the text decoration
   *  are given by the fill and stroke of the text at the point
   *  where the text decoration is declared.The paint order
   *  of the text decoration, i.e. the fill and stroke, is determined
   *  by the value of the paint-order attribute at the point
   *  where the text decoration is declared.Note: As a presentation
   *  attribute, text-decoration can be used as a CSS property.
   *  See the css text-decoration property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS text-decoration
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  textDecoration: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The text-rendering attribute provides hints to the renderer about
   *  what tradeoffs to make when rendering text.Note: As a
   *  presentation attribute, text-rendering can be used as
   *  a CSS property. See the css text-rendering property for
   *  more information.You can use this attribute with the following
   *  SVG elements:This value indicates that the user agent
   *  shall make appropriate tradeoffs to balance speed, legibility
   *  and geometric precision, but with legibility given more
   *  importance than speed and geometric precision.This value
   *  indicates that the user agent shall emphasize rendering
   *  speed over legibility and geometric precision. This option
   *  will sometimes cause some user agents to turn off text
   *  anti-aliasing.This value indicates that the user agent
   *  shall emphasize legibility over rendering speed and geometric
   *  precision. The user agent will often choose whether to
   *  apply anti-aliasing techniques, built-in font hinting
   *  or both to produce the most legible text.This value indicates
   *  that the user agent shall emphasize geometric precision
   *  over legibility and rendering speed. This option will
   *  usually cause the user agent to suspend the use of hinting
   *  so that glyph outlines are drawn with comparable geometric
   *  precision to the rendering of path data.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  textRendering: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The textLength attribute, available on SVG <text> and <tspan>
   *  elements, lets you specify the width of the space into
   *  which the text will draw. The user agent will ensure that
   *  the text does not extend farther than that distance, using
   *  the method or methods specified by the lengthAdjust attribute.
   *  By default, only the spacing between characters is adjusted,
   *  but the glyph size can also be adjusted if you change
   *  lengthAdjust.By using textLength, you can ensure that
   *  your SVG text displays at the same width regardless of
   *  conditions including web fonts failing to load (or not
   *  having loaded yet).You can use this attribute with the
   *  following SVG elements:This value specifies the width
   *  of the space the text will be adjusted to occupy as absolute
   *  length or percentage.A numeric value outlines a length
   *  referring to the units of the current coordinate system.Let's
   *  create a simple example that presents text you can resize
   *  using an <input> element of type "range".Let's start with
   *  the SVG. It's pretty basic, with a 1000-by-300 pixel space
   *  mapped into a 10 centimeter by 3 centimeter box.First,
   *  a <rect> element is used to create and stroke a rectangle
   *  to contain the text. Then <text> is used to create the
   *  text element itself, with an id of "hello".The HTML is
   *  also simple, with only two displayed elements contained
   *  inside a grouping <div>:The <input> element, of type "range",
   *  is used to create the slider control the user will manipulate
   *  to change the width of the text. A <span> element of ID
   *  "widthDisplay" is provided to display the current width
   *  value.Finally, let's have a look at the JavaScript code.
   *  It starts by stashing references to the elements it will
   *  need to access, using Document.getElementById():After
   *  fetching the element references, an EventListener is established
   *  by calling addEventListener() on the slider control, to
   *  receive any input events which occur. These events will
   *  be sent any time the slider's value changes, even if the
   *  user hasn't stopped moving it, so we can responsively
   *  adjust the text width.When an "input" event occurs, we
   *  call newValueSpecifiedUnits() to set the value of textLength
   *  to the slider's new value, using the SVGLength interface's
   *  SVG_LENGTHTYPE_PX unit type to indicate that the value
   *  represents pixels. Note that we have to dive into textLength
   *  to get its baseVal property; textLength is stored as an
   *  SVGLength object, so we can't treat it like a plain number.After
   *  updating the text width, the contents of the widthDisplay
   *  box are updated with the new value as well, and we're
   *  finished.Here's what the example looks like. Try dragging
   *  the slider around to get a feel for what it does.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jul 8, 2022, by
   *  MDN contributors
   */
  textLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The unicode-bidi attribute specifies how the accumulation of
   *  the background image is managed.Note: As a presentation
   *  attribute, unicode-bidi can be used as a CSS property.
   *  See the CSS unicode-bidi property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS unicode-bidi
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  unicodeBidi: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The word-spacing attribute specifies spacing behavior between
   *  words.If a <length> is provided without a unit identifier
   *  (e.g. an unqualified number such as 128), the browser
   *  processes the <length> as a width value in the current
   *  user coordinate system.If a <length> is provided with
   *  one of the unit identifiers (e.g. .25em or 1%), then the
   *  browser converts the <length> into a corresponding value
   *  in the current user coordinate system.Note: As a presentation
   *  attribute, word-spacing can be used as a CSS property.
   *  See the css word-spacing property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS letter-spacing
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  wordSpacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The writing-mode attribute specifies whether the initial inline-progression-direction
   *  for a <text> element shall be left-to-right, right-to-left,
   *  or top-to-bottom. The writing-mode attribute applies only
   *  to <text> elements; the attribute is ignored for <tspan>,
   *  <tref>, <altGlyph> and <textPath> sub-elements. (Note
   *  that the inline-progression-direction can change within
   *  a <text> element due to the Unicode bidirectional algorithm
   *  and properties direction and unicode-bidi.)Note: As a
   *  presentation attribute, writing-mode can be used as a
   *  CSS property. See the CSS writing-mode property for more
   *  information.You can use this attribute with the following
   *  SVG elements:This value defines a top-to-bottom block
   *  flow direction. Both the writing mode and the typographic
   *  mode are horizontal.This value defines a right-to-left
   *  block flow direction. Both the writing mode and the typographic
   *  mode are vertical.This value defines a left-to-right block
   *  flow direction. Both the writing mode and the typographic
   *  mode are vertical.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  writingMode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Text$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Text$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Text$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Text$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Text$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Text$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Text);

/***/ }),

/***/ "./src/lib/components/TextPath.react.js":
/*!**********************************************!*\
  !*** ./src/lib/components/TextPath.react.js ***!
  \**********************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _TextPath$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * TextPath is a wrapper for the <textPath> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/textPath
 */

var TextPath = function TextPath(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("textPath", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

TextPath.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
TextPath.propTypes = (_TextPath$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The alignment-baseline attribute specifies how an object is aligned
   *  with respect to its parent. This property specifies which
   *  baseline of this element is to be aligned with the corresponding
   *  baseline of the parent. For example, this allows alphabetic
   *  baselines in Roman text to stay aligned across font size
   *  changes. It defaults to the baseline with the same name
   *  as the computed value of the alignment-baseline property.Note:
   *  As a presentation attribute alignment-baseline can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:The value is the dominant-baseline
   *  of the script to which the character belongs - i.e., use
   *  the dominant-baseline of the parent.Uses the dominant
   *  baseline choice of the parent. Matches the box's corresponding
   *  baseline to that of its parent.The alignment-point of
   *  the object being aligned is aligned with the "before-edge"
   *  baseline of the parent text content element.Matches the
   *  bottom of the box to the top of the parent's content area.The
   *  alignment-point of the object being aligned is aligned
   *  with the "text-before-edge" baseline of the parent text
   *  content element.Note: This keyword may be mapped to text-top.Aligns
   *  the vertical midpoint of the box with the baseline of
   *  the parent box plus half the x-height of the parent.Matches
   *  the box's central baseline to the central baseline of
   *  its parent.The alignment-point of the object being aligned
   *  is aligned with the "after-edge" baseline of the parent
   *  text content element.Matches the top of the box to the
   *  top of the parent's content area.The alignment-point of
   *  the object being aligned is aligned with the "text-after-edge"
   *  baseline of the parent text content element.Note: This
   *  keyword may be mapped to text-bottom.Matches the box's
   *  ideographic character face under-side baseline to that
   *  of its parent.Matches the box's alphabetic baseline to
   *  that of its parent.The alignment-point of the object being
   *  aligned is aligned with the "hanging" baseline of the
   *  parent text content element.Matches the box's mathematical
   *  baseline to that of its parent.Aligns the top of the aligned
   *  subtree with the top of the line box.Aligns the center
   *  of the aligned subtree with the center of the line box.Aligns
   *  the bottom of the aligned subtree with the bottom of the
   *  line box.SVG 2 introduces some changes to the definition
   *  of this property. In particular: the values auto, before-edge,
   *  and after-edge have been removed. For backwards compatibility,
   *  text-before-edge may be mapped to text-top and text-after-edge
   *  to text-bottom. Neither text-before-edge nor text-after-edge
   *  should be used with the vertical-align property.For object
   *  alignment in other elements (such as <text>), see dominant-baseline.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  alignmentBaseline: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The baseline-shift attribute allows repositioning of the dominant-baseline
   *  relative to the dominant-baseline of the parent text content
   *  element. The shifted object might be a sub- or superscript.Note:
   *  As a presentation attribute baseline-shift can be used
   *  as a CSS property.Note: This property is going to be deprecated
   *  and authors are advised to use vertical-align instead.You
   *  can use this attribute with the following SVG elements:The
   *  dominant-baseline is shifted to the default position for
   *  subscripts.The dominant-baseline is shifted to the default
   *  position for superscripts.A length value raises (positive
   *  value) or lowers (negative value) the dominant-baseline
   *  of the parent text content element by the specified length.A
   *  percentage value raises (positive value) or lowers (negative
   *  value) the dominant-baseline of the parent text content
   *  element by the specified percentage of the line-height.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  baselineShift: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The direction attribute specifies the inline-base direction of
   *  a <text> or <tspan> element. It defines the start and
   *  end points of a line of text as used by the text-anchor
   *  and inline-size properties. It also may affect the direction
   *  in which characters are positioned if the unicode-bidi
   *  property's value is either embed or bidi-override.It applies
   *  only to glyphs oriented perpendicular to the inline-base
   *  direction, which includes the usual case of horizontally-oriented
   *  Latin or Arabic text and the case of narrow-cell Latin
   *  or Arabic characters rotated 90 degrees clockwise relative
   *  to a top-to-bottom inline-base direction.In many cases,
   *  the bidirectional Unicode algorithm produces the desired
   *  result automatically, so this attribute doesn't need to
   *  be specified in those cases. For other cases, such as
   *  when using right-to-left languages, it may be sufficient
   *  to add the direction attribute to the outermost <svg>
   *  element, and allow that direction to inherit to all text
   *  elements:Note: As a presentation attribute, direction
   *  can be used as a CSS property. See css direction for further
   *  information.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dominant-baseline attribute specifies the dominant baseline,
   *  which is the baseline used to align the box's text and
   *  inline-level contents. It also indicates the default alignment
   *  baseline of any boxes participating in baseline alignment
   *  in the box's alignment context.It is used to determine
   *  or re-determine a scaled-baseline-table. A scaled-baseline-table
   *  is a compound value with three components:Some values
   *  of the property re-determine all three values. Others
   *  only re-establish the baseline-table font-size. When the
   *  initial value, auto, would give an undesired result, this
   *  property can be used to explicitly set the desired scaled-baseline-table.If
   *  there is no baseline table in the nominal font, or if
   *  the baseline table lacks an entry for the desired baseline,
   *  then the browser may use heuristics to determine the position
   *  of the desired baseline.Note: As a presentation attribute,
   *  dominant-baseline can be used as a CSS property.You can
   *  use this attribute with the following SVG elements:If
   *  this property occurs on a <text> element, then the computed
   *  value depends on the value of the writing-mode attribute.If
   *  the writing-mode is horizontal, then the value of the
   *  dominant-baseline component is alphabetic. Otherwise,
   *  if the writing-mode is vertical, then the value of the
   *  dominant-baseline component is central.If this property
   *  occurs on a <tspan>, <tref>, <altGlyph>, or <textPath>
   *  element, then the dominant-baseline and the baseline-table
   *  components remain the same as those of the parent text
   *  content element.If the computed baseline-shift value actually
   *  shifts the baseline, then the baseline-table font-size
   *  component is set to the value of the font-size attribute
   *  on the element on which the dominant-baseline attribute
   *  occurs, otherwise the baseline-table font-size remains
   *  the same as that of the element.If there is no parent
   *  text content element, the scaled-baseline-table value
   *  is constructed as above for <text> elements.The dominant-baseline
   *  and the baseline-table components are set by determining
   *  the predominant script of the character data content.
   *  The writing-mode, whether horizontal or vertical, is used
   *  to select the appropriate set of baseline-tables and the
   *  dominant baseline is used to select the baseline-table
   *  that corresponds to that baseline. The baseline-table
   *  font-size component is set to the value of the font-size
   *  attribute on the element on which the dominant-baseline
   *  attribute occurs.The dominant-baseline, the baseline-table,
   *  and the baseline-table font-size remain the same as that
   *  of the parent text content element.The dominant-baseline
   *  and the baseline-table remain the same, but the baseline-table
   *  font-size is changed to the value of the font-size attribute
   *  on this element. This re-scales the baseline-table for
   *  the current font-size.The baseline-identifier for the
   *  dominant-baseline is set to be ideographic, the derived
   *  baseline-table is constructed using the ideographic baseline-table
   *  in the font, and the baseline-table font-size is changed
   *  to the value of the font-size attribute on this element.The
   *  baseline-identifier for the dominant-baseline is set to
   *  be alphabetic, the derived baseline-table is constructed
   *  using the alphabetic baseline-table in the font, and the
   *  baseline-table font-size is changed to the value of the
   *  font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be hanging, the derived
   *  baseline-table is constructed using the hanging baseline-table
   *  in the font, and the baseline-table font-size is changed
   *  to the value of the font-size attribute on this element.The
   *  baseline-identifier for the dominant-baseline is set to
   *  be mathematical, the derived baseline-table is constructed
   *  using the mathematical baseline-table in the font, and
   *  the baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be central. The derived
   *  baseline-table is constructed from the defined baselines
   *  in a baseline-table in the font. That font baseline-table
   *  is chosen using the following priority order of baseline-table
   *  names: ideographic, alphabetic, hanging, mathematical.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be middle. The derived
   *  baseline-table is constructed from the defined baselines
   *  in a baseline-table in the font. That font baseline-table
   *  is chosen using the following priority order of baseline-table
   *  names: alphabetic, ideographic, hanging, mathematical.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be text-after-edge.
   *  The derived baseline-table is constructed from the defined
   *  baselines in a baseline-table in the font. The choice
   *  of which font baseline-table to use from the baseline-tables
   *  in the font is browser dependent. The baseline-table font-size
   *  is changed to the value of the font-size attribute on
   *  this element.The baseline-identifier for the dominant-baseline
   *  is set to be text-before-edge. The derived baseline-table
   *  is constructed from the defined baselines in a baseline-table
   *  in the font. The choice of which baseline-table to use
   *  from the baseline-tables in the font is browser dependent.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.This value uses
   *  the top of the em box as the baseline.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: Jul 8, 2022, by MDN contributors
   * 
   */
  dominantBaseline: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fill-rule attribute is a presentation attribute defining
   *  the algorithm to use to determine the inside part of a
   *  shape.Note: As a presentation attribute, fill-rule can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:The fill-rule attribute provides
   *  two options for how the inside (that is, the area to be
   *  filled) of a shape is determined:The value nonzero determines
   *  the "insideness" of a point in the shape by drawing a
   *  ray from that point to infinity in any direction, and
   *  then examining the places where a segment of the shape
   *  crosses the ray. Starting with a count of zero, add one
   *  each time a path segment crosses the ray from left to
   *  right and subtract one each time a path segment crosses
   *  the ray from right to left. After counting the crossings,
   *  if the result is zero then the point is outside the path.
   *  Otherwise, it is inside.The value evenodd determines the
   *  "insideness" of a point in the shape by drawing a ray
   *  from that point to infinity in any direction and counting
   *  the number of path segments from the given shape that
   *  the ray crosses. If this number is odd, the point is inside;
   *  if even, the point is outside.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["evenodd", "inherit", "nonzero"]),

  /**
   *  The font-family attribute indicates which font family will be
   *  used to render the text, specified as a prioritized list
   *  of font family names and/or generic family names.Note:
   *  As a presentation attribute, font-family can be used as
   *  a CSS property. See the css font-family property for more
   *  information.You can use this attribute with the following
   *  SVG elements:For a description of the values, please refer
   *  to the CSS font-family property.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontFamily: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The font-size attribute refers to the size of the font from baseline
   *  to baseline when multiple lines of text are set solid
   *  in a multiline layout environment.Note: As a presentation
   *  attribute, font-size can be used as a CSS property. See
   *  the css font-size property for more information.You can
   *  use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS font-size
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  fontSize: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-size-adjust attribute allows authors to specify an aspect
   *  value for an element that will preserve the x-height of
   *  the first choice font in a substitute font.Note: As a
   *  presentation attribute, font-size-adjust can be used as
   *  a CSS property. See the css font-size-adjust property
   *  for more information.You can use this attribute with the
   *  following SVG elements:Choose the size of the font based
   *  only on the font-size property.Choose the size of the
   *  font so that its lowercase letters (as determined by the
   *  x-height of the font) are the specified number times the
   *  font-size.The number specified should generally be the
   *  aspect ratio (ratio of x-height to font size) of the first
   *  choice font-family. This means that the first-choice font,
   *  when available, will appear the same size in browsers,
   *  whether or not they support font-size-adjust.0 yields
   *  text of zero height (hidden text).BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fontSizeAdjust: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-stretch attribute indicates the desired amount of condensing
   *  or expansion in the glyphs used to render the text.Note:
   *  As a presentation attribute, font-stretch can be used
   *  as a CSS property. See the css font-stretch property for
   *  more information.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  fontStretch: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-style attribute specifies whether the text is to be
   *  rendered using a normal, italic, or oblique face.Note:
   *  As a presentation attribute, font-style can be used as
   *  a CSS property. See the css font-style property for more
   *  information.You can use this attribute with the following
   *  SVG elements:For a description of the values, please refer
   *  to the CSS font-style property.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontStyle: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-variant attribute indicates whether the text is to be
   *  rendered using variations of the font's glyphs.Note: As
   *  a presentation attribute, font-variant can be used as
   *  a CSS property. See the css font-variant property for
   *  more information.You can use this attribute with the following
   *  SVG elements:
        normal | none | [
        <common-lig-values>
   *  ||
        <discretionary-lig-values> ||
        <historical-lig-values>
   *  ||
        <contextual-alt-values> ||
        stylistic(
   *  <feature-value-name> ) ||
        historical-forms ||
    *           styleset( <feature-value-name># ) ||
     
   *    character-variant( <feature-value-name># ) ||
   
   *      swash( <feature-value-name> ) ||
        ornaments(
   *  <feature-value-name> ) ||
        annotation( <feature-value-name>
   *  ) || [
        small-caps | all-small-caps |
    
   *     petite-caps | all-petite-caps |
        unicase |
   *  titling-caps ] ||
        <numeric-figure-values> ||
    *           <numeric-spacing-values> ||
        <numeric-fraction-values>
   *  || ordinal ||
        slashed-zero ||
        <east-asian-variant-values>
   *  ||
        <east-asian-width-values> || ruby ]
  
   *     For a description of the values, please refer to the
   *  CSS font-variant property.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontVariant: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-weight attribute refers to the boldness or lightness
   *  of the glyphs used to render the text, relative to other
   *  fonts in the same font family.Note: As a presentation
   *  attribute, font-weight can be used as a CSS property.
   *  See the css font-weight property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS font-weight
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  fontWeight: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The glyph-orientation-horizontal
   *  attribute affects the amount that the current text position
   *  advances as each glyph is rendered.When the reference
   *  orientation direction is horizontal and the glyph-orientation-horizontal
   *  results in an orientation angle that is a multiple of
   *  180 degrees, then the current text position is incremented
   *  according to the horizontal metrics of the glyph. Otherwise,
   *  if the value of this attribute is not a multiple of 180
   *  degrees, then the current text position is incremented
   *  according to the vertical metrics of the glyph.This attribute
   *  is applied only to text written in a horizontal writing-mode.Note:
   *  As a presentation attribute, glyph-orientation-horizontal
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:
    The value of the
   *  angle is restricted to 0, 90, 180, and 270 degrees. If
   *  another angle is specified, it is rounded to the closest
   *  of the permitted values.
    A value of 0deg indicates
   *  that all glyphs are set with the top of the glyphs oriented
   *  towards the reference orientation. A value of 90deg indicates
   *  an orientation of 90 degrees clockwise from the reference
   *  orientation.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  glyphOrientationHorizontal: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The glyph-orientation-vertical
   *  attribute affects the amount that hte current text position
   *  advances as each glyph is rendered.When the inline-progression-direction
   *  is vertical and the glyph-orientation-vertical results
   *  in an orientation angle that is a multiple of 180 degrees,
   *  then the current text position is incremented according
   *  to the vertical metrics of the glyph. Otherwise, if the
   *  angle is not a multiple of 180 degrees, then the current
   *  text position is incremented according to the horizontal
   *  metrics of the glyph.This attribute is applied only to
   *  text written in a vertical writing-mode.Note: As a presentation
   *  attribute, glyph-orientation-vertical can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Fullwidth ideographic and fullwidth Latin
   *  text will be set with a glyph orientation of 0 degrees.
   *  Ideographic punctuation and other ideographic characters
   *  having alternate horizontal and vertical forms will use
   *  the vertical form of the glyph. Text which is not fullwidth
   *  will be set with a glyph orientation of 90 degrees.This
   *  reorientation rule applies only to the first-level non-ideographic
   *  text. All further embedding of writing modes or bidirectional
   *  processing will be based on the first-level rotation.Note:
   *  Text set in this "rotated" manner may contain ligatures
   *  or other glyph combining and reordering common to the
   *  language and script. (This presentation form does not
   *  disable auto-ligature formation or similar context-driven
   *  variations.)The determination of which characters should
   *  be auto-rotated may vary across user agents. The determination
   *  is based on a complex interaction between country, language,
   *  script, character properties, font, and character context.
    *       The value of the angle is restricted to 0, 90, 180,
   *  and 270 degrees. If another angle is specified, it is
   *  rounded to the closest of the permitted values.
   
   *  A value of 0deg indicates that all glyphs are set with
   *  the top of the glyphs oriented towards the reference orientation.
   *  A value of 90deg indicates an orientation of 90 degrees
   *  clockwise from the reference orientation.
  BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  glyphOrientationVertical: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The kerning attribute indicates
   *  whether the spacing between glyphs should be adjusted
   *  based on kerning tables that are included in the relevant
   *  font (i.e., enable auto-kerning) or instead disable auto-kerning
   *  and set the spacing between them to a specific length
   *  (typically, zero).Note: As a presentation attribute kerning
   *  can be used as a CSS property. In CSS the property is
   *  called font-kerning, though.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the spacing between glyphs is adjusted based on kerning
   *  tables that are included in the font that will be used.If
   *  a length is provided, then auto-kerning is disabled. Instead,
   *  inter-character spacing is set to the given length.If
   *  a length is provided without a unit identifier (e.g.,
   *  an unqualified number such as 128), the length is processed
   *  as a width value in the current user coordinate system.
   *  If a unit identifier (e.g., 0.25em or 1%) is provided,
   *  then the length is converted into a corresponding value
   *  in the current user coordinate system.The most common
   *  scenario, other than auto, is to set kerning to a value
   *  of 0 so that auto-kerning is disabled.The given length
   *  is added to the inter-character spacing value specified
   *  by the letter-spacing attribute.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: Feb 4, 2022, by MDN contributors
   * 
   */
  kerning: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The lengthAdjust attribute controls how the text is stretched
   *  into the length defined by the textLength attribute.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  lengthAdjust: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The letter-spacing attribute controls spacing between text characters,
   *  in addition to any spacing from the kerning attribute.If
   *  the attribute value is a unitless number (like 128), the
   *  browser processes it as a <length> in the current user
   *  coordinate system.If the attribute value has a unit identifier,
   *  such as .25em or 1%, then the browser converts the <length>
   *  into its corresponding value in the current user coordinate
   *  system.Note: As a presentation attribute, letter-spacing
   *  can be used as a CSS property. See the css letter-spacing
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please refer to the CSS letter-spacing property.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  letterSpacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The spacing attribute indicates how the user agent should determine
   *  the spacing between typographic characters that are to
   *  be rendered along a path.You can use this attribute with
   *  the following SVG elements:This value indicates that the
   *  user agent should use text-on-a-path layout algorithms
   *  to adjust the spacing between typographic characters in
   *  order to achieve visually appealing results.This value
   *  indicates that the typographic characters should be rendered
   *  exactly according to the spacing rules as specified by
   *  the layout rules for text-on-a-path.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  spacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The startOffset attribute defines an offset from the start of
   *  the path for the initial current text position along the
   *  path after converting the path to the <textPath> element's
   *  coordinate system.You can use this attribute with the
   *  following SVG elements:A length represents a distance
   *  along the path measured in the current user coordinate
   *  system for the <textPath> element.If a percentage is given,
   *  then the start offset represents a percentage distance
   *  along the entire path. Thus, 0% indicates the start point
   *  of the path and 100% indicates the end point of the path.This
   *  value indicates a distance along the path measured in
   *  the current user coordinate system for the <textPath>
   *  element.Note: Negative values and values larger than the
   *  path length (e.g. 150%) are allowed.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  startOffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linecap attribute is a presentation attribute defining
   *  the shape to be used at the end of open subpaths when
   *  they are stroked.Note: As a presentation attribute stroke-linecap
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:The butt value indicates
   *  that the stroke for each subpath does not extend beyond
   *  its two endpoints. On a zero length subpath, the path
   *  will not be rendered at all.The round value indicates
   *  that at the end of each subpath the stroke will be extended
   *  by a half circle with a diameter equal to the stroke width.
   *  On a zero length subpath, the stroke consists of a full
   *  circle centered at the subpath's point.The square value
   *  indicates that at the end of each subpath the stroke will
   *  be extended by a rectangle with a width equal to half
   *  the width of the stroke and a height equal to the width
   *  of the stroke. On a zero length subpath, the stroke consists
   *  of a square with its width equal to the stroke width,
   *  centered at the subpath's point.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeLinecap: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["butt", "inherit", "round", "square"]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The text-anchor attribute is used to align (start-, middle- or
   *  end-alignment) a string of pre-formatted text or auto-wrapped
   *  text where the wrapping area is determined from the inline-size
   *  property relative to a given point.This attribute is not
   *  applicable to other types of auto-wrapped text. For those
   *  cases you should use text-align. For multi-line text,
   *  the alignment takes place for each line.The text-anchor
   *  attribute is applied to each individual text chunk within
   *  a given <text> element. Each text chunk has an initial
   *  current text position, which represents the point in the
   *  user coordinate system resulting from (depending on context)
   *  application of the x and y attributes on the <text> element,
   *  any x or y attribute values on a <tspan>, <tref> or <altGlyph>
   *  element assigned explicitly to the first rendered character
   *  in a text chunk, or determination of the initial current
   *  text position for a <textPath> element.Note: As a presentation
   *  attribute, text-anchor can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:The
   *  rendered characters are aligned such that the start of
   *  the text string is at the initial current text position.
   *  For an element with a direction property value of ltr
   *  (typical for most European languages), the left side of
   *  the text is rendered at the initial text position. For
   *  an element with a direction property value of rtl (typical
   *  for Arabic and Hebrew), the right side of the text is
   *  rendered at the initial text position. For an element
   *  with a vertical primary text direction (often typical
   *  for Asian text), the top side of the text is rendered
   *  at the initial text position.The rendered characters are
   *  aligned such that the middle of the text string is at
   *  the current text position. (For text on a path, conceptually
   *  the text string is first laid out in a straight line.
   *  The midpoint between the start of the text string and
   *  the end of the text string is determined. Then, the text
   *  string is mapped onto the path with this midpoint placed
   *  at the current text position.)The rendered characters
   *  are shifted such that the end of the resulting rendered
   *  text (final current text position before applying the
   *  text-anchor property) is at the initial current text position.
   *  For an element with a direction property value of ltr
   *  (typical for most European languages), the right side
   *  of the text is rendered at the initial text position.
   *  For an element with a direction property value of rtl
   *  (typical for Arabic and Hebrew), the left side of the
   *  text is rendered at the initial text position. For an
   *  element with a vertical primary text direction (often
   *  typical for Asian text), the bottom of the text is rendered
   *  at the initial text position.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  textAnchor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The text-decoration attribute defines whether text is decorated
   *  with an underline, overline and/or strike-through. It
   *  is a shorthand for the text-decoration-line and text-decoration-style
   *  properties.The fill and stroke of the text decoration
   *  are given by the fill and stroke of the text at the point
   *  where the text decoration is declared.The paint order
   *  of the text decoration, i.e. the fill and stroke, is determined
   *  by the value of the paint-order attribute at the point
   *  where the text decoration is declared.Note: As a presentation
   *  attribute, text-decoration can be used as a CSS property.
   *  See the css text-decoration property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS text-decoration
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  textDecoration: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The textLength attribute, available on SVG <text> and <tspan>
   *  elements, lets you specify the width of the space into
   *  which the text will draw. The user agent will ensure that
   *  the text does not extend farther than that distance, using
   *  the method or methods specified by the lengthAdjust attribute.
   *  By default, only the spacing between characters is adjusted,
   *  but the glyph size can also be adjusted if you change
   *  lengthAdjust.By using textLength, you can ensure that
   *  your SVG text displays at the same width regardless of
   *  conditions including web fonts failing to load (or not
   *  having loaded yet).You can use this attribute with the
   *  following SVG elements:This value specifies the width
   *  of the space the text will be adjusted to occupy as absolute
   *  length or percentage.A numeric value outlines a length
   *  referring to the units of the current coordinate system.Let's
   *  create a simple example that presents text you can resize
   *  using an <input> element of type "range".Let's start with
   *  the SVG. It's pretty basic, with a 1000-by-300 pixel space
   *  mapped into a 10 centimeter by 3 centimeter box.First,
   *  a <rect> element is used to create and stroke a rectangle
   *  to contain the text. Then <text> is used to create the
   *  text element itself, with an id of "hello".The HTML is
   *  also simple, with only two displayed elements contained
   *  inside a grouping <div>:The <input> element, of type "range",
   *  is used to create the slider control the user will manipulate
   *  to change the width of the text. A <span> element of ID
   *  "widthDisplay" is provided to display the current width
   *  value.Finally, let's have a look at the JavaScript code.
   *  It starts by stashing references to the elements it will
   *  need to access, using Document.getElementById():After
   *  fetching the element references, an EventListener is established
   *  by calling addEventListener() on the slider control, to
   *  receive any input events which occur. These events will
   *  be sent any time the slider's value changes, even if the
   *  user hasn't stopped moving it, so we can responsively
   *  adjust the text width.When an "input" event occurs, we
   *  call newValueSpecifiedUnits() to set the value of textLength
   *  to the slider's new value, using the SVGLength interface's
   *  SVG_LENGTHTYPE_PX unit type to indicate that the value
   *  represents pixels. Note that we have to dive into textLength
   *  to get its baseVal property; textLength is stored as an
   *  SVGLength object, so we can't treat it like a plain number.After
   *  updating the text width, the contents of the widthDisplay
   *  box are updated with the new value as well, and we're
   *  finished.Here's what the example looks like. Try dragging
   *  the slider around to get a feel for what it does.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jul 8, 2022, by
   *  MDN contributors
   */
  textLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The unicode-bidi attribute specifies how the accumulation of
   *  the background image is managed.Note: As a presentation
   *  attribute, unicode-bidi can be used as a CSS property.
   *  See the CSS unicode-bidi property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS unicode-bidi
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  unicodeBidi: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The word-spacing attribute specifies spacing behavior between
   *  words.If a <length> is provided without a unit identifier
   *  (e.g. an unqualified number such as 128), the browser
   *  processes the <length> as a width value in the current
   *  user coordinate system.If a <length> is provided with
   *  one of the unit identifiers (e.g. .25em or 1%), then the
   *  browser converts the <length> into a corresponding value
   *  in the current user coordinate system.Note: As a presentation
   *  attribute, word-spacing can be used as a CSS property.
   *  See the css word-spacing property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS letter-spacing
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  wordSpacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The writing-mode attribute specifies whether the initial inline-progression-direction
   *  for a <text> element shall be left-to-right, right-to-left,
   *  or top-to-bottom. The writing-mode attribute applies only
   *  to <text> elements; the attribute is ignored for <tspan>,
   *  <tref>, <altGlyph> and <textPath> sub-elements. (Note
   *  that the inline-progression-direction can change within
   *  a <text> element due to the Unicode bidirectional algorithm
   *  and properties direction and unicode-bidi.)Note: As a
   *  presentation attribute, writing-mode can be used as a
   *  CSS property. See the CSS writing-mode property for more
   *  information.You can use this attribute with the following
   *  SVG elements:This value defines a top-to-bottom block
   *  flow direction. Both the writing mode and the typographic
   *  mode are horizontal.This value defines a right-to-left
   *  block flow direction. Both the writing mode and the typographic
   *  mode are vertical.This value defines a left-to-right block
   *  flow direction. Both the writing mode and the typographic
   *  mode are vertical.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  writingMode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])
}, _defineProperty(_TextPath$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_TextPath$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_TextPath$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _TextPath$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (TextPath);

/***/ }),

/***/ "./src/lib/components/Tspan.react.js":
/*!*******************************************!*\
  !*** ./src/lib/components/Tspan.react.js ***!
  \*******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Tspan$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Tspan is a wrapper for the <tspan> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/tspan
 */

var Tspan = function Tspan(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("tspan", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Tspan.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Tspan.propTypes = (_Tspan$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The alignment-baseline attribute specifies how an object is aligned
   *  with respect to its parent. This property specifies which
   *  baseline of this element is to be aligned with the corresponding
   *  baseline of the parent. For example, this allows alphabetic
   *  baselines in Roman text to stay aligned across font size
   *  changes. It defaults to the baseline with the same name
   *  as the computed value of the alignment-baseline property.Note:
   *  As a presentation attribute alignment-baseline can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:The value is the dominant-baseline
   *  of the script to which the character belongs - i.e., use
   *  the dominant-baseline of the parent.Uses the dominant
   *  baseline choice of the parent. Matches the box's corresponding
   *  baseline to that of its parent.The alignment-point of
   *  the object being aligned is aligned with the "before-edge"
   *  baseline of the parent text content element.Matches the
   *  bottom of the box to the top of the parent's content area.The
   *  alignment-point of the object being aligned is aligned
   *  with the "text-before-edge" baseline of the parent text
   *  content element.Note: This keyword may be mapped to text-top.Aligns
   *  the vertical midpoint of the box with the baseline of
   *  the parent box plus half the x-height of the parent.Matches
   *  the box's central baseline to the central baseline of
   *  its parent.The alignment-point of the object being aligned
   *  is aligned with the "after-edge" baseline of the parent
   *  text content element.Matches the top of the box to the
   *  top of the parent's content area.The alignment-point of
   *  the object being aligned is aligned with the "text-after-edge"
   *  baseline of the parent text content element.Note: This
   *  keyword may be mapped to text-bottom.Matches the box's
   *  ideographic character face under-side baseline to that
   *  of its parent.Matches the box's alphabetic baseline to
   *  that of its parent.The alignment-point of the object being
   *  aligned is aligned with the "hanging" baseline of the
   *  parent text content element.Matches the box's mathematical
   *  baseline to that of its parent.Aligns the top of the aligned
   *  subtree with the top of the line box.Aligns the center
   *  of the aligned subtree with the center of the line box.Aligns
   *  the bottom of the aligned subtree with the bottom of the
   *  line box.SVG 2 introduces some changes to the definition
   *  of this property. In particular: the values auto, before-edge,
   *  and after-edge have been removed. For backwards compatibility,
   *  text-before-edge may be mapped to text-top and text-after-edge
   *  to text-bottom. Neither text-before-edge nor text-after-edge
   *  should be used with the vertical-align property.For object
   *  alignment in other elements (such as <text>), see dominant-baseline.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  alignmentBaseline: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The baseline-shift attribute allows repositioning of the dominant-baseline
   *  relative to the dominant-baseline of the parent text content
   *  element. The shifted object might be a sub- or superscript.Note:
   *  As a presentation attribute baseline-shift can be used
   *  as a CSS property.Note: This property is going to be deprecated
   *  and authors are advised to use vertical-align instead.You
   *  can use this attribute with the following SVG elements:The
   *  dominant-baseline is shifted to the default position for
   *  subscripts.The dominant-baseline is shifted to the default
   *  position for superscripts.A length value raises (positive
   *  value) or lowers (negative value) the dominant-baseline
   *  of the parent text content element by the specified length.A
   *  percentage value raises (positive value) or lowers (negative
   *  value) the dominant-baseline of the parent text content
   *  element by the specified percentage of the line-height.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  baselineShift: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The direction attribute specifies the inline-base direction of
   *  a <text> or <tspan> element. It defines the start and
   *  end points of a line of text as used by the text-anchor
   *  and inline-size properties. It also may affect the direction
   *  in which characters are positioned if the unicode-bidi
   *  property's value is either embed or bidi-override.It applies
   *  only to glyphs oriented perpendicular to the inline-base
   *  direction, which includes the usual case of horizontally-oriented
   *  Latin or Arabic text and the case of narrow-cell Latin
   *  or Arabic characters rotated 90 degrees clockwise relative
   *  to a top-to-bottom inline-base direction.In many cases,
   *  the bidirectional Unicode algorithm produces the desired
   *  result automatically, so this attribute doesn't need to
   *  be specified in those cases. For other cases, such as
   *  when using right-to-left languages, it may be sufficient
   *  to add the direction attribute to the outermost <svg>
   *  element, and allow that direction to inherit to all text
   *  elements:Note: As a presentation attribute, direction
   *  can be used as a CSS property. See css direction for further
   *  information.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  direction: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dominant-baseline attribute specifies the dominant baseline,
   *  which is the baseline used to align the box's text and
   *  inline-level contents. It also indicates the default alignment
   *  baseline of any boxes participating in baseline alignment
   *  in the box's alignment context.It is used to determine
   *  or re-determine a scaled-baseline-table. A scaled-baseline-table
   *  is a compound value with three components:Some values
   *  of the property re-determine all three values. Others
   *  only re-establish the baseline-table font-size. When the
   *  initial value, auto, would give an undesired result, this
   *  property can be used to explicitly set the desired scaled-baseline-table.If
   *  there is no baseline table in the nominal font, or if
   *  the baseline table lacks an entry for the desired baseline,
   *  then the browser may use heuristics to determine the position
   *  of the desired baseline.Note: As a presentation attribute,
   *  dominant-baseline can be used as a CSS property.You can
   *  use this attribute with the following SVG elements:If
   *  this property occurs on a <text> element, then the computed
   *  value depends on the value of the writing-mode attribute.If
   *  the writing-mode is horizontal, then the value of the
   *  dominant-baseline component is alphabetic. Otherwise,
   *  if the writing-mode is vertical, then the value of the
   *  dominant-baseline component is central.If this property
   *  occurs on a <tspan>, <tref>, <altGlyph>, or <textPath>
   *  element, then the dominant-baseline and the baseline-table
   *  components remain the same as those of the parent text
   *  content element.If the computed baseline-shift value actually
   *  shifts the baseline, then the baseline-table font-size
   *  component is set to the value of the font-size attribute
   *  on the element on which the dominant-baseline attribute
   *  occurs, otherwise the baseline-table font-size remains
   *  the same as that of the element.If there is no parent
   *  text content element, the scaled-baseline-table value
   *  is constructed as above for <text> elements.The dominant-baseline
   *  and the baseline-table components are set by determining
   *  the predominant script of the character data content.
   *  The writing-mode, whether horizontal or vertical, is used
   *  to select the appropriate set of baseline-tables and the
   *  dominant baseline is used to select the baseline-table
   *  that corresponds to that baseline. The baseline-table
   *  font-size component is set to the value of the font-size
   *  attribute on the element on which the dominant-baseline
   *  attribute occurs.The dominant-baseline, the baseline-table,
   *  and the baseline-table font-size remain the same as that
   *  of the parent text content element.The dominant-baseline
   *  and the baseline-table remain the same, but the baseline-table
   *  font-size is changed to the value of the font-size attribute
   *  on this element. This re-scales the baseline-table for
   *  the current font-size.The baseline-identifier for the
   *  dominant-baseline is set to be ideographic, the derived
   *  baseline-table is constructed using the ideographic baseline-table
   *  in the font, and the baseline-table font-size is changed
   *  to the value of the font-size attribute on this element.The
   *  baseline-identifier for the dominant-baseline is set to
   *  be alphabetic, the derived baseline-table is constructed
   *  using the alphabetic baseline-table in the font, and the
   *  baseline-table font-size is changed to the value of the
   *  font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be hanging, the derived
   *  baseline-table is constructed using the hanging baseline-table
   *  in the font, and the baseline-table font-size is changed
   *  to the value of the font-size attribute on this element.The
   *  baseline-identifier for the dominant-baseline is set to
   *  be mathematical, the derived baseline-table is constructed
   *  using the mathematical baseline-table in the font, and
   *  the baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be central. The derived
   *  baseline-table is constructed from the defined baselines
   *  in a baseline-table in the font. That font baseline-table
   *  is chosen using the following priority order of baseline-table
   *  names: ideographic, alphabetic, hanging, mathematical.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be middle. The derived
   *  baseline-table is constructed from the defined baselines
   *  in a baseline-table in the font. That font baseline-table
   *  is chosen using the following priority order of baseline-table
   *  names: alphabetic, ideographic, hanging, mathematical.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.The baseline-identifier
   *  for the dominant-baseline is set to be text-after-edge.
   *  The derived baseline-table is constructed from the defined
   *  baselines in a baseline-table in the font. The choice
   *  of which font baseline-table to use from the baseline-tables
   *  in the font is browser dependent. The baseline-table font-size
   *  is changed to the value of the font-size attribute on
   *  this element.The baseline-identifier for the dominant-baseline
   *  is set to be text-before-edge. The derived baseline-table
   *  is constructed from the defined baselines in a baseline-table
   *  in the font. The choice of which baseline-table to use
   *  from the baseline-tables in the font is browser dependent.
   *  The baseline-table font-size is changed to the value of
   *  the font-size attribute on this element.This value uses
   *  the top of the em box as the baseline.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: Jul 8, 2022, by MDN contributors
   * 
   */
  dominantBaseline: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dx attribute indicates a shift along the x-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dx defines a shift along the
   *  x-axis for all alternate glyph.If there are multiple values,
   *  dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dx defines the x offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dx defines the
   *  x offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dx defines the x offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dx defines
   *  a shift along the x-axis for all glyphs.If there are multiple
   *  values, dx defines a shift along the x-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dx defines a shift along the x-axis for all glyphs.If
   *  there are multiple values, dx defines a shift along the
   *  x-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dx defines a shift along the x-axis for
   *  all alternate glyph.If there are multiple values, dx defines
   *  a shift along the x-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dx: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The dy attribute indicates a shift along the y-axis on the position
   *  of an element or its content.You can use this attribute
   *  with the following SVG elements:Warning: As of SVG2 <altGlyph>
   *  is deprecated and shouldn't be used.For <altGlyph>, if
   *  it contains a single value, dy defines a shift along the
   *  y-axis for all alternate glyph.If there are multiple values,
   *  dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.For <feDropShadow>, dy defines the y offset
   *  of the dropped shadow. The unit used to resolve the value
   *  of the attribute is set by the primitiveUnits attribute
   *  of the <filter> element.For <feOffset>, dy defines the
   *  y offset of the filter input graphic. The unit used to
   *  resolve the value of the attribute is set by the primitiveUnits
   *  attribute of the <filter> element.Warning: As of SVG2
   *  <glyphRef> is deprecated and shouldn't be used.For <glyphRef>,
   *  dy defines the y offset of the glyph, in the font metric
   *  system.For <text>, if it contains a single value, dy defines
   *  a shift along the y-axis for all glyphs.If there are multiple
   *  values, dy defines a shift along the y-axis for each individual
   *  glyph relative to the preceding glyph. If there are less
   *  values than glyphs, the remaining glyphs use a value of
   *  0. If there are more values than glyphs, extra values
   *  are ignored.Warning: As of SVG2 <tref> is deprecated and
   *  shouldn't be used.For <tref>, if it contains a single
   *  value, dy defines a shift along the y-axis for all glyphs.If
   *  there are multiple values, dy defines a shift along the
   *  y-axis for each individual glyph relative to the preceding
   *  glyph. If there are less values than glyphs, the remaining
   *  glyphs use a value of 0. If there are more values than
   *  glyphs, extra values are ignored.For <tspan>, if it contains
   *  a single value, dy defines a shift along the y-axis for
   *  all alternate glyph.If there are multiple values, dy defines
   *  a shift along the y-axis for each individual glyph relative
   *  to the preceding glyph. If there are less values than
   *  glyphs, the remaining glyphs use a value of 0. If there
   *  are more values than glyphs, extra values are ignored.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  dy: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The fill-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to a shape.Note: As a presentation attribute
   *  fill-opacity can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:Note: SVG2
   *  introduces percentage values for fill-opacity, however,
   *  it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The fill-rule attribute is a presentation attribute defining
   *  the algorithm to use to determine the inside part of a
   *  shape.Note: As a presentation attribute, fill-rule can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:The fill-rule attribute provides
   *  two options for how the inside (that is, the area to be
   *  filled) of a shape is determined:The value nonzero determines
   *  the "insideness" of a point in the shape by drawing a
   *  ray from that point to infinity in any direction, and
   *  then examining the places where a segment of the shape
   *  crosses the ray. Starting with a count of zero, add one
   *  each time a path segment crosses the ray from left to
   *  right and subtract one each time a path segment crosses
   *  the ray from right to left. After counting the crossings,
   *  if the result is zero then the point is outside the path.
   *  Otherwise, it is inside.The value evenodd determines the
   *  "insideness" of a point in the shape by drawing a ray
   *  from that point to infinity in any direction and counting
   *  the number of path segments from the given shape that
   *  the ray crosses. If this number is odd, the point is inside;
   *  if even, the point is outside.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fillRule: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["evenodd", "inherit", "nonzero"]),

  /**
   *  The font-family attribute indicates which font family will be
   *  used to render the text, specified as a prioritized list
   *  of font family names and/or generic family names.Note:
   *  As a presentation attribute, font-family can be used as
   *  a CSS property. See the css font-family property for more
   *  information.You can use this attribute with the following
   *  SVG elements:For a description of the values, please refer
   *  to the CSS font-family property.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontFamily: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The font-size attribute refers to the size of the font from baseline
   *  to baseline when multiple lines of text are set solid
   *  in a multiline layout environment.Note: As a presentation
   *  attribute, font-size can be used as a CSS property. See
   *  the css font-size property for more information.You can
   *  use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS font-size
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  fontSize: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-size-adjust attribute allows authors to specify an aspect
   *  value for an element that will preserve the x-height of
   *  the first choice font in a substitute font.Note: As a
   *  presentation attribute, font-size-adjust can be used as
   *  a CSS property. See the css font-size-adjust property
   *  for more information.You can use this attribute with the
   *  following SVG elements:Choose the size of the font based
   *  only on the font-size property.Choose the size of the
   *  font so that its lowercase letters (as determined by the
   *  x-height of the font) are the specified number times the
   *  font-size.The number specified should generally be the
   *  aspect ratio (ratio of x-height to font size) of the first
   *  choice font-family. This means that the first-choice font,
   *  when available, will appear the same size in browsers,
   *  whether or not they support font-size-adjust.0 yields
   *  text of zero height (hidden text).BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  fontSizeAdjust: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-stretch attribute indicates the desired amount of condensing
   *  or expansion in the glyphs used to render the text.Note:
   *  As a presentation attribute, font-stretch can be used
   *  as a CSS property. See the css font-stretch property for
   *  more information.You can use this attribute with the following
   *  SVG elements:BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  fontStretch: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-style attribute specifies whether the text is to be
   *  rendered using a normal, italic, or oblique face.Note:
   *  As a presentation attribute, font-style can be used as
   *  a CSS property. See the css font-style property for more
   *  information.You can use this attribute with the following
   *  SVG elements:For a description of the values, please refer
   *  to the CSS font-style property.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontStyle: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-variant attribute indicates whether the text is to be
   *  rendered using variations of the font's glyphs.Note: As
   *  a presentation attribute, font-variant can be used as
   *  a CSS property. See the css font-variant property for
   *  more information.You can use this attribute with the following
   *  SVG elements:
        normal | none | [
        <common-lig-values>
   *  ||
        <discretionary-lig-values> ||
        <historical-lig-values>
   *  ||
        <contextual-alt-values> ||
        stylistic(
   *  <feature-value-name> ) ||
        historical-forms ||
    *           styleset( <feature-value-name># ) ||
     
   *    character-variant( <feature-value-name># ) ||
   
   *      swash( <feature-value-name> ) ||
        ornaments(
   *  <feature-value-name> ) ||
        annotation( <feature-value-name>
   *  ) || [
        small-caps | all-small-caps |
    
   *     petite-caps | all-petite-caps |
        unicase |
   *  titling-caps ] ||
        <numeric-figure-values> ||
    *           <numeric-spacing-values> ||
        <numeric-fraction-values>
   *  || ordinal ||
        slashed-zero ||
        <east-asian-variant-values>
   *  ||
        <east-asian-width-values> || ruby ]
  
   *     For a description of the values, please refer to the
   *  CSS font-variant property.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 17, 2022, by MDN contributors
   * 
   */
  fontVariant: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The font-weight attribute refers to the boldness or lightness
   *  of the glyphs used to render the text, relative to other
   *  fonts in the same font family.Note: As a presentation
   *  attribute, font-weight can be used as a CSS property.
   *  See the css font-weight property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS font-weight
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 17, 2022, by MDN contributors
   */
  fontWeight: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The glyph-orientation-horizontal
   *  attribute affects the amount that the current text position
   *  advances as each glyph is rendered.When the reference
   *  orientation direction is horizontal and the glyph-orientation-horizontal
   *  results in an orientation angle that is a multiple of
   *  180 degrees, then the current text position is incremented
   *  according to the horizontal metrics of the glyph. Otherwise,
   *  if the value of this attribute is not a multiple of 180
   *  degrees, then the current text position is incremented
   *  according to the vertical metrics of the glyph.This attribute
   *  is applied only to text written in a horizontal writing-mode.Note:
   *  As a presentation attribute, glyph-orientation-horizontal
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:
    The value of the
   *  angle is restricted to 0, 90, 180, and 270 degrees. If
   *  another angle is specified, it is rounded to the closest
   *  of the permitted values.
    A value of 0deg indicates
   *  that all glyphs are set with the top of the glyphs oriented
   *  towards the reference orientation. A value of 90deg indicates
   *  an orientation of 90 degrees clockwise from the reference
   *  orientation.
  BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  glyphOrientationHorizontal: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The glyph-orientation-vertical
   *  attribute affects the amount that hte current text position
   *  advances as each glyph is rendered.When the inline-progression-direction
   *  is vertical and the glyph-orientation-vertical results
   *  in an orientation angle that is a multiple of 180 degrees,
   *  then the current text position is incremented according
   *  to the vertical metrics of the glyph. Otherwise, if the
   *  angle is not a multiple of 180 degrees, then the current
   *  text position is incremented according to the horizontal
   *  metrics of the glyph.This attribute is applied only to
   *  text written in a vertical writing-mode.Note: As a presentation
   *  attribute, glyph-orientation-vertical can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:Fullwidth ideographic and fullwidth Latin
   *  text will be set with a glyph orientation of 0 degrees.
   *  Ideographic punctuation and other ideographic characters
   *  having alternate horizontal and vertical forms will use
   *  the vertical form of the glyph. Text which is not fullwidth
   *  will be set with a glyph orientation of 90 degrees.This
   *  reorientation rule applies only to the first-level non-ideographic
   *  text. All further embedding of writing modes or bidirectional
   *  processing will be based on the first-level rotation.Note:
   *  Text set in this "rotated" manner may contain ligatures
   *  or other glyph combining and reordering common to the
   *  language and script. (This presentation form does not
   *  disable auto-ligature formation or similar context-driven
   *  variations.)The determination of which characters should
   *  be auto-rotated may vary across user agents. The determination
   *  is based on a complex interaction between country, language,
   *  script, character properties, font, and character context.
    *       The value of the angle is restricted to 0, 90, 180,
   *  and 270 degrees. If another angle is specified, it is
   *  rounded to the closest of the permitted values.
   
   *  A value of 0deg indicates that all glyphs are set with
   *  the top of the glyphs oriented towards the reference orientation.
   *  A value of 90deg indicates an orientation of 90 degrees
   *  clockwise from the reference orientation.
  BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  glyphOrientationVertical: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The kerning attribute indicates
   *  whether the spacing between glyphs should be adjusted
   *  based on kerning tables that are included in the relevant
   *  font (i.e., enable auto-kerning) or instead disable auto-kerning
   *  and set the spacing between them to a specific length
   *  (typically, zero).Note: As a presentation attribute kerning
   *  can be used as a CSS property. In CSS the property is
   *  called font-kerning, though.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the spacing between glyphs is adjusted based on kerning
   *  tables that are included in the font that will be used.If
   *  a length is provided, then auto-kerning is disabled. Instead,
   *  inter-character spacing is set to the given length.If
   *  a length is provided without a unit identifier (e.g.,
   *  an unqualified number such as 128), the length is processed
   *  as a width value in the current user coordinate system.
   *  If a unit identifier (e.g., 0.25em or 1%) is provided,
   *  then the length is converted into a corresponding value
   *  in the current user coordinate system.The most common
   *  scenario, other than auto, is to set kerning to a value
   *  of 0 so that auto-kerning is disabled.The given length
   *  is added to the inter-character spacing value specified
   *  by the letter-spacing attribute.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: Feb 4, 2022, by MDN contributors
   * 
   */
  kerning: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The lengthAdjust attribute controls how the text is stretched
   *  into the length defined by the textLength attribute.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  lengthAdjust: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The letter-spacing attribute controls spacing between text characters,
   *  in addition to any spacing from the kerning attribute.If
   *  the attribute value is a unitless number (like 128), the
   *  browser processes it as a <length> in the current user
   *  coordinate system.If the attribute value has a unit identifier,
   *  such as .25em or 1%, then the browser converts the <length>
   *  into its corresponding value in the current user coordinate
   *  system.Note: As a presentation attribute, letter-spacing
   *  can be used as a CSS property. See the css letter-spacing
   *  property for more information.You can use this attribute
   *  with the following SVG elements:For a description of the
   *  values, please refer to the CSS letter-spacing property.BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  letterSpacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The paint-order attribute specifies the order that the fill,
   *  stroke, and markers of a given shape or text element are
   *  painted.Note: As a presentation attribute, paint-order
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value indicates that
   *  the fill will be painted first, then the stroke, and finally
   *  the markers.The order of these three keywords indicates
   *  the order in which the painting happens, from left to
   *  right. If any of the three painting components is omitted,
   *  they will be painted in their default order after the
   *  specified components. For example, using stroke is equivalent
   *  to stroke fill markers.The example would be rendered as
   *  follows:
  The stroke under effect could be achieved
   *  via the following CSS property:BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  paintOrder: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  stroke color
   */
  stroke: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The stroke-dasharray attribute is a presentation attribute defining
   *  the pattern of dashes and gaps used to paint the outline
   *  of the shape;Note: As a presentation attribute, stroke-dasharray
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:A list of comma and/or
   *  white space separated <length>s and <percentage>s that
   *  specify the lengths of alternating dashes and gaps.If
   *  an odd number of values is provided, then the list of
   *  values is repeated to yield an even number of values.
   *  Thus, 5,3,2 is equivalent to 5,3,2,5,3,2.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeDasharray: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-dashoffset attribute is a presentation attribute defining
   *  an offset on the rendering of the associated dash array.Note:
   *  As a presentation attribute stroke-dashoffset can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:The offset is usually expressed
   *  in user units resolved against the pathLength but if a
   *  <percentage> is used, the value is resolved as a percentage
   *  of the current viewport.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeDashoffset: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-linecap attribute is a presentation attribute defining
   *  the shape to be used at the end of open subpaths when
   *  they are stroked.Note: As a presentation attribute stroke-linecap
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:The butt value indicates
   *  that the stroke for each subpath does not extend beyond
   *  its two endpoints. On a zero length subpath, the path
   *  will not be rendered at all.The round value indicates
   *  that at the end of each subpath the stroke will be extended
   *  by a half circle with a diameter equal to the stroke width.
   *  On a zero length subpath, the stroke consists of a full
   *  circle centered at the subpath's point.The square value
   *  indicates that at the end of each subpath the stroke will
   *  be extended by a rectangle with a width equal to half
   *  the width of the stroke and a height equal to the width
   *  of the stroke. On a zero length subpath, the stroke consists
   *  of a square with its width equal to the stroke width,
   *  centered at the subpath's point.BCD tables only load in
   *  the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeLinecap: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["butt", "inherit", "round", "square"]),

  /**
   *  The stroke-linejoin attribute is a presentation attribute defining
   *  the shape to be used at the corners of paths when they
   *  are stroked.Note: As a presentation attribute stroke-linejoin
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:Note: The arcs value as
   *  been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The arcs
   *  value indicates that an arcs corner is to be used to join
   *  path segments. The arcs shape is formed by extending the
   *  outer edges of the stroke at the join point with arcs
   *  that have the same curvature as the outer edges at the
   *  join point.The bevel value indicates that a bevelled corner
   *  is to be used to join path segments.The miter value indicates
   *  that a sharp corner is to be used to join path segments.
   *  The corner is formed by extending the outer edges of the
   *  stroke at the tangents of the path segments until they
   *  intersect.Note: If the stroke-miterlimit is exceeded,
   *  the line join falls back to bevel.Note: the miter-clip
   *  value as been introduced in SVG2 and it isn't widely supported
   *  yet, see Browser compatibility below for details.The miter-clip
   *  value indicates that a sharp corner is to be used to join
   *  path segments. The corner is formed by extending the outer
   *  edges of the stroke at the tangents of the path segments
   *  until they intersect.If the stroke-miterlimit is exceeded,
   *  the miter is clipped at a distance equal to half the stroke-miterlimit
   *  value multiplied by the stroke width from the intersection
   *  of the path segments. This provides a better rendering
   *  than miter on very sharp join or in case of an animation.The
   *  round value indicates that a round corner is to be used
   *  to join path segments.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  strokeLinejoin: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOf(["bevel", "inherit", "miter", "round"]),

  /**
   *  The stroke-miterlimit attribute is a presentation attribute defining
   *  a limit on the ratio of the miter length to the stroke-width
   *  used to draw a miter join. When the limit is exceeded,
   *  the join is converted from a miter to a bevel.Note: As
   *  a presentation attribute stroke-miterlimit can be used
   *  as a CSS property.You can use this attribute with the
   *  following SVG elements:When two line segments meet at
   *  a sharp angle and miter joins have been specified for
   *  stroke-linejoin, it is possible for the miter to extend
   *  far beyond the thickness of the line stroking the path.
   *  The stroke-miterlimit ratio is used to define when the
   *  limit is exceeded, if so the join is converted from a
   *  miter to a bevel.The ratio of miter length (distance between
   *  the outer tip and the inner corner of the miter) to stroke-width
   *  is directly related to the angle (theta) between the segments
   *  in user space by the formula:
     
    stroke-miterlimit
    *       =
    
      
        miterLength
      
    *         
        stroke-width
      
    
    =
    *       
      
        1
      
      
      
   *   
          sin
          
            (
    
   *         
              
                θ
      
   *         
              
                2
      
   *         
            
            )
          
     *          
      
    
  
  For example, a miter
   *  limit of 1.414 converts miters to bevels for theta less
   *  than 90 degrees, a limit of 4.0 converts them for theta
   *  less than approximately 29 degrees, and a limit of 10.0
   *  converts them for theta less than approximately 11.5 degrees.The
   *  value of stroke-miterlimit must be greater than or equal
   *  to 1.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeMiterlimit: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-opacity attribute is a presentation attribute defining
   *  the opacity of the paint server (color, gradient, pattern,
   *  etc) applied to the stroke of a shape.Note: As a presentation
   *  attribute stroke-opacity can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:Note:
   *  SVG2 introduces percentage values for stroke-opacity,
   *  however, it is not widely supported yet (See Browser compatibility
   *  below) as a consequence, it is best practices to set opacity
   *  with a value in the range [0-1].It's important to know
   *  that the stroke partially covers the fill of a shape,
   *  so a stroke with an opacity different than 1 will partially
   *  show the fill underneath. To avoid this effect, it is
   *  possible to apply a global opacity with the opacity attribute
   *  or to put the stroke behind the fill with the paint-order
   *  attribute.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  strokeOpacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The stroke-width attribute is a presentation attribute defining
   *  the width of the stroke to be applied to the shape.You
   *  can use this attribute with the following SVG elements:Note:
   *  A percentage value is always computed as a percentage
   *  of the normalized viewBox diagonal length.BCD tables only
   *  load in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  strokeWidth: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The text-anchor attribute is used to align (start-, middle- or
   *  end-alignment) a string of pre-formatted text or auto-wrapped
   *  text where the wrapping area is determined from the inline-size
   *  property relative to a given point.This attribute is not
   *  applicable to other types of auto-wrapped text. For those
   *  cases you should use text-align. For multi-line text,
   *  the alignment takes place for each line.The text-anchor
   *  attribute is applied to each individual text chunk within
   *  a given <text> element. Each text chunk has an initial
   *  current text position, which represents the point in the
   *  user coordinate system resulting from (depending on context)
   *  application of the x and y attributes on the <text> element,
   *  any x or y attribute values on a <tspan>, <tref> or <altGlyph>
   *  element assigned explicitly to the first rendered character
   *  in a text chunk, or determination of the initial current
   *  text position for a <textPath> element.Note: As a presentation
   *  attribute, text-anchor can be used as a CSS property.You
   *  can use this attribute with the following SVG elements:The
   *  rendered characters are aligned such that the start of
   *  the text string is at the initial current text position.
   *  For an element with a direction property value of ltr
   *  (typical for most European languages), the left side of
   *  the text is rendered at the initial text position. For
   *  an element with a direction property value of rtl (typical
   *  for Arabic and Hebrew), the right side of the text is
   *  rendered at the initial text position. For an element
   *  with a vertical primary text direction (often typical
   *  for Asian text), the top side of the text is rendered
   *  at the initial text position.The rendered characters are
   *  aligned such that the middle of the text string is at
   *  the current text position. (For text on a path, conceptually
   *  the text string is first laid out in a straight line.
   *  The midpoint between the start of the text string and
   *  the end of the text string is determined. Then, the text
   *  string is mapped onto the path with this midpoint placed
   *  at the current text position.)The rendered characters
   *  are shifted such that the end of the resulting rendered
   *  text (final current text position before applying the
   *  text-anchor property) is at the initial current text position.
   *  For an element with a direction property value of ltr
   *  (typical for most European languages), the right side
   *  of the text is rendered at the initial text position.
   *  For an element with a direction property value of rtl
   *  (typical for Arabic and Hebrew), the left side of the
   *  text is rendered at the initial text position. For an
   *  element with a vertical primary text direction (often
   *  typical for Asian text), the bottom of the text is rendered
   *  at the initial text position.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  textAnchor: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The text-decoration attribute defines whether text is decorated
   *  with an underline, overline and/or strike-through. It
   *  is a shorthand for the text-decoration-line and text-decoration-style
   *  properties.The fill and stroke of the text decoration
   *  are given by the fill and stroke of the text at the point
   *  where the text decoration is declared.The paint order
   *  of the text decoration, i.e. the fill and stroke, is determined
   *  by the value of the paint-order attribute at the point
   *  where the text decoration is declared.Note: As a presentation
   *  attribute, text-decoration can be used as a CSS property.
   *  See the css text-decoration property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS text-decoration
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  textDecoration: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The textLength attribute, available on SVG <text> and <tspan>
   *  elements, lets you specify the width of the space into
   *  which the text will draw. The user agent will ensure that
   *  the text does not extend farther than that distance, using
   *  the method or methods specified by the lengthAdjust attribute.
   *  By default, only the spacing between characters is adjusted,
   *  but the glyph size can also be adjusted if you change
   *  lengthAdjust.By using textLength, you can ensure that
   *  your SVG text displays at the same width regardless of
   *  conditions including web fonts failing to load (or not
   *  having loaded yet).You can use this attribute with the
   *  following SVG elements:This value specifies the width
   *  of the space the text will be adjusted to occupy as absolute
   *  length or percentage.A numeric value outlines a length
   *  referring to the units of the current coordinate system.Let's
   *  create a simple example that presents text you can resize
   *  using an <input> element of type "range".Let's start with
   *  the SVG. It's pretty basic, with a 1000-by-300 pixel space
   *  mapped into a 10 centimeter by 3 centimeter box.First,
   *  a <rect> element is used to create and stroke a rectangle
   *  to contain the text. Then <text> is used to create the
   *  text element itself, with an id of "hello".The HTML is
   *  also simple, with only two displayed elements contained
   *  inside a grouping <div>:The <input> element, of type "range",
   *  is used to create the slider control the user will manipulate
   *  to change the width of the text. A <span> element of ID
   *  "widthDisplay" is provided to display the current width
   *  value.Finally, let's have a look at the JavaScript code.
   *  It starts by stashing references to the elements it will
   *  need to access, using Document.getElementById():After
   *  fetching the element references, an EventListener is established
   *  by calling addEventListener() on the slider control, to
   *  receive any input events which occur. These events will
   *  be sent any time the slider's value changes, even if the
   *  user hasn't stopped moving it, so we can responsively
   *  adjust the text width.When an "input" event occurs, we
   *  call newValueSpecifiedUnits() to set the value of textLength
   *  to the slider's new value, using the SVGLength interface's
   *  SVG_LENGTHTYPE_PX unit type to indicate that the value
   *  represents pixels. Note that we have to dive into textLength
   *  to get its baseVal property; textLength is stored as an
   *  SVGLength object, so we can't treat it like a plain number.After
   *  updating the text width, the contents of the widthDisplay
   *  box are updated with the new value as well, and we're
   *  finished.Here's what the example looks like. Try dragging
   *  the slider around to get a feel for what it does.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: Jul 8, 2022, by
   *  MDN contributors
   */
  textLength: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The unicode-bidi attribute specifies how the accumulation of
   *  the background image is managed.Note: As a presentation
   *  attribute, unicode-bidi can be used as a CSS property.
   *  See the CSS unicode-bidi property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS unicode-bidi
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  unicodeBidi: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The visibility attribute lets you control the visibility of graphical
   *  elements. With a value of hidden or collapse the current
   *  graphics element is invisible.Note: If the visibility
   *  attribute is set to hidden on a text element, then the
   *  text is invisible but still takes up space in text layout
   *  calculations.Depending on the value of attribute pointer-events,
   *  graphics elements which have their visibility attribute
   *  set to hidden still might receive events.Note: As a presentation
   *  attribute, visibility can be used as a CSS property. See
   *  the css visibility property for more information.You can
   *  use this attribute with the following SVG elements:The
   *  following example toggles the CSS visibility of the SVG
   *  image path.This value indicates that the element will
   *  be painted.This value indicates that the element will
   *  not be painted. Though it is still part of the rendering
   *  tree, i.e. it may receive pointer events depending on
   *  the pointer-events attribute, may receive focus depending
   *  on the tabindex attribute, contributes to bounding box
   *  calculations and clipping paths, and does affect text
   *  layout.This value is equal to hidden.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  visibility: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The word-spacing attribute specifies spacing behavior between
   *  words.If a <length> is provided without a unit identifier
   *  (e.g. an unqualified number such as 128), the browser
   *  processes the <length> as a width value in the current
   *  user coordinate system.If a <length> is provided with
   *  one of the unit identifiers (e.g. .25em or 1%), then the
   *  browser converts the <length> into a corresponding value
   *  in the current user coordinate system.Note: As a presentation
   *  attribute, word-spacing can be used as a CSS property.
   *  See the css word-spacing property for more information.You
   *  can use this attribute with the following SVG elements:For
   *  a description of the values, please refer to the CSS letter-spacing
   *  property.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  wordSpacing: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The writing-mode attribute specifies whether the initial inline-progression-direction
   *  for a <text> element shall be left-to-right, right-to-left,
   *  or top-to-bottom. The writing-mode attribute applies only
   *  to <text> elements; the attribute is ignored for <tspan>,
   *  <tref>, <altGlyph> and <textPath> sub-elements. (Note
   *  that the inline-progression-direction can change within
   *  a <text> element due to the Unicode bidirectional algorithm
   *  and properties direction and unicode-bidi.)Note: As a
   *  presentation attribute, writing-mode can be used as a
   *  CSS property. See the CSS writing-mode property for more
   *  information.You can use this attribute with the following
   *  SVG elements:This value defines a top-to-bottom block
   *  flow direction. Both the writing mode and the typographic
   *  mode are horizontal.This value defines a right-to-left
   *  block flow direction. Both the writing mode and the typographic
   *  mode are vertical.This value defines a left-to-right block
   *  flow direction. Both the writing mode and the typographic
   *  mode are vertical.BCD tables only load in the browser
   *  with JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  writingMode: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Tspan$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Tspan$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Tspan$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Tspan$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Tspan$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Tspan$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Tspan);

/***/ }),

/***/ "./src/lib/components/Use.react.js":
/*!*****************************************!*\
  !*** ./src/lib/components/Use.react.js ***!
  \*****************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
var _Use$propTypes;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * Use is a wrapper for the <use> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/use
 */

var Use = function Use(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("use", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

Use.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
Use.propTypes = (_Use$propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The clip-path presentation attribute defines or associates a
   *  clipping path with the element it is related to.Note:
   *  As a presentation attribute clip-path can be used as a
   *  CSS property.You can use this attribute with the following
   *  SVG elements:An extra information to tell how a <basic-shape>
   *  is applied to an element: fill-box indicates to use the
   *  object bounding box; stroke-box indicates to use the object
   *  bounding box extended with the stroke; view-box indicates
   *  to use the nearest SVG viewport as the reference box.Note:
   *  For more details on the clip-path syntax, see the CSS
   *  property clip-path reference page.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  clipPath: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The color-interpolation attribute specifies the color space for
   *  gradient interpolations, color animations, and alpha compositing.Note:
   *  For filter effects, the color-interpolation-filters property
   *  controls which color space is used.The color-interpolation
   *  property chooses between color operations occurring in
   *  the sRGB color space or in a (light energy linear) linearized
   *  RGB color space. Having chosen the appropriate color space,
   *  component-wise linear interpolation is used.When a child
   *  element is blended into a background, the value of the
   *  color-interpolation property on the child determines the
   *  type of blending, not the value of the color-interpolation
   *  on the parent. For gradients which make use of the href
   *  or the deprecated xlink:href attribute to reference another
   *  gradient, the gradient uses the property's value from
   *  the gradient element which is directly referenced by the
   *  fill or stroke property. When animating colors, color
   *  interpolation is performed according to the value of the
   *  color-interpolation property on the element being animated.Note:
   *  As a presentation attribute, color-interpolation can be
   *  used as a CSS property.You can use this attribute with
   *  the following SVG elements:Indicates that the user agent
   *  can choose either the sRGB or linearRGB spaces for color
   *  interpolation. This option indicates that the author doesn't
   *  require that color interpolation occur in a particular
   *  color space.Indicates that color interpolation should
   *  occur in the sRGB color space.Indicates that color interpolation
   *  should occur in the linearized RGB color space as described
   *  in the sRGB specification.BCD tables only load in the
   *  browser with JavaScript enabled. Enable JavaScript to
   *  view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  colorInterpolation: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  height: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The mask attribute is a presentation attribute mainly used to
   *  bind a given <mask> element with the element the attribute
   *  belongs to.Note: As a presentation attribute mask can
   *  be used as a CSS property.You can use this attribute with
   *  the following SVG elements:Since SVG2, the mask attribute
   *  is defined as a css property and is a shorthand for many
   *  other properties: mask-image, mask-mode, mask-repeat,
   *  mask-position, mask-clip, mask-origin, mask-size, and
   *  mask-composite.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  mask: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The opacity attribute specifies the transparency of an object
   *  or of a group of objects, that is, the degree to which
   *  the background behind the element is overlaid.Note: As
   *  a presentation attribute, opacity can be used as a CSS
   *  property. See the css opacity property for more information.You
   *  can use this attribute with the following SVG elements:The
   *  uniform opacity setting to be applied across an entire
   *  object, as a <number>. Any values outside the range 0.0
   *  (fully transparent) to 1.0 (fully opaque) will be clamped
   *  to this range.BCD tables only load in the browser with
   *  JavaScript enabled. Enable JavaScript to view data.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  opacity: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The pointer-events attribute is a presentation attribute that
   *  allows defining whether or when an element may be the
   *  target of a mouse event.Note: As a presentation attribute
   *  pointer-events can be used as a CSS property.You can use
   *  this attribute with the following SVG elements:For a detailed
   *  explanation of each possible value, have a look at the
   *  CSS pointer-events documentation.BCD tables only load
   *  in the browser with JavaScript enabled. Enable JavaScript
   *  to view data.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  pointerEvents: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The requiredFeatures attribute
   *  takes a list of feature strings, with the individual strings
   *  separated by white space. It determines whether or not
   *  all of the named features are supported by the browser;
   *  if all of them are supported, the attribute evaluates
   *  to true end the element is rendered; otherwise, the attribute
   *  evaluates to false and the current element and its children
   *  are skipped and thus will not be rendered. This provides
   *  a way to design SVG that gracefully falls back when features
   *  aren't available.If the attribute is not present, then
   *  its implicit evaluated value is true. If a null string
   *  or empty string value is given to attribute requiredFeatures,
   *  the attribute is evaluate to false.requiredFeatures is
   *  often used in conjunction with the <switch> element. If
   *  requiredFeatures is used in other situations, it represents
   *  a simple switch on the given element whether to render
   *  the element or not.To detect availability of an SVG feature
   *  from script, there is the (also deprecated) DOMImplementation.hasFeature()
   *  method.You can use this attribute with the following SVG
   *  elements:This is a list of feature strings, separated
   *  using white space. Determines whether all of the named
   *  features are supported by the browser. See Feature strings
   *  below for a list of allowed values.The following are the
   *  feature strings for the requiredFeatures attribute. These
   *  same feature strings apply to the hasFeature method call
   *  that is part of the SVG DOM's support for the DOMImplementation
   *  interface. In some cases the feature strings map directly
   *  to a set of attributes, properties or elements, in others
   *  they represent some functionality of the browser. Note
   *  that the format and naming for feature strings changed
   *  from SVG 1.0 to SVG 1.1. The SVG 1.0 feature strings are
   *  not listed here but can be found in the SVG Specification.
   *  Some browser support SVG 1.0 Feature strings for compatibility
   *  reasons. However, the SVG 1.0 feature strings are considered
   *  deprecated.At least one of the following feature is supported:At
   *  least one of the following feature is supported:The browser
   *  supports all the following features:The browser supports
   *  all of the DOM interfaces and methods that correspond
   *  to the language features for http://www.w3.org/TR/SVG11/feature#SVG-static.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-static
   *  plus the feature http://www.w3.org/TR/SVG11/feature#Animation.The
   *  browser supports all of the DOM interfaces and methods
   *  that correspond to the language features for http://www.w3.org/TR/SVG11/feature#SVG-animation.The
   *  browser supports all of the language features from http://www.w3.org/TR/SVG11/feature#SVG-animation
   *  plus the following features:The browser supports all of
   *  the DOM interfaces and methods that correspond to the
   *  language features for http://www.w3.org/TR/SVG11/feature#SVG-dynamic.The
   *  browser supports the id, xml:base, xml:lang and xml:space
   *  attributesThe browser supports <svg>, <g>, <defs>, <desc>,
   *  <title>, <metadata>, <symbol> and <use> elements.The browser
   *  supports <svg>, <g>, <defs>, <desc>, <title>, <metadata>
   *  and <use> elements.The browser supports the enable-background
   *  attributeThe browser supports the <switch> element, and
   *  the requiredFeatures, requiredExtensions, systemLanguage
   *  attributesThe browser supports the <image> element.The
   *  browser supports the <style> element.The browser supports
   *  the clip and overflow attributes.The browser supports
   *  the <rect>, <circle>, <line>, <polyline>, <polygon>, <ellipse>
   *  and <path> elements.The browser supports the <text>, <tspan>,
   *  <tref>, <textPath>, <altGlyph>, <altGlyphDef>, <altGlyphItem>
   *  and <glyphRef> elements.The browser supports the <text>
   *  elementThe browser supports the color, fill, fill-rule,
   *  stroke, stroke-dasharray, stroke-dashoffset, stroke-linecap,
   *  stroke-linejoin, stroke-miterlimit, stroke-width, color-interpolation
   *  and color-rendering attributesThe browser supports the
   *  color, fill, fill-rule, stroke, stroke-dasharray, stroke-dashoffset,
   *  stroke-linecap, stroke-linejoin, stroke-miterlimit, stroke-width
   *  and color-rendering attributesThe browser supports the
   *  opacity, stroke-opacity and fill-opacity attributesThe
   *  browser supports the display, image-rendering, pointer-events,
   *  shape-rendering, text-rendering and visibility attributesThe
   *  browser supports the display and visibility attributesThe
   *  browser supports the <marker> elementThe browser supports
   *  the <linearGradient>, <radialGradient> and <stop> elementsThe
   *  browser supports the <pattern> elementThe browser supports
   *  the <clipPath> element and the clip-path, clip-rule attributesThe
   *  browser supports the <clipPath> element and the clip-path
   *  attributeThe browser supports the <mask> elementThe browser
   *  supports the <filter>, <feBlend>, <feColorMatrix>, <feComponentTransfer>,
   *  <feComposite>, <feConvolveMatrix>, <feDiffuseLighting>,
   *  <feDisplacementMap>, <feFlood>, <feGaussianBlur>, <feImage>,
   *  <feMerge>, <feMergeNode>, <feMorphology>, <feOffset>,
   *  <feSpecularLighting>, <feTile>, <feDistantLight>, <fePointLight>,
   *  <feSpotLight>, <feFuncR>, <feFuncG>, <feFuncB> and <feFuncA>
   *  elementsThe browser supports the <filter>, <feBlend>,
   *  <feColorMatrix>, <feComponentTransfer>, <feComposite>,
   *  <feFlood>, <feGaussianBlur>, <feImage>, <feMerge>, <feMergeNode>,
   *  <feOffset>, <feTile>, <feFuncR>, <feFuncG>, <feFuncB>
   *  and <feFuncA> elementsThe browser supports the onunload,
   *  onabort, onerror, onresize, onscroll and onzoom attributesThe
   *  browser supports the onfocusin, onfocusout, onactivate,
   *  onclick, onmousedown, onmouseup, onmouseover, onmousemove,
   *  onmouseout and onload attributesThe browser supports the
   *  onbegin, onend, onrepeat and onload attributesThe browser
   *  supports the <cursor> elementThe browser supports the
   *  <a> elementThe browser supports the xlink:type, xlink:href,
   *  xlink:role, xlink:arcrole, xlink:title, xlink:show and
   *  xlink:actuate attributesThe browser supports the <view>
   *  elementThe browser supports the <script> elementThe browser
   *  supports the <animate>, <set>, <animateMotion>, <animateTransform>,
   *  <animateColor> and <mpath> elementsThe browser supports
   *  the <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <vkern>, <font-face-src>, <font-face-uri>, <font-face-format>
   *  and <font-face-name> elementsThe browser supports the
   *  <font>, <font-face>, <glyph>, <missing-glyph>, <hkern>,
   *  <font-face-src> and <font-face-name> elementsThe browser
   *  supports the <foreignObject> elementSee also requiredFeatures.svgBCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  requiredFeatures: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The systemLanguage attribute represents a list of supported language
   *  tags. This list is matched against the language defined
   *  in the user preferences.You can use this attribute with
   *  the following SVG elements:The value is a set of comma-separated
   *  tokens, each of which must be a language tag, as defined
   *  in RFC 5646: Tags for Identifying Languages (also known
   *  as BCP 47).systemLanguage is often used in conjunction
   *  with the <switch> element. If the attribute is used in
   *  other situations, then it represents a simple switch on
   *  the given element whether to render the element or not.Note:
   *  If several alternative language objects are enclosed in
   *  a <switch> and none of them matches, this may lead to
   *  situations where no content is displayed. It is thus recommended
   *  to include a "catch-all" choice at the end of such a <switch>
   *  which is acceptable in all cases.The attribute evaluates
   *  to "true" if one of the language tags indicated by user
   *  preferences is a case-insensitive match or prefix (followed
   *  by a "-") of one of the language tags given in the value
   *  of this parameter. Otherwise it evaluates to "false".Note:
   *  The prefix matching rule does not imply that if a user
   *  understands a language with a certain tag, that the user
   *  will also understand all languages with the tag as prefix.If
   *  the attribute is not present, then it implicitly evaluates
   *  to "true". If a null string or empty string value is given,
   *  the attribute evaluates to "false".The prefix rule allows
   *  the use of prefix tags if this is the case.Multiple languages
   *  may be listed for content that is intended for multiple
   *  audiences. For example, content that is presented simultaneously
   *  in the original Maori and English versions, would call
   *  for:However, just because multiple languages are present
   *  within the object on which the systemLanguage test attribute
   *  is placed, this does not mean that it is intended for
   *  multiple linguistic audiences. An example would be a beginner's
   *  language primer, such as "A First Lesson in Latin," which
   *  is clearly intended to be used by an English-literate
   *  audience. In this case, the attribute should only include
   *  en.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  systemLanguage: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  The vector-effect property specifies the vector effect to use
   *  when drawing an object. Vector effects are applied before
   *  any of the other compositing operations, i.e. filters,
   *  masks and clips.Note: As a presentation attribute, vector-effect
   *  can be used as a CSS property.You can use this attribute
   *  with the following SVG elements:This value specifies that
   *  no vector effect shall be applied, i.e. the default rendering
   *  behavior is used which is to first fill the geometry of
   *  a shape with a specified paint, then stroke the outline
   *  with a specified paint.This value modifies the way an
   *  object is stroked. Normally stroking involves calculating
   *  stroke outline of the shape's path in current user coordinate
   *  system and filling that outline with the stroke paint
   *  (color or gradient). The resulting visual effect of this
   *  value is that the stroke width is not dependent on the
   *  transformations of the element (including non-uniform
   *  scaling and shear transformations) and zoom level.This
   *  value specifies a special user coordinate system used
   *  by the element and its descendants. The scale of that
   *  user coordinate system does not change in spite of any
   *  transformation changes from a host coordinate space. However,
   *  it does not specify the suppression of rotation and skew.
   *  Also, it does not specify the origin of the user coordinate
   *  system. Since this value suppresses scaling of the user
   *  coordinate system, it also has the characteristics of
   *  non-scaling-stroke.This value specifies a special user
   *  coordinate system used by the element and its descendants.
   *  The rotation and skew of that user coordinate system is
   *  suppressed in spite of any transformation changes from
   *  a host coordinate space. However, it does not specify
   *  the suppression of scaling. Also, it does not specify
   *  the origin of user coordinate system.This value specifies
   *  a special user coordinate system used by the element and
   *  its descendants. The position of user coordinate system
   *  is fixed in spite of any transformation changes from a
   *  host coordinate space. However, it does not specify the
   *  suppression of rotation, skew and scaling. When this vector
   *  effect and the transform property are defined at the same
   *  time, that property is consumed for this effect.BCD tables
   *  only load in the browser with JavaScript enabled. Enable
   *  JavaScript to view data.Last modified: May 13, 2022, by
   *  MDN contributors
   */
  vectorEffect: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  width
   */
  width: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]))
}, _defineProperty(_Use$propTypes, "x", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Use$propTypes, "y", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])), _defineProperty(_Use$propTypes, "fill", prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string), _defineProperty(_Use$propTypes, 'loading_state', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
  /**
   * Determines if the component is loading or not
   */
  is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

  /**
   * Holds which property is loading
   */
  prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Holds the name of the component that is loading
   */
  component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
})), _defineProperty(_Use$propTypes, 'setProps', prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func), _Use$propTypes);
/* harmony default export */ __webpack_exports__["default"] = (Use);

/***/ }),

/***/ "./src/lib/components/View.react.js":
/*!******************************************!*\
  !*** ./src/lib/components/View.react.js ***!
  \******************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ "react");
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! prop-types */ "prop-types");
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ramda__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ramda */ "./node_modules/ramda/es/index.js");
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }




/**
 * View is a wrapper for the <view> SVG element.
 * For detailed attribute info see:
 * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/view
 */

var View = function View(props) {
  var dataAttributes = {};

  if (props.loading_state && props.loading_state.is_loading) {
    dataAttributes['data-dash-is-loading'] = true;
  }

  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default.a.createElement("view", _extends({
    onClick: function onClick() {
      return props.setProps({
        n_clicks: props.n_clicks + 1,
        n_clicks_timestamp: Date.now()
      });
    }
  }, Object(ramda__WEBPACK_IMPORTED_MODULE_2__["omit"])(['n_clicks', 'n_clicks_timestamp', 'loading_state', 'setProps'], props), dataAttributes), props.children);
};

View.defaultProps = {
  n_clicks: 0,
  n_clicks_timestamp: -1
};
View.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  'id': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The children of this component
   */
  'children': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.node,

  /**
   * An integer that represents the number of times
   * that this element has been clicked on.
   */
  'n_clicks': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * An integer that represents the time (in ms since 1970)
   * at which n_clicks changed. This can be used to tell
   * which button was changed most recently.
   */
  'n_clicks_timestamp': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  'key': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * The ARIA role attribute
   */
  'role': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard data attribute
   */
  'data-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * A wildcard aria attribute
   */
  'aria-*': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The preserveAspectRatio attribute indicates how an element with
   *  a viewBox providing a given aspect ratio must fit into
   *  a viewport with a different aspect ratio.Because the aspect
   *  ratio of an SVG image is defined by the viewBox attribute,
   *  if this attribute isn't set, the preserveAspectRatio attribute
   *  has no effect (with one exception, the <image> element,
   *  as described below).Its value is made of one or two keywords:
   *  A required alignment value and an optional "meet or slice"
   *  reference as described below:The alignment value indicates
   *  whether to force uniform scaling and, if so, the alignment
   *  method to use in case the aspect ratio of the viewBox
   *  doesn't match the aspect ratio of the viewport. The alignment
   *  value must be one of the following keywords:The meet or
   *  slice reference is optional and, if provided, must be
   *  one of the following keywords:You can use this attribute
   *  with the following SVG elements:For <feImage>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <feImage> element.For <image>, preserveAspectRatio
   *  defines how the referenced image should fit in the rectangle
   *  define by the <image> element.For <marker>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <pattern>, preserveAspectRatio
   *  indicates if a uniform scaling must be performed to fit
   *  the element viewport.For <svg>, preserveAspectRatio indicates
   *  if a uniform scaling must be performed to fit the element
   *  viewport.For <symbol>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.For <view>, preserveAspectRatio indicates if
   *  a uniform scaling must be performed to fit the element
   *  viewport.Last modified: May 13, 2022, by MDN contributors
   * 
   */
  preserveAspectRatio: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  The viewBox attribute defines the position and dimension, in
   *  user space, of an SVG viewport.The value of the viewBox
   *  attribute is a list of four numbers: min-x, min-y, width
   *  and height. The numbers, which are separated by whitespace
   *  and/or a comma, specify a rectangle in user space which
   *  is mapped to the bounds of the viewport established for
   *  the associated SVG element (not the browser viewport).You
   *  can use this attribute with the following SVG elements:The
   *  exact effect of this attribute is influenced by the preserveAspectRatio
   *  attribute.Note: Values for width or height lower or equal
   *  to 0 disable rendering of the element.For <marker>, viewBox
   *  defines the position and dimension for the content of
   *  the <marker> element.For <pattern>, viewBox defines the
   *  position and dimension for the content of the pattern
   *  tile.For <svg>, viewBox defines the position and dimension
   *  for the content of the <svg> element.For <symbol>, viewBox
   *  defines the position and dimension for the content of
   *  the <symbol> element.For <view>, viewBox defines the position
   *  and dimension for the content of the <view> element.Last
   *  modified: May 13, 2022, by MDN contributors
   */
  viewBox: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The viewTarget attribute
   *  indicates the target object associated with the view.You
   *  can use this attribute with the following SVG elements:This
   *  value specifies the name of the object associated with
   *  the view.BCD tables only load in the browser with JavaScript
   *  enabled. Enable JavaScript to view data.Last modified:
   *  May 13, 2022, by MDN contributors
   */
  viewTarget: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  Deprecated: This feature is no longer recommended. Though some
   *  browsers might still support it, it may have already been
   *  removed from the relevant web standards, may be in the
   *  process of being dropped, or may only be kept for compatibility
   *  purposes. Avoid using it, and update existing code if
   *  possible; see the compatibility table at the bottom of
   *  this page to guide your decision. Be aware that this feature
   *  may cease to work at any time.The zoomAndPan attribute
   *  specifies whether the SVG document can be magnified and
   *  panned.Magnification in this context means the effect
   *  of a supplemental scale and translate transformation on
   *  the outermost SVG document fragment.Panning represents
   *  a translation (i.e., a shift) transformation on an SVG
   *  document fragment in response to a user interface action.You
   *  can use this attribute with the following SVG elements:BCD
   *  tables only load in the browser with JavaScript enabled.
   *  Enable JavaScript to view data.Last modified: May 13,
   *  2022, by MDN contributors
   */
  zoomAndPan: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Often used with CSS to style elements with common properties.
   * 
   */
  className: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  Transformation to apply to the element 
   */
  transform: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   *  CSS style to apply to the element 
   */
  style: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.PropTypes.objectOf(prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number])),

  /**
   *  x position
   */
  x: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  y position
   */
  y: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string, prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.number]),

  /**
   *  fill color
   */
  fill: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  'loading_state': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.bool,

    /**
     * Holds which property is loading
     */
    prop_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string,

    /**
     * Holds the name of the component that is loading
     */
    component_name: prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.string
  }),

  /**
   * Dash-assigned callback that gets fired when the element is clicked.
   */
  'setProps': prop_types__WEBPACK_IMPORTED_MODULE_1___default.a.func
};
/* harmony default export */ __webpack_exports__["default"] = (View);

/***/ }),

/***/ "./src/lib/index.js":
/*!**************************!*\
  !*** ./src/lib/index.js ***!
  \**************************/
/*! exports provided: Animate, Circle, ClipPath, Defs, Desc, Ellipse, FeBlend, FeColorMatrix, FeComponentTransfer, FeComposite, FeConvolveMatrix, FeDiffuseLighting, FeDisplacementMap, FeDistantLight, FeDropShadow, FeFlood, FeFuncA, FeFuncB, FeFuncG, FeFuncR, FeGaussianBlur, FeImage, FeMerge, FeMergeNode, FeMorphology, FeOffset, FePointLight, FeSpecularLighting, FeSpotLight, FeTile, FeTurbulence, Filter, ForeignObject, G, Image, Line, LinearGradient, Marker, Mask, Metadata, Path, Pattern, Polygon, Polyline, RadialGradient, Rect, Stop, Svg, Switch, Symbol, Text, TextPath, Tspan, Use, View */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _components_Animate_react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./components/Animate.react */ "./src/lib/components/Animate.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Animate", function() { return _components_Animate_react__WEBPACK_IMPORTED_MODULE_0__["default"]; });

/* harmony import */ var _components_Circle_react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./components/Circle.react */ "./src/lib/components/Circle.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Circle", function() { return _components_Circle_react__WEBPACK_IMPORTED_MODULE_1__["default"]; });

/* harmony import */ var _components_ClipPath_react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./components/ClipPath.react */ "./src/lib/components/ClipPath.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ClipPath", function() { return _components_ClipPath_react__WEBPACK_IMPORTED_MODULE_2__["default"]; });

/* harmony import */ var _components_Defs_react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! ./components/Defs.react */ "./src/lib/components/Defs.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Defs", function() { return _components_Defs_react__WEBPACK_IMPORTED_MODULE_3__["default"]; });

/* harmony import */ var _components_Desc_react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ./components/Desc.react */ "./src/lib/components/Desc.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Desc", function() { return _components_Desc_react__WEBPACK_IMPORTED_MODULE_4__["default"]; });

/* harmony import */ var _components_Ellipse_react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! ./components/Ellipse.react */ "./src/lib/components/Ellipse.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Ellipse", function() { return _components_Ellipse_react__WEBPACK_IMPORTED_MODULE_5__["default"]; });

/* harmony import */ var _components_FeBlend_react__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! ./components/FeBlend.react */ "./src/lib/components/FeBlend.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeBlend", function() { return _components_FeBlend_react__WEBPACK_IMPORTED_MODULE_6__["default"]; });

/* harmony import */ var _components_FeColorMatrix_react__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! ./components/FeColorMatrix.react */ "./src/lib/components/FeColorMatrix.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeColorMatrix", function() { return _components_FeColorMatrix_react__WEBPACK_IMPORTED_MODULE_7__["default"]; });

/* harmony import */ var _components_FeComponentTransfer_react__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! ./components/FeComponentTransfer.react */ "./src/lib/components/FeComponentTransfer.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeComponentTransfer", function() { return _components_FeComponentTransfer_react__WEBPACK_IMPORTED_MODULE_8__["default"]; });

/* harmony import */ var _components_FeComposite_react__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! ./components/FeComposite.react */ "./src/lib/components/FeComposite.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeComposite", function() { return _components_FeComposite_react__WEBPACK_IMPORTED_MODULE_9__["default"]; });

/* harmony import */ var _components_FeConvolveMatrix_react__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! ./components/FeConvolveMatrix.react */ "./src/lib/components/FeConvolveMatrix.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeConvolveMatrix", function() { return _components_FeConvolveMatrix_react__WEBPACK_IMPORTED_MODULE_10__["default"]; });

/* harmony import */ var _components_FeDiffuseLighting_react__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! ./components/FeDiffuseLighting.react */ "./src/lib/components/FeDiffuseLighting.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeDiffuseLighting", function() { return _components_FeDiffuseLighting_react__WEBPACK_IMPORTED_MODULE_11__["default"]; });

/* harmony import */ var _components_FeDisplacementMap_react__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! ./components/FeDisplacementMap.react */ "./src/lib/components/FeDisplacementMap.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeDisplacementMap", function() { return _components_FeDisplacementMap_react__WEBPACK_IMPORTED_MODULE_12__["default"]; });

/* harmony import */ var _components_FeDistantLight_react__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! ./components/FeDistantLight.react */ "./src/lib/components/FeDistantLight.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeDistantLight", function() { return _components_FeDistantLight_react__WEBPACK_IMPORTED_MODULE_13__["default"]; });

/* harmony import */ var _components_FeDropShadow_react__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! ./components/FeDropShadow.react */ "./src/lib/components/FeDropShadow.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeDropShadow", function() { return _components_FeDropShadow_react__WEBPACK_IMPORTED_MODULE_14__["default"]; });

/* harmony import */ var _components_FeFlood_react__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! ./components/FeFlood.react */ "./src/lib/components/FeFlood.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeFlood", function() { return _components_FeFlood_react__WEBPACK_IMPORTED_MODULE_15__["default"]; });

/* harmony import */ var _components_FeFuncA_react__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! ./components/FeFuncA.react */ "./src/lib/components/FeFuncA.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeFuncA", function() { return _components_FeFuncA_react__WEBPACK_IMPORTED_MODULE_16__["default"]; });

/* harmony import */ var _components_FeFuncB_react__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(/*! ./components/FeFuncB.react */ "./src/lib/components/FeFuncB.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeFuncB", function() { return _components_FeFuncB_react__WEBPACK_IMPORTED_MODULE_17__["default"]; });

/* harmony import */ var _components_FeFuncG_react__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(/*! ./components/FeFuncG.react */ "./src/lib/components/FeFuncG.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeFuncG", function() { return _components_FeFuncG_react__WEBPACK_IMPORTED_MODULE_18__["default"]; });

/* harmony import */ var _components_FeFuncR_react__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(/*! ./components/FeFuncR.react */ "./src/lib/components/FeFuncR.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeFuncR", function() { return _components_FeFuncR_react__WEBPACK_IMPORTED_MODULE_19__["default"]; });

/* harmony import */ var _components_FeGaussianBlur_react__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(/*! ./components/FeGaussianBlur.react */ "./src/lib/components/FeGaussianBlur.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeGaussianBlur", function() { return _components_FeGaussianBlur_react__WEBPACK_IMPORTED_MODULE_20__["default"]; });

/* harmony import */ var _components_FeImage_react__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(/*! ./components/FeImage.react */ "./src/lib/components/FeImage.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeImage", function() { return _components_FeImage_react__WEBPACK_IMPORTED_MODULE_21__["default"]; });

/* harmony import */ var _components_FeMerge_react__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(/*! ./components/FeMerge.react */ "./src/lib/components/FeMerge.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeMerge", function() { return _components_FeMerge_react__WEBPACK_IMPORTED_MODULE_22__["default"]; });

/* harmony import */ var _components_FeMergeNode_react__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(/*! ./components/FeMergeNode.react */ "./src/lib/components/FeMergeNode.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeMergeNode", function() { return _components_FeMergeNode_react__WEBPACK_IMPORTED_MODULE_23__["default"]; });

/* harmony import */ var _components_FeMorphology_react__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(/*! ./components/FeMorphology.react */ "./src/lib/components/FeMorphology.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeMorphology", function() { return _components_FeMorphology_react__WEBPACK_IMPORTED_MODULE_24__["default"]; });

/* harmony import */ var _components_FeOffset_react__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(/*! ./components/FeOffset.react */ "./src/lib/components/FeOffset.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeOffset", function() { return _components_FeOffset_react__WEBPACK_IMPORTED_MODULE_25__["default"]; });

/* harmony import */ var _components_FePointLight_react__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(/*! ./components/FePointLight.react */ "./src/lib/components/FePointLight.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FePointLight", function() { return _components_FePointLight_react__WEBPACK_IMPORTED_MODULE_26__["default"]; });

/* harmony import */ var _components_FeSpecularLighting_react__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(/*! ./components/FeSpecularLighting.react */ "./src/lib/components/FeSpecularLighting.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeSpecularLighting", function() { return _components_FeSpecularLighting_react__WEBPACK_IMPORTED_MODULE_27__["default"]; });

/* harmony import */ var _components_FeSpotLight_react__WEBPACK_IMPORTED_MODULE_28__ = __webpack_require__(/*! ./components/FeSpotLight.react */ "./src/lib/components/FeSpotLight.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeSpotLight", function() { return _components_FeSpotLight_react__WEBPACK_IMPORTED_MODULE_28__["default"]; });

/* harmony import */ var _components_FeTile_react__WEBPACK_IMPORTED_MODULE_29__ = __webpack_require__(/*! ./components/FeTile.react */ "./src/lib/components/FeTile.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeTile", function() { return _components_FeTile_react__WEBPACK_IMPORTED_MODULE_29__["default"]; });

/* harmony import */ var _components_FeTurbulence_react__WEBPACK_IMPORTED_MODULE_30__ = __webpack_require__(/*! ./components/FeTurbulence.react */ "./src/lib/components/FeTurbulence.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "FeTurbulence", function() { return _components_FeTurbulence_react__WEBPACK_IMPORTED_MODULE_30__["default"]; });

/* harmony import */ var _components_Filter_react__WEBPACK_IMPORTED_MODULE_31__ = __webpack_require__(/*! ./components/Filter.react */ "./src/lib/components/Filter.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Filter", function() { return _components_Filter_react__WEBPACK_IMPORTED_MODULE_31__["default"]; });

/* harmony import */ var _components_ForeignObject_react__WEBPACK_IMPORTED_MODULE_32__ = __webpack_require__(/*! ./components/ForeignObject.react */ "./src/lib/components/ForeignObject.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "ForeignObject", function() { return _components_ForeignObject_react__WEBPACK_IMPORTED_MODULE_32__["default"]; });

/* harmony import */ var _components_G_react__WEBPACK_IMPORTED_MODULE_33__ = __webpack_require__(/*! ./components/G.react */ "./src/lib/components/G.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "G", function() { return _components_G_react__WEBPACK_IMPORTED_MODULE_33__["default"]; });

/* harmony import */ var _components_Image_react__WEBPACK_IMPORTED_MODULE_34__ = __webpack_require__(/*! ./components/Image.react */ "./src/lib/components/Image.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Image", function() { return _components_Image_react__WEBPACK_IMPORTED_MODULE_34__["default"]; });

/* harmony import */ var _components_Line_react__WEBPACK_IMPORTED_MODULE_35__ = __webpack_require__(/*! ./components/Line.react */ "./src/lib/components/Line.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Line", function() { return _components_Line_react__WEBPACK_IMPORTED_MODULE_35__["default"]; });

/* harmony import */ var _components_LinearGradient_react__WEBPACK_IMPORTED_MODULE_36__ = __webpack_require__(/*! ./components/LinearGradient.react */ "./src/lib/components/LinearGradient.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "LinearGradient", function() { return _components_LinearGradient_react__WEBPACK_IMPORTED_MODULE_36__["default"]; });

/* harmony import */ var _components_Marker_react__WEBPACK_IMPORTED_MODULE_37__ = __webpack_require__(/*! ./components/Marker.react */ "./src/lib/components/Marker.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Marker", function() { return _components_Marker_react__WEBPACK_IMPORTED_MODULE_37__["default"]; });

/* harmony import */ var _components_Mask_react__WEBPACK_IMPORTED_MODULE_38__ = __webpack_require__(/*! ./components/Mask.react */ "./src/lib/components/Mask.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Mask", function() { return _components_Mask_react__WEBPACK_IMPORTED_MODULE_38__["default"]; });

/* harmony import */ var _components_Metadata_react__WEBPACK_IMPORTED_MODULE_39__ = __webpack_require__(/*! ./components/Metadata.react */ "./src/lib/components/Metadata.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Metadata", function() { return _components_Metadata_react__WEBPACK_IMPORTED_MODULE_39__["default"]; });

/* harmony import */ var _components_Path_react__WEBPACK_IMPORTED_MODULE_40__ = __webpack_require__(/*! ./components/Path.react */ "./src/lib/components/Path.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Path", function() { return _components_Path_react__WEBPACK_IMPORTED_MODULE_40__["default"]; });

/* harmony import */ var _components_Pattern_react__WEBPACK_IMPORTED_MODULE_41__ = __webpack_require__(/*! ./components/Pattern.react */ "./src/lib/components/Pattern.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Pattern", function() { return _components_Pattern_react__WEBPACK_IMPORTED_MODULE_41__["default"]; });

/* harmony import */ var _components_Polygon_react__WEBPACK_IMPORTED_MODULE_42__ = __webpack_require__(/*! ./components/Polygon.react */ "./src/lib/components/Polygon.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Polygon", function() { return _components_Polygon_react__WEBPACK_IMPORTED_MODULE_42__["default"]; });

/* harmony import */ var _components_Polyline_react__WEBPACK_IMPORTED_MODULE_43__ = __webpack_require__(/*! ./components/Polyline.react */ "./src/lib/components/Polyline.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Polyline", function() { return _components_Polyline_react__WEBPACK_IMPORTED_MODULE_43__["default"]; });

/* harmony import */ var _components_RadialGradient_react__WEBPACK_IMPORTED_MODULE_44__ = __webpack_require__(/*! ./components/RadialGradient.react */ "./src/lib/components/RadialGradient.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "RadialGradient", function() { return _components_RadialGradient_react__WEBPACK_IMPORTED_MODULE_44__["default"]; });

/* harmony import */ var _components_Rect_react__WEBPACK_IMPORTED_MODULE_45__ = __webpack_require__(/*! ./components/Rect.react */ "./src/lib/components/Rect.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Rect", function() { return _components_Rect_react__WEBPACK_IMPORTED_MODULE_45__["default"]; });

/* harmony import */ var _components_Stop_react__WEBPACK_IMPORTED_MODULE_46__ = __webpack_require__(/*! ./components/Stop.react */ "./src/lib/components/Stop.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Stop", function() { return _components_Stop_react__WEBPACK_IMPORTED_MODULE_46__["default"]; });

/* harmony import */ var _components_Svg_react__WEBPACK_IMPORTED_MODULE_47__ = __webpack_require__(/*! ./components/Svg.react */ "./src/lib/components/Svg.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Svg", function() { return _components_Svg_react__WEBPACK_IMPORTED_MODULE_47__["default"]; });

/* harmony import */ var _components_Switch_react__WEBPACK_IMPORTED_MODULE_48__ = __webpack_require__(/*! ./components/Switch.react */ "./src/lib/components/Switch.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Switch", function() { return _components_Switch_react__WEBPACK_IMPORTED_MODULE_48__["default"]; });

/* harmony import */ var _components_Symbol_react__WEBPACK_IMPORTED_MODULE_49__ = __webpack_require__(/*! ./components/Symbol.react */ "./src/lib/components/Symbol.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Symbol", function() { return _components_Symbol_react__WEBPACK_IMPORTED_MODULE_49__["default"]; });

/* harmony import */ var _components_Text_react__WEBPACK_IMPORTED_MODULE_50__ = __webpack_require__(/*! ./components/Text.react */ "./src/lib/components/Text.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Text", function() { return _components_Text_react__WEBPACK_IMPORTED_MODULE_50__["default"]; });

/* harmony import */ var _components_TextPath_react__WEBPACK_IMPORTED_MODULE_51__ = __webpack_require__(/*! ./components/TextPath.react */ "./src/lib/components/TextPath.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "TextPath", function() { return _components_TextPath_react__WEBPACK_IMPORTED_MODULE_51__["default"]; });

/* harmony import */ var _components_Tspan_react__WEBPACK_IMPORTED_MODULE_52__ = __webpack_require__(/*! ./components/Tspan.react */ "./src/lib/components/Tspan.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Tspan", function() { return _components_Tspan_react__WEBPACK_IMPORTED_MODULE_52__["default"]; });

/* harmony import */ var _components_Use_react__WEBPACK_IMPORTED_MODULE_53__ = __webpack_require__(/*! ./components/Use.react */ "./src/lib/components/Use.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "Use", function() { return _components_Use_react__WEBPACK_IMPORTED_MODULE_53__["default"]; });

/* harmony import */ var _components_View_react__WEBPACK_IMPORTED_MODULE_54__ = __webpack_require__(/*! ./components/View.react */ "./src/lib/components/View.react.js");
/* harmony reexport (safe) */ __webpack_require__.d(__webpack_exports__, "View", function() { return _components_View_react__WEBPACK_IMPORTED_MODULE_54__["default"]; });


























































/***/ }),

/***/ "prop-types":
/*!****************************!*\
  !*** external "PropTypes" ***!
  \****************************/
/*! no static exports found */
/***/ (function(module, exports) {

(function() { module.exports = window["PropTypes"]; }());

/***/ }),

/***/ "react":
/*!************************!*\
  !*** external "React" ***!
  \************************/
/*! no static exports found */
/***/ (function(module, exports) {

(function() { module.exports = window["React"]; }());

/***/ })

/******/ });
//# sourceMappingURL=dash_svg.dev.js.map
//# sourceMappingURL=dash_svg.dev.js.map